/*****************************************************************************
 *  Rohde&Schwarz RF Signal Generator instrument driver
 *
 *  VXIpnp Instrument Driver
 *****************************************************************************/

#ifndef __RSRFSIGGEN_HEADER
#define __RSRFSIGGEN_HEADER

#include "rscore.h"
#include "rsrfsiggen_attributes.h"
#include "rsrfsiggen_utility.h"

#include <string.h>
#include <stdlib.h>
#include <stdio.h>

#if defined(__cplusplus) || defined(__cplusplus__)
extern "C" {
#endif

/*****************************************************************************
 *- Useful Macros & Constants -----------------------------------------------*
 *****************************************************************************/

#define RSRFSIGGEN_SIMULATION_ID_QUERY      "Rohde&Schwarz,SMW200A,123456/789,1.23"  /* Default definition of ID Query Response for simulation */
#define RSRFSIGGEN_VALID_ID_RESPONSE_STRING "Rohde&Schwarz"      /* Valid response for identification query */
#define RSRFSIGGEN_SIMULATION_OPT_QUERY     ""      /* Simulated response for *OPT? command */

#define RSRFSIGGEN_OPC_TIMEOUT              30000L   /* Maximum time to wait for OPC in milliseconds */

/****************************************************************************
 *----------------- Instrument Driver Revision Information -----------------*
 ****************************************************************************/

/* Class Driver Identification */

#define RSRFSIGGEN_CLASS_DRIVER_DESCRIPTION           ""
#define RSRFSIGGEN_CLASS_DRIVER_PREFIX                ""
#define RSRFSIGGEN_CLASS_DRIVER_VENDOR                ""
#define RSRFSIGGEN_CLASS_DRIVER_REVISION              ""
#define RSRFSIGGEN_CLASS_SPEC_MAJOR_VERSION           1L    /* Class specification major version */
#define RSRFSIGGEN_CLASS_SPEC_MINOR_VERSION           6L    /* Class specification minor version */

/* Driver Identification */

#define RSRFSIGGEN_SPECIFIC_DRIVER_DESCRIPTION        ""
#define RSRFSIGGEN_SPECIFIC_DRIVER_PREFIX             "RSRFSIGGEN"
#define RSRFSIGGEN_SPECIFIC_DRIVER_LOCATOR            ""
#define RSRFSIGGEN_SPECIFIC_DRIVER_VENDOR             ""
#define RSRFSIGGEN_MAJOR_VERSION                      5L    /* Instrument driver major version          */
#define RSRFSIGGEN_MINOR_VERSION                      30L   /* Instrument driver minor version          */
#define RSRFSIGGEN_MINOR_MINOR_VERSION                0L    /* Instrument driver minor minor version    */

/* Driver Capabilities */

#define RSRFSIGGEN_SUPPORTED_INSTRUMENT_MODELS        "SMU,SMATE,SMJ,AMU,SMBV,SMW,SMA,SMB,SMC,SMF,SGS,SGT,SMCV,SMM"    /* Instrument driver supported model(s)     */
#define RSRFSIGGEN_GROUP_CAPABILITIES                 ""
#define RSRFSIGGEN_FUNCTION_CAPABILITIES              ""

/****************************************************************************
 *---------------------------- Attribute Defines ---------------------------*
 ****************************************************************************/

    /*- Inherent Instrument Specific Attributes ----------------------------*/

        /* User Options */

#define RSCMW_ATTR_RANGE_CHECK                                           RS_ATTR_RANGE_CHECK                                     /* ViBoolean */
#define RSCMW_ATTR_QUERY_INSTRUMENT_STATUS                               RS_ATTR_QUERY_INSTRUMENT_STATUS                         /* ViBoolean */
#define RSCMW_ATTR_CACHE                                                 RS_ATTR_CACHE                                           /* ViBoolean */
#define RSCMW_ATTR_SIMULATE                                              RS_ATTR_SIMULATE                                        /* ViBoolean */
#define RSCMW_ATTR_RECORD_COERCIONS                                      RS_ATTR_RECORD_COERCIONS                                /* ViBoolean */
#define RSCMW_ATTR_INTERCHANGE_CHECK                                     RS_ATTR_INTERCHANGE_CHECK                               /* ViBoolean */
#define RSCMW_ATTR_SPY                                                   RS_ATTR_SPY                                             /* ViBoolean */
#define RSCMW_ATTR_USE_SPECIFIC_SIMULATION                               RS_ATTR_USE_SPECIFIC_SIMULATION                         /* ViBoolean */

        /* Class Driver Identification */

#define RSCMW_ATTR_CLASS_DRIVER_DESCRIPTION                              RS_ATTR_CLASS_DRIVER_DESCRIPTION                        /* ViString, read-only */
#define RSCMW_ATTR_CLASS_DRIVER_PREFIX                                   RS_ATTR_CLASS_DRIVER_PREFIX                             /* ViString, read-only */
#define RSCMW_ATTR_CLASS_DRIVER_VENDOR                                   RS_ATTR_CLASS_DRIVER_VENDOR                             /* ViString, read-only */
#define RSCMW_ATTR_CLASS_DRIVER_REVISION                                 RS_ATTR_CLASS_DRIVER_REVISION                           /* ViString, read-only */
#define RSCMW_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MAJOR_VERSION           /* ViInt32,  read-only */
#define RSCMW_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION                 RS_ATTR_CLASS_DRIVER_CLASS_SPEC_MINOR_VERSION           /* ViInt32,  read-only */

        /* Driver Identification */

#define RSCMW_ATTR_SPECIFIC_DRIVER_DESCRIPTION                           RS_ATTR_SPECIFIC_DRIVER_DESCRIPTION                     /* ViString, read-only */
#define RSCMW_ATTR_SPECIFIC_DRIVER_PREFIX                                RS_ATTR_SPECIFIC_DRIVER_PREFIX                          /* ViString, read-only */
#define RSCMW_ATTR_SPECIFIC_DRIVER_LOCATOR                               RS_ATTR_SPECIFIC_DRIVER_LOCATOR                         /* ViString, read-only */
#define RSCMW_ATTR_SPECIFIC_DRIVER_VENDOR                                RS_ATTR_SPECIFIC_DRIVER_VENDOR                          /* ViString, read-only */
#define RSCMW_ATTR_SPECIFIC_DRIVER_REVISION                              RS_ATTR_SPECIFIC_DRIVER_REVISION                        /* ViString, read-only */
#define RSCMW_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MAJOR_VERSION        /* ViInt32,  read-only */
#define RSCMW_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION              RS_ATTR_SPECIFIC_DRIVER_CLASS_SPEC_MINOR_VERSION        /* ViInt32,  read-only */

        /* Driver Capabilities */

#define RSCMW_ATTR_SUPPORTED_INSTRUMENT_MODELS                           RS_ATTR_SUPPORTED_INSTRUMENT_MODELS                     /* ViString, read-only */
#define RSCMW_ATTR_GROUP_CAPABILITIES                                    RS_ATTR_GROUP_CAPABILITIES                              /* ViString, read-only */
#define RSCMW_ATTR_FUNCTION_CAPABILITIES                                 RS_ATTR_FUNCTION_CAPABILITIES                           /* ViString, read-only */
#define RSCMW_ATTR_CHANNEL_COUNT                                         RS_ATTR_CHANNEL_COUNT                                   /* ViInt32,  read-only */

        /* Driver Setup */

#define RSCMW_ATTR_DRIVER_SETUP                                          RS_ATTR_DRIVER_SETUP                                    /* ViString            */

        /* Instrument Identification */

#define RSCMW_ATTR_INSTRUMENT_MANUFACTURER                               RS_ATTR_INSTRUMENT_MANUFACTURER                         /* ViString, read-only */
#define RSCMW_ATTR_INSTRUMENT_MODEL                                      RS_ATTR_INSTRUMENT_MODEL                                /* ViString, read-only */
#define RSCMW_ATTR_INSTRUMENT_FIRMWARE_REVISION                          RS_ATTR_INSTRUMENT_FIRMWARE_REVISION                    /* ViString, read-only */

        /* Advanced Session Information */

#define RSCMW_ATTR_IO_RESOURCE_DESCRIPTOR                                RS_ATTR_IO_RESOURCE_DESCRIPTOR                          /* ViString, read-only */
#define RSCMW_ATTR_LOGICAL_NAME                                          RS_ATTR_LOGICAL_NAME                                    /* ViString, read-only */

    /*- Instrument-Specific Attributes -------------------------------------*/

/* BEGIN GENERATE */
#define RSRFSIGGEN_ATTR_REFERENCE_OSCILLATOR_SOURCE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345479
#define RSRFSIGGEN_ATTR_REFERENCE_OSCILLATOR_EXTERNAL_FREQUENCY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345480
#define RSRFSIGGEN_ATTR_REFERENCE_OSCILLATOR_OUTPUT_FREQUENCY_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353558
#define RSRFSIGGEN_ATTR_REFERENCE_OSCILLATOR_USER_DEFINED_CALIBRATION_DATA                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356640
#define RSRFSIGGEN_ATTR_REFERENCE_OSCILLATOR_USER_DEFINED_FREQUENCY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356641
#define RSRFSIGGEN_ATTR_RF_ATTENUATOR_ATTENUATION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353559
#define RSRFSIGGEN_ATTR_RESET_SIGNAL_PATH                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355560
#define RSRFSIGGEN_ATTR_ACTIVATE_ALL_MODULATIONS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357681
#define RSRFSIGGEN_ATTR_BB_FREQUENCY_OFFSET                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345482
#define RSRFSIGGEN_ATTR_BB_PATH_GAIN                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345483
#define RSRFSIGGEN_ATTR_BB_SIGNAL_ROUTING                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345484
#define RSRFSIGGEN_ATTR_BB_SIGNAL_SOURCE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345485
#define RSRFSIGGEN_ATTR_BB_MEASUREMENT_DURATION                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345486
#define RSRFSIGGEN_ATTR_BB_MEASUREMENT_REMAINING_DURATION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345487
#define RSRFSIGGEN_ATTR_BB_MEASUREMENT_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345488
#define RSRFSIGGEN_ATTR_BB_MEASUREMENT_POWER_PEAK                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345489
#define RSRFSIGGEN_ATTR_BB_MEASUREMENT_POWER_RMS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345490
#define RSRFSIGGEN_ATTR_BB_PHASE_OFFSET                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345491
#define RSRFSIGGEN_ATTR_BB_GENERATOR_SOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353560
#define RSRFSIGGEN_ATTR_GSM_ENABLED                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345492
#define RSRFSIGGEN_ATTR_GSM_SET_TO_DEFAULT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345493
#define RSRFSIGGEN_ATTR_GSM_MODE                                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345494
#define RSRFSIGGEN_ATTR_GSM_SYMBOL_RATE_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345495
#define RSRFSIGGEN_ATTR_GSM_SIMULATION_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345496
#define RSRFSIGGEN_ATTR_GSM_SEQUENCE_LENGTH_SYMBOLS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345497
#define RSRFSIGGEN_ATTR_GSM_SEQUENCE_LENGTH_FRAMES                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345498
#define RSRFSIGGEN_ATTR_GSM_GENERATE_WAVEFORM_FILE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345499
#define RSRFSIGGEN_ATTR_GSM_SETTINGS_CATALOG                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345500
#define RSRFSIGGEN_ATTR_GSM_DELETE_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345501
#define RSRFSIGGEN_ATTR_GSM_RECALL_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345502
#define RSRFSIGGEN_ATTR_GSM_SAVE_SETTINGS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345503
#define RSRFSIGGEN_ATTR_GSM_FAST_STORING                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353236
#define RSRFSIGGEN_ATTR_GSM_RECALL_PREDEFINED_FRAME                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345505
#define RSRFSIGGEN_ATTR_GSM_USER_FRAME_CATALOG                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345506
#define RSRFSIGGEN_ATTR_GSM_RECALL_USER_FRAME                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345507
#define RSRFSIGGEN_ATTR_GSM_SAVE_USER_FRAME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345508
#define RSRFSIGGEN_ATTR_GSM_DELETE_USER_FRAME                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345509
#define RSRFSIGGEN_ATTR_GSM_SYMBOL_RATE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345510
#define RSRFSIGGEN_ATTR_GSM_IGNORE_QUARTER_SYM                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345511
#define RSRFSIGGEN_ATTR_GSM_FORCE_DUMMY_BITS_TO_1                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345512
#define RSRFSIGGEN_ATTR_GSM_MODULATION_TYPE_AQPSK                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360309
#define RSRFSIGGEN_ATTR_GSM_MODULATION_TYPE_EDGE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360310
#define RSRFSIGGEN_ATTR_GSM_MODULATION_TYPE_16QAM                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360311
#define RSRFSIGGEN_ATTR_GSM_MODULATION_TYPE_32QAM                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360312
#define RSRFSIGGEN_ATTR_GSM_FILTER_TYPE_AQPSK                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360313
#define RSRFSIGGEN_ATTR_GSM_FILTER_TYPE_EDGE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360314
#define RSRFSIGGEN_ATTR_GSM_FILTER_TYPE_16QAM                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360315
#define RSRFSIGGEN_ATTR_GSM_FILTER_TYPE_32QAM                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360316
#define RSRFSIGGEN_ATTR_GSM_MODULATION                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345515
#define RSRFSIGGEN_ATTR_GSM_FSK_DEVIATION                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345516
#define RSRFSIGGEN_ATTR_GSM_FILTER                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345517
#define RSRFSIGGEN_ATTR_GSM_FILTER_PARAMETER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345518
#define RSRFSIGGEN_ATTR_GSM_AQPSK_ANGLE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345519
#define RSRFSIGGEN_ATTR_GSM_AQPSK_SUBCHANNEL_POWER_IMBALANCE_RATIO                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353237
#define RSRFSIGGEN_ATTR_GSM_HSR_MODULATION_TYPE_QPSK                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360317
#define RSRFSIGGEN_ATTR_GSM_HSR_MODULATION_TYPE_16QAM                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360318
#define RSRFSIGGEN_ATTR_GSM_HSR_MODULATION_TYPE_32QAM                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360319
#define RSRFSIGGEN_ATTR_GSM_HSR_FILTER_TYPE_QPSK                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360320
#define RSRFSIGGEN_ATTR_GSM_HSR_FILTER_TYPE_16QAM                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360321
#define RSRFSIGGEN_ATTR_GSM_HSR_FILTER_TYPE_32QAM                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360322
#define RSRFSIGGEN_ATTR_GSM_RAMP_TIME                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345522
#define RSRFSIGGEN_ATTR_GSM_RAMP_FUNCTION                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345523
#define RSRFSIGGEN_ATTR_GSM_RAMP_RISE_OFFSET                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345524
#define RSRFSIGGEN_ATTR_GSM_RAMP_FALL_OFFSET                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345525
#define RSRFSIGGEN_ATTR_GSM_SLOT_ATTENUATIONS_IN_BB_ONLY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357204
#define RSRFSIGGEN_ATTR_GSM_SLOT_ATTENUATION_VALUE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345526
#define RSRFSIGGEN_ATTR_GSM_TRIGGER_EXECUTE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345527
#define RSRFSIGGEN_ATTR_GSM_TRIGGER_ARM                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353238
#define RSRFSIGGEN_ATTR_GSM_TRIGGER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345528
#define RSRFSIGGEN_ATTR_GSM_TRIGGER_MODE_STATUS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353239
#define RSRFSIGGEN_ATTR_GSM_TRIGGER_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345529
#define RSRFSIGGEN_ATTR_GSM_TRIGGER_SOURCE_LEGACY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350968
#define RSRFSIGGEN_ATTR_GSM_SEQUENCE_LENGTH                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353240
#define RSRFSIGGEN_ATTR_GSM_TRIGGER_SIGNAL_DURATION_UNIT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353241
#define RSRFSIGGEN_ATTR_GSM_TIME_BASED_TRIGGER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363329
#define RSRFSIGGEN_ATTR_GSM_INTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345530
#define RSRFSIGGEN_ATTR_GSM_INTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345531
#define RSRFSIGGEN_ATTR_GSM_EXTERNAL_TRIGGER_CLOCK_DELAY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353242
#define RSRFSIGGEN_ATTR_GSM_EXTERNAL_TRIGGER_CLOCK_INHIBIT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353243
#define RSRFSIGGEN_ATTR_GSM_EXTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345532
#define RSRFSIGGEN_ATTR_GSM_EXTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345533
#define RSRFSIGGEN_ATTR_GSM_MARKER_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345534
#define RSRFSIGGEN_ATTR_GSM_MARKER_FRAME_PERIOD                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345535
#define RSRFSIGGEN_ATTR_GSM_MARKER_SLOT_PERIOD                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345536
#define RSRFSIGGEN_ATTR_GSM_MARKER_PATTERN                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345537
#define RSRFSIGGEN_ATTR_GSM_MARKER_OFF_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345538
#define RSRFSIGGEN_ATTR_GSM_MARKER_ON_TIME                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345539
#define RSRFSIGGEN_ATTR_GSM_MARKER_PULSE_DIVIDER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345540
#define RSRFSIGGEN_ATTR_GSM_MARKER_PULSE_FREQUENCY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345541
#define RSRFSIGGEN_ATTR_GSM_MARKER_DELAY                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345542
#define RSRFSIGGEN_ATTR_GSM_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345543
#define RSRFSIGGEN_ATTR_GSM_FIXED_MARKER_DELAY_MAXIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345544
#define RSRFSIGGEN_ATTR_GSM_FIXED_MARKER_DELAY_MINIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345545
#define RSRFSIGGEN_ATTR_GSM_CLOCK_SOURCE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345546
#define RSRFSIGGEN_ATTR_GSM_CLOCK_SOURCE_LEGACY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350994
#define RSRFSIGGEN_ATTR_GSM_CLOCK_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345547
#define RSRFSIGGEN_ATTR_GSM_SYMBOL_CLOCK_MULTIPLIER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345548
#define RSRFSIGGEN_ATTR_GSM_SYMBOL_CLOCK_DIVIDER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345549
#define RSRFSIGGEN_ATTR_GSM_CLOCK_SYNCHRONISATION_EXECUTE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345550
#define RSRFSIGGEN_ATTR_GSM_CLOCK_SYNCHRONISATION_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345552
#define RSRFSIGGEN_ATTR_GSM_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345553
#define RSRFSIGGEN_ATTR_GSM_FRAME_REPETITIONS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353244
#define RSRFSIGGEN_ATTR_GSM_BURST_TYPE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345554
#define RSRFSIGGEN_ATTR_GSM_HSR_SLOT_FILTER_TYPE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345556
#define RSRFSIGGEN_ATTR_GSM_MULTISLOT_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345557
#define RSRFSIGGEN_ATTR_GSM_NUMBER_OF_SLOTS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345558
#define RSRFSIGGEN_ATTR_GSM_GMSK_TIMING_JITTER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353245
#define RSRFSIGGEN_ATTR_GSM_VAMOS_OFFSET_JITTER_MEAN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357205
#define RSRFSIGGEN_ATTR_GSM_VAMOS_OFFSET_JITTER_STANDARD                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357206
#define RSRFSIGGEN_ATTR_GSM_ETSC                                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345559
#define RSRFSIGGEN_ATTR_GSM_ETSC_PATTERN                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345560
#define RSRFSIGGEN_ATTR_GSM_TRAINING_SEQUENCE_SYNC                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345561
#define RSRFSIGGEN_ATTR_GSM_SYNC_PATTERN                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345562
#define RSRFSIGGEN_ATTR_GSM_FIXED                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345563
#define RSRFSIGGEN_ATTR_GSM_FIXED_PATTERN                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345564
#define RSRFSIGGEN_ATTR_GSM_MIXED_PATTERN                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345565
#define RSRFSIGGEN_ATTR_GSM_SCPIR                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357207
#define RSRFSIGGEN_ATTR_GSM_SLOT_LEVEL                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345566
#define RSRFSIGGEN_ATTR_GSM_SLOT_ATTENUATION                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345567
#define RSRFSIGGEN_ATTR_GSM_STEALING_FLAG_ENABLE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345568
#define RSRFSIGGEN_ATTR_GSM_STEALING_FLAG_VALUE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345569
#define RSRFSIGGEN_ATTR_GSM_DATA                                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345570
#define RSRFSIGGEN_ATTR_GSM_DATA_PATTERN                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345571
#define RSRFSIGGEN_ATTR_GSM_SELECT_DATA_LIST                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345572
#define RSRFSIGGEN_ATTR_GSM_DATA_LIST_CATALOG                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357208
#define RSRFSIGGEN_ATTR_GSM_TRAINING_SEQUENCE_SET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345573
#define RSRFSIGGEN_ATTR_GSM_TSC                                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345574
#define RSRFSIGGEN_ATTR_GSM_TSC_PATTERN                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345575
#define RSRFSIGGEN_ATTR_GSM_PREDEFINED_SLOTS_CATALOG                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345576
#define RSRFSIGGEN_ATTR_GSM_RECALL_PREDEFINED_SLOT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345577
#define RSRFSIGGEN_ATTR_GSM_USER_SLOT_CATALOG                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345578
#define RSRFSIGGEN_ATTR_GSM_RECALL_USER_SLOT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345579
#define RSRFSIGGEN_ATTR_GSM_SAVE_USER_SLOT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345580
#define RSRFSIGGEN_ATTR_GSM_DELETE_USER_SLOT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345581
#define RSRFSIGGEN_ATTR_BT_ENABLED                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345582
#define RSRFSIGGEN_ATTR_BT_SET_TO_DEFAULT                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345583
#define RSRFSIGGEN_ATTR_BT_GENERATE_WAVEFORM_FILE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345584
#define RSRFSIGGEN_ATTR_BT_VERSION                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345585
#define RSRFSIGGEN_ATTR_BT_MODE                                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345586
#define RSRFSIGGEN_ATTR_BT_TRANSPORT_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345587
#define RSRFSIGGEN_ATTR_BT_PACKET_TYPE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345588
#define RSRFSIGGEN_ATTR_BT_SEQUENCE_LENGTH                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345589
#define RSRFSIGGEN_ATTR_BT_FREQUENCY_DEVIATION                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345590
#define RSRFSIGGEN_ATTR_BT_CONTROLLER_STATE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345591
#define RSRFSIGGEN_ATTR_BT_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345592
#define RSRFSIGGEN_ATTR_BT_SLOT_TIMING_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353369
#define RSRFSIGGEN_ATTR_BT_SETTINGS_CATALOG                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345593
#define RSRFSIGGEN_ATTR_BT_DELETE_SETTINGS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345594
#define RSRFSIGGEN_ATTR_BT_RECALL_SETTINGS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345595
#define RSRFSIGGEN_ATTR_BT_SAVE_SETTINGS                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345596
#define RSRFSIGGEN_ATTR_BT_FAST_STORE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353262
#define RSRFSIGGEN_ATTR_BT_FILTER_TYPE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345597
#define RSRFSIGGEN_ATTR_BT_FILTER_PARAMETER_ROOT_COSINE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345598
#define RSRFSIGGEN_ATTR_BT_FILTER_PARAMETER_COSINE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345599
#define RSRFSIGGEN_ATTR_BT_FILTER_PARAMETER_GAUSS_PURE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345600
#define RSRFSIGGEN_ATTR_BT_FILTER_PARAMETER_GAUSS_FSK                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345601
#define RSRFSIGGEN_ATTR_BT_FILTER_PARAMETER_GAUSS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345602
#define RSRFSIGGEN_ATTR_BT_FILTER_PARAMETER_APCO25                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345603
#define RSRFSIGGEN_ATTR_BT_FILTER_PARAMETER_SPLIT_PHASE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345604
#define RSRFSIGGEN_ATTR_BT_FILTER_PARAMETER_LOWPASS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345605
#define RSRFSIGGEN_ATTR_BT_FILTER_IMPULSE_LENGTH_AUTO                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345606
#define RSRFSIGGEN_ATTR_BT_FILTER_IMPULSE_LENGTH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345607
#define RSRFSIGGEN_ATTR_BT_FILTER_OVERSAMPLING_AUTO                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345608
#define RSRFSIGGEN_ATTR_BT_FILTER_OVERSAMPLING                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345609
#define RSRFSIGGEN_ATTR_BT_FILTER_SYMBOL_RATE_VARIATION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345610
#define RSRFSIGGEN_ATTR_BT_FILTER_MODULATION_INDEX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345611
#define RSRFSIGGEN_ATTR_BT_FILTER_MODULATION_TYPE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345612
#define RSRFSIGGEN_ATTR_BT_CLIPPING_ENABLED                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345613
#define RSRFSIGGEN_ATTR_BT_CLIPPING_LEVEL                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345614
#define RSRFSIGGEN_ATTR_BT_CLIPPING_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345615
#define RSRFSIGGEN_ATTR_BT_TRIGGER_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345616
#define RSRFSIGGEN_ATTR_BT_TRIGGER_SOURCE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345617
#define RSRFSIGGEN_ATTR_BT_TRIGGER_SOURCE_LEGACY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350970
#define RSRFSIGGEN_ATTR_BT_TRIGGER_SIGNAL_DURATION_UNIT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345618
#define RSRFSIGGEN_ATTR_BT_TRIGGER_SIGNAL_DURATION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345619
#define RSRFSIGGEN_ATTR_BT_TRIGGER_EXECUTE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353263
#define RSRFSIGGEN_ATTR_BT_TRIGGER_ARM                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353264
#define RSRFSIGGEN_ATTR_BT_TRIGGER_STATUS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353265
#define RSRFSIGGEN_ATTR_BT_TIME_BASED_TRIGGER                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363332
#define RSRFSIGGEN_ATTR_BT_INTERNAL_TRIGGER_DELAY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345620
#define RSRFSIGGEN_ATTR_BT_INTERNAL_TRIGGER_INHIBIT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345621
#define RSRFSIGGEN_ATTR_BT_EXTERNAL_TRIGGER_DELAY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345622
#define RSRFSIGGEN_ATTR_BT_EXTERNAL_TRIGGER_INHIBIT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345623
#define RSRFSIGGEN_ATTR_BT_MARKER_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345624
#define RSRFSIGGEN_ATTR_BT_MARKER_PULSE_DIVIDER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345625
#define RSRFSIGGEN_ATTR_BT_MARKER_PULSE_FREQUENCY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345626
#define RSRFSIGGEN_ATTR_BT_MARKER_PATTERN                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345627
#define RSRFSIGGEN_ATTR_BT_MARKER_ON_TIME                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345628
#define RSRFSIGGEN_ATTR_BT_MARKER_OFF_TIME                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345629
#define RSRFSIGGEN_ATTR_BT_MARKER_FE_SHIFT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359797
#define RSRFSIGGEN_ATTR_BT_MARKER_RE_SHIFT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359798
#define RSRFSIGGEN_ATTR_BT_MARKER_PACKETS_INDEX                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363104
#define RSRFSIGGEN_ATTR_BT_MARKER_DELAY                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345630
#define RSRFSIGGEN_ATTR_BT_FIXED_MARKER_DELAY_MAXIMUM                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345631
#define RSRFSIGGEN_ATTR_BT_FIXED_MARKER_DELAY_MINIMUM                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345632
#define RSRFSIGGEN_ATTR_BT_CLOCK_SOURCE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345633
#define RSRFSIGGEN_ATTR_BT_CLOCK_SOURCE_LEGACY                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350996
#define RSRFSIGGEN_ATTR_BT_CLOCK_MODE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345634
#define RSRFSIGGEN_ATTR_BT_CLOCK_MULTIPLIER                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345635
#define RSRFSIGGEN_ATTR_BT_CLOCK_SYNCHRONISATION_EXECUTE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345636
#define RSRFSIGGEN_ATTR_BT_CLOCK_SYNCHRONISATION_MODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345637
#define RSRFSIGGEN_ATTR_BT_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345638
#define RSRFSIGGEN_ATTR_BT_RAMP_FUNCTION                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345639
#define RSRFSIGGEN_ATTR_BT_RAMP_TIME                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345640
#define RSRFSIGGEN_ATTR_BT_RAMP_RISE_OFFSET                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345641
#define RSRFSIGGEN_ATTR_BT_RAMP_FALL_OFFSET                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345642
#define RSRFSIGGEN_ATTR_BT_PACKET_DATA_SOURCE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345643
#define RSRFSIGGEN_ATTR_BT_PACKET_DATA_WHITENING                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345644
#define RSRFSIGGEN_ATTR_BT_PACKET_NAP                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345645
#define RSRFSIGGEN_ATTR_BT_PACKET_UAP                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345646
#define RSRFSIGGEN_ATTR_BT_PACKET_LAP                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345647
#define RSRFSIGGEN_ATTR_BT_PACKET_LAP_SYNCHRONIZATION_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357210
#define RSRFSIGGEN_ATTR_BT_PACKET_LAP_FOR_SYNC_WORD                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357211
#define RSRFSIGGEN_ATTR_BT_PACKET_LENGTH                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345648
#define RSRFSIGGEN_ATTR_BT_PACKET_DATA_SOURCE_VOICE_FIELD                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353266
#define RSRFSIGGEN_ATTR_BT_PACKET_HEADER_LOGICAL_TRANSPORT_ADDRESS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345649
#define RSRFSIGGEN_ATTR_BT_PACKET_HEADER_FLOW_CONTROL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345650
#define RSRFSIGGEN_ATTR_BT_PACKET_HEADER_ACKNOWLEDGMENT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345651
#define RSRFSIGGEN_ATTR_BT_PACKET_HEADER_SEQN_VALUE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345652
#define RSRFSIGGEN_ATTR_BT_PACKET_PAYLOAD_DATA_SOURCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345653
#define RSRFSIGGEN_ATTR_BT_PACKET_PAYLOAD_DATA_LIST                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345654
#define RSRFSIGGEN_ATTR_BT_PACKET_PAYLOAD_PATTERN                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345655
#define RSRFSIGGEN_ATTR_BT_PACKET_PAYLOAD_DATA_LENGTH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345656
#define RSRFSIGGEN_ATTR_BT_PACKET_PAYLOAD_EIR_PACKET_FOLLOWS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345657
#define RSRFSIGGEN_ATTR_BT_PACKET_PAYLOAD_CLASS_OF_DEVICE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345658
#define RSRFSIGGEN_ATTR_BT_PACKET_PAYLOAD_SCAN_REPETITION_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345659
#define RSRFSIGGEN_ATTR_BT_PACKET_PAYLOAD_FLOW_CONTROL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345660
#define RSRFSIGGEN_ATTR_BT_PACKET_DV_PAYLOAD_DATA_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345661
#define RSRFSIGGEN_ATTR_BT_PACKET_DV_PAYLOAD_DATA_LIST                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345662
#define RSRFSIGGEN_ATTR_BT_PACKET_DV_PAYLOAD_PATTERN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345663
#define RSRFSIGGEN_ATTR_BT_DTT_SET_TO_DEFAULT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345664
#define RSRFSIGGEN_ATTR_BT_DTT_TABLE_SETTINGS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345665
#define RSRFSIGGEN_ATTR_BT_DTT_ENABLED                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345666
#define RSRFSIGGEN_ATTR_BT_DTT_FREQUENCY_DRIFT_RATE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345667
#define RSRFSIGGEN_ATTR_BT_DTT_FREQUENCY_DRIFT_DEVIATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345668
#define RSRFSIGGEN_ATTR_BT_DTT_START_PHASE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345669
#define RSRFSIGGEN_ATTR_BT_DTT_MODULATION_INDEX_MODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356477
#define RSRFSIGGEN_ATTR_BT_DTT_NUMBER_OF_PACKETS_PER_SET                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357212
#define RSRFSIGGEN_ATTR_BT_DTT_SHORT_TABLE_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345670
#define RSRFSIGGEN_ATTR_BT_DTT_SHORT_TABLE_CARRIER_FREQUENCY_OFFSET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345671
#define RSRFSIGGEN_ATTR_BT_DTT_SHORT_TABLE_SYMBOL_TIMING_ERROR                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345672
#define RSRFSIGGEN_ATTR_BT_DTT_LONG_TABLE_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345673
#define RSRFSIGGEN_ATTR_BT_DTT_LONG_TABLE_CARRIER_FREQUENCY_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345674
#define RSRFSIGGEN_ATTR_BT_DTT_LONG_TABLE_SYMBOL_TIMING_ERROR                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345675
#define RSRFSIGGEN_ATTR_BT_DTT_LONG_TABLE_MODULATION_INDEX                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345676
#define RSRFSIGGEN_ATTR_BT_DTT_TPC_PACKET_INTERVAL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345677
#define RSRFSIGGEN_ATTR_BT_DTT_TPC_PAYLOAD_TYPE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345678
#define RSRFSIGGEN_ATTR_BT_DTT_TPC_SYMBOLS_PER_A_BIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357213
#define RSRFSIGGEN_ATTR_BT_DTT_TPC_PAYLOAD_LENGTH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345679
#define RSRFSIGGEN_ATTR_BT_LE_CHANNEL_TYPE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345680
#define RSRFSIGGEN_ATTR_BT_LE_PACKET_TYPE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345681
#define RSRFSIGGEN_ATTR_BT_LE_PACKET_FORMAT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357214
#define RSRFSIGGEN_ATTR_BT_LE_SEQUENCE_LENGTH                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345682
#define RSRFSIGGEN_ATTR_BT_LE_ENCRYPTED_DIVERSIFIER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345683
#define RSRFSIGGEN_ATTR_BT_LE_ACCESS_ADDRESS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345684
#define RSRFSIGGEN_ATTR_BT_LE_LONG_TERM_KEY                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345685
#define RSRFSIGGEN_ATTR_BT_LE_ROLE                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345686
#define RSRFSIGGEN_ATTR_BT_LE_ADVERTISING_PACKET_INTERVAL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345687
#define RSRFSIGGEN_ATTR_BT_LE_ADVERTISERS_NAME                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345688
#define RSRFSIGGEN_ATTR_BT_LE_CONNECTION_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345689
#define RSRFSIGGEN_ATTR_BT_LE_FEATURE_SET_LENGTH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345690
#define RSRFSIGGEN_ATTR_BT_LE_HOP_LENGTH                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345691
#define RSRFSIGGEN_ATTR_BT_LE_NEW_HOP_LENGTH                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345692
#define RSRFSIGGEN_ATTR_BT_LE_LL_CONNECTION_EVENT_COUNT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345693
#define RSRFSIGGEN_ATTR_BT_LE_LL_CONNECTION_TIMEOUT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345694
#define RSRFSIGGEN_ATTR_BT_LE_NEW_LL_CONNECTION_TIMEOUT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345695
#define RSRFSIGGEN_ATTR_BT_LE_LL_CONNECTION_INSTANT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353267
#define RSRFSIGGEN_ATTR_BT_LE_MORE_PROFILES                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345696
#define RSRFSIGGEN_ATTR_BT_LE_NEW_SLAVE_LATENCY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345697
#define RSRFSIGGEN_ATTR_BT_LE_NEW_TRANSMIT_WINDOW_OFFSET                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345698
#define RSRFSIGGEN_ATTR_BT_LE_NEW_TRANSMIT_WINDOW_SIZE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345699
#define RSRFSIGGEN_ATTR_BT_LE_GET_TRANSMIT_WINDOW_OFFSET                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353268
#define RSRFSIGGEN_ATTR_BT_LE_GET_TRANSMIT_WINDOW_SIZE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353269
#define RSRFSIGGEN_ATTR_BT_LE_PACKETS_PER_EVENT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345700
#define RSRFSIGGEN_ATTR_BT_LE_NESN_START_VALUE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345701
#define RSRFSIGGEN_ATTR_BT_LE_PROFILE_ID                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345702
#define RSRFSIGGEN_ATTR_BT_LE_RANDOM_VECTOR                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345703
#define RSRFSIGGEN_ATTR_BT_LE_SLEEP_CLOCK_ACCURACY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345704
#define RSRFSIGGEN_ATTR_BT_LE_SCAN_INTERVAL                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345705
#define RSRFSIGGEN_ATTR_BT_LE_SCAN_WINDOW                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345706
#define RSRFSIGGEN_ATTR_BT_LE_SN_START_VALUE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345707
#define RSRFSIGGEN_ATTR_BT_LE_CTE_INFO_PRESENT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359799
#define RSRFSIGGEN_ATTR_BT_LE_CTC_INFO_HEADER                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359800
#define RSRFSIGGEN_ATTR_BT_LE_CTE_TIME                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359801
#define RSRFSIGGEN_ATTR_BT_LE_CTE_TYPE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359802
#define RSRFSIGGEN_ATTR_BT_LE_CTE_NUMBER_OF_ANTENNAS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360712
#define RSRFSIGGEN_ATTR_BT_LE_CTE_ANTENNA_GAIN                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360713
#define RSRFSIGGEN_ATTR_BT_LE_CTE_TYPEREQ                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359803
#define RSRFSIGGEN_ATTR_BT_LE_CTE_MIN_LEN_REQ                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359804
#define RSRFSIGGEN_ATTR_BT_LE_HOST_IDENTIFIER_ID                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359805
#define RSRFSIGGEN_ATTR_BT_LE_SID_CTR_DATA                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359806
#define RSRFSIGGEN_ATTR_BT_LE_LAST_PA_EVENT_COUNTER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359807
#define RSRFSIGGEN_ATTR_BT_LE_SYNC_CONNECTION_EVENT_COUNTER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359808
#define RSRFSIGGEN_ATTR_BT_LE_SESSION_KEY_ID_SKDM                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345708
#define RSRFSIGGEN_ATTR_BT_LE_SESSION_KEY_ID_SKDS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345709
#define RSRFSIGGEN_ATTR_BT_LE_SLAVE_LATENCY                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345710
#define RSRFSIGGEN_ATTR_BT_LE_TRANSMIT_WINDOW_OFFSET                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345711
#define RSRFSIGGEN_ATTR_BT_LE_TRANSMIT_WINDOW_SIZE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345712
#define RSRFSIGGEN_ATTR_BT_LE_ADRESS_TYPE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359809
#define RSRFSIGGEN_ATTR_BT_LE_CTR_DATA_CONNECTION_EVENT_COUNT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359810
#define RSRFSIGGEN_ATTR_BT_LE_UNKNOWN_TYPE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345713
#define RSRFSIGGEN_ATTR_BT_LE_DATA_LENGTH                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345714
#define RSRFSIGGEN_ATTR_BT_LE_DATA_SOURCE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345715
#define RSRFSIGGEN_ATTR_BT_LE_DATA_PATTERN                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345716
#define RSRFSIGGEN_ATTR_BT_LE_DATA_LIST                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345717
#define RSRFSIGGEN_ATTR_BT_LE_DATA_WHITENING                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345718
#define RSRFSIGGEN_ATTR_BT_LE_CHANNEL_SELECTION                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356478
#define RSRFSIGGEN_ATTR_BT_LE_CRC_INITIAL                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345719
#define RSRFSIGGEN_ATTR_BT_LE_INITIALIZATION_VECTOR_M                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345720
#define RSRFSIGGEN_ATTR_BT_LE_INITIALIZATION_VECTOR_S                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345721
#define RSRFSIGGEN_ATTR_BT_LE_DEVICES_ADDR_TYPE_ADVERTISER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345722
#define RSRFSIGGEN_ATTR_BT_LE_DEVICES_ADDR_TYPE_SCANNER                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345723
#define RSRFSIGGEN_ATTR_BT_LE_DEVICES_ADDR_TYPE_INITIATOR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345724
#define RSRFSIGGEN_ATTR_BT_LE_DEVICES_ADDR_TYPE_TX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353270
#define RSRFSIGGEN_ATTR_BT_LE_DEVICES_ADDR_TYPE_RX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353271
#define RSRFSIGGEN_ATTR_BT_LE_DEVICES_ADDR_ACID                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353272
#define RSRFSIGGEN_ATTR_BT_LE_DEVICES_ADDR_ACAS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353273
#define RSRFSIGGEN_ATTR_BT_LE_DEVICES_ADDR_SCID                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353274
#define RSRFSIGGEN_ATTR_BT_LE_DEVICES_ADDR_SCAS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353275
#define RSRFSIGGEN_ATTR_BT_LE_DEVICES_ADDR_ICID                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353276
#define RSRFSIGGEN_ATTR_BT_LE_DEVICES_ADDR_ICAS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353277
#define RSRFSIGGEN_ATTR_BT_LE_DATA_CHANNEL_MAP_TABLE_AC_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345725
#define RSRFSIGGEN_ATTR_BT_LE_DATA_CHANNEL_MAP_TABLE_DC_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345726
#define RSRFSIGGEN_ATTR_BT_LE_DATA_CHANNEL_MAP_TABLE_DCM_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345727
#define RSRFSIGGEN_ATTR_BT_LE_DATA_CHANNEL_MAP_TABLE_AC_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353278
#define RSRFSIGGEN_ATTR_BT_LE_DATA_CHANNEL_MAP_TABLE_DC_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353279
#define RSRFSIGGEN_ATTR_BT_LE_DATA_CHANNEL_MAP_TABLE_PCON_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353280
#define RSRFSIGGEN_ATTR_BT_LE_PAYLOAD_ERROR_CODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345728
#define RSRFSIGGEN_ATTR_BT_LE_PAYLOAD_VERSION_NUMBER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345729
#define RSRFSIGGEN_ATTR_BT_LE_PAYLOAD_SUBVERSION_NUMBER                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345730
#define RSRFSIGGEN_ATTR_BT_LE_PAYLOAD_COMPANY_ID                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345731
#define RSRFSIGGEN_ATTR_BT_LE_CLOCK_ACCURACY                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353370
#define RSRFSIGGEN_ATTR_BT_LE_FIRST_ACTIVE_DATA_CHANNEL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353375
#define RSRFSIGGEN_ATTR_BT_LE_CORRUPTED_CRC                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356479
#define RSRFSIGGEN_ATTR_BT_LE_DURATION                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356480
#define RSRFSIGGEN_ATTR_BT_LE_MODULATION_FORMAT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356481
#define RSRFSIGGEN_ATTR_BT_LE_ADVERTISING_EVENT_DELAY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345732
#define RSRFSIGGEN_ATTR_BT_LE_ADVERTISING_EVENT_DIRECT_INTERVAL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353281
#define RSRFSIGGEN_ATTR_BT_LE_ADVERTISING_EVENT_DUTY_CYCLE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357215
#define RSRFSIGGEN_ATTR_BT_LE_ADVERTISING_EVENT_INTERVAL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345733
#define RSRFSIGGEN_ATTR_BT_LE_CONNECTION_EVENT_INTERVAL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345734
#define RSRFSIGGEN_ATTR_BT_LE_NEW_CONNECTION_EVENT_INTERVAL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345735
#define RSRFSIGGEN_ATTR_BT_LE_NEW_CONNECTION_EVENT_INTERVAL_MINIMUM                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357216
#define RSRFSIGGEN_ATTR_BT_LE_NEW_CONNECTION_EVENT_INTERVAL_MAXIMUM                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357217
#define RSRFSIGGEN_ATTR_BT_LE_EVENT_OFFSET_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357218
#define RSRFSIGGEN_ATTR_BT_LE_EVENT_OFFSET_VALUE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357219
#define RSRFSIGGEN_ATTR_BT_LE_CONNECTION_EVENT_COUNT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357220
#define RSRFSIGGEN_ATTR_BT_LE_EVENT_REJECT_OPCODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357221
#define RSRFSIGGEN_ATTR_BT_LE_MAIN_PAYLOAD_PREFERRED_PERIODICITY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357222
#define RSRFSIGGEN_ATTR_BT_LE_MAIN_PAYLOAD_ADVERTISING_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356482
#define RSRFSIGGEN_ATTR_BT_LE_MAIN_PAYLOAD_MIN_USED_CHANNELS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356483
#define RSRFSIGGEN_ATTR_BT_LE_MAIN_PAYLOAD_MAX_RX_OCTETS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357223
#define RSRFSIGGEN_ATTR_BT_LE_MAIN_PAYLOAD_MAX_TX_OCTETS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357224
#define RSRFSIGGEN_ATTR_BT_LE_MAIN_PAYLOAD_MAX_RX_TIME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357225
#define RSRFSIGGEN_ATTR_BT_LE_MAIN_PAYLOAD_MAX_TX_TIME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357226
#define RSRFSIGGEN_ATTR_BT_LE_DEVICE_ADDR_ADVERTISER_UPPER_PART                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356484
#define RSRFSIGGEN_ATTR_BT_LE_DEVICE_ADDR_ADVERTISER_LOWER_PART                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356485
#define RSRFSIGGEN_ATTR_BT_LE_DEVICE_ADDR_INITIATOR_UPPER_PART                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356486
#define RSRFSIGGEN_ATTR_BT_LE_DEVICE_ADDR_INITIATOR_LOWER_PART                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356487
#define RSRFSIGGEN_ATTR_BT_LE_DEVICE_ADDR_SCANNER_UPPER_PART                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356488
#define RSRFSIGGEN_ATTR_BT_LE_DEVICE_ADDR_SCANNER_LOWER_PART                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356489
#define RSRFSIGGEN_ATTR_BT_LE_DEVICE_ADDR_TARGET_UPPER_PART                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356490
#define RSRFSIGGEN_ATTR_BT_LE_DEVICE_ADDR_TARGET_LOWER_PART                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356491
#define RSRFSIGGEN_ATTR_BT_LE_EXTENDED_HEADER_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356492
#define RSRFSIGGEN_ATTR_BT_LE_EXTENDED_HEADER_ADVA                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356493
#define RSRFSIGGEN_ATTR_BT_LE_EXTENDED_HEADER_TARGETA                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356494
#define RSRFSIGGEN_ATTR_BT_LE_EXTENDED_HEADER_ADVDATA_INFO                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356495
#define RSRFSIGGEN_ATTR_BT_LE_EXTENDED_HEADER_AUXPTR                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356496
#define RSRFSIGGEN_ATTR_BT_LE_EXTENDED_HEADER_SYNCINFO                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356497
#define RSRFSIGGEN_ATTR_BT_LE_EXTENDED_HEADER_TX_POWER_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356498
#define RSRFSIGGEN_ATTR_BT_LE_EXTENDED_HEADER_TX_POWER                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356499
#define RSRFSIGGEN_ATTR_BT_LE_EXTENDED_HEADER_ACAD_LENGTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356500
#define RSRFSIGGEN_ATTR_BT_LE_EXTENDED_HEADER_ACAD                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356501
#define RSRFSIGGEN_ATTR_BT_LE_EXTENDED_HEADER_APATTERN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356502
#define RSRFSIGGEN_ATTR_BT_LE_EXTENDED_HEADER_ALIST                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356503
#define RSRFSIGGEN_ATTR_BT_LE_RX_PHY_LE1_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356504
#define RSRFSIGGEN_ATTR_BT_LE_RX_PHY_LE2_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356505
#define RSRFSIGGEN_ATTR_BT_LE_RX_PHY_LE_CODED_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356506
#define RSRFSIGGEN_ATTR_BT_LE_TX_PHY_LE1_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356507
#define RSRFSIGGEN_ATTR_BT_LE_TX_PHY_LE2_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356508
#define RSRFSIGGEN_ATTR_BT_LE_TX_PHY_LE_CODED_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356006
#define RSRFSIGGEN_ATTR_BT_LE_PHY_LE1M_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359811
#define RSRFSIGGEN_ATTR_BT_LE_PHY_LE2M_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359812
#define RSRFSIGGEN_ATTR_BT_LE_PHY_LCOD_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359813
#define RSRFSIGGEN_ATTR_BT_LE_PHY_LE1_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356007
#define RSRFSIGGEN_ATTR_BT_LE_PHY_LE2_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356008
#define RSRFSIGGEN_ATTR_BT_LE_PHY_LE_CODED_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356009
#define RSRFSIGGEN_ATTR_BT_LE_M_TO_S_PHY_1MBIT_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357227
#define RSRFSIGGEN_ATTR_BT_LE_M_TO_S_PHY_2MBIT_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357228
#define RSRFSIGGEN_ATTR_BT_LE_M_TO_S_PHY_1MBIT_CODED_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357229
#define RSRFSIGGEN_ATTR_BT_LE_S_TO_M_PHY_1MBIT_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357230
#define RSRFSIGGEN_ATTR_BT_LE_S_TO_M_PHY_2MBIT_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357231
#define RSRFSIGGEN_ATTR_BT_LE_S_TO_M_PHY_1MBIT_CODED_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357232
#define RSRFSIGGEN_ATTR_BT_LE_ADVERTISING_DATA_ID                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356010
#define RSRFSIGGEN_ATTR_BT_LE_ADVERTISING_SET_ID                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356011
#define RSRFSIGGEN_ATTR_BT_LE_AUXPTR_CLOCK_ACCURACY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356012
#define RSRFSIGGEN_ATTR_BT_LE_AUXPTR_OFFSET_UNITS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356013
#define RSRFSIGGEN_ATTR_BT_LE_AUXPTR_AUX_OFFSET                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356014
#define RSRFSIGGEN_ATTR_BT_LE_AUXPTR_AUX_PHY                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356015
#define RSRFSIGGEN_ATTR_BT_LE_SYNC_PACKET_OFFSET                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356016
#define RSRFSIGGEN_ATTR_BT_LE_SYNC_OFFSET_UNITS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356017
#define RSRFSIGGEN_ATTR_BT_LE_SYNC_OFFSET_ADJUST                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359814
#define RSRFSIGGEN_ATTR_BT_LE_SYNC_PERIODIC_ADVERTISING_INTERVAL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356018
#define RSRFSIGGEN_ATTR_BT_LE_SYNC_EVENT_COUNTER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356021
#define RSRFSIGGEN_ATTR_W3GPP_ENABLED                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345736
#define RSRFSIGGEN_ATTR_W3GPP_SET_TO_DEFAULT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345737
#define RSRFSIGGEN_ATTR_W3GPP_VERSION                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345738
#define RSRFSIGGEN_ATTR_W3GPP_CHIP_RATE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345739
#define RSRFSIGGEN_ATTR_W3GPP_LINK_DIRECTION                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345740
#define RSRFSIGGEN_ATTR_W3GPP_ADJUST_TOTAL_POWER_TO_0DB                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345741
#define RSRFSIGGEN_ATTR_W3GPP_TOTAL_POWER                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345742
#define RSRFSIGGEN_ATTR_W3GPP_GENERATE_WAVEFORM_FILE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357233
#define RSRFSIGGEN_ATTR_W3GPP_SETTINGS_CATALOG                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345743
#define RSRFSIGGEN_ATTR_W3GPP_DELETE_3GPP_SETTINGS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345744
#define RSRFSIGGEN_ATTR_W3GPP_RECALL_3GPP_SETTINGS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345745
#define RSRFSIGGEN_ATTR_W3GPP_SAVE_3GPP_SETTINGS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345746
#define RSRFSIGGEN_ATTR_W3GPP_SEQUENCE_LENGTH_ARB                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345747
#define RSRFSIGGEN_ATTR_W3GPP_FILTER_TYPE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345748
#define RSRFSIGGEN_ATTR_W3GPP_FILTER_PARAMETER_APCO25                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345749
#define RSRFSIGGEN_ATTR_W3GPP_FILTER_PARAMETER_ROOT_COSINE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345750
#define RSRFSIGGEN_ATTR_W3GPP_FILTER_PARAMETER_COSINE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345751
#define RSRFSIGGEN_ATTR_W3GPP_FILTER_PARAMETER_SPLIT_PHASE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345752
#define RSRFSIGGEN_ATTR_W3GPP_FILTER_PARAMETER_LOWPASS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345753
#define RSRFSIGGEN_ATTR_W3GPP_FILTER_PARAMETER_LOWPASS_EVM                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345754
#define RSRFSIGGEN_ATTR_W3GPP_FILTER_PARAMETER_GAUSS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357235
#define RSRFSIGGEN_ATTR_W3GPP_CHIP_RATE_VARIATION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345755
#define RSRFSIGGEN_ATTR_W3GPP_CLIPPING_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345756
#define RSRFSIGGEN_ATTR_W3GPP_CLIPPING_LEVEL                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345757
#define RSRFSIGGEN_ATTR_W3GPP_CLIPPING_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345758
#define RSRFSIGGEN_ATTR_W3GPP_TRIGGER_STATUS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345759
#define RSRFSIGGEN_ATTR_W3GPP_TRIGGER_ARM                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345760
#define RSRFSIGGEN_ATTR_W3GPP_TRIGGER_EXECUTE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345761
#define RSRFSIGGEN_ATTR_W3GPP_TRIGGER_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345762
#define RSRFSIGGEN_ATTR_W3GPP_TRIGGER_SOURCE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345763
#define RSRFSIGGEN_ATTR_W3GPP_TRIGGER_SOURCE_LEGACY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350972
#define RSRFSIGGEN_ATTR_W3GPP_TRIGGER_SINGLE_SEQUENCE_LENGTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357236
#define RSRFSIGGEN_ATTR_W3GPP_TRIGGER_SINGLE_SIGNAL_DURATION_UNIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357237
#define RSRFSIGGEN_ATTR_W3GPP_INTERNAL_TRIGGER_DELAY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345764
#define RSRFSIGGEN_ATTR_W3GPP_INTERNAL_TRIGGER_INHIBIT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345765
#define RSRFSIGGEN_ATTR_W3GPP_EXTERNAL_TRIGGER_DELAY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345766
#define RSRFSIGGEN_ATTR_W3GPP_EXTERNAL_TRIGGER_INHIBIT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345767
#define RSRFSIGGEN_ATTR_W3GPP_MARKER_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345768
#define RSRFSIGGEN_ATTR_W3GPP_MARKER_USER_PERIOD                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345769
#define RSRFSIGGEN_ATTR_W3GPP_MARKER_ON_TIME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357238
#define RSRFSIGGEN_ATTR_W3GPP_MARKER_OFF_TIME                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357239
#define RSRFSIGGEN_ATTR_W3GPP_MARKER_DELAY                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345770
#define RSRFSIGGEN_ATTR_W3GPP_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345771
#define RSRFSIGGEN_ATTR_W3GPP_FIXED_MARKER_DELAY_MAXIMUM                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345772
#define RSRFSIGGEN_ATTR_W3GPP_FIXED_MARKER_DELAY_MINIMUM                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345773
#define RSRFSIGGEN_ATTR_W3GPP_CLOCK_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345774
#define RSRFSIGGEN_ATTR_W3GPP_CLOCK_SOURCE_LEGACY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350998
#define RSRFSIGGEN_ATTR_W3GPP_CLOCK_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345775
#define RSRFSIGGEN_ATTR_W3GPP_CHIP_CLOCK_MULTIPLIER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345776
#define RSRFSIGGEN_ATTR_W3GPP_CLOCK_SYNCHRONISATION_EXECUTE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345777
#define RSRFSIGGEN_ATTR_W3GPP_CLOCK_SYNCHRONISATION_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345779
#define RSRFSIGGEN_ATTR_W3GPP_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345780
#define RSRFSIGGEN_ATTR_W3GPP_OCNS_ADD_BS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345781
#define RSRFSIGGEN_ATTR_W3GPP_OCNS_SEED                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353077
#define RSRFSIGGEN_ATTR_W3GPP_OCNS_MODE_BS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345782
#define RSRFSIGGEN_ATTR_W3GPP_RESET_ALL_BASESTATIONS_BS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345783
#define RSRFSIGGEN_ATTR_W3GPP_COPY_FROM_SOURCE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353078
#define RSRFSIGGEN_ATTR_W3GPP_COPY_TO_DESTINATION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353079
#define RSRFSIGGEN_ATTR_W3GPP_COPY_EXECUTE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353080
#define RSRFSIGGEN_ATTR_W3GPP_CHANNELIZATION_CODE_OFFSET                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353081
#define RSRFSIGGEN_ATTR_W3GPP_BS_TEST_MODEL_CATALOG                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345784
#define RSRFSIGGEN_ATTR_W3GPP_BS_TEST_MODEL                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345785
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_TEST_MODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353082
#define RSRFSIGGEN_ATTR_W3GPP_BS_TEST_CASE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353083
#define RSRFSIGGEN_ATTR_W3GPP_BS_TEST_CASE_EXECUTE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353084
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_CARRIER_NOISE_RATIO                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353085
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_QUERY_CARRIER_NOISE_RATIO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353086
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_SIGNAL_NOISE_RATIO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353087
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_QUERY_SIGNAL_NOISE_RATIO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353088
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_NOISE_LEVEL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353089
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_BLOCK_ERROR_RATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353090
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_REQUIRED_PROBABILITY_OF_DETECTION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353091
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_AWGN_SIGNAL_STATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353092
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_BS_POWER_CLASS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353093
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_BS_RF_FREQUENCY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353094
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_BS_RF_POWER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353095
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_FADING_STATE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353096
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_TRIGGER_CONFIGURATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353097
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_MARKER_CONFIGURATION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353098
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_BLOCKING_SCENARIO                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353099
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_POWER_RATIO_DPCCH_DPDCH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353100
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_SLOT_FORMAT_DPCCH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353101
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_TPC_REPEAT_PATTERN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353102
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_TPC_DATA_LIST                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353103
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_TPC_BIT_PATTERN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353104
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_TPC_START_PATTERN                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353105
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_TPC_START_PATTERN_DATA_LIST                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353106
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_TPC_POWER_DOWN_STEPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353107
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_TPC_POWER_UP_STEPS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353108
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_RMC_CODING_TYPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353109
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_BIT_ERROR_RATE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353110
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_DPDCH_BLOCK_ERROR_RATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353111
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_OVERALL_SYMBOL_RATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353112
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_WANTED_SIGNAL_RF_FREQUENCY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353113
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_WANTED_SIGNAL_OPERATING_BAND                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353114
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_TRANSPORT_BLOCK_SIZE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353115
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_WANTED_SIGNAL_POWER_LEVEL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353116
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_RACH_TRANSPORT_BLOCK_SIZE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353117
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_WANTED_SIGNAL_STATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353118
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_WANTED_SIGNAL_PROPAGATION_DELAY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353119
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_BASEBAND_A_SIGNAL_ROUTING                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353120
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_BASEBAND_DIVERSITY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353121
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_SCRAMBLING_CODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353122
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_SCRAMBLING_CODE_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353123
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_INTERFERER_BANDWIDTH_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353124
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_SIGNAL_LEVEL_RATIO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353125
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_CW_INTERFERING_SIGNAL_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353126
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_CW_INTERFERING_SIGNAL_FREQUENCY_OFFSET                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353127
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_CW_INTERFERING_SIGNAL_POWER_LEVEL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353128
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_MODULATED_INTERFERING_SIGNAL_STATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353129
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_MODULATED_INTERFERING_SIGNAL_FREQUENCY_OFFSET                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353130
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_MODULATED_INTERFERING_SIGNAL_POWER_LEVEL                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353131
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_INTERFERER_2_MODULATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353132
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_INTERFERER_STATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353133
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_INTERFERING_SIGNAL_FREQUENCY_OFFSET                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353134
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_INTERFERING_SIGNAL_POWER_LEVEL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353135
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_INTERFERENCE_MODEL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353136
#define RSRFSIGGEN_ATTR_W3GPP_TS25141_INTERFERER_MODULATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353137
#define RSRFSIGGEN_ATTR_W3GPP_BS1_USER_CHANNEL_CODING_CATALOG                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349958
#define RSRFSIGGEN_ATTR_W3GPP_BS1_CHANNEL_CODING_USER_CODING_DELETE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 349959
#define RSRFSIGGEN_ATTR_W3GPP_BS_ENABLED                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345786
#define RSRFSIGGEN_ATTR_W3GPP_BS_HSDPA_H_SET_TO_DEFAULT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353138
#define RSRFSIGGEN_ATTR_W3GPP_BS_CHANNEL_TABLE_SET_TO_DEFAULT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353139
#define RSRFSIGGEN_ATTR_W3GPP_BS_SCRAMBLING_CODE_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345787
#define RSRFSIGGEN_ATTR_W3GPP_BS_SCRAMBLING_CODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345788
#define RSRFSIGGEN_ATTR_W3GPP_BS_TIME_DELAY                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345789
#define RSRFSIGGEN_ATTR_W3GPP_BS_SCPICH_PHASE_REFERENCE_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353140
#define RSRFSIGGEN_ATTR_W3GPP_BS_SECOND_SEARCH_CODE_GROUP                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345790
#define RSRFSIGGEN_ATTR_W3GPP_BS_PAGE_INDICATORS_FRAME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345791
#define RSRFSIGGEN_ATTR_W3GPP_BS_TRANSMIT_DIVERSITY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345792
#define RSRFSIGGEN_ATTR_W3GPP_BS_OPEN_LOOP_TRANSMIT_DIVERSITY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345793
#define RSRFSIGGEN_ATTR_W3GPP_BS_RESOLVE_DOMAIN_CONFLICT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345794
#define RSRFSIGGEN_ATTR_W3GPP_BS_DOMAIN_CONFLICT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345795
#define RSRFSIGGEN_ATTR_W3GPP_BS_COMPRESSED_MODE_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345796
#define RSRFSIGGEN_ATTR_W3GPP_BS_COMPRESSED_MODE_METHOD                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345797
#define RSRFSIGGEN_ATTR_W3GPP_BS_COMPRESSED_MODE_DL_FRAME_STRUCTURE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345798
#define RSRFSIGGEN_ATTR_W3GPP_BS_COMPRESSED_MODE_POWER_OFFSET_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345799
#define RSRFSIGGEN_ATTR_W3GPP_BS_COMPRESSED_MODE_POWER_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345800
#define RSRFSIGGEN_ATTR_W3GPP_BS_COMPRESSED_MODE_SLOT_NUMBER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345801
#define RSRFSIGGEN_ATTR_W3GPP_BS_COMPRESSED_MODE_TRANSMISSION_GAP_DISTANCE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345802
#define RSRFSIGGEN_ATTR_W3GPP_BS_COMPRESSED_MODE_PATTERN_LENGTH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345803
#define RSRFSIGGEN_ATTR_W3GPP_BS_COMPRESSED_MODE_GAP_LENGTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345804
#define RSRFSIGGEN_ATTR_W3GPP_BS_USE_CHANNELS_NEEDED_FOR_SYNC                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345805
#define RSRFSIGGEN_ATTR_W3GPP_BS_USE_SCCPCH                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345806
#define RSRFSIGGEN_ATTR_W3GPP_BS_SYMBOL_RATE_SCCPCH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345807
#define RSRFSIGGEN_ATTR_W3GPP_BS_NUMBER_OF_DPCH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345808
#define RSRFSIGGEN_ATTR_W3GPP_BS_SYMBOL_RATE_DPCH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345809
#define RSRFSIGGEN_ATTR_W3GPP_BS_CREST_FACTOR                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345810
#define RSRFSIGGEN_ATTR_W3GPP_BS_PREDEFINED_SETTINGS_ACCEPT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345811
#define RSRFSIGGEN_ATTR_W3GPP_BS_CHANNEL_TYPE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345812
#define RSRFSIGGEN_ATTR_W3GPP_BS_SLOT_FORMAT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345813
#define RSRFSIGGEN_ATTR_W3GPP_BS_SYMBOL_RATE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345814
#define RSRFSIGGEN_ATTR_W3GPP_BS_CHANNELIZATION_CODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345815
#define RSRFSIGGEN_ATTR_W3GPP_BS_CHANNEL_POWER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345816
#define RSRFSIGGEN_ATTR_W3GPP_BS_DATA_SOURCE_OF_DATA_FIELDS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345817
#define RSRFSIGGEN_ATTR_W3GPP_BS_DLIST_PATTERN_DATA_LISTS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345818
#define RSRFSIGGEN_ATTR_W3GPP_BS_DLIST_PATTERN_DLIST_PATTERN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345819
#define RSRFSIGGEN_ATTR_W3GPP_BS_TIMING_OFFSET                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345820
#define RSRFSIGGEN_ATTR_W3GPP_BS_CHANNEL_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345821
#define RSRFSIGGEN_ATTR_W3GPP_BS_TFCI_FIELD_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345822
#define RSRFSIGGEN_ATTR_W3GPP_BS_TFCI_FIELD                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345823
#define RSRFSIGGEN_ATTR_W3GPP_BS_PILOT_LENGTH                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345824
#define RSRFSIGGEN_ATTR_W3GPP_BS_MULTICODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345825
#define RSRFSIGGEN_ATTR_W3GPP_BS_DYNAMIC_POWER_CONTROL_UP_RANGE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357240
#define RSRFSIGGEN_ATTR_W3GPP_BS_TPC_DATA_SOURCE_FIELD                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345826
#define RSRFSIGGEN_ATTR_W3GPP_BS_TPC_PATTERN_FIELD                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345827
#define RSRFSIGGEN_ATTR_W3GPP_BS_TPC_DATA_LISTS_SELECT_TPC_LIST                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345828
#define RSRFSIGGEN_ATTR_W3GPP_BS_TPC_READ_OUT_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345829
#define RSRFSIGGEN_ATTR_W3GPP_BS_TPC_FOR_OUTPUT_POWER_CONTROL_MISUSE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345830
#define RSRFSIGGEN_ATTR_W3GPP_BS_TPC_MISUSE_POWER_STEP                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345831
#define RSRFSIGGEN_ATTR_W3GPP_BS_FDPCH_TPC_DATA_SOURCE_FIELD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345832
#define RSRFSIGGEN_ATTR_W3GPP_BS_FDPCH_TPC_PATTERN_FIELD                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345833
#define RSRFSIGGEN_ATTR_W3GPP_BS_FDPCH_TPC_DATA_LISTS_SELECT_TPC_LIST                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345834
#define RSRFSIGGEN_ATTR_W3GPP_BS_FDPCH_TPC_READ_OUT_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345835
#define RSRFSIGGEN_ATTR_W3GPP_BS_FDPCH_TPC_FOR_OUTPUT_POWER_CONTROL_MISUSE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345836
#define RSRFSIGGEN_ATTR_W3GPP_BS_FDPCH_TPC_MISUSE_POWER_STEP                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345837
#define RSRFSIGGEN_ATTR_W3GPP_BS_DPCCH_POWER_OFFSET_PILOT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345838
#define RSRFSIGGEN_ATTR_W3GPP_BS_DPCCH_POWER_OFFSET_TPC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345839
#define RSRFSIGGEN_ATTR_W3GPP_BS_DPCCH_POWER_OFFSET_TFCI                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345840
#define RSRFSIGGEN_ATTR_W3GPP_BS_ERGCH_TYPE_OF_CELL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345841
#define RSRFSIGGEN_ATTR_W3GPP_BS_ERGCH_EDCH_TTI                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345842
#define RSRFSIGGEN_ATTR_W3GPP_BS_ERGCH_SIGNATURE_HOPPING_PATTERN_INDEX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345843
#define RSRFSIGGEN_ATTR_W3GPP_BS_ERGCH_RELATIVE_GRANT_PATTERN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345844
#define RSRFSIGGEN_ATTR_W3GPP_BS_ERGCH_TAU_DPCH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345845
#define RSRFSIGGEN_ATTR_W3GPP_BS_ERGCH_TAU_ERGCH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345846
#define RSRFSIGGEN_ATTR_W3GPP_BS_EHICH_TYPE_OF_CELL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345847
#define RSRFSIGGEN_ATTR_W3GPP_BS_EHICH_EDCH_TTI                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345848
#define RSRFSIGGEN_ATTR_W3GPP_BS_EHICH_SIGNATURE_HOPPING_PATTERN_INDEX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345849
#define RSRFSIGGEN_ATTR_W3GPP_BS_EHICH_ACK_NACK_PATTERN                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345850
#define RSRFSIGGEN_ATTR_W3GPP_BS_EHICH_TAU_DPCH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345851
#define RSRFSIGGEN_ATTR_W3GPP_BS_EHICH_TAU_EHICH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345852
#define RSRFSIGGEN_ATTR_W3GPP_BS_AICH_ACCESS_SLOT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345853
#define RSRFSIGGEN_ATTR_W3GPP_BS_AICH_SIGNATURE_ACKNACK_PATTERN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345854
#define RSRFSIGGEN_ATTR_W3GPP_BS_APAICH_ACCESS_SLOT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345855
#define RSRFSIGGEN_ATTR_W3GPP_BS_APAICH_SIGNATURE_ACKNACK_PATTERN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345856
#define RSRFSIGGEN_ATTR_W3GPP_EAGCH_INFORMATION_FIELD_CODING                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345857
#define RSRFSIGGEN_ATTR_W3GPP_EAGCH_EDCH_TTI                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345858
#define RSRFSIGGEN_ATTR_W3GPP_EAGCH_CONFIGURABLE_TTIS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345859
#define RSRFSIGGEN_ATTR_W3GPP_EAGCH_UEID                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345860
#define RSRFSIGGEN_ATTR_W3GPP_EAGCH_ABSOLUTE_GRANT_VALUE_INDEX                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345861
#define RSRFSIGGEN_ATTR_W3GPP_EAGCH_ABSOLUTE_GRANT_SCOPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345862
#define RSRFSIGGEN_ATTR_W3GPP_BS_ENH_PCPICH_PATTERN                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345863
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_MIMO_PRECODING_WEIGHT_PATTERN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345864
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_MIMO_STREAM_2_ACTIVE_PATTERN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345865
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 349944
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_INTER_TTI_DISTANCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353141
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_MIMO_MODULATION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345866
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_MIMO_CONSTELLATION_VERSION_PARAMETER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345867
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_PREDEFINED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345868
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_ADVANCED_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345869
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_SUGGESTED_ARB_SEQ_LENGTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345870
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_ADJUST_ARB_SEQUENCE_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345871
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_NAIB                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345873
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_UE_CATEGORY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345874
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_HSSCCH_TYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345875
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_BURST_MODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353142
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_CONSTELLATION_VERSION_PARAMETER_B_STATE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353143
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_PRECODING_WEIGHT_PATTERN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345876
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_DATA_SOURCE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345877
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_DATA_SOURCE_DATA_LIST                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345878
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_DATA_SOURCE_PATTERN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345879
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_UEID                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345880
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_CHANNELIZATION_CODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345881
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_RANDOMLY_VARYING_MODULATION_AND_NUMBER_OF_CODES_STATE        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353144
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_ALTERNATIVE_NUMBER_HSPDSCH_CHANNELIZATION_CODES              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353145
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_RANDOM_SEED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353146
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_ALTERNATIVE_HSPDSCH_MODULATION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353147
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_TOTAL_HSPDSCH_POWER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353148
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_HSPDSCH_CHANNELIZATION_CODES                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345882
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_START_CHANNELIZATION_CODE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345883
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_UE_SUPPORTS_64QAM                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345884
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_STREAM_2_ACTIVE_PATTERN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345885
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_HSPDSCH_MODULATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345886
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_BINARY_CHANNEL_BITS_PER_TTI                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345887
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_TBS_TABLE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345888
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_TBS_INDEX                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345889
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_TBS_REFERENCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345890
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_INFORMATION_BIT_PAYLOAD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345891
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_CODING_RATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345892
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_VIRTUAL_IR_BUFFER_SIZE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345893
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_HARQ_PROCESSES                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345894
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_SIGNALLING_PATTERN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345895
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_HARQ_MODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345896
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_REDUNDANCY_VERSION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345897
#define RSRFSIGGEN_ATTR_W3GPP_ENH_HSDPA_HS_REDUNDANCY_VERSION_SEQUENCE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345898
#define RSRFSIGGEN_ATTR_W3GPP_BS1_DPCH_ENHANCED_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 349961
#define RSRFSIGGEN_ATTR_W3GPP_BS1_TCH_INTERLEAVER_2                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 349962
#define RSRFSIGGEN_ATTR_W3GPP_BS1_CHANNEL_CODING_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 349963
#define RSRFSIGGEN_ATTR_W3GPP_BS1_CHANNEL_CODING_TYPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 349964
#define RSRFSIGGEN_ATTR_W3GPP_BS1_CHANNEL_CODING_USER_CODING_RECALL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 349965
#define RSRFSIGGEN_ATTR_W3GPP_BS1_CHANNEL_CODING_USER_CODING_SAVE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349967
#define RSRFSIGGEN_ATTR_W3GPP_BS1_SLOT_FORMAT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349969
#define RSRFSIGGEN_ATTR_W3GPP_BS1_SYMBOL_RATE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349970
#define RSRFSIGGEN_ATTR_W3GPP_BS1_BITS_PER_FRAME_DPDCH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 349971
#define RSRFSIGGEN_ATTR_W3GPP_BS1_TCH_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349972
#define RSRFSIGGEN_ATTR_W3GPP_BS1_TCH_DATA_SOURCE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349973
#define RSRFSIGGEN_ATTR_W3GPP_BS1_TCH_DATA_LIST                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 349974
#define RSRFSIGGEN_ATTR_W3GPP_BS1_TCH_PATTERN                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349975
#define RSRFSIGGEN_ATTR_W3GPP_BS1_TCH_TRANSPORT_BLOCK_SIZE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 349976
#define RSRFSIGGEN_ATTR_W3GPP_BS1_TCH_TRANSPORT_BLOCKS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 349977
#define RSRFSIGGEN_ATTR_W3GPP_BS1_TCH_RATE_MATCHING_ATTRIBUTE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349978
#define RSRFSIGGEN_ATTR_W3GPP_BS1_TCH_TRANSPORT_TIME_INTERVAL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349979
#define RSRFSIGGEN_ATTR_W3GPP_BS1_TCH_DTX_INDICATION_BITS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353149
#define RSRFSIGGEN_ATTR_W3GPP_BS1_TCH_SIZE_OF_CRC                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349980
#define RSRFSIGGEN_ATTR_W3GPP_BS1_TCH_ERROR_PROTECTION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 349981
#define RSRFSIGGEN_ATTR_W3GPP_BS1_TCH_INTERLEAVER_1                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 349982
#define RSRFSIGGEN_ATTR_W3GPP_BS1_BIT_ERROR_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 349983
#define RSRFSIGGEN_ATTR_W3GPP_BS1_BIT_ERROR_RATE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349984
#define RSRFSIGGEN_ATTR_W3GPP_BS1_INSERT_ERRORS_ON                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349985
#define RSRFSIGGEN_ATTR_W3GPP_BS1_BLOCK_ERROR_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 349986
#define RSRFSIGGEN_ATTR_W3GPP_BS1_BLOCK_ERROR_RATE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349987
#define RSRFSIGGEN_ATTR_W3GPP_BS1_DYNAMIC_POWER_CONTROL_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 349988
#define RSRFSIGGEN_ATTR_W3GPP_BS1_DYNAMIC_POWER_CONTROL_DEVIATION_VALUE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357241
#define RSRFSIGGEN_ATTR_W3GPP_BS1_DYNAMIC_POWER_CONTROL_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 349989
#define RSRFSIGGEN_ATTR_W3GPP_BS1_DYNAMIC_POWER_CONTROL_DIRECTION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349990
#define RSRFSIGGEN_ATTR_W3GPP_BS1_DYNAMIC_POWER_CONTROL_CONNECTOR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353150
#define RSRFSIGGEN_ATTR_W3GPP_BS1_DYNAMIC_POWER_CONTROL_MANUAL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349991
#define RSRFSIGGEN_ATTR_W3GPP_BS1_DYNAMIC_POWER_CONTROL_POWER_STEP                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349992
#define RSRFSIGGEN_ATTR_W3GPP_BS1_DYNAMIC_POWER_CONTROL_UP_RANGE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349993
#define RSRFSIGGEN_ATTR_W3GPP_BS1_DYNAMIC_POWER_CONTROL_DOWN_RANGE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349994
#define RSRFSIGGEN_ATTR_W3GPP_BS1_ENHANCED_PCCPCH_STATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353151
#define RSRFSIGGEN_ATTR_W3GPP_BS1_ENHANCED_PCCPCH_CHANNEL_CODING_STATE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353152
#define RSRFSIGGEN_ATTR_W3GPP_BS1_ENHANCED_PCCPCH_INTERLEAVER_1_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353153
#define RSRFSIGGEN_ATTR_W3GPP_BS1_ENHANCED_PCCPCH_INTERLEAVER_2_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353154
#define RSRFSIGGEN_ATTR_W3GPP_BS1_ENHANCED_PCCPCH_CHANNEL_CODING_TYPE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353155
#define RSRFSIGGEN_ATTR_W3GPP_UE_TEST_SETUPS_MODELS_CATALOG                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345899
#define RSRFSIGGEN_ATTR_W3GPP_UE_TEST_SETUPS_MODELS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345900
#define RSRFSIGGEN_ATTR_W3GPP_UE_ENABLED_ADDITIONAL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345901
#define RSRFSIGGEN_ATTR_W3GPP_UE_NUMBER_OF_ADDITIONAL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345902
#define RSRFSIGGEN_ATTR_W3GPP_UE_SCRAMBLING_CODE_STEP_ADDITIONAL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345903
#define RSRFSIGGEN_ATTR_W3GPP_UE_POWER_OFFSET_ADDITIONAL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345904
#define RSRFSIGGEN_ATTR_W3GPP_UE_TIME_DELAY_STEP_ADDITIONAL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345905
#define RSRFSIGGEN_ATTR_W3GPP_UE_RESET                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345906
#define RSRFSIGGEN_ATTR_W3GPP_UE_ENABLED                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345907
#define RSRFSIGGEN_ATTR_W3GPP_UE_MODE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345908
#define RSRFSIGGEN_ATTR_W3GPP_UE_SCRAMBLING_CODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345909
#define RSRFSIGGEN_ATTR_W3GPP_UE_SCRAMBLING_MODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345910
#define RSRFSIGGEN_ATTR_W3GPP_UE_TIME_DELAY                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345911
#define RSRFSIGGEN_ATTR_W3GPP_UE_REFERENCE_LEVEL                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357242
#define RSRFSIGGEN_ATTR_W3GPP_UE_COMPRESSED_MODE_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345912
#define RSRFSIGGEN_ATTR_W3GPP_UE_COMPRESSED_MODE_METHOD                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 345913
#define RSRFSIGGEN_ATTR_W3GPP_UE_COMPRESSED_MODE_POWER_OFFSET_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345914
#define RSRFSIGGEN_ATTR_W3GPP_UE_COMPRESSED_MODE_POWER_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345915
#define RSRFSIGGEN_ATTR_W3GPP_UE_COMPRESSED_MODE_SLOT_NUMBER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345916
#define RSRFSIGGEN_ATTR_W3GPP_UE_COMPRESSED_MODE_GAP_DISTANCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 345917
#define RSRFSIGGEN_ATTR_W3GPP_UE_COMPRESSED_MODE_PATTERN_LENGTH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345918
#define RSRFSIGGEN_ATTR_W3GPP_UE_COMPRESSED_MODE_GAP_LENGTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345919
#define RSRFSIGGEN_ATTR_W3GPP_UE_START_OFFSET_PRACH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345920
#define RSRFSIGGEN_ATTR_W3GPP_UE_TIME_PRE_PRE_PRACH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345921
#define RSRFSIGGEN_ATTR_W3GPP_UE_TIME_PRE_MP_PRACH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345922
#define RSRFSIGGEN_ATTR_W3GPP_UE_SEQUENCE_PERIOD_PRACH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345923
#define RSRFSIGGEN_ATTR_W3GPP_UE_PREAMBLE_POWER_PRACH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345924
#define RSRFSIGGEN_ATTR_W3GPP_UE_PREAMBLE_POWER_STEP_PRACH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345925
#define RSRFSIGGEN_ATTR_W3GPP_UE_PREAMBLE_DELTA_POWER_PRACH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353156
#define RSRFSIGGEN_ATTR_W3GPP_UE_PREAMBLE_REPETITION_PRACH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345926
#define RSRFSIGGEN_ATTR_W3GPP_UE_SIGNATURE_PRACH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345927
#define RSRFSIGGEN_ATTR_W3GPP_UE_AICH_TRANSMISSION_TIMING_PRACH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353157
#define RSRFSIGGEN_ATTR_W3GPP_UE_DATA_POWER_PRACH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345928
#define RSRFSIGGEN_ATTR_W3GPP_UE_CONTROL_POWER_PRACH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345929
#define RSRFSIGGEN_ATTR_W3GPP_UE_MESSAGE_LENGTH_PRACH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345930
#define RSRFSIGGEN_ATTR_W3GPP_UE_SLOT_FORMAT_PRACH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345931
#define RSRFSIGGEN_ATTR_W3GPP_UE_SYMBOL_RATE_PRACH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345932
#define RSRFSIGGEN_ATTR_W3GPP_UE_TFCI_PRACH                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345933
#define RSRFSIGGEN_ATTR_W3GPP_UE_DATA_SOURCE_PRACH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345934
#define RSRFSIGGEN_ATTR_W3GPP_UE_DATA_LIST_PRACH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345935
#define RSRFSIGGEN_ATTR_W3GPP_UE_PATTERN_PRACH                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345936
#define RSRFSIGGEN_ATTR_W3GPP_UE_LEVEL_CORRECTION_DELTA_POWER_PRACH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353158
#define RSRFSIGGEN_ATTR_W3GPP_UE_LEVEL_CORRECTION_MESSAGE_CONTROL_PRACH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353159
#define RSRFSIGGEN_ATTR_W3GPP_UE_LEVEL_CORRECTION_MESSAGE_DATA_PRACH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353160
#define RSRFSIGGEN_ATTR_W3GPP_UE_REPEATED_DURING_ARB_SEQUENCE_PRACH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353371
#define RSRFSIGGEN_ATTR_W3GPP_UE_REPEAT_AFTER_PRACH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353372
#define RSRFSIGGEN_ATTR_W3GPP_UE_CODING_ENABLED_PRACH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345937
#define RSRFSIGGEN_ATTR_W3GPP_UE_CODING_TYPE_PRACH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345938
#define RSRFSIGGEN_ATTR_W3GPP_UE_START_OFFSET_PCPCH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345939
#define RSRFSIGGEN_ATTR_W3GPP_UE_TIME_PRE_PRE_PCPCH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345940
#define RSRFSIGGEN_ATTR_W3GPP_UE_SEQUENCE_PERIOD_PCPCH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345942
#define RSRFSIGGEN_ATTR_W3GPP_UE_PREAMBLE_POWER_PCPCH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345943
#define RSRFSIGGEN_ATTR_W3GPP_UE_PREAMBLE_POWER_STEP_PCPCH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345944
#define RSRFSIGGEN_ATTR_W3GPP_UE_PREAMBLE_REPETITION_PCPCH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345945
#define RSRFSIGGEN_ATTR_W3GPP_UE_POWER_CONTROL_PREAMBLE_LENGTH_PCPCH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345946
#define RSRFSIGGEN_ATTR_W3GPP_UE_SIGNATURE_PCPCH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345947
#define RSRFSIGGEN_ATTR_W3GPP_UE_AICH_PREAMBLE_POWER_PCPCH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353161
#define RSRFSIGGEN_ATTR_W3GPP_UE_TIME_PREAMBLE_MESSAGE_PART_PCPCH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353163
#define RSRFSIGGEN_ATTR_W3GPP_UE_TIME_PREAMBLES_DIFFERENCE_PCPCH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353164
#define RSRFSIGGEN_ATTR_W3GPP_UE_REPEATED_DURING_ARB_SEQUENCE_PCPCH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353373
#define RSRFSIGGEN_ATTR_W3GPP_UE_REPEAT_AFTER_PCPCH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353374
#define RSRFSIGGEN_ATTR_W3GPP_UE_DATA_POWER_PCPCH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345948
#define RSRFSIGGEN_ATTR_W3GPP_UE_CONTROL_POWER_PCPCH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345949
#define RSRFSIGGEN_ATTR_W3GPP_UE_MESSAGE_LENGTH_PCPCH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345950
#define RSRFSIGGEN_ATTR_W3GPP_UE_LEVEL_CORRECTION_PCPCH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353165
#define RSRFSIGGEN_ATTR_W3GPP_UE_SLOT_FORMAT_CONTROL_PART_PCPCH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345951
#define RSRFSIGGEN_ATTR_W3GPP_UE_FBI_MODE_PCPCH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345952
#define RSRFSIGGEN_ATTR_W3GPP_UE_FBI_PATTERN_PCPCH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345953
#define RSRFSIGGEN_ATTR_W3GPP_UE_SYMBOL_RATE_PCPCH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345954
#define RSRFSIGGEN_ATTR_W3GPP_UE_DATA_SOURCE_PCPCH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345955
#define RSRFSIGGEN_ATTR_W3GPP_UE_DATA_LIST_PCPCH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345956
#define RSRFSIGGEN_ATTR_W3GPP_UE_DATA_PATTERN_PCPCH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345957
#define RSRFSIGGEN_ATTR_W3GPP_UE_TFCI_VALUE_PCPCH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345958
#define RSRFSIGGEN_ATTR_W3GPP_UE_TPC_DATA_SOURCE_PCPCH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345959
#define RSRFSIGGEN_ATTR_W3GPP_UE_TPC_DATA_LIST_PCPCH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345960
#define RSRFSIGGEN_ATTR_W3GPP_UE_TPC_PATTERN_PCPCH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345961
#define RSRFSIGGEN_ATTR_W3GPP_UE_TPC_READ_OUT_MODE_PCPCH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345962
#define RSRFSIGGEN_ATTR_W3GPP_UE_CODING_ENABLED_PCPCH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345963
#define RSRFSIGGEN_ATTR_W3GPP_UE_CODING_TYPE_PCPCH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345964
#define RSRFSIGGEN_ATTR_W3GPP_UE_POWER_DPCCH                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345965
#define RSRFSIGGEN_ATTR_W3GPP_UE_DLUL_TIMING_OFFSET_DPCCH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345966
#define RSRFSIGGEN_ATTR_W3GPP_UE_SLOT_FORMAT_DPCCH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345967
#define RSRFSIGGEN_ATTR_W3GPP_UE_USE_TFCI_DPCCH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345968
#define RSRFSIGGEN_ATTR_W3GPP_UE_TFCI_VALUE_DPCCH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345969
#define RSRFSIGGEN_ATTR_W3GPP_UE_FBI_MODE_DPCCH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345970
#define RSRFSIGGEN_ATTR_W3GPP_UE_FBI_PATTERN_DPCCH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345971
#define RSRFSIGGEN_ATTR_W3GPP_UE_DPCCH_CHANNELIZATION_CODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353166
#define RSRFSIGGEN_ATTR_W3GPP_UE_TPC_MODE_DPCCH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 345972
#define RSRFSIGGEN_ATTR_W3GPP_UE_TPC_DATA_SOURCE_DPCCH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 345973
#define RSRFSIGGEN_ATTR_W3GPP_UE_TPC_DATA_LIST_DPCCH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345974
#define RSRFSIGGEN_ATTR_W3GPP_UE_TPC_PATTERN_DPCCH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345975
#define RSRFSIGGEN_ATTR_W3GPP_UE_TPC_READ_OUT_MODE_DPCCH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 345976
#define RSRFSIGGEN_ATTR_W3GPP_UE_MISUSE_TPC_FOR_OUTPUT_POWER_CONTROL_DPCCH                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345977
#define RSRFSIGGEN_ATTR_W3GPP_UE_POWER_STEP_TPC_DPCCH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 345978
#define RSRFSIGGEN_ATTR_W3GPP_UE_ENABLED_HSDPCCH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 345979
#define RSRFSIGGEN_ATTR_W3GPP_UE_POWER_HSDPCCH                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345980
#define RSRFSIGGEN_ATTR_W3GPP_UE_START_DELAY_HSDPCCH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345981
#define RSRFSIGGEN_ATTR_W3GPP_UE_INTER_TTI_DISTANCE_HSDPCCH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345982
#define RSRFSIGGEN_ATTR_W3GPP_UE_CQI_PATTERN_LENGTH_HSDPCCH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 345983
#define RSRFSIGGEN_ATTR_W3GPP_UE_ACK_NACK_PATTERN_HSDPCCH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 345984
#define RSRFSIGGEN_ATTR_W3GPP_UE_CHANNELIZATION_CODE_HSDPCCH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357243
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345986
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_POWER_OFFSET_ACKACK                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 345987
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_POWER_OFFSET_ACKNACK                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345988
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_POWER_OFFSET_NACKACK                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345989
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_POWER_OFFSET_NACKNACK                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345990
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_NUMBER_OF_TTIS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 345991
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_RELEASE_8_MIMO_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353167
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_HARQ_ACK_REPEAT_AFTER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353168
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_HARQ_ACK_NUMBER_OF_ROWS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353169
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_POWER_OFFSET_CQI_TYPE_A                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353170
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_PCI_CQI_REPEAT_AFTER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353171
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_PCI_CQI_NUMBER_OF_ROWS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353172
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_POWER_OFFSET_ACK                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353173
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_POWER_OFFSET_NACK                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353174
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_SECONDARY_CELL_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353175
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_SECONDARY_CELL_ACTIVE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353176
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_SLOT_FORMAT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353177
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_ADJUST_ARB_SEQUENCE_LENGTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353178
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_SUGGESTED_CURRENT_ARB_SEQUENCE_LENGTH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353179
#define RSRFSIGGEN_ATTR_W3GPP_UE_CQI_VALUES_HSDPCCH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345985
#define RSRFSIGGEN_ATTR_W3GPP_HSDPCCH_MIMO_HARQACK                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345992
#define RSRFSIGGEN_ATTR_W3GPP_HSDPCCH_MIMO_PCI                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345993
#define RSRFSIGGEN_ATTR_W3GPP_HSDPCCH_MIMO_CQI_TYPE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 345994
#define RSRFSIGGEN_ATTR_W3GPP_HSDPCCH_MIMO_CQI                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345995
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_HARQ_ACK_FROM_INTERVAL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353180
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_HARQ_ACK_TO_INTERVAL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353181
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_HARQ_ACK_POWER_OFFSET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353182
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_HARQ_ACK                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353183
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_PCI_CQI_FROM_INTERVAL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353184
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_PCI_CQI_TO_INTERVAL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353185
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_PCI_CQI_POWER_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353186
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_PCI_CQI_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353187
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_PCI                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353188
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSDPCCH_MIMO_PCI_CQI_CONTENT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353189
#define RSRFSIGGEN_ATTR_W3GPP_UE_ENABLED_DPDCH                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 345996
#define RSRFSIGGEN_ATTR_W3GPP_UE_CHANNEL_POWER_DPDCH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 345997
#define RSRFSIGGEN_ATTR_W3GPP_UE_OVERALL_SYMBOL_RATE_DPDCH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 345998
#define RSRFSIGGEN_ATTR_W3GPP_UE_FORCE_CHANNELIZATION_CODE_TO_IO_DPDCH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353190
#define RSRFSIGGEN_ATTR_W3GPP_UE_SYMBOL_RATE_DPDCH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 345999
#define RSRFSIGGEN_ATTR_W3GPP_UE_CHANNELIZATION_CODE_DPDCH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346000
#define RSRFSIGGEN_ATTR_W3GPP_UE_DPDCH_DATA_SOURCE_DPDCH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346001
#define RSRFSIGGEN_ATTR_W3GPP_UE_DPDCH_PATTERN_DPDCH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346002
#define RSRFSIGGEN_ATTR_W3GPP_UE_DPDCH_DATA_LIST_DPDCH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346003
#define RSRFSIGGEN_ATTR_W3GPP_UE_DCCH_DATA_SOURCE_DPDCH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346004
#define RSRFSIGGEN_ATTR_W3GPP_UE_DCCH_PATTERN_DPDCH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346005
#define RSRFSIGGEN_ATTR_W3GPP_UE_DCCH_DATA_LIST_DPDCH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346006
#define RSRFSIGGEN_ATTR_W3GPP_UE1_CHANNEL_CODING_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346007
#define RSRFSIGGEN_ATTR_W3GPP_UE1_CHANNEL_CODING_TYPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346008
#define RSRFSIGGEN_ATTR_W3GPP_UE1_USER_CODING_CATALOG                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346009
#define RSRFSIGGEN_ATTR_W3GPP_UE1_USER_CODING_DELETE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346010
#define RSRFSIGGEN_ATTR_W3GPP_UE1_USER_CODING_RECALL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346011
#define RSRFSIGGEN_ATTR_W3GPP_UE1_USER_CODING_SAVE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346012
#define RSRFSIGGEN_ATTR_W3GPP_UE1_OVERALL_SYMBOL_RATE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346013
#define RSRFSIGGEN_ATTR_W3GPP_UE1_BITS_PER_FRAME_DPDCH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346014
#define RSRFSIGGEN_ATTR_W3GPP_UE1_INTERLEAVER_2_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346015
#define RSRFSIGGEN_ATTR_W3GPP_UE1_BS_ENHANCED_STATE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353191
#define RSRFSIGGEN_ATTR_W3GPP_UE1_DATA_SOURCE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346016
#define RSRFSIGGEN_ATTR_W3GPP_UE1_DATA_PATTERN                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346017
#define RSRFSIGGEN_ATTR_W3GPP_UE1_DATA_LIST                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346018
#define RSRFSIGGEN_ATTR_W3GPP_UE1_TRANSPORT_CHANNEL_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346019
#define RSRFSIGGEN_ATTR_W3GPP_UE1_TRANSPORT_BLOCK_SIZE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346020
#define RSRFSIGGEN_ATTR_W3GPP_UE1_TRANSPORT_BLOCKS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346021
#define RSRFSIGGEN_ATTR_W3GPP_UE1_RATE_MATCHING_ATTRIBUTE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346022
#define RSRFSIGGEN_ATTR_W3GPP_UE1_TRANSPORT_TIME_INTERVAL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346023
#define RSRFSIGGEN_ATTR_W3GPP_UE1_SIZE_OF_CRC                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346024
#define RSRFSIGGEN_ATTR_W3GPP_UE1_ERROR_PROTECTION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346025
#define RSRFSIGGEN_ATTR_W3GPP_UE1_INTERLEAVER_1_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346026
#define RSRFSIGGEN_ATTR_W3GPP_UE1_BIT_ERROR_INSERTION_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346027
#define RSRFSIGGEN_ATTR_W3GPP_UE1_BIT_ERROR_RATE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346028
#define RSRFSIGGEN_ATTR_W3GPP_UE1_INSERT_ERRORS_ON                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346029
#define RSRFSIGGEN_ATTR_W3GPP_UE1_BLOCK_ERROR_INSERTION_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346030
#define RSRFSIGGEN_ATTR_W3GPP_UE1_BLOCK_ERROR_RATE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346031
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346032
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_POWER                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346033
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_RETRANS_SEQUENCE_NUMBER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346034
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_CHANNELIZATION_CODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 354138
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_ETFCI_INFORMATION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346035
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_EDCH_TTI                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346036
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_HAPPY_BIT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346037
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_DTX_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346038
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_DTX_PATTERN                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346039
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_FRC_UE_CATEGORY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346040
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_FRC_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346041
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_FRC_DATA_SOURCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346042
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_FRC_DATA_LIST                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346043
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_FRC_PATTERN                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346044
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_FRC_OVERALL_SYMBOL_RATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346045
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_FRC_TBS_TABLE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346046
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPCCH_FRC_TBS_INDEX                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346047
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPDCH_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346048
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPDCH_CHANNEL_POWER                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346049
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPDCH_OVERALL_SYMBOL_RATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346050
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPDCH_MODULATION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346051
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPDCH_EDCH_TTI                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346052
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPDCH_FORCE_CHANNELIZATION_CODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346053
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPDCH_DTX_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346054
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPDCH_DTX_PATTERN                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346055
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPDCH_DATA_SOURCE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346056
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPDCH_PATTERN                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346057
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPDCH_DATA_LIST                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346058
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPDCH_SYMBOL_RATE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346059
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPDCH_CHANNELIZATION_CODE_AND_MODULATION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353192
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDPDCH_SELECTED_CHANNEL_POWER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353193
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDCH_TTI                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353194
#define RSRFSIGGEN_ATTR_W3GPP_UE_ULDTX_EDCH_TTI                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353195
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDCH_NUMBER_OF_TABLE_ROWS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353196
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDCH_SCHEDULE_REPEATS_AFTER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353197
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDCH_FROM_TTI                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353198
#define RSRFSIGGEN_ATTR_W3GPP_UE_EDCH_TO_TTI                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353199
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346060
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_CHANNEL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346061
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_MIBRATE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346062
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_EDCH_TTI                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346063
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_HARQ_PROCESSES                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346064
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_PAYBITS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346065
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_TTIBITS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346066
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_CODING_RATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346067
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_PHYSICAL_CHAN_CODES                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346068
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_MODULATION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346069
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_DTX_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346070
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_DTX_PATTERN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346071
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_HARQ_MODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346072
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_HARQ_FEEDBACK_SIMULATION_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346073
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_HARQ_FEEDBACK_REDUNDANCY_VERSION_0                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346074
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_HARQ_FEEDBACK_MAX_NUMBER_OF_RETRANSMISSIONS                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346075
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_HARQ_FEEDBACK_ACK_DEFINITION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346076
#define RSRFSIGGEN_ATTR_W3GPP_HSUPA_FRC_HARQ_FEEDBACK_CONNECTOR                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 349995
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_HARQ_FEEDBACK_DELAY_BETWEEN_FEEDBACK_AND_HARQ                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346077
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_HARQ_FEEDBACK_ADITIONAL_USER_DELAY                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346078
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_BIT_ERROR_INSERTION_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346079
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_BIT_ERROR_RATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353200
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_BIT_ERROR_INSERTION_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346080
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_BIT_ERROR_INSERTION_LAYER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346081
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_BLOCK_ERROR_INSERTION_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346082
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_BLOCK_ERROR_RATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353201
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_BLOCK_ERROR_INSERTION_RATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346083
#define RSRFSIGGEN_ATTR_W3GPP_UE_HSUPA_FRC_VIRTUAL_HARQ_ACKNACK                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346084
#define RSRFSIGGEN_ATTR_W3GPP_HSDPA_BIT_ERROR_INSERTION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353202
#define RSRFSIGGEN_ATTR_W3GPP_HSDPA_BIT_ERROR_RATE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353203
#define RSRFSIGGEN_ATTR_W3GPP_HSDPA_BIT_ERROR_STATE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353204
#define RSRFSIGGEN_ATTR_W3GPP_HSDPA_BLOCK_ERROR_STATE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353205
#define RSRFSIGGEN_ATTR_W3GPP_HSDPA_BLOCK_ERROR_RATE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353206
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_ENABLED                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346085
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_DPCCH_BURST_LENGTH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346086
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_DPCCH_CYCLE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346087
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_DPCCH_OFFSET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346088
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_DPCCH_PREAMBLE_LENGTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346090
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_DPCCH_POSTAMBLE_LENGTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346089
#define RSRFSIGGEN_ATTR_W3GPP_UE_ULDTX_USER_SCHEDULING_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353207
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353208
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_SCHEDULING_CATALOG                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353209
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_DELETE_FILE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353210
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_SELECT_FILE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353212
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_OFFSET                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353213
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_SCHEDULING_EDCH_TTI                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353214
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_INACTIVITY_THRESHOLD_FOR_CYCLE_2                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353215
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_LONG_PREAMBLE_LENGTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353216
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_BURST_LENGTH_1                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353217
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_BURST_LENGTH_2                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353218
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_CYCLE_1                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353219
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_CYCLE_2                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353220
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_POSTAMBLE_LENGTH_1                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353221
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_POSTAMBLE_LENGTH_2                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353222
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_PREAMBLE_LENGTH_1                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353223
#define RSRFSIGGEN_ATTR_W3GPP_UE_DTX_PREAMBLE_LENGTH_2                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353224
#define RSRFSIGGEN_ATTR_W3GPP_UE_DYNAMIC_POWER_CONTROL_ENABLE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349996
#define RSRFSIGGEN_ATTR_W3GPP_UE_DYNAMIC_POWER_CONTROL_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349997
#define RSRFSIGGEN_ATTR_W3GPP_UE_DYNAMIC_POWER_CONTROL_MANUAL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349998
#define RSRFSIGGEN_ATTR_W3GPP_UE_DYNAMIC_POWER_CONTROL_DIRECTION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349999
#define RSRFSIGGEN_ATTR_W3GPP_UE_DYNAMIC_POWER_CONTROL_CONNECTOR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353225
#define RSRFSIGGEN_ATTR_W3GPP_UE_DYNAMIC_POWER_CONTROL_POWER_STEP                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350000
#define RSRFSIGGEN_ATTR_W3GPP_UE_DYNAMIC_POWER_CONTROL_UP_RANGE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350001
#define RSRFSIGGEN_ATTR_W3GPP_UE_DYNAMIC_POWER_CONTROL_DOWN_RANGE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350002
#define RSRFSIGGEN_ATTR_W3GPP_UE_DYNAMIC_POWER_CONTROL_POWER_DEVIATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350003
#define RSRFSIGGEN_ATTR_W3GPP_UE_DYNAMIC_POWER_CONTROL_ASSIGNMENT_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350004
#define RSRFSIGGEN_ATTR_W3GPP_UE_DYNAMIC_POWER_CONTROL_ENABLE_ALL_ACTIVE_UES                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353376
#define RSRFSIGGEN_ATTR_C2K_ENABLED                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346091
#define RSRFSIGGEN_ATTR_C2K_SET_TO_DEFAULT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346092
#define RSRFSIGGEN_ATTR_C2K_VERSION                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346093
#define RSRFSIGGEN_ATTR_C2K_SPREADING_RATE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346094
#define RSRFSIGGEN_ATTR_C2K_LINK_DIRECTION                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346095
#define RSRFSIGGEN_ATTR_C2K_ADJUST_TOTAL_POWER_TO_0DB                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346096
#define RSRFSIGGEN_ATTR_C2K_TOTAL_POWER                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346097
#define RSRFSIGGEN_ATTR_C2K_SETTINGS_CATALOG                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346098
#define RSRFSIGGEN_ATTR_C2K_DELETE_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346099
#define RSRFSIGGEN_ATTR_C2K_RECALL_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346100
#define RSRFSIGGEN_ATTR_C2K_SAVE_SETTINGS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346101
#define RSRFSIGGEN_ATTR_C2K_FAST_STORE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353282
#define RSRFSIGGEN_ATTR_C2K_GENERATE_WAVEFORM_FILE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353283
#define RSRFSIGGEN_ATTR_C2K_SEQUENCE_LENGTH_ARB                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346102
#define RSRFSIGGEN_ATTR_C2K_INVERT_Q_FOR_CORRECT_BASEBAND_OUTPUT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346103
#define RSRFSIGGEN_ATTR_C2K_FILTER_TYPE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346104
#define RSRFSIGGEN_ATTR_C2K_FILTER_PARAMETER_APCO25                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346105
#define RSRFSIGGEN_ATTR_C2K_FILTER_PARAMETER_COSINE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346111
#define RSRFSIGGEN_ATTR_C2K_FILTER_PARAMETER_GAUSS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346112
#define RSRFSIGGEN_ATTR_C2K_FILTER_PARAMETER_PURE_GAUSS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353285
#define RSRFSIGGEN_ATTR_C2K_FILTER_PARAMETER_ROOT_COSINE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346115
#define RSRFSIGGEN_ATTR_C2K_FILTER_PARAMETER_SPLIT_PHASE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346117
#define RSRFSIGGEN_ATTR_C2K_FILTER_PARAMETER_LOWPASS_EVM                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346119
#define RSRFSIGGEN_ATTR_C2K_FILTER_PARAMETER_LOWPASS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353286
#define RSRFSIGGEN_ATTR_C2K_CHIP_RATE_VARIATION                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346120
#define RSRFSIGGEN_ATTR_C2K_CLIPPING_ENABLED                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346121
#define RSRFSIGGEN_ATTR_C2K_CLIPPING_LEVEL                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346122
#define RSRFSIGGEN_ATTR_C2K_CLIPPING_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346123
#define RSRFSIGGEN_ATTR_C2K_TRIGGER_STATUS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346124
#define RSRFSIGGEN_ATTR_C2K_TRIGGER_ARM                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346125
#define RSRFSIGGEN_ATTR_C2K_TRIGGER_EXECUTE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346126
#define RSRFSIGGEN_ATTR_C2K_TRIGGER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346127
#define RSRFSIGGEN_ATTR_C2K_TRIGGER_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346128
#define RSRFSIGGEN_ATTR_C2K_TRIGGER_SOURCE_LEGACY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350974
#define RSRFSIGGEN_ATTR_C2K_TRIGGER_SIGNAL_DURATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353287
#define RSRFSIGGEN_ATTR_C2K_TRIGGER_SIGNAL_DURATION_UNIT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353288
#define RSRFSIGGEN_ATTR_C2K_INTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346129
#define RSRFSIGGEN_ATTR_C2K_INTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346130
#define RSRFSIGGEN_ATTR_C2K_EXTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346131
#define RSRFSIGGEN_ATTR_C2K_EXTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346132
#define RSRFSIGGEN_ATTR_C2K_MARKER_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346133
#define RSRFSIGGEN_ATTR_C2K_MARKER_USER_PERIOD                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346134
#define RSRFSIGGEN_ATTR_C2K_MARKER_OFF_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346135
#define RSRFSIGGEN_ATTR_C2K_MARKER_ON_TIME                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346136
#define RSRFSIGGEN_ATTR_C2K_MARKER_DELAY                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346137
#define RSRFSIGGEN_ATTR_C2K_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346138
#define RSRFSIGGEN_ATTR_C2K_FIXED_MARKER_DELAY_MAXIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346139
#define RSRFSIGGEN_ATTR_C2K_FIXED_MARKER_DELAY_MINIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346140
#define RSRFSIGGEN_ATTR_C2K_CLOCK_SOURCE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346141
#define RSRFSIGGEN_ATTR_C2K_CLOCK_SOURCE_LEGACY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351000
#define RSRFSIGGEN_ATTR_C2K_CLOCK_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346142
#define RSRFSIGGEN_ATTR_C2K_CHIP_CLOCK_MULTIPLIER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346143
#define RSRFSIGGEN_ATTR_C2K_CLOCK_SYNCHRONISATION_EXECUTE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346144
#define RSRFSIGGEN_ATTR_C2K_CLOCK_SYNCHRONISATION_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346146
#define RSRFSIGGEN_ATTR_C2K_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346147
#define RSRFSIGGEN_ATTR_C2K_COPY_FROM_SOURCE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346148
#define RSRFSIGGEN_ATTR_C2K_TO_DESTINATION                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346149
#define RSRFSIGGEN_ATTR_C2K_COPY_WALSH_CODE_OFFSET                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346150
#define RSRFSIGGEN_ATTR_C2K_EXECUTE_COPY                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346151
#define RSRFSIGGEN_ATTR_C2K_BS_RESET                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353289
#define RSRFSIGGEN_ATTR_C2K_BS_ENABLED                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357244
#define RSRFSIGGEN_ATTR_C2K_BS_TIME_DELAY                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346152
#define RSRFSIGGEN_ATTR_C2K_BS_PN_OFFSET                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346153
#define RSRFSIGGEN_ATTR_C2K_BS_TRANSMIT_DIVERSITY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346154
#define RSRFSIGGEN_ATTR_C2K_BS_DIVERSITY_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346155
#define RSRFSIGGEN_ATTR_C2K_BS_QUASI_ORTH_WALSH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346156
#define RSRFSIGGEN_ATTR_C2K_BS_RESOLVE_DOMAIN_CONFLICT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346157
#define RSRFSIGGEN_ATTR_C2K_BS_DOMAIN_CONFLICT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346158
#define RSRFSIGGEN_ATTR_C2K_BS_DOMAIN_ORDER                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353290
#define RSRFSIGGEN_ATTR_C2K_BS_PREDEFINED_RADIO_CONFIGURATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346159
#define RSRFSIGGEN_ATTR_C2K_BS_USE_PILOT_FPICH                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346160
#define RSRFSIGGEN_ATTR_C2K_BS_USE_SYNC_FSYNC                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346161
#define RSRFSIGGEN_ATTR_C2K_BS_USE_PAGING_CHANNEL_FPCH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346162
#define RSRFSIGGEN_ATTR_C2K_BS_CREST_FACTOR                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346163
#define RSRFSIGGEN_ATTR_C2K_BS_PREDEFINED_SETTINGS_ACCEPT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346164
#define RSRFSIGGEN_ATTR_C2K_BS_NUMBER_OF_TRAFFIC_CHANNELS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346165
#define RSRFSIGGEN_ATTR_C2K_BS_USE_DEDICATED_CONTROL_FDCCH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346166
#define RSRFSIGGEN_ATTR_C2K_BS_USE_FUNDAMENTAL_FFCH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346167
#define RSRFSIGGEN_ATTR_C2K_BS_NUMBER_OF_SUPPLEMENTAL_FSCH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346168
#define RSRFSIGGEN_ATTR_C2K_BS_PREDEFINED_FRAME_LENGTH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346169
#define RSRFSIGGEN_ATTR_C2K_BS_PREDEFINED_DATA_RATE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346170
#define RSRFSIGGEN_ATTR_C2K_BS_REAL_TIME_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346171
#define RSRFSIGGEN_ATTR_C2K_BS_CHANNEL_TYPE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346172
#define RSRFSIGGEN_ATTR_C2K_BS_RADIO_CONFIGURATION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346173
#define RSRFSIGGEN_ATTR_C2K_BS_FRAME_LENGTH                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346174
#define RSRFSIGGEN_ATTR_C2K_BS_DATA_RATE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346175
#define RSRFSIGGEN_ATTR_C2K_BS_WALSH                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346176
#define RSRFSIGGEN_ATTR_C2K_BS_Q_ORTH_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346177
#define RSRFSIGGEN_ATTR_C2K_BS_CHANNEL_POWER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346178
#define RSRFSIGGEN_ATTR_C2K_BS_CHANNEL_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357245
#define RSRFSIGGEN_ATTR_C2K_BS_DATA                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346179
#define RSRFSIGGEN_ATTR_C2K_BS_DLIST_PATTERN_DATA_LIST                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346180
#define RSRFSIGGEN_ATTR_C2K_BS_DLIST_PATTERN_PATTERN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346181
#define RSRFSIGGEN_ATTR_C2K_BS_WALSH_LENGTH                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346182
#define RSRFSIGGEN_ATTR_C2K_BS_LC_MASK_HEX                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346183
#define RSRFSIGGEN_ATTR_C2K_BS_POWER_CONTROL_DATA_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346184
#define RSRFSIGGEN_ATTR_C2K_BS_POWER_CONTROL_DATA_LIST                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346185
#define RSRFSIGGEN_ATTR_C2K_BS_POWER_CONTROL_PATTERN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346186
#define RSRFSIGGEN_ATTR_C2K_BS_POWER_CONTROL_READ_OUT_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346187
#define RSRFSIGGEN_ATTR_C2K_BS_MISUSE_FOR_OUTPUT_POWER_CONTROL_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346188
#define RSRFSIGGEN_ATTR_C2K_BS_POWER_CONTROL_POWER_STEP                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346189
#define RSRFSIGGEN_ATTR_C2K_BS_CHANNEL_CODING_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346190
#define RSRFSIGGEN_ATTR_C2K_BS_EFFECTIVE_DATA_RATE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346191
#define RSRFSIGGEN_ATTR_C2K_BS_SOURCE_BITS_PER_FRAME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346192
#define RSRFSIGGEN_ATTR_C2K_BS_CRC_LENGTH                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346193
#define RSRFSIGGEN_ATTR_C2K_BS_CODER_TYPE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346194
#define RSRFSIGGEN_ATTR_C2K_BS_SYMBOL_REPETITION                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346195
#define RSRFSIGGEN_ATTR_C2K_BS_SYMBOL_PUNCTURE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350141
#define RSRFSIGGEN_ATTR_C2K_BS_BLOCK_INTERLEAVER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346197
#define RSRFSIGGEN_ATTR_C2K_BS_BIT_ERROR_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346198
#define RSRFSIGGEN_ATTR_C2K_BS_BIT_ERROR_RATE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346199
#define RSRFSIGGEN_ATTR_C2K_BS_BLOCK_ERROR_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346200
#define RSRFSIGGEN_ATTR_C2K_BS_BLOCK_ERROR_RATE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346201
#define RSRFSIGGEN_ATTR_C2K_BS_PACKET_INTERVAL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346202
#define RSRFSIGGEN_ATTR_C2K_BS_WALSH_CODE_COLUMN_INDEX                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346203
#define RSRFSIGGEN_ATTR_C2K_BS_SAME_PACKET_SETUP_FOR_ALL_SUBPACKETS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346204
#define RSRFSIGGEN_ATTR_C2K_BS_SUBPACKET_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346205
#define RSRFSIGGEN_ATTR_C2K_BS_SPID                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346206
#define RSRFSIGGEN_ATTR_C2K_BS_SUBPACKET_TIME_SLOT_OFFSET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346207
#define RSRFSIGGEN_ATTR_C2K_BS_SUBPACKET_PARAMETERS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346208
#define RSRFSIGGEN_ATTR_C2K_BS_SUBPACKET_WELSH_CODES                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357246
#define RSRFSIGGEN_ATTR_C2K_BS_SYNC_ADDITIONAL_CHANNEL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346209
#define RSRFSIGGEN_ATTR_C2K_BS_SYNC_PROTOCOL_REVISION_LEVEL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346210
#define RSRFSIGGEN_ATTR_C2K_BS_SYNC_MINIMUM_PROTOCOL_REVISION_LEVEL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346211
#define RSRFSIGGEN_ATTR_C2K_BS_SYNC_NETWORK_IDENTIFICATION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346212
#define RSRFSIGGEN_ATTR_C2K_BS_SYNC_SYSTEM_IDENTIFICATION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346213
#define RSRFSIGGEN_ATTR_C2K_BS_SYNC_LC_STATE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353291
#define RSRFSIGGEN_ATTR_C2K_BS_SYNC_SYSTEM_TIME                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353292
#define RSRFSIGGEN_ATTR_C2K_MS_RESET                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346214
#define RSRFSIGGEN_ATTR_C2K_MS_ENABLED_ADDITIONAL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346215
#define RSRFSIGGEN_ATTR_C2K_MS_NUMBER_OF_ADDITIONAL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346216
#define RSRFSIGGEN_ATTR_C2K_MS_LC_MASK_STEP_ADDITIONAL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346217
#define RSRFSIGGEN_ATTR_C2K_MS_POWER_OFFSET_ADDITIONAL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346218
#define RSRFSIGGEN_ATTR_C2K_MS_TIME_DELAY_STEP_ADDITIONAL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346219
#define RSRFSIGGEN_ATTR_C2K_MS_ENABLED                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346220
#define RSRFSIGGEN_ATTR_C2K_MS_RADIO_CONFIGURATION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346221
#define RSRFSIGGEN_ATTR_C2K_MS_CHANNEL_CODING                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346222
#define RSRFSIGGEN_ATTR_C2K_MS_OPERATION_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346223
#define RSRFSIGGEN_ATTR_C2K_MS_LC_MASK_HEX                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346224
#define RSRFSIGGEN_ATTR_C2K_MS_POWER_CONTROL_DATA_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346225
#define RSRFSIGGEN_ATTR_C2K_MS_POWER_CONTROL_DATA_LIST                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346226
#define RSRFSIGGEN_ATTR_C2K_MS_POWER_CONTROL_PATTERN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346227
#define RSRFSIGGEN_ATTR_C2K_MS_POWER_CONTROL_READ_OUT_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346228
#define RSRFSIGGEN_ATTR_C2K_MS_MISUSE_FOR_OUTPUT_POWER_CONTROL_STATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346229
#define RSRFSIGGEN_ATTR_C2K_MS_POWER_CONTROL_POWER_STEP                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346230
#define RSRFSIGGEN_ATTR_C2K_MS_CHANNEL_TYPE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346231
#define RSRFSIGGEN_ATTR_C2K_MS_FRAME_LENGTH                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346232
#define RSRFSIGGEN_ATTR_C2K_MS_DATA_RATE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346233
#define RSRFSIGGEN_ATTR_C2K_MS_WALSH                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346234
#define RSRFSIGGEN_ATTR_C2K_MS_SPREAD                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346235
#define RSRFSIGGEN_ATTR_C2K_MS_CHANNEL_POWER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346236
#define RSRFSIGGEN_ATTR_C2K_MS_DATA                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346237
#define RSRFSIGGEN_ATTR_C2K_MS_DLIST_PATTERN_DATA_LIST                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346238
#define RSRFSIGGEN_ATTR_C2K_MS_DLIST_PATTERN_PATTERN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346239
#define RSRFSIGGEN_ATTR_C2K_MS_CHANNEL_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346240
#define RSRFSIGGEN_ATTR_TDSCDMA_ENABLED                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346241
#define RSRFSIGGEN_ATTR_TDSCDMA_SET_TO_DEFAULT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346242
#define RSRFSIGGEN_ATTR_TDSCDMA_GENERATE_WAVEFORM_FILE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346243
#define RSRFSIGGEN_ATTR_TDSCDMA_VERSION                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346244
#define RSRFSIGGEN_ATTR_TDSCDMA_CHIP_RATE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346245
#define RSRFSIGGEN_ATTR_TDSCDMA_LINK_DIRECTION                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346246
#define RSRFSIGGEN_ATTR_TDSCDMA_SETTINGS_CATALOG                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346247
#define RSRFSIGGEN_ATTR_TDSCDMA_DELETE_SETTINGS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346248
#define RSRFSIGGEN_ATTR_TDSCDMA_RECALL_SETTINGS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346249
#define RSRFSIGGEN_ATTR_TDSCDMA_SAVE_SETTINGS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346250
#define RSRFSIGGEN_ATTR_TDSCDMA_SETTINGS_TEST_MODEL_CATALOG                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346251
#define RSRFSIGGEN_ATTR_TDSCDMA_SETTINGS_TEST_MODEL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346252
#define RSRFSIGGEN_ATTR_TDSCDMA_SEQUENCE_LENGTH_ARB                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346253
#define RSRFSIGGEN_ATTR_TDSCDMA_FILTER_TYPE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346254
#define RSRFSIGGEN_ATTR_TDSCDMA_FILTER_PARAMETER_ROOT_COSINE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346255
#define RSRFSIGGEN_ATTR_TDSCDMA_FILTER_PARAMETER_COSINE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346256
#define RSRFSIGGEN_ATTR_TDSCDMA_FILTER_PARAMETER_PURE_GAUSS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346257
#define RSRFSIGGEN_ATTR_TDSCDMA_FILTER_PARAMETER_GAUSS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346258
#define RSRFSIGGEN_ATTR_TDSCDMA_FILTER_PARAMETER_APCO25                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346259
#define RSRFSIGGEN_ATTR_TDSCDMA_FILTER_PARAMETER_SPLIT_PHASE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346260
#define RSRFSIGGEN_ATTR_TDSCDMA_FILTER_PARAMETER_LOWPASS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346261
#define RSRFSIGGEN_ATTR_TDSCDMA_FILTER_PARAMETER_LOWPASS_EVM                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346262
#define RSRFSIGGEN_ATTR_TDSCDMA_CHIP_RATE_VARIATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346263
#define RSRFSIGGEN_ATTR_TDSCDMA_FILTER_IMPULSE_LENGTH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353025
#define RSRFSIGGEN_ATTR_TDSCDMA_FILTER_IMPULSE_LENGTH_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353026
#define RSRFSIGGEN_ATTR_TDSCDMA_FILTER_OVERSAMPLING_FACTOR_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353027
#define RSRFSIGGEN_ATTR_TDSCDMA_FILTER_OVERSAMPLING_FACTOR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353028
#define RSRFSIGGEN_ATTR_TDSCDMA_CLIPPING_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346264
#define RSRFSIGGEN_ATTR_TDSCDMA_CLIPPING_LEVEL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346265
#define RSRFSIGGEN_ATTR_TDSCDMA_CLIPPING_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346266
#define RSRFSIGGEN_ATTR_TDSCDMA_RAMP_FUNCTION                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346267
#define RSRFSIGGEN_ATTR_TDSCDMA_RAMP_TIME                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346268
#define RSRFSIGGEN_ATTR_TDSCDMA_RAMP_RISE_DELAY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346269
#define RSRFSIGGEN_ATTR_TDSCDMA_RAMP_FALL_DELAY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346270
#define RSRFSIGGEN_ATTR_TDSCDMA_IN_BASEBAND_ONLY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346271
#define RSRFSIGGEN_ATTR_TDSCDMA_TRIGGER_STATUS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346272
#define RSRFSIGGEN_ATTR_TDSCDMA_TRIGGER_ARM                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346273
#define RSRFSIGGEN_ATTR_TDSCDMA_TRIGGER_EXECUTE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346274
#define RSRFSIGGEN_ATTR_TDSCDMA_TRIGGER_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346275
#define RSRFSIGGEN_ATTR_TDSCDMA_TRIGGER_SOURCE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346276
#define RSRFSIGGEN_ATTR_TDSCDMA_TRIGGER_SOURCE_LEGACY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350976
#define RSRFSIGGEN_ATTR_TDSCDMA_TRIGGER_SIGNAL_DURATION_UNIT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346277
#define RSRFSIGGEN_ATTR_TDSCDMA_TRIGGER_SIGNAL_DURATION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346278
#define RSRFSIGGEN_ATTR_TDSCDMA_INTERNAL_TRIGGER_DELAY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346279
#define RSRFSIGGEN_ATTR_TDSCDMA_INTERNAL_TRIGGER_INHIBIT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346280
#define RSRFSIGGEN_ATTR_TDSCDMA_EXTERNAL_TRIGGER_DELAY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346281
#define RSRFSIGGEN_ATTR_TDSCDMA_EXTERNAL_TRIGGER_INHIBIT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346282
#define RSRFSIGGEN_ATTR_TDSCDMA_MARKER_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346283
#define RSRFSIGGEN_ATTR_TDSCDMA_MARKER_USER_PERIOD                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346284
#define RSRFSIGGEN_ATTR_TDSCDMA_MARKER_OFF_TIME                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346285
#define RSRFSIGGEN_ATTR_TDSCDMA_MARKER_ON_TIME                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346286
#define RSRFSIGGEN_ATTR_TDSCDMA_MARKER_DELAY                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346287
#define RSRFSIGGEN_ATTR_TDSCDMA_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346288
#define RSRFSIGGEN_ATTR_TDSCDMA_CLOCK_SOURCE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346289
#define RSRFSIGGEN_ATTR_TDSCDMA_CLOCK_SOURCE_LEGACY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351002
#define RSRFSIGGEN_ATTR_TDSCDMA_CLOCK_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346290
#define RSRFSIGGEN_ATTR_TDSCDMA_CHIP_CLOCK_MULTIPLIER                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346291
#define RSRFSIGGEN_ATTR_TDSCDMA_CLOCK_SYNCHRONISATION_EXECUTE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346292
#define RSRFSIGGEN_ATTR_TDSCDMA_CLOCK_SYNCHRONISATION_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346293
#define RSRFSIGGEN_ATTR_TDSCDMA_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346294
#define RSRFSIGGEN_ATTR_TDSCDMA_RESET_ALL_CELLS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346295
#define RSRFSIGGEN_ATTR_TDSCDMA_ADJUST_TOTAL_POWER_TO_0DB                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346296
#define RSRFSIGGEN_ATTR_TDSCDMA_TOTAL_POWER                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346297
#define RSRFSIGGEN_ATTR_TDSCDMA_USE_PCCPCH                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346298
#define RSRFSIGGEN_ATTR_TDSCDMA_SPREADING_FACTOR_DEDICATED_CHANNELS_DL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360323
#define RSRFSIGGEN_ATTR_TDSCDMA_SPREADING_FACTOR_DEDICATED_CHANNELS_UL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360324
#define RSRFSIGGEN_ATTR_TDSCDMA_NUMBER_OF_DEDICATED_CHANNELS_DL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360325
#define RSRFSIGGEN_ATTR_TDSCDMA_NUMBER_OF_DEDICATED_CHANNELS_UL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360326
#define RSRFSIGGEN_ATTR_TDSCDMA_CREST_FACTOR_DL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360327
#define RSRFSIGGEN_ATTR_TDSCDMA_CREST_FACTOR_UL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360328
#define RSRFSIGGEN_ATTR_TDSCDMA_PREDEFINED_SETTINGS_ACCEPT_DL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360329
#define RSRFSIGGEN_ATTR_TDSCDMA_PREDEFINED_SETTINGS_ACCEPT_UL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360330
#define RSRFSIGGEN_ATTR_TDSCDMA_COPY_CELL_FROM_SOURCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346303
#define RSRFSIGGEN_ATTR_TDSCDMA_COPY_CELL_TO_DESTINATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346304
#define RSRFSIGGEN_ATTR_TDSCDMA_CELL_COPY_EXECUTE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346305
#define RSRFSIGGEN_ATTR_TDSCDMA_DWPTS_POWER                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346306
#define RSRFSIGGEN_ATTR_TDSCDMA_UPPTS_POWER                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346307
#define RSRFSIGGEN_ATTR_TDSCDMA_DWPTS_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352902
#define RSRFSIGGEN_ATTR_TDSCDMA_UPPTS_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352903
#define RSRFSIGGEN_ATTR_TDSCDMA_CELL_ENABLE_DL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360331
#define RSRFSIGGEN_ATTR_TDSCDMA_CELL_ENABLE_UL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360332
#define RSRFSIGGEN_ATTR_TDSCDMA_USE_SCRAMBLING_CODE_DL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360333
#define RSRFSIGGEN_ATTR_TDSCDMA_USE_SCRAMBLING_CODE_UL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360334
#define RSRFSIGGEN_ATTR_TDSCDMA_SCRAMBLING_CODE_DL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360335
#define RSRFSIGGEN_ATTR_TDSCDMA_SCRAMBLING_CODE_UL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360336
#define RSRFSIGGEN_ATTR_TDSCDMA_BASIC_MIDAMBLE_CODE_ID_DL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360337
#define RSRFSIGGEN_ATTR_TDSCDMA_BASIC_MIDAMBLE_CODE_ID_UL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360338
#define RSRFSIGGEN_ATTR_TDSCDMA_SYNC_DL_CODE_DL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360339
#define RSRFSIGGEN_ATTR_TDSCDMA_SYNC_DL_CODE_UL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360340
#define RSRFSIGGEN_ATTR_TDSCDMA_PHASE_ROTATION_DL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360341
#define RSRFSIGGEN_ATTR_TDSCDMA_PHASE_ROTATION_UL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360342
#define RSRFSIGGEN_ATTR_TDSCDMA_SYNC_UL_CODE_DL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360343
#define RSRFSIGGEN_ATTR_TDSCDMA_SYNC_UL_CODE_UL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360344
#define RSRFSIGGEN_ATTR_TDSCDMA_NUMBER_OF_USERS_DL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360345
#define RSRFSIGGEN_ATTR_TDSCDMA_NUMBER_OF_USERS_UL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360346
#define RSRFSIGGEN_ATTR_TDSCDMA_SWITCHING_POINT_DL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360347
#define RSRFSIGGEN_ATTR_TDSCDMA_SWITCHING_POINT_UL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360348
#define RSRFSIGGEN_ATTR_TDSCDMA_TIME_DELAY_DL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360349
#define RSRFSIGGEN_ATTR_TDSCDMA_TIME_DELAY_UL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360350
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_CODING_TYPE_DOWNLINK                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346318
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_CODING_TYPE_UPLINK                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346319
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_ENABLE_DL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360351
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_ENABLE_UL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360352
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_NUMBER_OF_TIME_SLOTS_DL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360353
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_NUMBER_OF_TIME_SLOTS_UL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360354
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_NUMBER_OF_CHANNELS_DL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360355
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_NUMBER_OF_CHANNELS_UL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360356
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_RESOURCE_UNITS_ON_PHYSICAL_LAYER_DL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360357
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_RESOURCE_UNITS_ON_PHYSICAL_LAYER_UL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360358
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_SLOT_FORMAT_DL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360359
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_SLOT_FORMAT_UL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360360
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_DATA_BITS_PER_FRAME_10MS_DL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360361
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_DATA_BITS_PER_FRAME_10MS_UL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360362
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_CHANNEL_ENABLE_DL_DTCH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360363
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_CHANNEL_ENABLE_DL_DCCH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360364
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_CHANNEL_ENABLE_UL_DTCH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360365
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_CHANNEL_ENABLE_UL_DCCH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360366
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_CHANNEL_DATA_SOURCE_DL_DTCH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360367
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_CHANNEL_DATA_SOURCE_DL_DCCH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360368
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_CHANNEL_DATA_SOURCE_UL_DTCH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360369
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_CHANNEL_DATA_SOURCE_UL_DCCH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360370
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_CHANNEL_DATA_PATTERN_DL_DTCH                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360371
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_CHANNEL_DATA_PATTERN_DL_DCCH                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360372
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_CHANNEL_DATA_PATTERN_UL_DTCH                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360373
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_CHANNEL_DATA_PATTERN_UL_DCCH                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360374
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_CHANNEL_DATA_LIST_DL_DTCH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360375
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_CHANNEL_DATA_LIST_DL_DCCH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360376
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_CHANNEL_DATA_LIST_UL_DTCH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360377
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_CHANNEL_DATA_LIST_UL_DCCH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360378
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_TIME_INTERVAL_DL_DTCH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360379
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_TIME_INTERVAL_DL_DCCH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360380
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_TIME_INTERVAL_UL_DTCH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360381
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_TIME_INTERVAL_UL_DCCH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360382
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_BLOCKS_DL_DTCH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360383
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_BLOCKS_DL_DCCH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360384
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_BLOCKS_UL_DTCH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360385
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_BLOCKS_UL_DCCH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360386
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_BLOCK_SIZE_DL_DTCH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360387
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_BLOCK_SIZE_DL_DCCH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360388
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_BLOCK_SIZE_UL_DTCH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360389
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_BLOCK_SIZE_UL_DCCH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360390
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_SIZE_OF_CRC_DL_DTCH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360391
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_SIZE_OF_CRC_DL_DCCH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360392
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_SIZE_OF_CRC_UL_DTCH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360393
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_SIZE_OF_CRC_UL_DCCH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360394
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_RATE_MATCHING_ATTRIBUTE_DL_DTCH                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360395
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_RATE_MATCHING_ATTRIBUTE_DL_DCCH                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360396
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_RATE_MATCHING_ATTRIBUTE_UL_DTCH                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360397
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_RATE_MATCHING_ATTRIBUTE_UL_DCCH                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360398
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_ERROR_PROTECTION_DL_DTCH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360399
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_ERROR_PROTECTION_DL_DCCH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360400
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_ERROR_PROTECTION_UL_DTCH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360401
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_ERROR_PROTECTION_UL_DCCH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360402
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_INTERLEAVER1_ENABLE_DL_DTCH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360403
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_INTERLEAVER1_ENABLE_DL_DCCH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360404
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_INTERLEAVER1_ENABLE_UL_DTCH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360405
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_INTERLEAVER1_ENABLE_UL_DCCH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360406
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_INTERLEAVER2_ENABLE_DL_DTCH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360407
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_INTERLEAVER2_ENABLE_DL_DCCH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360408
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_INTERLEAVER2_ENABLE_UL_DTCH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360409
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_TRANSPORT_INTERLEAVER2_ENABLE_UL_DCCH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360410
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_SPREADING_CODE_SELECTION_DL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360411
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_SPREADING_CODE_SELECTION_UL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360412
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_MAPPING_ON_PHYSICAL_CHANNELS_DL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360413
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_MAPPING_ON_PHYSICAL_CHANNELS_UL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360414
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_BIT_ERROR_INSERTION_ENABLE_DL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360415
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_BIT_ERROR_INSERTION_ENABLE_UL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360416
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_BIT_ERROR_RATE_DL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360417
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_BIT_ERROR_RATE_UL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360418
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_INSERT_ERRORS_ON_DL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360419
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_INSERT_ERRORS_ON_UL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360420
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_BLOCK_ERROR_INSERTION_ENABLE_DL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360421
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_BLOCK_ERROR_INSERTION_ENABLE_UL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360422
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_BLOCK_ERROR_RATE_DL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360423
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_BLOCK_ERROR_RATE_UL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360424
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSCH_REDUNDANCY_VERSION_PAR_DL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360425
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSCH_REDUNDANCY_VERSION_PAR_UL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360426
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSCH_PRIORISATION_DL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360427
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSCH_PRIORISATION_UL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360428
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSCH_PUNCTURING_DL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360429
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSCH_PUNCTURING_UL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360430
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSCH_CONSTELLATION_DL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360431
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSCH_CONSTELLATION_UL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360432
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_RMC_CONFIGURATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346349
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSUPA_EDCH_FRC                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346350
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSSCCH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346351
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_UEID_HRNTI                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346352
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_VIRTUAL_IR_BUFFER_SIZE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346353
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_INTER_TTI_DISTANCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346354
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_SIGNALING_PATTERN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346355
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSUPA_NUMBER_OF_EUCCH_PER_TTI                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346356
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_TRANSPORT_BLOCK_SIZE_TABLE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346357
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSUPA_TRANSPORT_BLOCK_SIZE_TABLE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346358
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSUPA_SPREADING_FACTOR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346359
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSUPA_RETRANSMISSION_SEQUENCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346360
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSUPA_RETRANSMISSION_SEQUENCE_NUMBER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346361
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_UE_CATEGORY_DL_HSDPA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360433
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_UE_CATEGORY_DL_HSUPA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360434
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_UE_CATEGORY_UL_HSDPA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360435
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_UE_CATEGORY_UL_HSUPA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360436
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_MAXIMUM_INFORMATION_BIT_THROUGHPUT_DL_HSDPA             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360437
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_MAXIMUM_INFORMATION_BIT_THROUGHPUT_DL_HSUPA             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360438
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_MAXIMUM_INFORMATION_BIT_THROUGHPUT_UL_HSDPA             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360439
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_MAXIMUM_INFORMATION_BIT_THROUGHPUT_UL_HSUPA             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360440
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_NUMBER_OF_TIME_SLOTS_DL_HSDPA                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360441
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_NUMBER_OF_TIME_SLOTS_DL_HSUPA                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360442
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_NUMBER_OF_TIME_SLOTS_UL_HSDPA                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360443
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_NUMBER_OF_TIME_SLOTS_UL_HSUPA                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360444
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_NUMBER_OF_CODES_PER_TS_DL_HSDPA                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360445
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_NUMBER_OF_CODES_PER_TS_DL_HSUPA                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360446
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_NUMBER_OF_CODES_PER_TS_UL_HSDPA                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360447
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_NUMBER_OF_CODES_PER_TS_UL_HSUPA                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360448
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_DATA_SOURCE_DL_HSDPA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360449
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_DATA_SOURCE_DL_HSUPA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360450
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_DATA_SOURCE_UL_HSDPA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360451
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_DATA_SOURCE_UL_HSUPA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360452
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_DATA_PATTERN_DL_HSDPA                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360453
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_DATA_PATTERN_DL_HSUPA                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360454
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_DATA_PATTERN_UL_HSDPA                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360455
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_DATA_PATTERN_UL_HSUPA                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360456
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_DATA_LIST_DL_HSDPA                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360457
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_DATA_LIST_DL_HSUPA                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360458
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_DATA_LIST_UL_HSDPA                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360459
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_DATA_LIST_UL_HSUPA                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360460
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_MODULATION_DL_HSDPA                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360461
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_MODULATION_DL_HSUPA                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360462
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_MODULATION_UL_HSDPA                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360463
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_MODULATION_UL_HSUPA                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360464
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_NUMBER_OF_CODED_BITS_PER_TTI_DL_HSDPA                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360465
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_NUMBER_OF_CODED_BITS_PER_TTI_DL_HSUPA                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360466
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_NUMBER_OF_CODED_BITS_PER_TTI_UL_HSDPA                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360467
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_NUMBER_OF_CODED_BITS_PER_TTI_UL_HSUPA                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360468
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_TRANSMISSION_TIME_INTERVAL_DL_HSDPA                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360469
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_TRANSMISSION_TIME_INTERVAL_DL_HSUPA                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360470
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_TRANSMISSION_TIME_INTERVAL_UL_HSDPA                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360471
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_TRANSMISSION_TIME_INTERVAL_UL_HSUPA                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360472
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_TRANSPORT_BLOCK_SIZE_INDEX_DL_HSDPA                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360473
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_TRANSPORT_BLOCK_SIZE_INDEX_DL_HSUPA                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360474
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_TRANSPORT_BLOCK_SIZE_INDEX_UL_HSDPA                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360475
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_TRANSPORT_BLOCK_SIZE_INDEX_UL_HSUPA                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360476
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_INFORMATION_BIT_PAYLOAD_DL_HSDPA                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360477
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_INFORMATION_BIT_PAYLOAD_DL_HSUPA                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360478
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_INFORMATION_BIT_PAYLOAD_UL_HSDPA                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360479
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_INFORMATION_BIT_PAYLOAD_UL_HSUPA                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360480
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_CODING_RATE_DL_HSDPA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360481
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_CODING_RATE_DL_HSUPA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360482
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_CODING_RATE_UL_HSDPA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360483
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_CODING_RATE_UL_HSUPA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360484
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_NUMBER_OF_HARQ_PROCESSES_DL_HSDPA                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360485
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_NUMBER_OF_HARQ_PROCESSES_DL_HSUPA                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360486
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_NUMBER_OF_HARQ_PROCESSES_UL_HSDPA                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360487
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_NUMBER_OF_HARQ_PROCESSES_UL_HSUPA                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360488
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_HARQ_MODE_DL_HSDPA                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360489
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_HARQ_MODE_DL_HSUPA                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360490
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_HARQ_MODE_UL_HSDPA                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360491
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_HARQ_MODE_UL_HSUPA                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360492
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_REDUNDANCY_VERSION_PARAMETER_DL_HSDPA                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360493
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_REDUNDANCY_VERSION_PARAMETER_DL_HSUPA                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360494
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_REDUNDANCY_VERSION_PARAMETER_UL_HSDPA                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360495
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_REDUNDANCY_VERSION_PARAMETER_UL_HSUPA                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360496
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_REDUNDANCY_VERSION_SEQUENCE_DL_HSDPA                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360497
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_REDUNDANCY_VERSION_SEQUENCE_DL_HSUPA                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360498
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_REDUNDANCY_VERSION_SEQUENCE_UL_HSDPA                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360499
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_REDUNDANCY_VERSION_SEQUENCE_UL_HSUPA                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360500
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_SLOT_FORMAT_DL_HSDPA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360501
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_SLOT_FORMAT_DL_HSUPA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360502
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_SLOT_FORMAT_UL_HSDPA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360503
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSDPA_HSUPA_SLOT_FORMAT_UL_HSUPA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360504
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_PLCCH_SYNC_SHIFT_PATTERN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346380
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_PLCCH_TPC_PATTERN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346381
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_PLCCH_TTI                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346382
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSSICH_CQI_MODULATION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346383
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSSICH_CQI_VALUE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346384
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSSICH_ACK_NAK_PATTERN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346385
#define RSRFSIGGEN_ATTR_TDSCDMA_DCH_HSSICH_TTI                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346386
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_ENABLE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346387
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_CODING_TYPE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346388
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_SLOT_FORMAT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346389
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_DATA_BITS_PER_FRAME_10MS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346390
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_TRANSPORT_CHANNEL_ENABLE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346391
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_TRANSPORT_CHANNEL_DATA_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346392
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_TRANSPORT_CHANNEL_DATA_PATTERN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346393
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_TRANSPORT_CHANNEL_DATA_LIST                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346394
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_TRANSPORT_TIME_INTERVAL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346395
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_TRANSPORT_BLOCKS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346396
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_TRANSPORT_BLOCKS_SIZE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346397
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_TRANSPORT_SIZE_OF_CRC                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346398
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_TRANSPORT_RATE_MATCHING_ATTRIBUTE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346399
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_TRANSPORT_ERROR_PROTECTION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346400
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_TRANSPORT_INTERLEAVER1_ENABLE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346401
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_TRANSPORT_INTERLEAVER2_ENABLE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346402
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_SPREADING_CODE_SELECTION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346403
#define RSRFSIGGEN_ATTR_TDSCDMA_BCH_MAPPING_ON_PHYSICAL_CHANNELS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352904
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_IN_THE_SUBFRAME_ENABLE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346404
#define RSRFSIGGEN_ATTR_TDSCDMA_UPLINK_SLOT_IN_THE_SUBFRAME_ENABLE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353029
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_CONFLICT_DOWNLINK                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346405
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_CONFLICT_UPLINK                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346406
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_CHANNEL_TYPE_DL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360505
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_CHANNEL_TYPE_UL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360506
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_ENHANCED_DL                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360507
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_ENHANCED_UL                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360508
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_CRT_USER_MIDAMBLE_SHIFT_DL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360509
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_CRT_USER_MIDAMBLE_SHIFT_UL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360510
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_MIDAMBLE_SHIFT_DL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360511
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_MIDAMBLE_SHIFT_UL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360512
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_FMT_DL                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360513
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_FMT_UL                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360514
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_SPREADING_FACTOR_DL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360515
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_SPREADING_FACTOR_UL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360516
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_SPREADING_CODE_DL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360517
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_SPREADING_CODE_UL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360518
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_POWER_DL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360519
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_POWER_UL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360520
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_DATA_SOURCE_DL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360521
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_DATA_SOURCE_UL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360522
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_DATA_PATTERN_DL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360523
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_DATA_PATTERN_UL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360524
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_DATA_LIST_DL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360525
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_DATA_LIST_UL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360526
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_CHANNEL_ENABLE_DL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360527
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_CHANNEL_ENABLE_UL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360528
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_EUCCH_CHANNELS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346419
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_EUCCH_ETFCI_VALUE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346420
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_EUCCH_RETRANSMISSION_SEQUENCE_NUMBER                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346421
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_EUCCH_HARQ_PROCESS_ID                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346422
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_NUMBER_OF_TFCI_BITS_DL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360529
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_NUMBER_OF_TFCI_BITS_UL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360530
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_TFCI_VALUE_DL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360531
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_TFCI_VALUE_UL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360532
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_NUMBER_OF_SYNC_SHIFT_TPC_BITS_DL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360533
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_NUMBER_OF_SYNC_SHIFT_TPC_BITS_UL                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360534
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_SYNC_SHIFT_PATTERN_DL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360535
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_SYNC_SHIFT_PATTERN_UL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360536
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_SYNC_SHIFT_REPETITION_M_DL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360537
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_SYNC_SHIFT_REPETITION_M_UL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360538
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_TPC_SOURCE_DL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360539
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_TPC_SOURCE_UL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360540
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_TPC_SOURCE_PATTERN_DL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360541
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_TPC_SOURCE_PATTERN_UL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360542
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_TPC_SOURCE_DATA_LIST_DL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360543
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_TPC_SOURCE_DATA_LIST_UL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360544
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_READ_OUT_MODE_DL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360545
#define RSRFSIGGEN_ATTR_TDSCDMA_DPCCH_READ_OUT_MODE_UL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360546
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_UP_SLOT_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346432
#define RSRFSIGGEN_ATTR_TDSCDMA_PRACH_POWER_STEP                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346433
#define RSRFSIGGEN_ATTR_TDSCDMA_PRACH_UPPTS_START                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346434
#define RSRFSIGGEN_ATTR_TDSCDMA_PRACH_UPPTS_DISTANCE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346435
#define RSRFSIGGEN_ATTR_TDSCDMA_PRACH_UPPTS_POWER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346436
#define RSRFSIGGEN_ATTR_TDSCDMA_PRACH_UPPTS_POWER_CORRECTION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353030
#define RSRFSIGGEN_ATTR_TDSCDMA_PRACH_UPPTS_SEQUENCE_LENGTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353031
#define RSRFSIGGEN_ATTR_TDSCDMA_PRACH_UPPTS_REPETITION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346437
#define RSRFSIGGEN_ATTR_TDSCDMA_RACH_ENABLE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346438
#define RSRFSIGGEN_ATTR_TDSCDMA_RACH_SLOT_FORMAT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346439
#define RSRFSIGGEN_ATTR_TDSCDMA_RACH_SPREADING_FACTOR                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346440
#define RSRFSIGGEN_ATTR_TDSCDMA_RACH_DATA_SOURCE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346441
#define RSRFSIGGEN_ATTR_TDSCDMA_RACH_DATA_PATTERN                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346442
#define RSRFSIGGEN_ATTR_TDSCDMA_RACH_DATA_LIST                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346443
#define RSRFSIGGEN_ATTR_TDSCDMA_RACH_CURRENT_USER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346444
#define RSRFSIGGEN_ATTR_TDSCDMA_RACH_MESSAGE_LENGTH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346445
#define RSRFSIGGEN_ATTR_TDSCDMA_RACH_POWER                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346446
#define RSRFSIGGEN_ATTR_TDSCDMA_RACH_POWER_CORRECTION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353032
#define RSRFSIGGEN_ATTR_TDSCDMA_RACH_SPREADING_CODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346447
#define RSRFSIGGEN_ATTR_TDSCDMA_RACH_MIDAMBLE_SHIFT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346448
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_DW_PTS_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346449
#define RSRFSIGGEN_ATTR_TDSCDMA_SLOT_UP_PTS_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346450
#define RSRFSIGGEN_ATTR_EVDO_ENABLED                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346451
#define RSRFSIGGEN_ATTR_EVDO_SET_TO_DEFAULT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346452
#define RSRFSIGGEN_ATTR_EVDO_GENERATE_WAVEFORM_FILE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346453
#define RSRFSIGGEN_ATTR_EVDO_VERSION                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346454
#define RSRFSIGGEN_ATTR_EVDO_LINK_DIRECTION                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346455
#define RSRFSIGGEN_ATTR_EVDO_PN_OFFSET                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346456
#define RSRFSIGGEN_ATTR_EVDO_SYSTEM_TIME                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346457
#define RSRFSIGGEN_ATTR_EVDO_SETTINGS_CATALOG                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353248
#define RSRFSIGGEN_ATTR_EVDO_DELETE_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353249
#define RSRFSIGGEN_ATTR_EVDO_RECALL_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353251
#define RSRFSIGGEN_ATTR_EVDO_SAVE_SETTINGS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353253
#define RSRFSIGGEN_ATTR_EVDO_FAST_STORE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353255
#define RSRFSIGGEN_ATTR_EVDO_ANET_PILOT_CHANNEL_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346458
#define RSRFSIGGEN_ATTR_EVDO_ANET_PHYSICAL_LAYER_SUBTYPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346459
#define RSRFSIGGEN_ATTR_EVDO_ANET_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346460
#define RSRFSIGGEN_ATTR_EVDO_ANET_OTHER_USERS_COUNT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346461
#define RSRFSIGGEN_ATTR_EVDO_CONTROL_CHANNEL_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346462
#define RSRFSIGGEN_ATTR_EVDO_CONTROL_CHANNEL_RATE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346463
#define RSRFSIGGEN_ATTR_EVDO_CONTROL_CHANNEL_OFFSET                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346464
#define RSRFSIGGEN_ATTR_EVDO_CONTROL_CHANNEL_REVISION_MINIMUM                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346465
#define RSRFSIGGEN_ATTR_EVDO_CONTROL_CHANNEL_REVISION_MAXIMUM                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346466
#define RSRFSIGGEN_ATTR_EVDO_RAB_ENABLED                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346467
#define RSRFSIGGEN_ATTR_EVDO_RAB_LEVEL                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346468
#define RSRFSIGGEN_ATTR_EVDO_RAB_LENGTH                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346469
#define RSRFSIGGEN_ATTR_EVDO_RAB_OFFSET                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346470
#define RSRFSIGGEN_ATTR_EVDO_RAB_MAC_INDEX                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353257
#define RSRFSIGGEN_ATTR_EVDO_MULTI_CARRIER_ENABLED_UP                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360547
#define RSRFSIGGEN_ATTR_EVDO_MULTI_CARRIER_ENABLED_DOWN                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360548
#define RSRFSIGGEN_ATTR_EVDO_BAND_CLASS_UP                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350006
#define RSRFSIGGEN_ATTR_EVDO_BAND_CLASS_DOWN                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360549
#define RSRFSIGGEN_ATTR_EVDO_MULTI_CARRIER_DELAY_UP                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360550
#define RSRFSIGGEN_ATTR_EVDO_MULTI_CARRIER_DELAY_DOWN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360551
#define RSRFSIGGEN_ATTR_EVDO_MULTI_CARRIER_CENTER_FREQUENCY_UP                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360552
#define RSRFSIGGEN_ATTR_EVDO_MULTI_CARRIER_CENTER_FREQUENCY_DOWN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360553
#define RSRFSIGGEN_ATTR_EVDO_CARRIER_ENABLED_UP                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360554
#define RSRFSIGGEN_ATTR_EVDO_CARRIER_ENABLED_DOWN                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360555
#define RSRFSIGGEN_ATTR_EVDO_CARRIER_CDMA_CHANNEL_NUMBER_UP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360556
#define RSRFSIGGEN_ATTR_EVDO_CARRIER_CDMA_CHANNEL_NUMBER_DOWN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360557
#define RSRFSIGGEN_ATTR_EVDO_CARRIER_CENTER_FREQUENCY_UP                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360558
#define RSRFSIGGEN_ATTR_EVDO_CARRIER_CENTER_FREQUENCY_DOWN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360559
#define RSRFSIGGEN_ATTR_EVDO_TU_ENABLED                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346471
#define RSRFSIGGEN_ATTR_EVDO_TU_NUMBER_OF_PACKETS_INFINITE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346472
#define RSRFSIGGEN_ATTR_EVDO_TU_NUMBER_OF_PACKETS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346473
#define RSRFSIGGEN_ATTR_EVDO_TU_OFFSET                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346474
#define RSRFSIGGEN_ATTR_EVDO_TU_RATE_INDEX                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346475
#define RSRFSIGGEN_ATTR_EVDO_TU_PACKET_SIZE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346476
#define RSRFSIGGEN_ATTR_EVDO_TU_RATE                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346477
#define RSRFSIGGEN_ATTR_EVDO_TU_SLOT_COUNT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346478
#define RSRFSIGGEN_ATTR_EVDO_TU_DATA_PATTERN                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346479
#define RSRFSIGGEN_ATTR_EVDO_TU_MAC_INDEX                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346480
#define RSRFSIGGEN_ATTR_EVDO_TU_MAC_LEVEL                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346481
#define RSRFSIGGEN_ATTR_EVDO_TU_INTERLEAVE_FACTOR                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346482
#define RSRFSIGGEN_ATTR_EVDO_TU_RPC_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346483
#define RSRFSIGGEN_ATTR_EVDO_TU_RPC_RANGE_COUNT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346484
#define RSRFSIGGEN_ATTR_EVDO_TU_RPC_INJECT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353260
#define RSRFSIGGEN_ATTR_EVDO_TU_RPC_BIT                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346485
#define RSRFSIGGEN_ATTR_EVDO_TU_RPC_COUNT                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346486
#define RSRFSIGGEN_ATTR_EVDO_TU_DRC_LOCK_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346487
#define RSRFSIGGEN_ATTR_EVDO_TU_DRC_LOCK_PERIOD                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346488
#define RSRFSIGGEN_ATTR_EVDO_TU_DRC_LOCK_LENGTH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346489
#define RSRFSIGGEN_ATTR_EVDO_TU_DRC_FRAME_OFFSET                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346490
#define RSRFSIGGEN_ATTR_EVDO_TU_HARQ_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346491
#define RSRFSIGGEN_ATTR_EVDO_TERMINAL_PREDEFINED_SETTINGS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350010
#define RSRFSIGGEN_ATTR_EVDO_AT_ENABLED                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346492
#define RSRFSIGGEN_ATTR_EVDO_AT_PHYSICAL_LAYER_SUBTYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346493
#define RSRFSIGGEN_ATTR_EVDO_AT_LONG_CODE_MASK_I                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346494
#define RSRFSIGGEN_ATTR_EVDO_AT_PREAMBLE_LENGTH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346495
#define RSRFSIGGEN_ATTR_EVDO_AT_ACCESS_CYCLE_OFFSET                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346496
#define RSRFSIGGEN_ATTR_EVDO_AT_MODE                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346497
#define RSRFSIGGEN_ATTR_EVDO_AT_DISABLE_QUADRATURE_SPREADING                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346498
#define RSRFSIGGEN_ATTR_EVDO_AT_LONG_CODE_MASK_Q                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346499
#define RSRFSIGGEN_ATTR_EVDO_AT_ACCESS_CYCLE_DURATION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346500
#define RSRFSIGGEN_ATTR_EVDO_AT_PILOT_CHANNEL_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346501
#define RSRFSIGGEN_ATTR_EVDO_AT_PILOT_CHANNEL_GAIN                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346502
#define RSRFSIGGEN_ATTR_EVDO_AT_AUXILIARY_PILOT_CHANNEL_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346503
#define RSRFSIGGEN_ATTR_EVDO_AT_AUXILIARY_PILOT_CHANNEL_MINIMUM_PAYLOAD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346504
#define RSRFSIGGEN_ATTR_EVDO_AT_AUXILIARY_PILOT_CHANNEL_RELATIVE_GAIN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346505
#define RSRFSIGGEN_ATTR_EVDO_AT_RRI_CHANNEL_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346506
#define RSRFSIGGEN_ATTR_EVDO_AT_RRI_CHANNEL_RELATIVE_GAIN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346507
#define RSRFSIGGEN_ATTR_EVDO_AT_DSC_CHANNEL_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346508
#define RSRFSIGGEN_ATTR_EVDO_AT_DSC_CHANNEL_LENGTH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346509
#define RSRFSIGGEN_ATTR_EVDO_AT_DSC_CHANNEL_RELATIVE_GAIN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346510
#define RSRFSIGGEN_ATTR_EVDO_AT_DSC_CHANNEL_VALUES                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346511
#define RSRFSIGGEN_ATTR_EVDO_AT_DRC_CHANNEL_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346512
#define RSRFSIGGEN_ATTR_EVDO_AT_DRC_CHANNEL_LENGTH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346513
#define RSRFSIGGEN_ATTR_EVDO_AT_DRC_CHANNEL_COVER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346514
#define RSRFSIGGEN_ATTR_EVDO_AT_DRC_CHANNEL_RELATIVE_GAIN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346515
#define RSRFSIGGEN_ATTR_EVDO_AT_DRC_CHANNEL_VALUES                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346516
#define RSRFSIGGEN_ATTR_EVDO_AT_DRC_CHANNEL_GATING_ACTIVE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346517
#define RSRFSIGGEN_ATTR_EVDO_AT_ACK_CHANNEL_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346518
#define RSRFSIGGEN_ATTR_EVDO_AT_ACK_CHANNEL_MODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346519
#define RSRFSIGGEN_ATTR_EVDO_AT_ACK_CHANNEL_VALUES                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346520
#define RSRFSIGGEN_ATTR_EVDO_AT_ACK_CHANNEL_RELATIVE_GAIN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346521
#define RSRFSIGGEN_ATTR_EVDO_AT_ACK_CHANNEL_GATING                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346522
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346523
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_CAPSULE_LENGTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346524
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_DATA_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346525
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_APPEND_FCS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346526
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_RELATIVE_GAIN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346527
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_DATA_RATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346528
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_DATA_LIST                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346529
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_PATTERN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346530
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_PACKET_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346531
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_PACKET_RELATIVE_GAIN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346532
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_PACKET_INFINITE_PACKETS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346533
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_PACKETS_TO_SEND                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346534
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_PACKET_SUBPACKETS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346535
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_PACKET_PAYLOAD_SIZE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346536
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_PACKET_MODULATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346537
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_PACKET_DATA_RATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346538
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_PACKET_CODING                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346539
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_PACKET_DATA_SOURCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346540
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_PACKET_DATA_LIST                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346541
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_PACKET_PATTERN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346542
#define RSRFSIGGEN_ATTR_EVDO_AT_DATA_CHANNEL_PACKET_FCS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346543
#define RSRFSIGGEN_ATTR_EVDO_FILTER_TYPE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346544
#define RSRFSIGGEN_ATTR_EVDO_FILTER_PARAMETER_ROOT_COSINE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346545
#define RSRFSIGGEN_ATTR_EVDO_FILTER_PARAMETER_COSINE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346546
#define RSRFSIGGEN_ATTR_EVDO_FILTER_PARAMETER_GAUSS_PURE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346547
#define RSRFSIGGEN_ATTR_EVDO_FILTER_PARAMETER_GAUSS_FSK                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346548
#define RSRFSIGGEN_ATTR_EVDO_FILTER_PARAMETER_APCO25                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346549
#define RSRFSIGGEN_ATTR_EVDO_FILTER_PARAMETER_SPLIT_PHASE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346550
#define RSRFSIGGEN_ATTR_EVDO_FILTER_PARAMETER_LOW_PASS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346551
#define RSRFSIGGEN_ATTR_EVDO_FILTER_PARAMETER_LOW_PASS_EVM                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346552
#define RSRFSIGGEN_ATTR_EVDO_CHIP_RATE_VARIATION                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346553
#define RSRFSIGGEN_ATTR_EVDO_CLIPPING_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346554
#define RSRFSIGGEN_ATTR_EVDO_CLIPPING_LEVEL                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346555
#define RSRFSIGGEN_ATTR_EVDO_CLIPPING_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346556
#define RSRFSIGGEN_ATTR_EVDO_SEQUENCE_LENGTH_ARB                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346557
#define RSRFSIGGEN_ATTR_EVDO_INVERT_Q_FOR_CORRECT_BASEBAND_OUTPUT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346558
#define RSRFSIGGEN_ATTR_EVDO_TRIGGER_STATUS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346559
#define RSRFSIGGEN_ATTR_EVDO_TRIGGER_ARM                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346560
#define RSRFSIGGEN_ATTR_EVDO_TRIGGER_EXECUTE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346561
#define RSRFSIGGEN_ATTR_EVDO_TRIGGER_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346562
#define RSRFSIGGEN_ATTR_EVDO_TRIGGER_SOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346563
#define RSRFSIGGEN_ATTR_EVDO_TRIGGER_SOURCE_LEGACY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350978
#define RSRFSIGGEN_ATTR_EVDO_TRIGGER_SIGNAL_DURATION_UNIT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346564
#define RSRFSIGGEN_ATTR_EVDO_TRIGGER_SEQUENCE_LENGTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346565
#define RSRFSIGGEN_ATTR_EVDO_INTERNAL_TRIGGER_DELAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346566
#define RSRFSIGGEN_ATTR_EVDO_INTERNAL_TRIGGER_INHIBIT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346567
#define RSRFSIGGEN_ATTR_EVDO_EXTERNAL_TRIGGER_DELAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346568
#define RSRFSIGGEN_ATTR_EVDO_EXTERNAL_TRIGGER_INHIBIT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346569
#define RSRFSIGGEN_ATTR_EVDO_MARKER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346570
#define RSRFSIGGEN_ATTR_EVDO_MARKER_PERIOD                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346571
#define RSRFSIGGEN_ATTR_EVDO_MARKER_ON_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346572
#define RSRFSIGGEN_ATTR_EVDO_MARKER_OFF_TIME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346573
#define RSRFSIGGEN_ATTR_EVDO_MARKER_DELAY                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346574
#define RSRFSIGGEN_ATTR_EVDO_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346575
#define RSRFSIGGEN_ATTR_EVDO_FIXED_MARKER_DELAY_MAXIMUM                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346576
#define RSRFSIGGEN_ATTR_EVDO_FIXED_MARKER_DELAY_MINIMUM                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346577
#define RSRFSIGGEN_ATTR_EVDO_CLOCK_SOURCE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346578
#define RSRFSIGGEN_ATTR_EVDO_CLOCK_SOURCE_LEGACY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351004
#define RSRFSIGGEN_ATTR_EVDO_CLOCK_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346579
#define RSRFSIGGEN_ATTR_EVDO_CHIP_CLOCK_MULTIPLIER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346580
#define RSRFSIGGEN_ATTR_EVDO_CLOCK_SYNCHRONISATION_EXECUTE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346581
#define RSRFSIGGEN_ATTR_EVDO_CLOCK_SYNCHRONISATION_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346582
#define RSRFSIGGEN_ATTR_EVDO_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346583
#define RSRFSIGGEN_ATTR_WLAN_ENABLED                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346584
#define RSRFSIGGEN_ATTR_WLAN_SET_TO_DEFAULT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346585
#define RSRFSIGGEN_ATTR_WLAN_GENERATE_WAVEFORM_FILE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346586
#define RSRFSIGGEN_ATTR_WLAN_SETTINGS_CATALOG                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346587
#define RSRFSIGGEN_ATTR_WLAN_DELETE_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346588
#define RSRFSIGGEN_ATTR_WLAN_RECALL_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346589
#define RSRFSIGGEN_ATTR_WLAN_SAVE_SETTINGS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346590
#define RSRFSIGGEN_ATTR_WLAN_FAST_STORE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353232
#define RSRFSIGGEN_ATTR_WLAN_STANDARD                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346591
#define RSRFSIGGEN_ATTR_WLAN_PHYSICAL_LAYER_MODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346592
#define RSRFSIGGEN_ATTR_WLAN_SIMULATION_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346593
#define RSRFSIGGEN_ATTR_WLAN_PREDEFINED_FRAMES                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346594
#define RSRFSIGGEN_ATTR_WLAN_SEQUENCE_LENGTH                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346595
#define RSRFSIGGEN_ATTR_WLAN_IDLE_TIME                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346596
#define RSRFSIGGEN_ATTR_WLAN_PSDU_BIT_RATE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346597
#define RSRFSIGGEN_ATTR_WLAN_PSDU_MODULATION                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346598
#define RSRFSIGGEN_ATTR_WLAN_DATA_LENGTH                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346599
#define RSRFSIGGEN_ATTR_WLAN_PSDU_DATA_SOURCE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346600
#define RSRFSIGGEN_ATTR_WLAN_PSDU_DATA_LIST                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346601
#define RSRFSIGGEN_ATTR_WLAN_PSDU_PATTERN                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346602
#define RSRFSIGGEN_ATTR_WLAN_SCRAMBLING                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346603
#define RSRFSIGGEN_ATTR_WLAN_NUMBER_OF_DATA_SYMBOLS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346604
#define RSRFSIGGEN_ATTR_WLAN_SCRAMBLER_INITIALIZATION_VALUE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346605
#define RSRFSIGGEN_ATTR_WLAN_SERVICE_PATTERN                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353233
#define RSRFSIGGEN_ATTR_WLAN_INTERLEAVER_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346606
#define RSRFSIGGEN_ATTR_WLAN_SERVICE_FIELD_VALUE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346607
#define RSRFSIGGEN_ATTR_WLAN_TIME_DOMAIN_WINDOWING_ACTIVE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346608
#define RSRFSIGGEN_ATTR_WLAN_TRANSITION_TIME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346609
#define RSRFSIGGEN_ATTR_WLAN_PLCP_PH_FORMAT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346610
#define RSRFSIGGEN_ATTR_WLAN_SERVICE_FIELD_CLOCK_BIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346611
#define RSRFSIGGEN_ATTR_WLAN_BARKER_SPREADING                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346612
#define RSRFSIGGEN_ATTR_WLAN_MAC_HEADER                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346613
#define RSRFSIGGEN_ATTR_WLAN_FCS_CHECKSUM                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346614
#define RSRFSIGGEN_ATTR_WLAN_FRAME_CONTROL                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346615
#define RSRFSIGGEN_ATTR_WLAN_DURATION_ID                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346616
#define RSRFSIGGEN_ATTR_WLAN_MAC_ADDRESS_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346617
#define RSRFSIGGEN_ATTR_WLAN_MAC_ADDRESS                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346618
#define RSRFSIGGEN_ATTR_WLAN_FRAME_CONTROL_PROTOCOL_VERSION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350129
#define RSRFSIGGEN_ATTR_WLAN_FRAME_CONTROL_TYPE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350130
#define RSRFSIGGEN_ATTR_WLAN_FRAME_CONTROL_SUBTYPE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350131
#define RSRFSIGGEN_ATTR_WLAN_FRAME_CONTROL_TO_DS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350132
#define RSRFSIGGEN_ATTR_WLAN_FRAME_CONTROL_FROM_DS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350133
#define RSRFSIGGEN_ATTR_WLAN_FRAME_CONTROL_MORE_FRAG                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350134
#define RSRFSIGGEN_ATTR_WLAN_FRAME_CONTROL_RETRY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350135
#define RSRFSIGGEN_ATTR_WLAN_FRAME_CONTROL_PWR_MGT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350136
#define RSRFSIGGEN_ATTR_WLAN_FRAME_CONTROL_MORE_DATA                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350137
#define RSRFSIGGEN_ATTR_WLAN_FRAME_CONTROL_WEP                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350138
#define RSRFSIGGEN_ATTR_WLAN_FRAME_CONTROL_ORDER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350139
#define RSRFSIGGEN_ATTR_WLAN_SEQUENCE_CONTROL_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346630
#define RSRFSIGGEN_ATTR_WLAN_SEQUENCE_CONTROL_FRAG_START_NUMBER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346631
#define RSRFSIGGEN_ATTR_WLAN_SEQUENCE_CONTROL_SEQU_START_NUMBER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346632
#define RSRFSIGGEN_ATTR_WLAN_SEQUENCE_CONTROL_FRAG_INCREMENT_EVERY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346633
#define RSRFSIGGEN_ATTR_WLAN_SEQUENCE_CONTROL_SEQU_INCREMENT_EVERY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346634
#define RSRFSIGGEN_ATTR_WLAN_FILTER_TYPE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346635
#define RSRFSIGGEN_ATTR_WLAN_FILTER_PARAMETER_APCO25                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346636
#define RSRFSIGGEN_ATTR_WLAN_FILTER_PARAMETER_COSINE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346637
#define RSRFSIGGEN_ATTR_WLAN_FILTER_PARAMETER_GAUSS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346638
#define RSRFSIGGEN_ATTR_WLAN_FILTER_PARAMETER_PURE_GAUSS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346639
#define RSRFSIGGEN_ATTR_WLAN_FILTER_PARAMETER_ROOT_COSINE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346640
#define RSRFSIGGEN_ATTR_WLAN_FILTER_PARAMETER_SPLIT_PHASE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346641
#define RSRFSIGGEN_ATTR_WLAN_FILTER_PARAMETER_LOW_PASS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346642
#define RSRFSIGGEN_ATTR_WLAN_FILTER_PARAMETER_LOW_PASS_EVM                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346643
#define RSRFSIGGEN_ATTR_WLAN_CHIP_RATE_VARIATION                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346644
#define RSRFSIGGEN_ATTR_WLAN_CLIPPING_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346645
#define RSRFSIGGEN_ATTR_WLAN_CLIPPING_LEVEL                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346646
#define RSRFSIGGEN_ATTR_WLAN_CLIPPING_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346647
#define RSRFSIGGEN_ATTR_WLAN_TRIGGER_STATUS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346648
#define RSRFSIGGEN_ATTR_WLAN_TRIGGER_ARM                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346649
#define RSRFSIGGEN_ATTR_WLAN_TRIGGER_EXECUTE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346650
#define RSRFSIGGEN_ATTR_WLAN_TRIGGER_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346651
#define RSRFSIGGEN_ATTR_WLAN_TRIGGER_SOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346652
#define RSRFSIGGEN_ATTR_WLAN_TRIGGER_SOURCE_LEGACY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350980
#define RSRFSIGGEN_ATTR_WLAN_TRIGGER_SEQUENCE_LENGTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346653
#define RSRFSIGGEN_ATTR_WLAN_TRIGGER_SEQUENCE_LENGTH_UNIT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353234
#define RSRFSIGGEN_ATTR_WLAN_INTERNAL_TRIGGER_DELAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346654
#define RSRFSIGGEN_ATTR_WLAN_INTERNAL_TRIGGER_INHIBIT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346655
#define RSRFSIGGEN_ATTR_WLAN_EXTERNAL_TRIGGER_DELAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346656
#define RSRFSIGGEN_ATTR_WLAN_EXTERNAL_TRIGGER_INHIBIT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346657
#define RSRFSIGGEN_ATTR_WLAN_MARKER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346658
#define RSRFSIGGEN_ATTR_WLAN_MARKER_PULSE_DIVIDER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346659
#define RSRFSIGGEN_ATTR_WLAN_MARKER_PULSE_FREQUENCY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346660
#define RSRFSIGGEN_ATTR_WLAN_MARKER_PATTERN                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346661
#define RSRFSIGGEN_ATTR_WLAN_MARKER_OFF_TIME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346662
#define RSRFSIGGEN_ATTR_WLAN_MARKER_ON_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346663
#define RSRFSIGGEN_ATTR_WLAN_MARKER_DELAY                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346664
#define RSRFSIGGEN_ATTR_WLAN_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346665
#define RSRFSIGGEN_ATTR_WLAN_FIXED_MARKER_DELAY_MAXIMUM                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346666
#define RSRFSIGGEN_ATTR_WLAN_FIXED_MARKER_DELAY_MINIMUM                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346667
#define RSRFSIGGEN_ATTR_WLAN_CLOCK_SOURCE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346668
#define RSRFSIGGEN_ATTR_WLAN_CLOCK_SOURCE_LEGACY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351006
#define RSRFSIGGEN_ATTR_WLAN_CLOCK_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346669
#define RSRFSIGGEN_ATTR_WLAN_CHIP_CLOCK_MULTIPLIER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346670
#define RSRFSIGGEN_ATTR_WLAN_CLOCK_SYNCHRONISATION_EXECUTE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346671
#define RSRFSIGGEN_ATTR_WLAN_CLOCK_SYNCHRONISATION_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346672
#define RSRFSIGGEN_ATTR_WLAN_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346673
#define RSRFSIGGEN_ATTR_WLANN_ENABLED                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350719
#define RSRFSIGGEN_ATTR_WLANN_COUPLING_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350720
#define RSRFSIGGEN_ATTR_WLANN_SET_TO_DEFAULT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350721
#define RSRFSIGGEN_ATTR_WLANN_GENERATE_WAVEFORM_FILE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350722
#define RSRFSIGGEN_ATTR_WLANN_VERSION                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350723
#define RSRFSIGGEN_ATTR_WLANN_TRANSMISSION_BANDWIDTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350724
#define RSRFSIGGEN_ATTR_WLANN_SAMPLE_RATE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350725
#define RSRFSIGGEN_ATTR_WLANN_PSDU_MODULATION_TYPE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350726
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_EDIT_APPEND                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350727
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_EDIT_COPY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353061
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_EDIT_PASTE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353062
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_EDIT_INSERT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353063
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_EDIT_DELETE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353064
#define RSRFSIGGEN_ATTR_WLANN_SETTINGS_CATALOG                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350728
#define RSRFSIGGEN_ATTR_WLANN_DELETE_SETTINGS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350729
#define RSRFSIGGEN_ATTR_WLANN_RECALL_SETTINGS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350730
#define RSRFSIGGEN_ATTR_WLANN_SAVE_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350731
#define RSRFSIGGEN_ATTR_WLANN_FAST_STORE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353065
#define RSRFSIGGEN_ATTR_WLANN_NUMBER_OF_ANTENNAS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350732
#define RSRFSIGGEN_ATTR_WLANN_ANTENNAS_MAPPING_COORDINATES                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350733
#define RSRFSIGGEN_ATTR_WLANN_ANTENNA_COUPLING_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359815
#define RSRFSIGGEN_ATTR_WLANN_NUMBER_OF_BASEBANDS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359816
#define RSRFSIGGEN_ATTR_WLANN_ANTENNAS_CHAIN_MAPPING_OUTPUT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350734
#define RSRFSIGGEN_ATTR_WLANN_ANTENNAS_CHAIN_MAPPING_FILE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350735
#define RSRFSIGGEN_ATTR_WLANN_ANTENNAS_CHAIN_MAPPING_CARTESIAN_REAL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350736
#define RSRFSIGGEN_ATTR_WLANN_ANTENNAS_CHAIN_MAPPING_CARTESIAN_IMAGINARY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350737
#define RSRFSIGGEN_ATTR_WLANN_ANTENNAS_CHAIN_MAPPING_CYLINDRICAL_MAGNITUDE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350738
#define RSRFSIGGEN_ATTR_WLANN_ANTENNAS_CHAIN_MAPPING_CYLINDRICAL_PHASE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350739
#define RSRFSIGGEN_ATTR_WLANN_FILTER_DEFAULT_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359817
#define RSRFSIGGEN_ATTR_WLANN_FILTER_TYPE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350740
#define RSRFSIGGEN_ATTR_WLANN_CUT_OFF_FREQUENCY_SHIFT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350741
#define RSRFSIGGEN_ATTR_WLANN_FILTER_IFFT_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359818
#define RSRFSIGGEN_ATTR_WLANN_FILTER_PARAMETER_ROOT_COSINE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350742
#define RSRFSIGGEN_ATTR_WLANN_FILTER_PARAMETER_COSINE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350743
#define RSRFSIGGEN_ATTR_WLANN_FILTER_PARAMETER_GAUSS_PURE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350744
#define RSRFSIGGEN_ATTR_WLANN_FILTER_PARAMETER_GAUSS_FSK                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350745
#define RSRFSIGGEN_ATTR_WLANN_FILTER_PARAMETER_APCO25                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350746
#define RSRFSIGGEN_ATTR_WLANN_FILTER_PARAMETER_SPLIT_PHASE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350747
#define RSRFSIGGEN_ATTR_WLANN_FILTER_PARAMETER_LOW_PASS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350748
#define RSRFSIGGEN_ATTR_WLANN_FILTER_PARAMETER_LOW_PASS_EVM                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350749
#define RSRFSIGGEN_ATTR_WLANN_FILTER_IMPULSE_LENGTH_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350750
#define RSRFSIGGEN_ATTR_WLANN_FILTER_IMPULSE_LENGTH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350751
#define RSRFSIGGEN_ATTR_WLANN_FILTER_UPSAMPLING_FACTOR_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350752
#define RSRFSIGGEN_ATTR_WLANN_FILTER_UPSAMPLING_FACTOR                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350753
#define RSRFSIGGEN_ATTR_WLANN_SAMPLE_RATE_VARIATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350754
#define RSRFSIGGEN_ATTR_WLANN_CLIPPING_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350755
#define RSRFSIGGEN_ATTR_WLANN_CLIPPING_LEVEL                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350756
#define RSRFSIGGEN_ATTR_WLANN_CLIPPING_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350757
#define RSRFSIGGEN_ATTR_WLANN_CLIPPING_SIGNAL_FIELDS_TO_PAYLOAD_MAX_PEAK                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362647
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_TYPE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350758
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_INSERT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361906
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_COPY                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361907
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_PASTE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361908
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_DELETE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361909
#define RSRFSIGGEN_ATTR_WLANN_PLCP_FORMAT                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350759
#define RSRFSIGGEN_ATTR_WLANN_PLCP_LOCKED_CLOCK_BIT_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350760
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_PHYSICAL_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350761
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_TX_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350762
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_TX_MODE_LEGACY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350763
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_FRAMES                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350764
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_IDLE_TIME                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350765
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_DATA                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350766
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_PATTERN                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350767
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_DATA_LIST                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350768
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_BOOST                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350769
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350770
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_OFDMA_MODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361910
#define RSRFSIGGEN_ATTR_WLANN_PSDU_BIT_RATE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350771
#define RSRFSIGGEN_ATTR_WLANN_PSDU_BARKER_SPREADING                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350772
#define RSRFSIGGEN_ATTR_WLAN_FRAME_BLOCK_PSDU_MODULATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357247
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_STANDARD                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353033
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_BEAM_CHANGE_AND_SMOOTHING_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359819
#define RSRFSIGGEN_ATTR_WLANN_FRAME_320MHZ_TYPE_BW                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363105
#define RSRFSIGGEN_ATTR_WLANN_FRAME_DELAY                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363106
#define RSRFSIGGEN_ATTR_WLANN_STREAM_SPATIAL_STREAMS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350777
#define RSRFSIGGEN_ATTR_WLANN_STREAM_EXTENDED_SPATIAL_STREAMS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350778
#define RSRFSIGGEN_ATTR_WLANN_STREAM_MULTI_USER_MIMO                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350779
#define RSRFSIGGEN_ATTR_WLANN_STREAM_SEGMENT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350780
#define RSRFSIGGEN_ATTR_WLANN_STREAM_SPACE_TIME_STREAMS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350781
#define RSRFSIGGEN_ATTR_WLANN_STREAM_SPACE_TIME_BLOCK_CODING                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350782
#define RSRFSIGGEN_ATTR_WLANN_STREAM_RIGHT_106_TONE_RU                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355968
#define RSRFSIGGEN_ATTR_WLANN_USER_INDEX                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350783
#define RSRFSIGGEN_ATTR_WLANN_USER_N_STS                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350784
#define RSRFSIGGEN_ATTR_WLANN_USER_GROUP_ID                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350785
#define RSRFSIGGEN_ATTR_WLANN_BLOCK_MODULATION_AND_CODING_SCHEME                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350786
#define RSRFSIGGEN_ATTR_WLANN_RATE                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350787
#define RSRFSIGGEN_ATTR_WLANN_BITS_PER_SYMBOL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350788
#define RSRFSIGGEN_ATTR_WLANN_CHANNEL_CODING                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350789
#define RSRFSIGGEN_ATTR_WLANN_ENCODERS                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350790
#define RSRFSIGGEN_ATTR_WLANN_CODING_RATE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350791
#define RSRFSIGGEN_ATTR_WLANN_GUARD                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350792
#define RSRFSIGGEN_ATTR_WLANN_STREAM_MODULATION                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350793
#define RSRFSIGGEN_ATTR_WLANN_MODULATION_USER_RATE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357248
#define RSRFSIGGEN_ATTR_WLANN_MODULATION_USER_BITS_PER_SYMBOL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357249
#define RSRFSIGGEN_ATTR_WLANN_MODULATION_USER_ENCODERS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357250
#define RSRFSIGGEN_ATTR_WLANN_MODULATION_USER_COD_RATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357251
#define RSRFSIGGEN_ATTR_WLANN_MODULATION_USER_CHANNEL_CODING                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357252
#define RSRFSIGGEN_ATTR_WLANN_USER_BLOCK_MODULATION_AND_CODING_SCHEME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357253
#define RSRFSIGGEN_ATTR_WLANN_DCM                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355969
#define RSRFSIGGEN_ATTR_WLANN_USER_STREAM_MODULATION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357254
#define RSRFSIGGEN_ATTR_WLANN_DATA_LENGTH                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350794
#define RSRFSIGGEN_ATTR_WLANN_DATA_NUMBER_OF_DATA_SYMBOLS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350795
#define RSRFSIGGEN_ATTR_WLANN_DATA_FRAME_DURATION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359820
#define RSRFSIGGEN_ATTR_WLANN_DATA_DUTY_CYCLE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359821
#define RSRFSIGGEN_ATTR_WLANN_DATA_SCRAMBLER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350796
#define RSRFSIGGEN_ATTR_WLANN_DATA_SCRAMBLER_INIT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350797
#define RSRFSIGGEN_ATTR_WLANN_DATA_INTERLEAVER_ACTIVE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350798
#define RSRFSIGGEN_ATTR_WLANN_DATA_SERVICE_FIELD                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350799
#define RSRFSIGGEN_ATTR_WLANN_DATA_TIME_DOMAIN_WINDOWING_ACTIVE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350800
#define RSRFSIGGEN_ATTR_WLANN_DATA_TRANSITION_TIME                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350801
#define RSRFSIGGEN_ATTR_WLANN_DATA_CHANNEL_BANDWIDTH_IN_NON_HT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350802
#define RSRFSIGGEN_ATTR_WLANN_DATA_DYNAMIC_BANDWIDTH_IN_NON_HT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350803
#define RSRFSIGGEN_ATTR_WLANN_USER_DATA_LENGTH                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357255
#define RSRFSIGGEN_ATTR_WLANN_USER_DATA_NUMBER_OF_DATA_SYMBOLS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357256
#define RSRFSIGGEN_ATTR_WLANN_USER_DATA_INTERLEAVER_ACTIVE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357257
#define RSRFSIGGEN_ATTR_WLANN_USER_DATA_SCRAMBLER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357258
#define RSRFSIGGEN_ATTR_WLANN_USER_DATA_SCRAMBLER_INIT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357259
#define RSRFSIGGEN_ATTR_WLANN_USER_DATA_SERVICE_FIELD                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357260
#define RSRFSIGGEN_ATTR_WLANN_USER_DATA_DEAFULT_PN_SEED_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359822
#define RSRFSIGGEN_ATTR_WLANN_USER_DATA_PN_SEED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359823
#define RSRFSIGGEN_ATTR_WLANN_PREAMBLE_HEADER_ACTIVE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350804
#define RSRFSIGGEN_ATTR_WLANN_HEADER_BLOCK_SMOOTHING                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350805
#define RSRFSIGGEN_ATTR_WLANN_HEADER_NTPS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350806
#define RSRFSIGGEN_ATTR_WLANN_HEADER_PARTIAL_AID                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350807
#define RSRFSIGGEN_ATTR_WLANN_MAC_HEADER_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350808
#define RSRFSIGGEN_ATTR_WLANN_MAC_FCS_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350809
#define RSRFSIGGEN_ATTR_WLANN_MAC_FRAME_CONTROL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350810
#define RSRFSIGGEN_ATTR_WLANN_MAC_DURATION_ID                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350822
#define RSRFSIGGEN_ATTR_WLANN_MAC_QOS_CONTROL_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350830
#define RSRFSIGGEN_ATTR_WLANN_MAC_QOS_CONTROL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350831
#define RSRFSIGGEN_ATTR_WLANN_MAC_BSSID                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353066
#define RSRFSIGGEN_ATTR_WLANN_MAC_SOURCE_ADDRESS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353067
#define RSRFSIGGEN_ATTR_WLANN_MAC_FRAME_CONTROL_PROTOCOL_VERSION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350811
#define RSRFSIGGEN_ATTR_WLANN_MAC_FRAME_CONTROL_TYPE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350812
#define RSRFSIGGEN_ATTR_WLANN_MAC_FRAME_CONTROL_SUBTYPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350813
#define RSRFSIGGEN_ATTR_WLANN_MAC_FRAME_CONTROL_TO_DS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350814
#define RSRFSIGGEN_ATTR_WLANN_MAC_FRAME_CONTROL_FROM_DS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350815
#define RSRFSIGGEN_ATTR_WLANN_MAC_FRAME_CONTROL_MORE_FRAG                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350816
#define RSRFSIGGEN_ATTR_WLANN_MAC_FRAME_CONTROL_RETRY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350817
#define RSRFSIGGEN_ATTR_WLANN_MAC_FRAME_CONTROL_POWER_MANAGEMENT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350818
#define RSRFSIGGEN_ATTR_WLANN_MAC_FRAME_CONTROL_MORE_DATA                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350819
#define RSRFSIGGEN_ATTR_WLANN_MAC_FRAME_CONTROL_WEP                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350820
#define RSRFSIGGEN_ATTR_WLANN_MAC_FRAME_CONTROL_ORDER                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350821
#define RSRFSIGGEN_ATTR_WLANN_MAC_ADDRESS_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350823
#define RSRFSIGGEN_ATTR_WLANN_MAC_ADDRESS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350824
#define RSRFSIGGEN_ATTR_WLANN_MAC_SEQUENCE_CONTROL_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350825
#define RSRFSIGGEN_ATTR_WLANN_MAC_SEQUENCE_CONTROL_FRAG_START                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350826
#define RSRFSIGGEN_ATTR_WLANN_MAC_SEQUENCE_CONTROL_FRAG_INCREMENT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350827
#define RSRFSIGGEN_ATTR_WLANN_MAC_SEQUENCE_CONTROL_SEQ_START                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350828
#define RSRFSIGGEN_ATTR_WLANN_MAC_SEQUENCE_CONTROL_SEQ_INCREMENT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350829
#define RSRFSIGGEN_ATTR_WLANN_MAC_HT_CONTROL_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350832
#define RSRFSIGGEN_ATTR_WLANN_MAC_HT_CONTROL                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350833
#define RSRFSIGGEN_ATTR_WLANN_MAC_HT_RDG_MORE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350834
#define RSRFSIGGEN_ATTR_WLANN_MAC_HT_AC_CONSTRAINT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350835
#define RSRFSIGGEN_ATTR_WLANN_MAC_HT_RESERVED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350836
#define RSRFSIGGEN_ATTR_WLANN_MAC_HT_S_RESERVED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357261
#define RSRFSIGGEN_ATTR_WLANN_MAC_HT_ZLF_ANNOUNCEMENT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357262
#define RSRFSIGGEN_ATTR_WLANN_MAC_HT_NDP_ANNOUNCEMENT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350837
#define RSRFSIGGEN_ATTR_WLANN_MAC_HT_CSI_STEERING                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350838
#define RSRFSIGGEN_ATTR_WLANN_MAC_HT_FEEDBACK_REQUEST                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350839
#define RSRFSIGGEN_ATTR_WLANN_MAC_HT_CALIBRATION_SEQUENCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350840
#define RSRFSIGGEN_ATTR_WLANN_MAC_HT_CALIBRATION_POSITION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350841
#define RSRFSIGGEN_ATTR_WLANN_MAC_HT_LINK_ADAPTATION_CONTROL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350842
#define RSRFSIGGEN_ATTR_WLANN_MAC_HT_ENABLED                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350843
#define RSRFSIGGEN_ATTR_WLANN_MAC_VHT_CONTROL_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350844
#define RSRFSIGGEN_ATTR_WLANN_MAC_VHT_CONTROL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350845
#define RSRFSIGGEN_ATTR_WLANN_MAC_VHT_RDG_MORE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350846
#define RSRFSIGGEN_ATTR_WLANN_MAC_VHT_AC_CONSTRAINT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350847
#define RSRFSIGGEN_ATTR_WLANN_MAC_VHT_UNSOLICITED_MFB                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350848
#define RSRFSIGGEN_ATTR_WLANN_MAC_VHT_FB_TX_TYPE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350849
#define RSRFSIGGEN_ATTR_WLANN_MAC_VHT_CODING_TYPE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350850
#define RSRFSIGGEN_ATTR_WLANN_MAC_VHT_GIDH                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350851
#define RSRFSIGGEN_ATTR_WLANN_MAC_VHT_MFB                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350852
#define RSRFSIGGEN_ATTR_WLANN_MAC_VHT_MFSI_GIDL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350853
#define RSRFSIGGEN_ATTR_WLANN_MAC_VHT_MSI                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350854
#define RSRFSIGGEN_ATTR_WLANN_MAC_VHT_MRQ                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350855
#define RSRFSIGGEN_ATTR_WLANN_MAC_VHT_RESERVED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350856
#define RSRFSIGGEN_ATTR_WLANN_MAC_VHT_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350857
#define RSRFSIGGEN_ATTR_WLANN_MAC_HE_CONTROL                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355970
#define RSRFSIGGEN_ATTR_WLANN_MAC_HE_AGGREGATED_CONTROL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355971
#define RSRFSIGGEN_ATTR_WLANN_MAC_HE_INDICATOR                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355972
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_HEADER_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357263
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_FCS_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357264
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_FRAME_CONTROL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357265
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_DURATION_ID                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357266
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_QOS_CONTROL_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357267
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_QOS_CONTROL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357268
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_FRAME_CONTROL_PROTOCOL_VERSION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357269
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_FRAME_CONTROL_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357270
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_FRAME_CONTROL_SUBTYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357271
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_FRAME_CONTROL_TO_DS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357272
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_FRAME_CONTROL_FROM_DS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357273
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_FRAME_CONTROL_MORE_FRAG                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357274
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_FRAME_CONTROL_RETRY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357275
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_FRAME_CONTROL_POWER_MANAGEMENT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357276
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_FRAME_CONTROL_MORE_DATA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357277
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_FRAME_CONTROL_WEP                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357278
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_FRAME_CONTROL_ORDER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357279
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_ADDRESS_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357280
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_ADDRESS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357281
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_SEQUENCE_CONTROL_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357282
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_SEQUENCE_CONTROL_FRAG_START                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357283
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_SEQUENCE_CONTROL_FRAG_INCREMENT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357284
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_SEQUENCE_CONTROL_SEQ_START                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357285
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_SEQUENCE_CONTROL_SEQ_INCREMENT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357286
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_HT_CONTROL_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357287
#define RSRFSIGGEN_ATTR_WLANN_USER_MAC_VHT_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357288
#define RSRFSIGGEN_ATTR_WLANN_SPATIAL_MAPPING_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350858
#define RSRFSIGGEN_ATTR_WLANN_SPATIAL_MAPPING_BEAMFORMING_FILE_SELECTION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350859
#define RSRFSIGGEN_ATTR_WLANN_SPATIAL_MAPPING_INDEX                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350860
#define RSRFSIGGEN_ATTR_WLANN_SPATIAL_MAPPING_TIME_SHIFT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350861
#define RSRFSIGGEN_ATTR_WLANN_SPATIAL_MAPPING_I_VALUE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350862
#define RSRFSIGGEN_ATTR_WLANN_SPATIAL_MAPPING_Q_VALUE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350863
#define RSRFSIGGEN_ATTR_WLANN_HE_LINK_DIRECTION                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356023
#define RSRFSIGGEN_ATTR_WLANN_HE_GUARD_INTERVAL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356024
#define RSRFSIGGEN_ATTR_WLANN_HE_PACKET_EXTENSION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356025
#define RSRFSIGGEN_ATTR_WLANN_HE_TIME_DOMAIN_WINDOWING                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356026
#define RSRFSIGGEN_ATTR_WLANN_HE_BEAM_CHANGE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356027
#define RSRFSIGGEN_ATTR_WLANN_HE_PPDU_FORMAT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356028
#define RSRFSIGGEN_ATTR_WLANN_HE_LTF                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356029
#define RSRFSIGGEN_ATTR_WLANN_HE_CURRENT_PE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356030
#define RSRFSIGGEN_ATTR_WLANN_HE_106_TONE_RU                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356031
#define RSRFSIGGEN_ATTR_WLANN_HE_TRANSITION_TIME                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356032
#define RSRFSIGGEN_ATTR_WLANN_HE_LOCKED_CLOCK_BIT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356033
#define RSRFSIGGEN_ATTR_WLANN_HE_SIGB_DCM                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357289
#define RSRFSIGGEN_ATTR_WLANN_HE_SIGB_MCS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357290
#define RSRFSIGGEN_ATTR_WLANN_HE_PREAMBLE_PUNCTURING_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359824
#define RSRFSIGGEN_ATTR_WLANN_HE_PREAMBLE_PUNCTURING_BANDWIDTH_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359825
#define RSRFSIGGEN_ATTR_WLANN_HE_BSS_COLOR                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357291
#define RSRFSIGGEN_ATTR_WLANN_HE_TXOP_DURATION                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357292
#define RSRFSIGGEN_ATTR_WLANN_HE_SPATIAL_REUSE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357293
#define RSRFSIGGEN_ATTR_WLANN_HE_DOPPLER                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357294
#define RSRFSIGGEN_ATTR_WLANN_HE_PREFEC_PADDING_FACTOR                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357295
#define RSRFSIGGEN_ATTR_WLANN_HE_PE_DISAMBIGUITY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357296
#define RSRFSIGGEN_ATTR_WLANN_HE_LOGGING_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357297
#define RSRFSIGGEN_ATTR_WLANN_HE_LOGGING_OUTPUT_FILE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357298
#define RSRFSIGGEN_ATTR_WLANN_EHT_SIG_BLOCK_USER_X                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362648
#define RSRFSIGGEN_ATTR_WLANN_EHT_SIG_MCS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362649
#define RSRFSIGGEN_ATTR_WLANN_EHT_SIG_DIFF_PER_80MHZ                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362650
#define RSRFSIGGEN_ATTR_WLANN_EHT_SIG_NON_OFDMA_USERS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362651
#define RSRFSIGGEN_ATTR_WLANN_BEACON_TIME_STAMP                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353034
#define RSRFSIGGEN_ATTR_WLANN_BEACON_INTERVAL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353035
#define RSRFSIGGEN_ATTR_WLANN_BEACON_SSID                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353036
#define RSRFSIGGEN_ATTR_WLANN_BEACON_SUPPORTED_RATES                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353037
#define RSRFSIGGEN_ATTR_WLANN_BEACON_DSSS_CURRENT_CHANNEL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353038
#define RSRFSIGGEN_ATTR_WLANN_BEACON_ATIM_WINDOW                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353039
#define RSRFSIGGEN_ATTR_WLANN_BEACON_IMMEDIATE_BLOCK_ACK                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353040
#define RSRFSIGGEN_ATTR_WLANN_BEACON_APSD                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353041
#define RSRFSIGGEN_ATTR_WLANN_BEACON_CHANNEL_AGILITY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353042
#define RSRFSIGGEN_ATTR_WLANN_BEACON_CF_POLL_REQUEST                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353043
#define RSRFSIGGEN_ATTR_WLANN_BEACON_DELAYED_BLOCK_ACK                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353044
#define RSRFSIGGEN_ATTR_WLANN_BEACON_DELAYED_SHORT_SLOT_TIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353045
#define RSRFSIGGEN_ATTR_WLANN_BEACON_PBCC                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353046
#define RSRFSIGGEN_ATTR_WLANN_BEACON_CF_POLLABLE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353047
#define RSRFSIGGEN_ATTR_WLANN_BEACON_DSSS_OFDM                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353048
#define RSRFSIGGEN_ATTR_WLANN_BEACON_QOS                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353049
#define RSRFSIGGEN_ATTR_WLANN_BEACON_SHORT_PREAMBLE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353050
#define RSRFSIGGEN_ATTR_WLANN_BEACON_IBSS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353051
#define RSRFSIGGEN_ATTR_WLANN_BEACON_RADIO_MEASUREMENT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353052
#define RSRFSIGGEN_ATTR_WLANN_BEACON_SPECTRUM_MGMT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353053
#define RSRFSIGGEN_ATTR_WLANN_BEACON_PRIVACY                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353054
#define RSRFSIGGEN_ATTR_WLANN_BEACON_ESS                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353055
#define RSRFSIGGEN_ATTR_WLANN_BEACON_BARKER_PREAMBLE_MODE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353056
#define RSRFSIGGEN_ATTR_WLANN_BEACON_USE_PROTECTION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353057
#define RSRFSIGGEN_ATTR_WLANN_BEACON_NONERP_PRESENT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353058
#define RSRFSIGGEN_ATTR_WLANN_BEACON_HT_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353059
#define RSRFSIGGEN_ATTR_WLANN_BEACON_GREEN_FIELD                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353060
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_TRIGGER_TYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355973
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_LENGTH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355974
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_CASCADE_INDICATION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355975
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_CS_REQUIRED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355976
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_BANDWIDTH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355977
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_GI_LTF                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355978
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_MU_MIMO_LTF_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355979
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_NUM_HE_LTF_SYMBOLS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355980
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_STBC                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355981
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_LDPC_EXT_SYMB_SEG                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355982
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_AP_TX_POWER                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355983
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_PACKET_EXTENSION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355984
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_SPATIAL_REUSE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355985
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_DOPPLER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355986
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_HE_SIG_A_RESERVED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355987
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_RESERVED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355988
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_TF_TYPE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362652
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_EHT_RESERVED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363333
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_HE_EHT_P160                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363334
#define RSRFSIGGEN_ATTR_WLANN_COMMON_INFO_SPECIAL_USER_INFO_FIELD_PRESENT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363335
#define RSRFSIGGEN_ATTR_WLANN_USER_INFO_AID12                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355989
#define RSRFSIGGEN_ATTR_WLANN_USER_INFO_RU_ALLOCATION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355990
#define RSRFSIGGEN_ATTR_WLANN_USER_INFO_CODING_TYPE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355991
#define RSRFSIGGEN_ATTR_WLANN_USER_INFO_MCS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355992
#define RSRFSIGGEN_ATTR_WLANN_USER_INFO_DCM                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355993
#define RSRFSIGGEN_ATTR_WLANN_USER_INFO_SS_ALLOCATION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355994
#define RSRFSIGGEN_ATTR_WLANN_USER_INFO_TARGET_RSSI                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355995
#define RSRFSIGGEN_ATTR_WLANN_USER_INFO_TARGET_RSV                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355996
#define RSRFSIGGEN_ATTR_WLANN_TRIGGER_DEPENDENT_USER_INFO                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355997
#define RSRFSIGGEN_ATTR_WLANN_USER_INFO_PS160                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363336
#define RSRFSIGGEN_ATTR_WLANN_USER_INFO_PHY_VERSION_ID                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363337
#define RSRFSIGGEN_ATTR_WLANN_USER_INFO_FIRST_SPATIAL_REUSE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363338
#define RSRFSIGGEN_ATTR_WLANN_USER_INFO_SECOND_SPATIAL_REUSE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363339
#define RSRFSIGGEN_ATTR_WLANN_USER_INFO_UL_BAND_EXTENSION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363340
#define RSRFSIGGEN_ATTR_WLANN_USER_INFO_U_SIG_DISREGARD_AND_VALIDATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363341
#define RSRFSIGGEN_ATTR_WLANN_USER_INFO_RESERVED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363342
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_USER_RU_SELECTION_FIRST_CONTENT_CHANNEL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355998
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_USER_RU_ALLOCATION_FIRST_CONTENT_CHANNEL                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362653
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_USER_RU_ALLOCATION_SECOND_CONTENT_CHANNEL                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362654
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_USER_RU_SELECTION_SECOND_CONTENT_CHANNEL                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355999
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_NUMBER_OF_MU_MIMO_USERS_FIRST_CONTENT_CHANNEL                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356000
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_NUMBER_OF_MU_MIMO_USERS_SECOND_CONTENT_CHANNEL                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356001
#define RSRFSIGGEN_ATTR_WLANN_FRAME_BLOCK_CENTER_26_TONE_RU                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356002
#define RSRFSIGGEN_ATTR_WLANN_MPDU_NUMBER                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353068
#define RSRFSIGGEN_ATTR_WLANN_MPDU_EOF                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353069
#define RSRFSIGGEN_ATTR_WLANN_MPDU_DATA_SOURCE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353070
#define RSRFSIGGEN_ATTR_WLANN_MPDU_DATA_PATTERN                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353071
#define RSRFSIGGEN_ATTR_WLANN_MPDU_DATA_LIST                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353072
#define RSRFSIGGEN_ATTR_WLANN_MPDU_DATA_LENGTH                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353073
#define RSRFSIGGEN_ATTR_WLANN_MPDU_USER_EOF                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362655
#define RSRFSIGGEN_ATTR_WLANN_MPDU_USER_PADDING_LENGTH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362656
#define RSRFSIGGEN_ATTR_WLANN_MPDU_USER_TRIGGER_PROCESS_TIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362657
#define RSRFSIGGEN_ATTR_WLANN_FRAME_USER_GAIN                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357299
#define RSRFSIGGEN_ATTR_WLANN_FRAME_USER_MRU_INDEX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361911
#define RSRFSIGGEN_ATTR_WLANN_FRAME_USER_MU_MIMO                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357300
#define RSRFSIGGEN_ATTR_WLANN_FRAME_USER_NSTS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357301
#define RSRFSIGGEN_ATTR_WLANN_FRAME_USER_RU_TYPE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357302
#define RSRFSIGGEN_ATTR_WLANN_FRAME_USER_STATION_ID                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356034
#define RSRFSIGGEN_ATTR_WLANN_FRAME_USER_STATE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357303
#define RSRFSIGGEN_ATTR_WLANN_FRAME_USER_TXBF                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357304
#define RSRFSIGGEN_ATTR_WLANN_FRAME_USER_DUAL_CARRIER_MODULATION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356035
#define RSRFSIGGEN_ATTR_WLANN_FRAME_USER_MPDU_NUMBER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357305
#define RSRFSIGGEN_ATTR_WLANN_USER_MPDU_EOF                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357306
#define RSRFSIGGEN_ATTR_WLANN_USER_MPDU_DATA_SOURCE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357307
#define RSRFSIGGEN_ATTR_WLANN_USER_MPDU_DATA_PATTERN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357308
#define RSRFSIGGEN_ATTR_WLANN_USER_MPDU_DATA_LIST                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357309
#define RSRFSIGGEN_ATTR_WLANN_USER_MPDU_DATA_LENGTH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357310
#define RSRFSIGGEN_ATTR_WLANN_TRIGGER_STATUS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350864
#define RSRFSIGGEN_ATTR_WLANN_TRIGGER_ARM                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350865
#define RSRFSIGGEN_ATTR_WLANN_TRIGGER_EXECUTE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350866
#define RSRFSIGGEN_ATTR_WLANN_TRIGGER_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350867
#define RSRFSIGGEN_ATTR_WLANN_TRIGGER_SOURCE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350868
#define RSRFSIGGEN_ATTR_WLANN_TRIGGER_SIGNAL_DURATION_UNIT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350869
#define RSRFSIGGEN_ATTR_WLANN_TRIGGER_SIGNAL_DURATION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350870
#define RSRFSIGGEN_ATTR_WLANN_TIME_BASED_TRIGGER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363345
#define RSRFSIGGEN_ATTR_WLANN_INTERNAL_TRIGGER_DELAY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350871
#define RSRFSIGGEN_ATTR_WLANN_INTERNAL_TRIGGER_INHIBIT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350872
#define RSRFSIGGEN_ATTR_WLANN_EXTERNAL_TRIGGER_DELAY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350873
#define RSRFSIGGEN_ATTR_WLANN_EXTERNAL_TRIGGER_INHIBIT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350874
#define RSRFSIGGEN_ATTR_WLANN_TRIGGER_SHIFT_FALLING_EDGE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353074
#define RSRFSIGGEN_ATTR_WLANN_TRIGGER_SHIFT_RISING_EDGE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353075
#define RSRFSIGGEN_ATTR_WLANN_TRIGGER_FRAME_INDEX                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353076
#define RSRFSIGGEN_ATTR_WLANN_MARKER_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350875
#define RSRFSIGGEN_ATTR_WLANN_MARKER_FRAME_BLOCK_INDEX                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350876
#define RSRFSIGGEN_ATTR_WLANN_MARKER_FRAME_BLOCK_INDEX_SMW                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355519
#define RSRFSIGGEN_ATTR_WLANN_MARKER_PULSE_DIVIDER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350877
#define RSRFSIGGEN_ATTR_WLANN_MARKER_PULSE_FREQUENCY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350878
#define RSRFSIGGEN_ATTR_WLANN_MARKER_PATTERN                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350879
#define RSRFSIGGEN_ATTR_WLANN_MARKER_ON_TIME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350880
#define RSRFSIGGEN_ATTR_WLANN_MARKER_OFF_TIME                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350881
#define RSRFSIGGEN_ATTR_WLANN_MARKER_DELAY                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350882
#define RSRFSIGGEN_ATTR_WLANN_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350883
#define RSRFSIGGEN_ATTR_WLANN_FIXED_MARKER_DELAY_MAXIMUM                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350884
#define RSRFSIGGEN_ATTR_WLANN_FIXED_MARKER_DELAY_MINIMUM                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350885
#define RSRFSIGGEN_ATTR_WLANN_CLOCK_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350886
#define RSRFSIGGEN_ATTR_WLANN_CLOCK_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350887
#define RSRFSIGGEN_ATTR_WLANN_CHIP_CLOCK_MULTIPLIER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350888
#define RSRFSIGGEN_ATTR_WLANN_CLOCK_SYNCHRONISATION_EXECUTE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350889
#define RSRFSIGGEN_ATTR_WLANN_CLOCK_SYNCHRONISATION_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350890
#define RSRFSIGGEN_ATTR_WLANN_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350891
#define RSRFSIGGEN_ATTR_WLANAD_ENABLED                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355595
#define RSRFSIGGEN_ATTR_WLANAD_SET_TO_DEFAULT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355596
#define RSRFSIGGEN_ATTR_WLANAD_GENERATE_WAVEFORM_FILE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355597
#define RSRFSIGGEN_ATTR_WLANAD_FRAME_TYPE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355599
#define RSRFSIGGEN_ATTR_WLANAD_DMG_PHY_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355600
#define RSRFSIGGEN_ATTR_WLANAD_SETTINGS_CATALOG                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355601
#define RSRFSIGGEN_ATTR_WLANAD_DELETE_SETTINGS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355602
#define RSRFSIGGEN_ATTR_WLANAD_RECALL_SETTINGS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355604
#define RSRFSIGGEN_ATTR_WLANAD_SAVE_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355606
#define RSRFSIGGEN_ATTR_WLANAD_FILTER_TYPE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355609
#define RSRFSIGGEN_ATTR_WLANAD_CUT_OFF_FREQUENCY_SHIFT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355610
#define RSRFSIGGEN_ATTR_WLANAD_FILTER_PARAMETER_ROOT_COSINE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355611
#define RSRFSIGGEN_ATTR_WLANAD_FILTER_PARAMETER_COSINE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355612
#define RSRFSIGGEN_ATTR_WLANAD_FILTER_PARAMETER_GAUSS_PURE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355613
#define RSRFSIGGEN_ATTR_WLANAD_FILTER_PARAMETER_GAUSS_FSK                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355614
#define RSRFSIGGEN_ATTR_WLANAD_FILTER_PARAMETER_APCO25                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355615
#define RSRFSIGGEN_ATTR_WLANAD_FILTER_PARAMETER_SPLIT_PHASE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355616
#define RSRFSIGGEN_ATTR_WLANAD_FILTER_PARAMETER_LOW_PASS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355617
#define RSRFSIGGEN_ATTR_WLANAD_FILTER_PARAMETER_LOW_PASS_EVM                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355618
#define RSRFSIGGEN_ATTR_WLANAD_FILTER_IMPULSE_LENGTH_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355619
#define RSRFSIGGEN_ATTR_WLANAD_FILTER_IMPULSE_LENGTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355620
#define RSRFSIGGEN_ATTR_WLANAD_FILTER_UPSAMPLING_FACTOR_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355621
#define RSRFSIGGEN_ATTR_WLANAD_FILTER_UPSAMPLING_FACTOR                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355622
#define RSRFSIGGEN_ATTR_WLANAD_SAMPLE_RATE_VARIATION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355623
#define RSRFSIGGEN_ATTR_WLANAD_CLIPPING_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355624
#define RSRFSIGGEN_ATTR_WLANAD_CLIPPING_LEVEL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355625
#define RSRFSIGGEN_ATTR_WLANAD_CLIPPING_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355626
#define RSRFSIGGEN_ATTR_WLANAD_FRAME_SEQUENCE_LENGTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355627
#define RSRFSIGGEN_ATTR_WLANAD_FRAME_IDLE_TIME                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355628
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MCS                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355629
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MODULATION                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355630
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_CHANNEL_CODING                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355631
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_DATA_RATE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355632
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_REPETITION                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355633
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_CODE_RATE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355634
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_SCRAMBLER_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355635
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_SCRAMBLER_INIT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355636
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_DATA_SOURCE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355637
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_DATA_PATTERN                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355638
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_DATA_LIST                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355639
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_DATA_LENGTH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355641
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_DATA_SYMBOLS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355642
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_DATA_TIME_DOMAIN_WINDOWING_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355643
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_DATA_TRANSITION_TIME                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355644
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_PREAMBLE_HEADER_ACTIVE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355645
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_HEADER_PACKET_TYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355646
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_HEADER_TURNAROUND_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355647
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_HEADER_TRAINING_LENGTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355648
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_HEADER_BEAM_TRACKING_REQUEST_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355649
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_HEADER_LAST_RSSI                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355650
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_HEADER_EXTENDED_SC_MCS_INDICATION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357311
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_HEADER_TONE_PAIRING_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355651
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_HEADER_DTP_INDICATOR_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355652
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_NUMBER_OF_MPDUS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355653
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MPDU_DATA_LENGTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355654
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MPDU_DATA_SOURCE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355655
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MPDU_DATA_PATTERN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355656
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MPDU_DATA_LIST                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355657
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_HEADER_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355659
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_FCS_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355660
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_DURATION_ID                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355661
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_SEQUENCE_CONTROL_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355662
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_SEQUENCE_START_NUMBER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355663
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_FRAGMENT_START_NUMBER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355664
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_SEQUENCE_INCREMENT_EVERY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355665
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_FRAGMENT_INCREMENT_EVERY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355666
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_QOS_CONTROL_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355667
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_QOS_CONTROL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355668
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_FRAME_CONTROL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355669
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_FRAME_CONTROL_EXTENSION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355670
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_FRAME_CONTROL_FDS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355671
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_FRAME_CONTROL_MORE_DATA                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355672
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_FRAME_CONTROL_MORE_FRAGMENTS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355673
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_FRAME_CONTROL_ORDER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355674
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_FRAME_CONTROL_PFR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355675
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_FRAME_CONTROL_POWER_MANAGEMENT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355676
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_FRAME_CONTROL_PROTOCOL_VERSION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355677
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_FRAME_CONTROL_RETRY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355678
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_FRAME_CONTROL_SUBTYPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355679
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_FRAME_CONTROL_TDS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355680
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_FRAME_CONTROL_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355681
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_ADDRESS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355682
#define RSRFSIGGEN_ATTR_WLANAD_PPDU_MAC_ADDRESS_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355683
#define RSRFSIGGEN_ATTR_WLANAY_MINIMUM_DURATION_OF_DATA                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363350
#define RSRFSIGGEN_ATTR_WLANAY_CSD_ENABLED                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363351
#define RSRFSIGGEN_ATTR_WLANAY_PI_2_8_PSK_APPLIED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363352
#define RSRFSIGGEN_ATTR_WLANAY_SPATIAL_STREAMS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363353
#define RSRFSIGGEN_ATTR_WLANAY_TRN_AGGREGATION                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363354
#define RSRFSIGGEN_ATTR_WLANAY_ADDITIONAL_PPDU_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363355
#define RSRFSIGGEN_ATTR_WLANAY_GI_TYPE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363356
#define RSRFSIGGEN_ATTR_WLANAY_PPDU_AGGREGATION_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363357
#define RSRFSIGGEN_ATTR_WLANAY_CHANNEL_AGGREGATE_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363358
#define RSRFSIGGEN_ATTR_WLANAY_BEAMFORMED_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363359
#define RSRFSIGGEN_ATTR_WLANAY_BASE_MCS                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363360
#define RSRFSIGGEN_ATTR_WLANAY_BANDWIDTH                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363361
#define RSRFSIGGEN_ATTR_WLANAY_CHANNEL_CONFIGURATION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363362
#define RSRFSIGGEN_ATTR_WLANAY_LONG_LDPC_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363363
#define RSRFSIGGEN_ATTR_WLANAY_DUAL_POLARIZATION_TRN_TRAINING_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363364
#define RSRFSIGGEN_ATTR_WLANAY_FIRST_PATH_TRAINING_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363365
#define RSRFSIGGEN_ATTR_WLANAY_MU_FORMAT_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363366
#define RSRFSIGGEN_ATTR_WLANAY_NUC_ENABLED                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363367
#define RSRFSIGGEN_ATTR_WLANAY_PRIMARY_CHANNEL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363368
#define RSRFSIGGEN_ATTR_WLANAY_RX_TRN_UNITS_PER_EACH_TX_TRN_UNIT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363369
#define RSRFSIGGEN_ATTR_WLANAY_STBC_ENABLED                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363370
#define RSRFSIGGEN_ATTR_WLANAY_TRAINING_M                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363371
#define RSRFSIGGEN_ATTR_WLANAY_TRAINING_N                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363372
#define RSRFSIGGEN_ATTR_WLANAY_TRAINING_P                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363373
#define RSRFSIGGEN_ATTR_WLANAY_TRAINING_SEQUENCE_LENGTH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363374
#define RSRFSIGGEN_ATTR_WLANAY_DIFFERENTIAL_MODULATION_AND_CODING_SCHEME                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363375
#define RSRFSIGGEN_ATTR_WLANAY_SCRAMBLER_SEED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363376
#define RSRFSIGGEN_ATTR_WLANAY_SUPERIMPOSED_CODE_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363377
#define RSRFSIGGEN_ATTR_WLANAY_MU_MIMO_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363378
#define RSRFSIGGEN_ATTR_WLANAY_USER_STATE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363379
#define RSRFSIGGEN_ATTR_WLANAY_STATION_ID                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363380
#define RSRFSIGGEN_ATTR_WLANAY_NUMBER_OF_USERS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363381
#define RSRFSIGGEN_ATTR_WLANAD_TRIGGER_STATUS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355684
#define RSRFSIGGEN_ATTR_WLANAD_TRIGGER_ARM                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355685
#define RSRFSIGGEN_ATTR_WLANAD_TRIGGER_EXECUTE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355686
#define RSRFSIGGEN_ATTR_WLANAD_TRIGGER_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355687
#define RSRFSIGGEN_ATTR_WLANAD_TRIGGER_SOURCE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355688
#define RSRFSIGGEN_ATTR_WLANAD_TRIGGER_SIGNAL_DURATION_UNIT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355689
#define RSRFSIGGEN_ATTR_WLANAD_TRIGGER_SIGNAL_DURATION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355690
#define RSRFSIGGEN_ATTR_WLANAD_TIME_BASED_TRIGGER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363349
#define RSRFSIGGEN_ATTR_WLANAD_INTERNAL_TRIGGER_DELAY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355691
#define RSRFSIGGEN_ATTR_WLANAD_INTERNAL_TRIGGER_INHIBIT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355692
#define RSRFSIGGEN_ATTR_WLANAD_EXTERNAL_SYNCHRONISE_OUTPUT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355898
#define RSRFSIGGEN_ATTR_WLANAD_EXTERNAL_TRIGGER_DELAY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355693
#define RSRFSIGGEN_ATTR_WLANAD_EXTERNAL_TRIGGER_INHIBIT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355694
#define RSRFSIGGEN_ATTR_WLANAD_TRIGGER_SHIFT_FALLING_EDGE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355695
#define RSRFSIGGEN_ATTR_WLANAD_TRIGGER_SHIFT_RISING_EDGE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355696
#define RSRFSIGGEN_ATTR_WLANAD_TRIGGER_FRAME_INDEX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355697
#define RSRFSIGGEN_ATTR_WLANAD_MARKER_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355698
#define RSRFSIGGEN_ATTR_WLANAD_MARKER_PULSE_DIVIDER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355699
#define RSRFSIGGEN_ATTR_WLANAD_MARKER_PULSE_FREQUENCY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355700
#define RSRFSIGGEN_ATTR_WLANAD_MARKER_PATTERN                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355701
#define RSRFSIGGEN_ATTR_WLANAD_MARKER_ON_TIME                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355702
#define RSRFSIGGEN_ATTR_WLANAD_MARKER_OFF_TIME                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355703
#define RSRFSIGGEN_ATTR_WLANAD_MARKER_DELAY                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355704
#define RSRFSIGGEN_ATTR_WLANAD_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355705
#define RSRFSIGGEN_ATTR_WLANAD_FIXED_MARKER_DELAY_MAXIMUM                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355706
#define RSRFSIGGEN_ATTR_WLANAD_FIXED_MARKER_DELAY_MINIMUM                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355707
#define RSRFSIGGEN_ATTR_WLANAD_CLOCK_SOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355708
#define RSRFSIGGEN_ATTR_WLANAD_CLOCK_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355709
#define RSRFSIGGEN_ATTR_WLANAD_CHIP_CLOCK_MULTIPLIER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355710
#define RSRFSIGGEN_ATTR_WIMAX_ENABLED                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346840
#define RSRFSIGGEN_ATTR_WIMAX_SET_TO_DEFAULT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346841
#define RSRFSIGGEN_ATTR_WIMAX_VERSION                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346842
#define RSRFSIGGEN_ATTR_WIMAX_USE_BASEBAND_AB                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346843
#define RSRFSIGGEN_ATTR_WIMAX_BASEBAND_B_RELATIVE_TO_A                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346844
#define RSRFSIGGEN_ATTR_WIMAX_FAST_STORING                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352876
#define RSRFSIGGEN_ATTR_WIMAX_SETTINGS_CATALOG                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346845
#define RSRFSIGGEN_ATTR_WIMAX_DELETE_SETTINGS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346846
#define RSRFSIGGEN_ATTR_WIMAX_RECALL_SETTINGS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346847
#define RSRFSIGGEN_ATTR_WIMAX_SAVE_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346848
#define RSRFSIGGEN_ATTR_WIMAX_PHYSICAL_LAYER_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346849
#define RSRFSIGGEN_ATTR_WIMAX_GENERATE_WAVEFORM_FILE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346850
#define RSRFSIGGEN_ATTR_WIMAX_DUPLEXING                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346851
#define RSRFSIGGEN_ATTR_WIMAX_LINK_DIRECTION                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346852
#define RSRFSIGGEN_ATTR_WIMAX_FRAME_DURATION                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346853
#define RSRFSIGGEN_ATTR_WIMAX_USER_FRAME_DURATION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346854
#define RSRFSIGGEN_ATTR_WIMAX_DOWNLINK_SUBFRAME_DURATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346855
#define RSRFSIGGEN_ATTR_WIMAX_INITIAL_DELAY_OF_BURST_1                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346856
#define RSRFSIGGEN_ATTR_WIMAX_SEQUENCE_LENGTH                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346857
#define RSRFSIGGEN_ATTR_WIMAX_PREDEFINED_FRAMES                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346858
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_LEVEL_REFERENCE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346859
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_LEVEL_REFERENCE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346860
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_FREQUENCY_BAND                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346861
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_CHANNEL_BANDWIDTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346862
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_FACTOR_N                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346863
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_SAMPLING_RATE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346864
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_BSID                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346865
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_NUMBER_OF_BURSTS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346866
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_TG_TO_TB_RATIO                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346867
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_FFT_SIZE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352877
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_NUMBER_OF_USED_SUBCHANNELS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346868
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_SUBCHANNEL_INDEX                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346869
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_FRAME_PREAMBLE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346870
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_FRAME_NUMBER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346871
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_ULMAP_FILE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346872
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_ULMAP_UCD_COUNT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346873
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_FCH_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346874
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_FCH_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346875
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_FRAME_NUMBER_OFFSET                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346876
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_CONFIGURATION_CHANGE_COUNT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346877
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_FCH_DATA_SOURCE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346878
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_FCH_DATA_LIST                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346879
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_FCH_PATTERN                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346880
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_BURST_PREAMBLE_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352878
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_BURST_MIDAMBLE_REPETITION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346881
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_BURST_MODULATION_AND_RSCC_RATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346882
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_BURST_CHANNEL_CODING                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346883
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_BURST_DATA_LENGTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352879
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_BURST_SYMBOLS_COUNT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352880
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_BURST_DATA_SOURCE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346884
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_BURST_DATA_LIST                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346885
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_BURST_PATTERN                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346886
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_BURST_DIUC                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346887
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_BURST_UIUC                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346888
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_BURST_POWER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346889
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_BURST_GAP                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346890
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_BURST_TYPE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346891
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_BURST_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352881
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_ULMAP_ALLOCATION_START_TIME_BASE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346892
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_ULMAP_ALLOCATION_START_TIME                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346893
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_DLMAP_APPEND_DCD                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346894
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_DLMAP_APPEND_UCD                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346895
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_DLMAP_APPEND_ULMAP                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346896
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_DLMAP_ALLOCATION_START_TIME_BASE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346897
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_DLMAP_ALLOCATION_START_TIME                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346898
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_MAC_CRC_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346899
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_MAC_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346900
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_MAC_CID                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346901
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_MAC_PAYLOAD_ENCRYPTED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346902
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_MAC_EKS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346903
#define RSRFSIGGEN_ATTR_WIMAX_OFDM_MAC_TYPE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346904
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PREDEFINED_FRAME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346905
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_FREQUENCY_BAND                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346906
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_CHANNEL_BANDWIDTH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346907
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SAMPLING_RATE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346908
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_NUMBER_OF_ZONES                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346909
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_FACTOR_N                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346910
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PREAMBLE_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346911
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PREAMBLE_INDEX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346912
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_TG_TO_TB_RATIO                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346913
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_FFT_SIZE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346914
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ID_CELL                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346915
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ZONE_NUMBER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346916
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ZONE_TYPE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346917
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SEGMENT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346918
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_UPLINK_NUMBER_OF_SYMBOLS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352883
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_AUTO                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346919
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_BURST_TABLE_OFFSET_SYMBOL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346920
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PERMBASE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346921
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PRBS_ID                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346922
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DATA_LIST                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346923
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PATTERN                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346924
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_MAC_CRC_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346925
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_MAC_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346926
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_MAC_CID                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346927
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_MAC_EKS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346928
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_MAC_TYPE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346929
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_MAC_PAYLOAD_ENCRYPTED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346930
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_MAC_CRC_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346931
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_MAC_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346932
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_MAC_CID                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346933
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_MAC_EKS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346934
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_MAC_TYPE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346935
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_MAC_PAYLOAD_ENCRYPTED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346936
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SUBCARRIER_RANDOMIZATION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346937
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SUBCARRIER_PERMUTATION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352882
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DEDICATED_PILOTS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346938
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PILOT_PATTERN                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346939
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_NUMBER_OF_BURSTS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346940
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SPACE_TIME_CODING_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346941
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SPACE_TIME_CODING_ANTENNA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346942
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ZONE_BOOSTING                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346943
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_FCH_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346944
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ULMAP_FILE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346945
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ULMAP_UCD_COUNT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346946
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ALLOCATED_SUBCHANNELS_BITMAP                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352884
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SUBCHANNELS_ROTATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352885
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_USE_ALL_SUBCHANNELS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 346947
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_USED_SUBCHANNELS_BITMAP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352886
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_AMC_BAND_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346948
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_AMC_PHYSICAL_BANDS_BITMAP                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346949
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLMAP_MODE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346950
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLMAP_REPETITION_CODING                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346951
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DL_MAP_SLOT_COUNT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352887
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLMAP_FRAME_NUMBER_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346952
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLMAP_DCD_COUNT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346953
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLMAP_BASE_STATION_ID                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346954
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLMAP_INCLUDE_CID_SWITCH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346955
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLMAP_APPEND_DCD                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346956
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLMAP_DCD_CID                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346957
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLMAP_COMPRESSED_MAP                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346958
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLMAP_APPEND_COMPRESSED_ULMAP                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346959
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLMAP_ALLOCATION_START_TIME_BASE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346960
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLMAP_ALLOCATION_START_TIME                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346961
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLMAP_ULMAP_FILE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346962
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_TYPE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346963
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_RELEVANCE_FLAG                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346964
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_RELEVANCE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 346965
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_PERMUTATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346966
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_SEPARABILITY_TYPE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346967
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_DECIMATION_VALUE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346968
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_DECIMATION_OFFSET_RANDOMIZATION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346969
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_MAX_CYCLIC_SHIFT_INDEX                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346970
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_DL_PERMBASE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346971
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_ALLOCATION_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346972
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_SHIFT_VALUE_U                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 346973
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_TOTAL_NUMBER_OF_CIDS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346974
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_SYMBOL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 346975
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_CID                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 346976
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_POWER_BOOST                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346977
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_FREQUENCY_BANDS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 346978
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_START_FREQUENCY_BAND                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346979
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_RELEVANCE_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346980
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_CYCLIC_SHIFT_INDEX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 346981
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_DECIMATION_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346982
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_PERIODICITY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346983
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_SUBCHANNELS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346984
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_SUBCHANNEL_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 346985
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_SOUNDING_BAND_BITMAP                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 346986
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_CSTD_NUMBER_OF_ANTENNAS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 346987
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_CSTD_SHOW_CONFIGURATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356003
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_CSTD_TAPS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 346988
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_CSTD_CYCLIC_DELAY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346989
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_CSTD_LINEAR_GAIN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346990
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_BURST_MODULATION_AND_CODING_RATE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 346992
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_CHANNEL_CODING                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346993
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_BURST_DATA_LENGTH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346994
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DURATION_SLOTS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 346995
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_NUMBER_OF_SUBCHANNELS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 346996
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_NUMBER_OF_SYMBOLS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346997
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_OFFSET_SUBCHANNEL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 346998
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_OFFSET_SYMBOL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 346999
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_OFFSET_MODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347000
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_BURST_DATA_SOURCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347001
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_BOOST                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347002
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_BURST_TYPE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347003
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DIUC                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347004
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_UIUC                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347005
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_CONFLICT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347006
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347007
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_START_OFFSET_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347008
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_SLOTS_AVAILABLE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347009
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_COUNT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347010
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PDU_MULTIPLE_PDUS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347011
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PDU_NUMBER_OF_PDUS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347012
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_BURST_SPACE_TIME_CODING_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352888
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_RATE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347013
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_DATA_LENGTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347014
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_DATA_SOURCE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347015
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_DATA_LIST                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347016
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_DATA_PATTERN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347017
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_DIUC                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347018
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_ACID                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347019
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_DISABLE_ACK                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347020
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_CHASE_MODULATION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347021
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_SPID_SEQUENCE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347022
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_FORMAT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347023
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_PACKET_SIZE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347024
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_HARQ_SLOT_COUNT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347025
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PDU_DATA_LENGTH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347026
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PDU_DATA_SOURCE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347027
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PDU_DATA_LIST                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347028
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PDU_DATA_PATTERN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347029
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PDU_CID                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347030
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PDU_MAC_CRC_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347031
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PDU_MAC_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347032
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PDU_MAC_PAYLOAD_ENCRYPTED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347033
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PDU_MAC_EKS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347034
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_PDU_MAC_TYPE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347035
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_CHANNEL_CODING_RANDOMIZER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347036
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_CHANNEL_CODING_FEC                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347037
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_CHANNEL_CODING_INTERLEAVER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347038
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_CHANNEL_CODE_REPETITION_CODING                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347039
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ULMAP_ALLOCATION_START_TIME_BASE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347040
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ULMAP_ALLOCATION_START_TIME                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347041
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ULMAP_APPEND_DCD                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347042
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ULMAP_DCD_CID                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347043
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ULMAP_APPEND_UCD                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347044
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ULMAP_UCD_CID                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347045
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ULMAP_RANGING_BACKOFF_START                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347046
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ULMAP_RANGING_BACKOFF_END                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347047
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ULMAP_REQUEST_BACKOFF_START                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347048
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_ULMAP_REQUEST_BACKOFF_END                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347049
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_RANGING_OPPORTUNITY_SIZE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347050
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_RANGING_OPPORTUNITY_SLOT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347051
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_RANGING_SUBCHANNEL_GROUPS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347052
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_RANGING_ALLOCATED_CODES                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347053
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_FAST_FEEDBACK_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347054
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_FAST_FEEDBACK_CODEWORD_SIZE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347055
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_FAST_FEEDBACK_SUBCHANNELS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347056
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_FAST_FEEDBACK_SYMBOLS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347057
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_UCD_RANGING_BACKOFF_START                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347058
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_UCD_RANGING_BACKOFF_END                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347059
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_UCD_REQUEST_BACKOFF_START                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347060
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_UCD_REQUEST_BACKOFF_END                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347061
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_UCD_BURST_PROFILE_MAPPING                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347062
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_UCD_FEC_MODULATION_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347063
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DCD_FEC_MODULATION_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347064
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLUL_MAP_INDEX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347065
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLUL_HARQ_ACK_OFFSET_INDICATOR                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347066
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLUL_DL_HARQ_ACK_OFFSET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347067
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLUL_UL_HARQ_ACK_OFFSET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347068
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLUL_ACK_REGION_INDEX                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347069
#define RSRFSIGGEN_ATTR_WIMAX_OFDMA_DLUL_INCLUDE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347070
#define RSRFSIGGEN_ATTR_WIMAX_SAMPLE_RATE_VARIATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347071
#define RSRFSIGGEN_ATTR_WIMAX_FILTER_TYPE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347072
#define RSRFSIGGEN_ATTR_WIMAX_FILTER_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347073
#define RSRFSIGGEN_ATTR_WIMAX_CUT_OFF_FREQUENCY_SHIFT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347074
#define RSRFSIGGEN_ATTR_WIMAX_FILTER_PARAMETER_ROOT_COSINE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347075
#define RSRFSIGGEN_ATTR_WIMAX_FILTER_PARAMETER_COSINE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347076
#define RSRFSIGGEN_ATTR_WIMAX_FILTER_PARAMETER_GAUSS_PURE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347077
#define RSRFSIGGEN_ATTR_WIMAX_FILTER_PARAMETER_GAUSS_FSK                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347078
#define RSRFSIGGEN_ATTR_WIMAX_FILTER_PARAMETER_APCO25                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347079
#define RSRFSIGGEN_ATTR_WIMAX_FILTER_PARAMETER_SPLIT_PHASE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347080
#define RSRFSIGGEN_ATTR_WIMAX_FILTER_PARAMETER_LOWPASS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347081
#define RSRFSIGGEN_ATTR_WIMAX_FILTER_PARAMETER_LOWPASS_EVM                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347082
#define RSRFSIGGEN_ATTR_WIMAX_FILTER_IMPULSE_LENGTH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352889
#define RSRFSIGGEN_ATTR_WIMAX_FILTER_IMPULSE_LENGTH_AUTO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352890
#define RSRFSIGGEN_ATTR_WIMAX_FILTER_OVERSAMPLING_FACTOR                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352891
#define RSRFSIGGEN_ATTR_WIMAX_FILTER_OVERSAMPLING_FACTOR_AUTO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352892
#define RSRFSIGGEN_ATTR_WIMAX_CLIPPING_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347083
#define RSRFSIGGEN_ATTR_WIMAX_CLIPPING_LEVEL                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347084
#define RSRFSIGGEN_ATTR_WIMAX_CLIPPING_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347085
#define RSRFSIGGEN_ATTR_WIMAX_DATA_DUMP_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347086
#define RSRFSIGGEN_ATTR_WIMAX_DATA_DUMP_OUTPUT_DIRECTORY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347087
#define RSRFSIGGEN_ATTR_WIMAX_TRIGGER_STATUS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347088
#define RSRFSIGGEN_ATTR_WIMAX_TRIGGER_ARM                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347089
#define RSRFSIGGEN_ATTR_WIMAX_TRIGGER_EXECUTE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347090
#define RSRFSIGGEN_ATTR_WIMAX_TRIGGER_SOURCE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352893
#define RSRFSIGGEN_ATTR_WIMAX_INTERNAL_TRIGGER_DELAY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351046
#define RSRFSIGGEN_ATTR_WIMAX_INTERNAL_TRIGGER_INHIBIT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351047
#define RSRFSIGGEN_ATTR_WIMAX_TRIGGER_SIGNAL_DURATION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352894
#define RSRFSIGGEN_ATTR_WIMAX_EXTERNAL_TRIGGER_INHIBIT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355105
#define RSRFSIGGEN_ATTR_WIMAX_EXTERNAL_TRIGGER_DELAY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355106
#define RSRFSIGGEN_ATTR_WIMAX_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352895
#define RSRFSIGGEN_ATTR_WIMAX_CLOCK_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352896
#define RSRFSIGGEN_ATTR_WIMAX_EXTERNAL_CLOCK_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352897
#define RSRFSIGGEN_ATTR_WIMAX_EXTERNAL_CLOCK_MULTIPLIER                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352898
#define RSRFSIGGEN_ATTR_WIMAX_CLOCK_SYNCHRONIZATION_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352899
#define RSRFSIGGEN_ATTR_WIMAX_CLOCK_SYNCHRONIZATION_EXECUTE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352900
#define RSRFSIGGEN_ATTR_WIMAX_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352901
#define RSRFSIGGEN_ATTR_DVB_ENABLED                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347091
#define RSRFSIGGEN_ATTR_DVB_SET_TO_DEFAULT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347092
#define RSRFSIGGEN_ATTR_DVB_GENERATE_WAVEFORM_FILE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347093
#define RSRFSIGGEN_ATTR_DVB_STANDARD                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347094
#define RSRFSIGGEN_ATTR_DVB_SETTINGS_CATALOG                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347095
#define RSRFSIGGEN_ATTR_DVB_DELETE_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347096
#define RSRFSIGGEN_ATTR_DVB_RECALL_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347097
#define RSRFSIGGEN_ATTR_DVB_SAVE_SETTINGS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347098
#define RSRFSIGGEN_ATTR_DVB_FAST_STORE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353293
#define RSRFSIGGEN_ATTR_DVB_T_TRANSMITTED_SAMPLES                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355899
#define RSRFSIGGEN_ATTR_DVB_T_DATA_RATE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355900
#define RSRFSIGGEN_ATTR_DVB_T_SIGNAL_DURATION                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355901
#define RSRFSIGGEN_ATTR_DVB_T_SAMPLE_RATE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355902
#define RSRFSIGGEN_ATTR_DVB_T_NUMBER_OF_SUPER_FRAMES                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355903
#define RSRFSIGGEN_ATTR_DVB_T_HIERARCHY_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355904
#define RSRFSIGGEN_ATTR_DVB_T_SOURCE_HP                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355905
#define RSRFSIGGEN_ATTR_DVB_T_SOURCE_LP                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355906
#define RSRFSIGGEN_ATTR_DVB_T_TS_FILE_HP                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355907
#define RSRFSIGGEN_ATTR_DVB_T_TS_FILE_LP                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355909
#define RSRFSIGGEN_ATTR_DVB_T_PN_SCRAMBLER_HP                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355911
#define RSRFSIGGEN_ATTR_DVB_T_PN_SCRAMBLER_LP                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355912
#define RSRFSIGGEN_ATTR_DVB_T_OUTER_CODER_HP                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355913
#define RSRFSIGGEN_ATTR_DVB_T_OUTER_CODER_LP                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355914
#define RSRFSIGGEN_ATTR_DVB_T_OUTER_INTERLEAVER_HP                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355915
#define RSRFSIGGEN_ATTR_DVB_T_OUTER_INTERLEAVER_LP                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355916
#define RSRFSIGGEN_ATTR_DVB_T_INNER_CODER_HP                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355917
#define RSRFSIGGEN_ATTR_DVB_T_INNER_CODER_LP                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355918
#define RSRFSIGGEN_ATTR_DVB_T_INNER_CODER_RATE_HP                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355919
#define RSRFSIGGEN_ATTR_DVB_T_INNER_CODER_RATE_LP                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355920
#define RSRFSIGGEN_ATTR_DVB_T_INNER_INTERLEAVER_BIT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355921
#define RSRFSIGGEN_ATTR_DVB_T_INNER_INTERLEAVER_SYMBOL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355922
#define RSRFSIGGEN_ATTR_DVB_T_INNER_INTERLEAVER_MODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355923
#define RSRFSIGGEN_ATTR_DVB_T_INNER_INTERLEAVER_TX_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355924
#define RSRFSIGGEN_ATTR_DVB_T_OFDM_RF_BANDWIDTH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355925
#define RSRFSIGGEN_ATTR_DVB_T_OFDM_RF_MODULATION                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355926
#define RSRFSIGGEN_ATTR_DVB_T_OFDM_RF_ALPHA                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355927
#define RSRFSIGGEN_ATTR_DVB_T_OFDM_RF_GUARD_INTERVAL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355928
#define RSRFSIGGEN_ATTR_DVB_T_TPS_SETTINGS_CELL_IDENTIFICATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355929
#define RSRFSIGGEN_ATTR_DVB_T_TPS_SETTINGS_TIME_SLICING                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355930
#define RSRFSIGGEN_ATTR_DVB_T_TPS_SETTINGS_ID                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355931
#define RSRFSIGGEN_ATTR_DVB_T_TPS_SETTINGS_MPEFEC                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355932
#define RSRFSIGGEN_ATTR_DVB_H_TRANSMITTED_SAMPLES                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355933
#define RSRFSIGGEN_ATTR_DVB_H_DATA_RATE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355934
#define RSRFSIGGEN_ATTR_DVB_H_SIGNAL_DURATION                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355935
#define RSRFSIGGEN_ATTR_DVB_H_SAMPLE_RATE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355936
#define RSRFSIGGEN_ATTR_DVB_H_NUMBER_OF_SUPER_FRAMES                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355937
#define RSRFSIGGEN_ATTR_DVB_H_HIERARCHY_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355938
#define RSRFSIGGEN_ATTR_DVB_H_SOURCE_HP                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355939
#define RSRFSIGGEN_ATTR_DVB_H_SOURCE_LP                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355940
#define RSRFSIGGEN_ATTR_DVB_H_TS_FILE_HP                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355941
#define RSRFSIGGEN_ATTR_DVB_H_TS_FILE_LP                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355943
#define RSRFSIGGEN_ATTR_DVB_H_PN_SCRAMBLER_HP                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355945
#define RSRFSIGGEN_ATTR_DVB_H_PN_SCRAMBLER_LP                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355946
#define RSRFSIGGEN_ATTR_DVB_H_OUTER_CODER_HP                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355947
#define RSRFSIGGEN_ATTR_DVB_H_OUTER_CODER_LP                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355948
#define RSRFSIGGEN_ATTR_DVB_H_OUTER_INTERLEAVER_HP                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355949
#define RSRFSIGGEN_ATTR_DVB_H_OUTER_INTERLEAVER_LP                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355950
#define RSRFSIGGEN_ATTR_DVB_H_INNER_CODER_HP                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355951
#define RSRFSIGGEN_ATTR_DVB_H_INNER_CODER_LP                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355952
#define RSRFSIGGEN_ATTR_DVB_H_INNER_CODER_RATE_HP                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355953
#define RSRFSIGGEN_ATTR_DVB_H_INNER_CODER_RATE_LP                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355954
#define RSRFSIGGEN_ATTR_DVB_H_INNER_INTERLEAVER_BIT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355955
#define RSRFSIGGEN_ATTR_DVB_H_INNER_INTERLEAVER_SYMBOL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355956
#define RSRFSIGGEN_ATTR_DVB_H_INNER_INTERLEAVER_MODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355957
#define RSRFSIGGEN_ATTR_DVB_H_INNER_INTERLEAVER_TX_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355958
#define RSRFSIGGEN_ATTR_DVB_H_OFDM_RF_BANDWIDTH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355959
#define RSRFSIGGEN_ATTR_DVB_H_OFDM_RF_MODULATION                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355960
#define RSRFSIGGEN_ATTR_DVB_H_OFDM_RF_ALPHA                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355961
#define RSRFSIGGEN_ATTR_DVB_H_OFDM_RF_GUARD_INTERVAL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355962
#define RSRFSIGGEN_ATTR_DVB_H_TPS_SETTINGS_CELL_IDENTIFICATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355963
#define RSRFSIGGEN_ATTR_DVB_H_TPS_SETTINGS_TIME_SLICING                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355964
#define RSRFSIGGEN_ATTR_DVB_H_TPS_SETTINGS_ID                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355965
#define RSRFSIGGEN_ATTR_DVB_H_TPS_SETTINGS_MPEFEC                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355966
#define RSRFSIGGEN_ATTR_DVB_S2_FRAMES                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355711
#define RSRFSIGGEN_ATTR_DVB_S2_STREAM_TYPE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355712
#define RSRFSIGGEN_ATTR_DVB_S2_INPUT_STREAM                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355713
#define RSRFSIGGEN_ATTR_DVB_S2_DATA_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355714
#define RSRFSIGGEN_ATTR_DVB_S2_DATA_PATTERN                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355715
#define RSRFSIGGEN_ATTR_DVB_S2_DATA_LIST                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355716
#define RSRFSIGGEN_ATTR_DVB_S2_DATA_TS                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355718
#define RSRFSIGGEN_ATTR_DVB_S2_DATA_GSE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355720
#define RSRFSIGGEN_ATTR_DVB_S2_DATA_LENGTH                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355722
#define RSRFSIGGEN_ATTR_DVB_S2_BB_SCRAMBLER_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355723
#define RSRFSIGGEN_ATTR_DVB_S2_CRC32_ENABLED                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357312
#define RSRFSIGGEN_ATTR_DVB_S2_OUTER_CODER_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355724
#define RSRFSIGGEN_ATTR_DVB_S2_INNER_CODER_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355725
#define RSRFSIGGEN_ATTR_DVB_S2_INNER_CODER_RATE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355726
#define RSRFSIGGEN_ATTR_DVB_S2_BIT_INTERLEAVER_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355727
#define RSRFSIGGEN_ATTR_DVB_S2_CODE_TYPE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355728
#define RSRFSIGGEN_ATTR_DVB_S2_MODCOD                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355729
#define RSRFSIGGEN_ATTR_DVB_S2_MODULATION                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355730
#define RSRFSIGGEN_ATTR_DVB_S2_PILOT_STATE_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355731
#define RSRFSIGGEN_ATTR_DVB_S2_PL_SCRAMBLER_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355732
#define RSRFSIGGEN_ATTR_DVB_S2_UNCODED_MODE_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357313
#define RSRFSIGGEN_ATTR_DVB_S2_AUTO_DFL                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356036
#define RSRFSIGGEN_ATTR_DVB_S2_AUTO_DATA_LENGTH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356037
#define RSRFSIGGEN_ATTR_DVB_S2_MODCOD_NUMBER_OF_SETTINGS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357314
#define RSRFSIGGEN_ATTR_DVB_S2_COMPLETE_PN_SEQUENCE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362658
#define RSRFSIGGEN_ATTR_DVB_S2_GOLD_SEQUENCE_INDEX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362659
#define RSRFSIGGEN_ATTR_DVB_S2_BB_FRAMES                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362660
#define RSRFSIGGEN_ATTR_DVB_S2_MODCOD_UNIQUE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362661
#define RSRFSIGGEN_ATTR_DVB_S2_TS_HEADER_ACTIVE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355733
#define RSRFSIGGEN_ATTR_DVB_S2_TS_HEADER_SYNC_BYTE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355734
#define RSRFSIGGEN_ATTR_DVB_S2_TS_HEADER_TRANSPORT_ERROR_INDICATOR_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355735
#define RSRFSIGGEN_ATTR_DVB_S2_TS_HEADER_PAYLOAD_UNIT_START_INDICATION_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355736
#define RSRFSIGGEN_ATTR_DVB_S2_TS_HEADER_TRANSPORT_PRIORITY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355737
#define RSRFSIGGEN_ATTR_DVB_S2_TS_HEADER_PID                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355738
#define RSRFSIGGEN_ATTR_DVB_S2_TS_HEADER_SCRAMBLING_CONTROL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355739
#define RSRFSIGGEN_ATTR_DVB_S2_TS_HEADER_ADAPTATION_FIELD_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355740
#define RSRFSIGGEN_ATTR_DVB_S2_TS_HEADER_PAYLOAD_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355741
#define RSRFSIGGEN_ATTR_DVB_S2_TS_HEADER_CONTINUITY_COUNTER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355742
#define RSRFSIGGEN_ATTR_DVB_S2_BB_HEADER_ACTIVE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357315
#define RSRFSIGGEN_ATTR_DVB_S2_BB_CCM_ACM                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355743
#define RSRFSIGGEN_ATTR_DVB_S2_BB_ISSYI_ACTIVE_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355744
#define RSRFSIGGEN_ATTR_DVB_S2_BB_NDP_ACTIVE_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355745
#define RSRFSIGGEN_ATTR_DVB_S2_BB_UPL                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355746
#define RSRFSIGGEN_ATTR_DVB_S2_BB_DFL                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355747
#define RSRFSIGGEN_ATTR_DVB_S2_BB_SYNC                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355748
#define RSRFSIGGEN_ATTR_DVB_S2_MODCOD_TABLE_FRAMES                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357316
#define RSRFSIGGEN_ATTR_DVB_S2_MODCOD_TABLE_CODE_TYPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357317
#define RSRFSIGGEN_ATTR_DVB_S2_MODCOD_TABLE_MODCOD                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357318
#define RSRFSIGGEN_ATTR_DVB_S2_MODCOD_TABLE_PLS_CODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357319
#define RSRFSIGGEN_ATTR_DVB_S2_MODCOD_TABLE_SF                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357320
#define RSRFSIGGEN_ATTR_DVB_S2_MODCOD_TABLE_AUTO_DFL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357321
#define RSRFSIGGEN_ATTR_DVB_S2_MODCOD_TABLE_DFL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357322
#define RSRFSIGGEN_ATTR_DVB_S2_MODCOD_TABLE_PILOT_STATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357323
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_SUPER_FRAME_ACTIVE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362662
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_SFFI                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362663
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_SOSF_WH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362664
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_N_REF                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362665
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_N_PAY                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362666
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_SF_PILOT_STATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362667
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_SF_PILOT_WH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362668
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_ST_WH                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362669
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_SPECIFIC_SFL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362670
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_SPECIFIC_PLI                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362671
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_INFORMATION_CU_LENGTH                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362672
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_INFORMATION_D_SF                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362673
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_INFORMATION_P_SF                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362674
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_INFORMATION_POSTAMBLE_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362675
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_INFORMATION_EHF                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362676
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_INFORMATION_SFL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362677
#define RSRFSIGGEN_ATTR_DVB_S2_SF_CONFIG_TSN                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363107
#define RSRFSIGGEN_ATTR_DVB_S2_BH_CONFIG_BEAM_HOPING_ACTIVE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362678
#define RSRFSIGGEN_ATTR_DVB_S2_BH_CONFIG_ZERO_BEAM_SWITCHING_SIGNAL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362679
#define RSRFSIGGEN_ATTR_DVB_S2_BH_CONFIG_NUMBER_OF_DWELLS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362680
#define RSRFSIGGEN_ATTR_DVB_S2_BH_CONFIG_ATTENUATE_OTHER_DWELL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362681
#define RSRFSIGGEN_ATTR_DVB_S2_BH_CONFIG_BEAM_HOPPING_CYCLE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362682
#define RSRFSIGGEN_ATTR_DVB_S2_BH_CONFIG_FILL_OTHER_DWELLS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362683
#define RSRFSIGGEN_ATTR_DVB_S2_BH_CONFIG_DT_CONFIG_NUMBER_OF_SUPER_FRAMES                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362684
#define RSRFSIGGEN_ATTR_DVB_S2_BH_CONFIG_DT_CONFIG_SFL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362685
#define RSRFSIGGEN_ATTR_DVB_S2_BH_CONFIG_DT_CONFIG_BEAM_SWITCHING_TIME                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362686
#define RSRFSIGGEN_ATTR_DVB_S2_BH_CONFIG_DT_CONFIG_DWELL_LENGTH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362687
#define RSRFSIGGEN_ATTR_DVB_S2X_FRAMES                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355749
#define RSRFSIGGEN_ATTR_DVB_S2X_NUMBER_OF_SUPER_FRAMES                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363382
#define RSRFSIGGEN_ATTR_DVB_S2X_VL_SNR_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355750
#define RSRFSIGGEN_ATTR_DVB_S2X_STREAM_TYPE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355751
#define RSRFSIGGEN_ATTR_DVB_S2X_INPUT_STREAM                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355752
#define RSRFSIGGEN_ATTR_DVB_S2X_DATA_SOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355753
#define RSRFSIGGEN_ATTR_DVB_S2X_DATA_PATTERN                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355754
#define RSRFSIGGEN_ATTR_DVB_S2X_DATA_LIST                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355755
#define RSRFSIGGEN_ATTR_DVB_S2X_DATA_TS                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355757
#define RSRFSIGGEN_ATTR_DVB_S2X_DATA_GSE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355759
#define RSRFSIGGEN_ATTR_DVB_S2X_DATA_LENGTH                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355761
#define RSRFSIGGEN_ATTR_DVB_S2X_CRC32_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357324
#define RSRFSIGGEN_ATTR_DVB_S2X_BB_SCRAMBLER_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355762
#define RSRFSIGGEN_ATTR_DVB_S2X_OUTER_CODER_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355763
#define RSRFSIGGEN_ATTR_DVB_S2X_INNER_CODER_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355764
#define RSRFSIGGEN_ATTR_DVB_S2X_INNER_CODER_RATE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355765
#define RSRFSIGGEN_ATTR_DVB_S2X_SF                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355766
#define RSRFSIGGEN_ATTR_DVB_S2X_BIT_INTERLEAVER_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355767
#define RSRFSIGGEN_ATTR_DVB_S2X_CODE_TYPE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355768
#define RSRFSIGGEN_ATTR_DVB_S2X_MODCOD                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355769
#define RSRFSIGGEN_ATTR_DVB_S2X_MODULATION                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355770
#define RSRFSIGGEN_ATTR_DVB_S2X_PILOT_STATE_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355771
#define RSRFSIGGEN_ATTR_DVB_S2X_UNCODED_MODE_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357325
#define RSRFSIGGEN_ATTR_DVB_S2X_PL_SCRAMBLER_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355772
#define RSRFSIGGEN_ATTR_DVB_S2X_SCR_SEQUENCE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355773
#define RSRFSIGGEN_ATTR_DVB_S2X_AUTO_DFL                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356038
#define RSRFSIGGEN_ATTR_DVB_S2X_AUTO_DATA_LENGTH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356039
#define RSRFSIGGEN_ATTR_DVB_S2X_MODCOD_NUMBER_OF_SETTINGS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357326
#define RSRFSIGGEN_ATTR_DVB_S2X_COMPLETE_PN_SEQUENCE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362688
#define RSRFSIGGEN_ATTR_DVB_S2X_GOLD_SEQUENCE_INDEX                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362689
#define RSRFSIGGEN_ATTR_DVB_S2X_BB_FRAMES                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362690
#define RSRFSIGGEN_ATTR_DVB_S2X_MODCOD_UNIQUE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362691
#define RSRFSIGGEN_ATTR_DVB_S2X_TS_HEADER_ACTIVE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355774
#define RSRFSIGGEN_ATTR_DVB_S2X_TS_HEADER_SYNC_BYTE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355775
#define RSRFSIGGEN_ATTR_DVB_S2X_TS_HEADER_TRANSPORT_ERROR_INDICATOR_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355776
#define RSRFSIGGEN_ATTR_DVB_S2X_TS_HEADER_PAYLOAD_UNIT_START_INDICATION_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355777
#define RSRFSIGGEN_ATTR_DVB_S2X_TS_HEADER_TRANSPORT_PRIORITY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355778
#define RSRFSIGGEN_ATTR_DVB_S2X_TS_HEADER_PID                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355779
#define RSRFSIGGEN_ATTR_DVB_S2X_TS_HEADER_SCRAMBLING_CONTROL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355780
#define RSRFSIGGEN_ATTR_DVB_S2X_TS_HEADER_ADAPTATION_FIELD_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355781
#define RSRFSIGGEN_ATTR_DVB_S2X_TS_HEADER_PAYLOAD_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355782
#define RSRFSIGGEN_ATTR_DVB_S2X_TS_HEADER_CONTINUITY_COUNTER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355783
#define RSRFSIGGEN_ATTR_DVB_S2X_GSE_HEADER_ACTIVE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355784
#define RSRFSIGGEN_ATTR_DVB_S2X_GSE_LABEL_TYPE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355785
#define RSRFSIGGEN_ATTR_DVB_S2X_GSE_LENGTH                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355786
#define RSRFSIGGEN_ATTR_DVB_S2X_GSE_FRAGMENT_ID_USE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355787
#define RSRFSIGGEN_ATTR_DVB_S2X_GSE_FRAGMENT_ID                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355788
#define RSRFSIGGEN_ATTR_DVB_S2X_GSE_TOTAL_LENGTH_USE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355789
#define RSRFSIGGEN_ATTR_DVB_S2X_GSE_TOTAL_LENGTH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355790
#define RSRFSIGGEN_ATTR_DVB_S2X_GSE_PROTOCOL_TYPE_USE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355791
#define RSRFSIGGEN_ATTR_DVB_S2X_GSE_PROTOCOL_TYPE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355792
#define RSRFSIGGEN_ATTR_DVB_S2X_GSE_LABEL_USE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355793
#define RSRFSIGGEN_ATTR_DVB_S2X_GSE_LABEL                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355794
#define RSRFSIGGEN_ATTR_DVB_S2X_BB_CCM_ACM                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355795
#define RSRFSIGGEN_ATTR_DVB_S2X_BB_HEADER_ACTIVE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357327
#define RSRFSIGGEN_ATTR_DVB_S2X_BB_ISSYI_ACTIVE_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355796
#define RSRFSIGGEN_ATTR_DVB_S2X_BB_GSE_LITE_ACTIVE_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355797
#define RSRFSIGGEN_ATTR_DVB_S2X_BB_NDP_ACTIVE_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355798
#define RSRFSIGGEN_ATTR_DVB_S2X_BB_UPL                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355799
#define RSRFSIGGEN_ATTR_DVB_S2X_BB_DFL                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355800
#define RSRFSIGGEN_ATTR_DVB_S2X_BB_SYNC                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355801
#define RSRFSIGGEN_ATTR_DVB_S2X_MODCOD_TABLE_FRAMES                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357328
#define RSRFSIGGEN_ATTR_DVB_S2X_MODCOD_TABLE_CODE_TYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357329
#define RSRFSIGGEN_ATTR_DVB_S2X_MODCOD_TABLE_MODCOD                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357330
#define RSRFSIGGEN_ATTR_DVB_S2X_MODCOD_TABLE_PLS_CODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357331
#define RSRFSIGGEN_ATTR_DVB_S2X_MODCOD_TABLE_SF                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357332
#define RSRFSIGGEN_ATTR_DVB_S2X_MODCOD_TABLE_AUTO_DFL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357333
#define RSRFSIGGEN_ATTR_DVB_S2X_MODCOD_TABLE_DFL                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357334
#define RSRFSIGGEN_ATTR_DVB_S2X_MODCOD_TABLE_PILOT_STATE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357335
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_SUPER_FRAME_ACTIVE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362692
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_SFFI                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362693
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_SOSF_WH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362694
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_N_REF                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362695
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_N_PAY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362696
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_SF_PILOT_STATE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362697
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_SF_PILOT_WH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362698
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_ST_WH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362699
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_SPECIFIC_SFL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362700
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_SPECIFIC_PLI                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362701
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_INFORMATION_CU_LENGTH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362702
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_INFORMATION_D_SF                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362703
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_INFORMATION_P_SF                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362704
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_INFORMATION_POSTAMBLE_LENGTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362705
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_INFORMATION_EHF                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362706
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_INFORMATION_SFL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362707
#define RSRFSIGGEN_ATTR_DVB_S2X_SF_CONFIG_TSN                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363108
#define RSRFSIGGEN_ATTR_DVB_S2X_BH_CONFIG_BEAM_HOPING_ACTIVE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362708
#define RSRFSIGGEN_ATTR_DVB_S2X_BH_CONFIG_ZERO_BEAM_SWITCHING_SIGNAL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362709
#define RSRFSIGGEN_ATTR_DVB_S2X_BH_CONFIG_NUMBER_OF_DWELLS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362710
#define RSRFSIGGEN_ATTR_DVB_S2X_BH_CONFIG_ATTENUATE_OTHER_DWELL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362711
#define RSRFSIGGEN_ATTR_DVB_S2X_BH_CONFIG_BEAM_HOPPING_CYCLE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362712
#define RSRFSIGGEN_ATTR_DVB_S2X_BH_CONFIG_FILL_OTHER_DWELLS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362713
#define RSRFSIGGEN_ATTR_DVB_S2X_BH_CONFIG_DT_CONFIG_NUMBER_OF_SUPER_FRAMES                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362714
#define RSRFSIGGEN_ATTR_DVB_S2X_BH_CONFIG_DT_CONFIG_SFL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362715
#define RSRFSIGGEN_ATTR_DVB_S2X_BH_CONFIG_DT_CONFIG_BEAM_SWITCHING_TIME                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362716
#define RSRFSIGGEN_ATTR_DVB_S2X_BH_CONFIG_DT_CONFIG_DWELL_LENGTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362717
#define RSRFSIGGEN_ATTR_DVB_RCS2_NUMBER_OF_SUPERFRAMES                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362718
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_INDEX                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362719
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_APPEND                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362720
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_DELETE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362721
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAMES                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362722
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_RESET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362723
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_CONFLICT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362724
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_GRID_NUMBER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362725
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_NUMBERS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362726
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362727
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_BANDWIDTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362728
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_START_TIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362729
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_OFFSET                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362730
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_RESOLVE_CONFLICTS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362731
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_TX_FORMAT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362732
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_BTU_DURATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362733
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_BTU_BANDWIDTH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362734
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_BTU_CHIP_RATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362735
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_BTU_SYMBOL_RATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362736
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_BTU_TIME_UNIT_COUNT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362737
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_GRID_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362738
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362739
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_WAVEFORM_ID                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362740
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_START_BTU                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362741
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_REPEAT_COUNT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362742
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_TIMESLOT_SIZE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362743
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_BURST_START_OFFSET                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362744
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_MODULATION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362745
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_BURST_LENGTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362746
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_SPREADING_FACTOR                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362747
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_BURST_LENGTH_CHIP                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362748
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_PAYLOAD_CONTENT_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362749
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_PAYLOAD_LENGTH                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362750
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_PAYLOAD_PILOT_BLOCK_LENGTH                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362751
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_PAYLOAD_DATA_SOURCE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362752
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_PAYLOAD_DATA_LIST                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362753
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_PAYLOAD_DATA_PATTERN                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362754
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_ENCODING_P                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362755
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_ENCODING_Q0                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362756
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_ENCODING_Q1                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362757
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_ENCODING_Q2                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362758
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_ENCODING_Q3                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362759
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_ENCODING_Y_PUNCTURING_PATTERN                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362760
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_ENCODING_W_PUNCTURING_PATTERN                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362761
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_REFERENCE_UW                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362762
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_REFERENCE_UW_LENGTH                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362763
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_REFERENCE_PREAMBLE_LENGTH                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362764
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_REFERENCE_POSTAMBLE_LENGTH                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362765
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_REFERENCE_PILOT_PERIOD                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362766
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_REFERENCE_PILOT_BLOCK_LENGTH                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362767
#define RSRFSIGGEN_ATTR_DVB_RCS2_SUPERFRAME_FRAME_SECTION_REFERENCE_NUMBER_OF_PILOT_BLOCKS              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362768
#define RSRFSIGGEN_ATTR_DVB_FILTER_TYPE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347121
#define RSRFSIGGEN_ATTR_DVB_FILTER_ROLLOFF_RANGE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355802
#define RSRFSIGGEN_ATTR_DVB_FILTER_ROLLOFF_FACTOR                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355803
#define RSRFSIGGEN_ATTR_DVB_CUT_OFF_FREQUENCY_SHIFT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347122
#define RSRFSIGGEN_ATTR_DVB_FILTER_PARAMETER_ROOT_COSINE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347123
#define RSRFSIGGEN_ATTR_DVB_FILTER_PARAMETER_COSINE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347124
#define RSRFSIGGEN_ATTR_DVB_FILTER_PARAMETER_GAUSS_PURE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347125
#define RSRFSIGGEN_ATTR_DVB_FILTER_PARAMETER_GAUSS_FSK                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347126
#define RSRFSIGGEN_ATTR_DVB_FILTER_PARAMETER_APCO25                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347127
#define RSRFSIGGEN_ATTR_DVB_FILTER_PARAMETER_SPLIT_PHASE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347128
#define RSRFSIGGEN_ATTR_DVB_SAMPLE_RATE_VARIATION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347129
#define RSRFSIGGEN_ATTR_DVB_FILTER_PARAMETER_LOW_PASS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347130
#define RSRFSIGGEN_ATTR_DVB_FILTER_PARAMETER_LOW_PASS_EVM                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347131
#define RSRFSIGGEN_ATTR_DVB_CLIPPING_ENABLED                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347132
#define RSRFSIGGEN_ATTR_DVB_CLIPPING_LEVEL                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347133
#define RSRFSIGGEN_ATTR_DVB_CLIPPING_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347134
#define RSRFSIGGEN_ATTR_DVB_TRIGGER_STATUS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347135
#define RSRFSIGGEN_ATTR_DVB_TRIGGER_ARM                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347136
#define RSRFSIGGEN_ATTR_DVB_TRIGGER_EXECUTE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347137
#define RSRFSIGGEN_ATTR_DVB_TRIGGER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347138
#define RSRFSIGGEN_ATTR_DVB_TRIGGER_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347139
#define RSRFSIGGEN_ATTR_DVB_TRIGGER_SOURCE_LEGACY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350982
#define RSRFSIGGEN_ATTR_DVB_TRIGGER_SIGNAL_DURATION_UNIT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347140
#define RSRFSIGGEN_ATTR_DVB_TRIGGER_SIGNAL_DURATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347141
#define RSRFSIGGEN_ATTR_DVB_TIME_BASED_TRIGGER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363385
#define RSRFSIGGEN_ATTR_DVB_INTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347142
#define RSRFSIGGEN_ATTR_DVB_INTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347143
#define RSRFSIGGEN_ATTR_DVB_EXTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347144
#define RSRFSIGGEN_ATTR_DVB_EXTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347145
#define RSRFSIGGEN_ATTR_DVB_MARKER_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347146
#define RSRFSIGGEN_ATTR_DVB_MARKER_PULSE_DIVIDER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347147
#define RSRFSIGGEN_ATTR_DVB_MARKER_PULSE_FREQUENCY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347148
#define RSRFSIGGEN_ATTR_DVB_MARKER_PATTERN                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347149
#define RSRFSIGGEN_ATTR_DVB_MARKER_ON_TIME                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347150
#define RSRFSIGGEN_ATTR_DVB_MARKER_OFF_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347151
#define RSRFSIGGEN_ATTR_DVB_MARKER_SUPERFAME_INDEX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362769
#define RSRFSIGGEN_ATTR_DVB_MARKER_DELAY                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347152
#define RSRFSIGGEN_ATTR_DVB_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347153
#define RSRFSIGGEN_ATTR_DVB_FIXED_MARKER_DELAY_MAXIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347154
#define RSRFSIGGEN_ATTR_DVB_FIXED_MARKER_DELAY_MINIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347155
#define RSRFSIGGEN_ATTR_DVB_CLOCK_SOURCE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347156
#define RSRFSIGGEN_ATTR_DVB_CLOCK_SOURCE_LEGACY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351008
#define RSRFSIGGEN_ATTR_DVB_CLOCK_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347157
#define RSRFSIGGEN_ATTR_DVB_CHIP_CLOCK_MULTIPLIER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347158
#define RSRFSIGGEN_ATTR_DVB_CLOCK_SYNCHRONISATION_EXECUTE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347159
#define RSRFSIGGEN_ATTR_DVB_CLOCK_SYNCHRONISATION_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347160
#define RSRFSIGGEN_ATTR_DVB_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347161
#define RSRFSIGGEN_ATTR_DVB_NOTCH_FILTER_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357682
#define RSRFSIGGEN_ATTR_DVB_NOTCH_FILTER_CLOCK_FREQUENCY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357683
#define RSRFSIGGEN_ATTR_DVB_NOTCH_FILTER_NUMBER_OF_NOTCHES                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357684
#define RSRFSIGGEN_ATTR_DVB_NOTCH_FILTER_APPLY                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357685
#define RSRFSIGGEN_ATTR_DVB_NOTCH_FILTER_NOTCH_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357686
#define RSRFSIGGEN_ATTR_DVB_NOTCH_FILTER_NOTCH_BANDWIDTH_RELATIVE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357687
#define RSRFSIGGEN_ATTR_DVB_NOTCH_FILTER_NOTCH_BANDWIDTH_ABSOLUTE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357688
#define RSRFSIGGEN_ATTR_DVB_NOTCH_FILTER_NOTCH_FREQUENCY_OFFSET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357689
#define RSRFSIGGEN_ATTR_DAB_ENABLED                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347162
#define RSRFSIGGEN_ATTR_DAB_SET_TO_DEFAULT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347163
#define RSRFSIGGEN_ATTR_DAB_DATA_SOURCE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347164
#define RSRFSIGGEN_ATTR_DAB_ETI_FILE                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347165
#define RSRFSIGGEN_ATTR_DAB_NUMBER_OF_ETI_FRAMES                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347166
#define RSRFSIGGEN_ATTR_DAB_LOOP_DURATION                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347167
#define RSRFSIGGEN_ATTR_DAB_TRANSPORT_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347168
#define RSRFSIGGEN_ATTR_DAB_ETI_CATALOG                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347169
#define RSRFSIGGEN_ATTR_DAB_SETTINGS_CATALOG                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347170
#define RSRFSIGGEN_ATTR_DAB_DELETE_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347171
#define RSRFSIGGEN_ATTR_DAB_RECALL_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347172
#define RSRFSIGGEN_ATTR_DAB_SAVE_SETTINGS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347173
#define RSRFSIGGEN_ATTR_DAB_FAST_STORE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353294
#define RSRFSIGGEN_ATTR_DAB_PN_SCRAMBLER                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347174
#define RSRFSIGGEN_ATTR_DAB_CODER                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347175
#define RSRFSIGGEN_ATTR_DAB_INTERLEAVER                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347176
#define RSRFSIGGEN_ATTR_DAB_FILTER_TYPE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347177
#define RSRFSIGGEN_ATTR_DAB_FILTER_CUT_OFF_FREQUENCY_SHIFT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347178
#define RSRFSIGGEN_ATTR_DAB_FILTER_PARAMETER_ROOT_COSINE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347179
#define RSRFSIGGEN_ATTR_DAB_FILTER_PARAMETER_COSINE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347180
#define RSRFSIGGEN_ATTR_DAB_FILTER_PARAMETER_GAUSS_PURE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347181
#define RSRFSIGGEN_ATTR_DAB_FILTER_PARAMETER_GAUSS_FSK                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347182
#define RSRFSIGGEN_ATTR_DAB_FILTER_PARAMETER_APCO25                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347183
#define RSRFSIGGEN_ATTR_DAB_FILTER_PARAMETER_SPLIT_PHASE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347184
#define RSRFSIGGEN_ATTR_DAB_FILTER_SAMPLE_RATE_VARIATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347185
#define RSRFSIGGEN_ATTR_DAB_FILTER_PARAMETER_LOWPASS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347186
#define RSRFSIGGEN_ATTR_DAB_FILTER_PARAMETER_LOWPASS_EVM                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347187
#define RSRFSIGGEN_ATTR_DAB_CLIPPING_STATE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347188
#define RSRFSIGGEN_ATTR_DAB_CLIPPING_LEVEL                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347189
#define RSRFSIGGEN_ATTR_DAB_CLIPPING_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347190
#define RSRFSIGGEN_ATTR_DAB_TRIGGER_STATUS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347191
#define RSRFSIGGEN_ATTR_DAB_TRIGGER_ARM                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347192
#define RSRFSIGGEN_ATTR_DAB_TRIGGER_EXECUTE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347193
#define RSRFSIGGEN_ATTR_DAB_TRIGGER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347194
#define RSRFSIGGEN_ATTR_DAB_TRIGGER_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347195
#define RSRFSIGGEN_ATTR_DAB_TRIGGER_SOURCE_LEGACY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350984
#define RSRFSIGGEN_ATTR_DAB_TRIGGER_SIGNAL_DURATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347196
#define RSRFSIGGEN_ATTR_DAB_INTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347197
#define RSRFSIGGEN_ATTR_DAB_INTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347198
#define RSRFSIGGEN_ATTR_DAB_EXTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347199
#define RSRFSIGGEN_ATTR_DAB_EXTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347200
#define RSRFSIGGEN_ATTR_DAB_MARKER_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347201
#define RSRFSIGGEN_ATTR_DAB_MARKER_PULSE_DIVIDER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347202
#define RSRFSIGGEN_ATTR_DAB_MARKER_PULSE_FREQUENCY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347203
#define RSRFSIGGEN_ATTR_DAB_MARKER_PATTERN                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347204
#define RSRFSIGGEN_ATTR_DAB_MARKER_ON_TIME                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347205
#define RSRFSIGGEN_ATTR_DAB_MARKER_OFF_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347206
#define RSRFSIGGEN_ATTR_DAB_MARKER_DELAY                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347207
#define RSRFSIGGEN_ATTR_DAB_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347208
#define RSRFSIGGEN_ATTR_DAB_FIXED_MARKER_DELAY_MAXIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347209
#define RSRFSIGGEN_ATTR_DAB_FIXED_MARKER_DELAY_MINIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347210
#define RSRFSIGGEN_ATTR_DAB_CLOCK_SOURCE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347211
#define RSRFSIGGEN_ATTR_DAB_CLOCK_SOURCE_LEGACY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351010
#define RSRFSIGGEN_ATTR_DAB_CLOCK_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347212
#define RSRFSIGGEN_ATTR_DAB_CLOCK_MULTIPLIER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347213
#define RSRFSIGGEN_ATTR_DAB_CLOCK_SYNCHRONISATION_EXECUTE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347214
#define RSRFSIGGEN_ATTR_DAB_CLOCK_SYNCHRONISATION_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347215
#define RSRFSIGGEN_ATTR_DAB_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347216
#define RSRFSIGGEN_ATTR_DM_ENABLED                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347217
#define RSRFSIGGEN_ATTR_DM_SET_TO_DEFAULT                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347218
#define RSRFSIGGEN_ATTR_DM_GENERATE_WAVEFORM_FILE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347219
#define RSRFSIGGEN_ATTR_DM_ACC_TO_STANDARD                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347220
#define RSRFSIGGEN_ATTR_DM_SYMBOL_RATE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347221
#define RSRFSIGGEN_ATTR_DM_SEQUENCE_LENGTH                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347222
#define RSRFSIGGEN_ATTR_DM_CODING                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347223
#define RSRFSIGGEN_ATTR_DM_SETTINGS_CATALOG                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347224
#define RSRFSIGGEN_ATTR_DM_DELETE_SETTINGS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347225
#define RSRFSIGGEN_ATTR_DM_RECALL_SETTINGS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347226
#define RSRFSIGGEN_ATTR_DM_SAVE_SETTINGS                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347227
#define RSRFSIGGEN_ATTR_DM_USER_STANDARDS_CATALOG                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347228
#define RSRFSIGGEN_ATTR_DM_DELETE_USER_STANDARDS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347229
#define RSRFSIGGEN_ATTR_DM_LOAD_USER_STANDARDS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347230
#define RSRFSIGGEN_ATTR_DM_STORE_USER_STANDARDS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347231
#define RSRFSIGGEN_ATTR_DM_DATA_SOURCE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347232
#define RSRFSIGGEN_ATTR_DM_DATA_PATTERN                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347233
#define RSRFSIGGEN_ATTR_DM_PRBS_TYPE                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347234
#define RSRFSIGGEN_ATTR_DM_BIT_ORDER                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353561
#define RSRFSIGGEN_ATTR_DM_CLOCK_TO_DATA_TIME_DEVIATION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353562
#define RSRFSIGGEN_ATTR_DM_CONTROL_LIST_CATALOG                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347235
#define RSRFSIGGEN_ATTR_DM_CONTROL_LIST_COPY                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347236
#define RSRFSIGGEN_ATTR_DM_CONTROL_LIST_DELETE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347237
#define RSRFSIGGEN_ATTR_DM_CONTROL_LIST_SELECT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347238
#define RSRFSIGGEN_ATTR_DM_CONTROL_LIST_DATA_WRITE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347239
#define RSRFSIGGEN_ATTR_DM_CONTROL_LIST_NUMBER_OF_LINES                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347241
#define RSRFSIGGEN_ATTR_DM_CONTROL_LIST_FREE_MEMORY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353563
#define RSRFSIGGEN_ATTR_DM_DATA_LIST_CATALOG                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347242
#define RSRFSIGGEN_ATTR_DM_DATA_LIST_COPY                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347243
#define RSRFSIGGEN_ATTR_DM_DATA_LIST_DELETE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347244
#define RSRFSIGGEN_ATTR_DM_DATA_LIST_SELECT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347245
#define RSRFSIGGEN_ATTR_DM_DATA_LIST_DATA_WRITE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347247
#define RSRFSIGGEN_ATTR_DM_DATA_LIST_DATA_APPEND                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347249
#define RSRFSIGGEN_ATTR_DM_DATA_LIST_NUMBER_OF_BITS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347250
#define RSRFSIGGEN_ATTR_DM_DATA_LIST_FREE_MEMORY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353565
#define RSRFSIGGEN_ATTR_DM_MAPPING_LIST_CATALOG                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347251
#define RSRFSIGGEN_ATTR_DM_MAPPING_LIST_DELETE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347252
#define RSRFSIGGEN_ATTR_DM_MAPPING_LIST_FREE_MEMORY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347253
#define RSRFSIGGEN_ATTR_DM_MAPPING_LIST_LENGTH                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347254
#define RSRFSIGGEN_ATTR_DM_MAPPING_LIST_SELECT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347255
#define RSRFSIGGEN_ATTR_DM_MODULATION_TYPE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347256
#define RSRFSIGGEN_ATTR_DM_ASK_DEPTH                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347257
#define RSRFSIGGEN_ATTR_DM_FSK_DEVIATION                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347258
#define RSRFSIGGEN_ATTR_DM_VARIABLE_FSK_TYPE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347259
#define RSRFSIGGEN_ATTR_DM_MODULATION_DELAY                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347260
#define RSRFSIGGEN_ATTR_PULM_SYNC_ENABLED                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350019
#define RSRFSIGGEN_ATTR_DM_AQPSK_ANGLE_ALPHA                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347261
#define RSRFSIGGEN_ATTR_DM_16APSK_GAMMA                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357690
#define RSRFSIGGEN_ATTR_DM_32APSK_GAMMA                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357691
#define RSRFSIGGEN_ATTR_DM_RECEIVER_STATE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355524
#define RSRFSIGGEN_ATTR_DM_THROUGHPUT_DELAY                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355525
#define RSRFSIGGEN_ATTR_DM_VARIABLE_FSK_DEVIATION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347262
#define RSRFSIGGEN_ATTR_DM_FILTER_TYPE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347263
#define RSRFSIGGEN_ATTR_DM_FILTER_TYPE_PARAMETER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356642
#define RSRFSIGGEN_ATTR_DM_FILTER_PARAMETER_APCO25                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347264
#define RSRFSIGGEN_ATTR_DM_FILTER_PARAMETER_APCO25_LSM_GAUSS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347265
#define RSRFSIGGEN_ATTR_DM_FILTER_PARAMETER_APCO25_LSM_LOWPASS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347266
#define RSRFSIGGEN_ATTR_DM_FILTER_PARAMETER_COSINE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347267
#define RSRFSIGGEN_ATTR_DM_FILTER_PARAMETER_COSINE_BANDWIDTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347268
#define RSRFSIGGEN_ATTR_DM_FILTER_PARAMETER_GAUSS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347269
#define RSRFSIGGEN_ATTR_DM_FILTER_PARAMETER_PURE_GAUSS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347270
#define RSRFSIGGEN_ATTR_DM_FILTER_PARAMETER_ROOT_COSINE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347271
#define RSRFSIGGEN_ATTR_DM_FILTER_PARAMETER_SPLIT_PHASE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347272
#define RSRFSIGGEN_ATTR_DM_FILTER_PARAMETER_LOW_PASS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347273
#define RSRFSIGGEN_ATTR_DM_FILTER_PARAMETER_LOW_PASS_EVM                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347274
#define RSRFSIGGEN_ATTR_DM_FILTER_LIST_CATALOG                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347275
#define RSRFSIGGEN_ATTR_DM_FILTER_LIST_DELETE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347276
#define RSRFSIGGEN_ATTR_DM_FILTER_LIST_SELECT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347277
#define RSRFSIGGEN_ATTR_DM_FILTER_LIST_FREE_MEMORY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347278
#define RSRFSIGGEN_ATTR_DM_FILTER_LIST_LENGTH                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347279
#define RSRFSIGGEN_ATTR_DM_FILTER_OVERSAMPLING                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347280
#define RSRFSIGGEN_ATTR_DM_FILTER_OVERSAMPLING_AUTO                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347281
#define RSRFSIGGEN_ATTR_DM_POWER_RAMPING_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347282
#define RSRFSIGGEN_ATTR_DM_POWER_RAMP_SOURCE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347283
#define RSRFSIGGEN_ATTR_DM_POWER_RAMP_FUNCTION                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347284
#define RSRFSIGGEN_ATTR_DM_POWER_RAMP_TIME                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347285
#define RSRFSIGGEN_ATTR_DM_POWER_RAMP_RISE_DELAY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347286
#define RSRFSIGGEN_ATTR_DM_POWER_RAMP_FALL_DELAY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347287
#define RSRFSIGGEN_ATTR_DM_POWER_RAMP_ATTENUATION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347288
#define RSRFSIGGEN_ATTR_DM_POWER_RAMP_IN_BASEBAND_ONLY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347289
#define RSRFSIGGEN_ATTR_DM_TRIGGER_ARM_EXECUTE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347290
#define RSRFSIGGEN_ATTR_DM_TRIGGER_EXECUTE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347291
#define RSRFSIGGEN_ATTR_DM_TRIGGER_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347292
#define RSRFSIGGEN_ATTR_DM_TRIGGER_SOURCE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347293
#define RSRFSIGGEN_ATTR_DM_TRIGGER_SOURCE_LEGACY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350986
#define RSRFSIGGEN_ATTR_DM_TRIGGER_SIGNAL_DURATION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347294
#define RSRFSIGGEN_ATTR_DM_TRIGGER_STATUS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353567
#define RSRFSIGGEN_ATTR_DM_TIME_BASED_TRIGGER                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363388
#define RSRFSIGGEN_ATTR_DM_INTERNAL_TRIGGER_DELAY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347295
#define RSRFSIGGEN_ATTR_DM_INTERNAL_TRIGGER_INHIBIT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347296
#define RSRFSIGGEN_ATTR_DM_TRIGGER_ACTUAL_DELAY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353568
#define RSRFSIGGEN_ATTR_DM_TRIGGER_SPECIFIED_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353569
#define RSRFSIGGEN_ATTR_DM_EXTERNAL_TRIGGER_DELAY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347297
#define RSRFSIGGEN_ATTR_DM_EXTERNAL_TRIGGER_INHIBIT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347298
#define RSRFSIGGEN_ATTR_DM_EXTERNAL_TRIGGER_DELAY_UNIT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353570
#define RSRFSIGGEN_ATTR_DM_EXTERNAL_TRIGGER_ACTUAL_DELAY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353571
#define RSRFSIGGEN_ATTR_DM_EXTERNAL_TRIGGER_SPECIFIED_DELAY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353572
#define RSRFSIGGEN_ATTR_DM_MARKER_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347299
#define RSRFSIGGEN_ATTR_DM_MARKER_PULSE_DIVIDER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347300
#define RSRFSIGGEN_ATTR_DM_MARKER_PULSE_FREQUENCY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347301
#define RSRFSIGGEN_ATTR_DM_MARKER_PATTERN                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347302
#define RSRFSIGGEN_ATTR_DM_MARKER_ON_TIME                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347303
#define RSRFSIGGEN_ATTR_DM_MARKER_OFF_TIME                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347304
#define RSRFSIGGEN_ATTR_DM_MARKER_DELAY                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347305
#define RSRFSIGGEN_ATTR_DM_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347306
#define RSRFSIGGEN_ATTR_DM_FIXED_MARKER_DELAY_MAXIMUM                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347307
#define RSRFSIGGEN_ATTR_DM_FIXED_MARKER_DELAY_MINIMUM                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347308
#define RSRFSIGGEN_ATTR_DM_CLOCK_SOURCE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347309
#define RSRFSIGGEN_ATTR_DM_CLOCK_SOURCE_LEGACY                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351012
#define RSRFSIGGEN_ATTR_DM_CLOCK_MODE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347310
#define RSRFSIGGEN_ATTR_DM_CHIP_CLOCK_MULTIPLIER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347311
#define RSRFSIGGEN_ATTR_DM_BIT_CLOCK_SLOPE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353573
#define RSRFSIGGEN_ATTR_DM_CLOCK_SYNCHRONISATION_EXECUTE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347312
#define RSRFSIGGEN_ATTR_DM_CLOCK_SYNCHRONISATION_MODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347313
#define RSRFSIGGEN_ATTR_DM_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347314
#define RSRFSIGGEN_ATTR_DM_SWITCHING_ENABLED                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347315
#define RSRFSIGGEN_ATTR_DM_SWITCHING_SOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347316
#define RSRFSIGGEN_ATTR_ARB_ENABLED                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347317
#define RSRFSIGGEN_ATTR_ARB_ENABLED_NO_WAIT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355967
#define RSRFSIGGEN_ATTR_ARB_SET_TO_DEFAULT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347318
#define RSRFSIGGEN_ATTR_ARB_CLOCK_FREQUENCY                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347319
#define RSRFSIGGEN_ATTR_ARB_COUPLED_STATE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355526
#define RSRFSIGGEN_ATTR_ARB_RF_POWER_RAMPING_WITH_BURST_MARKER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357692
#define RSRFSIGGEN_ATTR_ARB_TEST_SIGNAL_FORM                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357693
#define RSRFSIGGEN_ATTR_ARB_MODE                                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362770
#define RSRFSIGGEN_ATTR_ARB_WAVEFORM_CATALOG                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350142
#define RSRFSIGGEN_ATTR_ARB_WAVEFORM_CATALOG_LENGTH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350143
#define RSRFSIGGEN_ATTR_ARB_WAVEFORM_DELETE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349774
#define RSRFSIGGEN_ATTR_ARB_WAVEFORM_POINTS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349775
#define RSRFSIGGEN_ATTR_ARB_WAVEFORM_SELECT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349776
#define RSRFSIGGEN_ATTR_ARB_TRIGGER_STATUS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347320
#define RSRFSIGGEN_ATTR_ARB_EXECUTE_TRIGGER                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347321
#define RSRFSIGGEN_ATTR_ARB_TRIGGER_ARM                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353574
#define RSRFSIGGEN_ATTR_ARB_TRIGGER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347322
#define RSRFSIGGEN_ATTR_ARB_EXTENDED_TRIGGER_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347323
#define RSRFSIGGEN_ATTR_ARB_TRIGGER_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347324
#define RSRFSIGGEN_ATTR_ARB_TRIGGER_SOURCE_LEGACY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350988
#define RSRFSIGGEN_ATTR_ARB_TRIGGER_SINGLE_SEQUENCE_LENGTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347325
#define RSRFSIGGEN_ATTR_ARB_TRIGGER_SINGLE_SIGNAL_DURATION_UNIT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347326
#define RSRFSIGGEN_ATTR_ARB_TRIGGER_WAVEFORM_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355527
#define RSRFSIGGEN_ATTR_ARB_TIME_BASED_TRIGGER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363391
#define RSRFSIGGEN_ATTR_ARB_INTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347327
#define RSRFSIGGEN_ATTR_ARB_INTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347328
#define RSRFSIGGEN_ATTR_ARB_INTERNAL_TRIGGER_EVENT_DELAY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353575
#define RSRFSIGGEN_ATTR_ARB_INTERNAL_TRIGGER_DELAY_FOR_TRIGGERING                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353576
#define RSRFSIGGEN_ATTR_ARB_EXTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347329
#define RSRFSIGGEN_ATTR_ARB_EXTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347330
#define RSRFSIGGEN_ATTR_ARB_EXTERNAL_TRIGGER_DELAY_UNIT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355556
#define RSRFSIGGEN_ATTR_ARB_EXTERNAL_TRIGGER_EVENT_DELAY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353577
#define RSRFSIGGEN_ATTR_ARB_EXTERNAL_TRIGGER_DELAY_FOR_TRIGGERING                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353578
#define RSRFSIGGEN_ATTR_ARB_EXTERNAL_TRIGGER_PROCESSING_TIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362771
#define RSRFSIGGEN_ATTR_ARB_MARKER_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347331
#define RSRFSIGGEN_ATTR_ARB_MARKER_PULSE_DIVIDER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347332
#define RSRFSIGGEN_ATTR_ARB_MARKER_PULSE_FREQUENCY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347333
#define RSRFSIGGEN_ATTR_ARB_MARKER_PATTERN                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347334
#define RSRFSIGGEN_ATTR_ARB_MARKER_ON_TIME                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347335
#define RSRFSIGGEN_ATTR_ARB_MARKER_OFF_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347336
#define RSRFSIGGEN_ATTR_ARB_MARKER_DELAY                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347337
#define RSRFSIGGEN_ATTR_ARB_MARKER_DELAY_IN_MICROSECONDS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361912
#define RSRFSIGGEN_ATTR_ARB_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347338
#define RSRFSIGGEN_ATTR_ARB_FIXED_MARKER_DELAY_MAXIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347339
#define RSRFSIGGEN_ATTR_ARB_FIXED_MARKER_DELAY_MINIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347340
#define RSRFSIGGEN_ATTR_ARB_CLOCK_SOURCE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347341
#define RSRFSIGGEN_ATTR_ARB_CLOCK_SOURCE_LEGACY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351014
#define RSRFSIGGEN_ATTR_ARB_CLOCK_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347342
#define RSRFSIGGEN_ATTR_ARB_CHIP_CLOCK_MULTIPLIER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347343
#define RSRFSIGGEN_ATTR_ARB_CLOCK_SYNCHRONISATION_EXECUTE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347344
#define RSRFSIGGEN_ATTR_ARB_CLOCK_SYNCHRONISATION_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347345
#define RSRFSIGGEN_ATTR_ARB_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347346
#define RSRFSIGGEN_ATTR_ARB_TSIGNAL_GENERATE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347347
#define RSRFSIGGEN_ATTR_ARB_TSIGNAL_CREATE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347348
#define RSRFSIGGEN_ATTR_ARB_TSIGNAL_FREQUENCY                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347349
#define RSRFSIGGEN_ATTR_ARB_TSIGNAL_PHASE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347350
#define RSRFSIGGEN_ATTR_ARB_TSIGNAL_SAMPLES                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347351
#define RSRFSIGGEN_ATTR_ARB_TSIGNAL_RECTANGLE_NAME                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347352
#define RSRFSIGGEN_ATTR_ARB_TSIGNAL_RECTANGLE_CREATE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347353
#define RSRFSIGGEN_ATTR_ARB_TSIGNAL_RECTANGLE_FREQUENCY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347354
#define RSRFSIGGEN_ATTR_ARB_TSIGNAL_RECTANGLE_AMPLITUDE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347355
#define RSRFSIGGEN_ATTR_ARB_TSIGNAL_RECTANGLE_OFFSET_DC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347356
#define RSRFSIGGEN_ATTR_ARB_TSIGNAL_RECTANGLE_SAMPLES                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347357
#define RSRFSIGGEN_ATTR_ARB_TSIGNAL_CIQ_NAME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347358
#define RSRFSIGGEN_ATTR_ARB_TSIGNAL_CIQ_CREATE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347359
#define RSRFSIGGEN_ATTR_ARB_TSIGNAL_CIQ_I                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347360
#define RSRFSIGGEN_ATTR_ARB_TSIGNAL_CIQ_Q                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347361
#define RSRFSIGGEN_ATTR_ARB_AWGN_SAMPLES                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357694
#define RSRFSIGGEN_ATTR_ARB_AWGN_CREATE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357695
#define RSRFSIGGEN_ATTR_ARB_CREATE_MULTI_CARRIER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347385
#define RSRFSIGGEN_ATTR_ARB_RESET_MULTI_CARRIER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347386
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_MODE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347387
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_CREST_FACTOR_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347388
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_OUTPUT_FILE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347389
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_SAVE_FILE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347390
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_CLOCK                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347391
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_SAMPLES                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347392
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_SIGNAL_PERIOD_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347393
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_POWER_REFERENCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353584
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_SIGNAL_PERIOD                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357696
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_COUNT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347394
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_SPACING                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347395
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_FREQUENCY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347396
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_DELAY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347397
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_DATA_FILE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347398
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_PHASE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347399
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_POWER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347400
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347401
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_CONFLICT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347402
#define RSRFSIGGEN_ATTR_ARB_EXECUTE_MULTI_CARRIER_EDITION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347403
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_EDIT_DELAY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347404
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_EDIT_DELAY_STEP                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347405
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_INPUT_IQ_FILE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347406
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_EDIT_PHASE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347407
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_EDIT_PHASE_STEP                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347408
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_EDIT_POWER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347409
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_EDIT_POWER_STEP                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347410
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_START                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347411
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_STOP                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347412
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_EDIT_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347413
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_CATALOG                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347414
#define RSRFSIGGEN_ATTR_ARB_LOAD_MULTI_CARRIER_SETTING_FILE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347415
#define RSRFSIGGEN_ATTR_ARB_STORE_MULTI_CARRIER_SETTING_FILE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347416
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_FAST_STORE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359759
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_CLIPPING_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347417
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_CLIPPING_TARGET_CREST_FACTOR                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347418
#define RSRFSIGGEN_ATTR_ARB_MULTI_CARRIER_CLIPPING_FILTER_CUT_OFF_FREQUENCY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347419
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_FREE_DISK_SPACE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347362
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_OUTPUT_SEGMENT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347363
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_CURRENT_OUTPUT_SEGMENT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347364
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_LEVEL_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347365
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_SEQUENCE_RESTART                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347366
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_SEGMENT_RESTART                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347367
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_SAVE_FILE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347368
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_APPEND_FILE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347369
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_NAME                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347370
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_EXECUTE_NEXT_SEGMENT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347371
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_NEXT_SEGMENT_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347372
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_NEXT_SEGMENT_LEVEL_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353580
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_SEQUENCING_LIST                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347373
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_WAVEFORM_TAG                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353581
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_MARKER_MODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353583
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_CONFIGURATION_FILE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347375
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_CREATE_FROM_CONFIGURATION_FILE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347376
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_LOAD_FROM_CONFIGURATION_FILE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347377
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_CATALOG                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347378
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_SEGMENT_CATALOG                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347379
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_DELETE_CONFIGURATION_FILE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347380
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_COMMENT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347382
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_CLOCK                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347383
#define RSRFSIGGEN_ATTR_ARB_MULTISEGMENT_CLOCK_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347384
#define RSRFSIGGEN_ATTR_ARB_NOTCH_FILTER_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357697
#define RSRFSIGGEN_ATTR_ARB_NOTCH_FILTER_CLOCK_FREQUENCY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357698
#define RSRFSIGGEN_ATTR_ARB_NOTCH_FILTER_NUMBER_OF_NOTCHES                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357699
#define RSRFSIGGEN_ATTR_ARB_NOTCH_FILTER_APPLY                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357700
#define RSRFSIGGEN_ATTR_ARB_NOTCH_FILTER_NOTCH_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357701
#define RSRFSIGGEN_ATTR_ARB_NOTCH_FILTER_NOTCH_BANDWIDTH_RELATIVE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357702
#define RSRFSIGGEN_ATTR_ARB_NOTCH_FILTER_NOTCH_BANDWIDTH_ABSOLUTE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357703
#define RSRFSIGGEN_ATTR_ARB_NOTCH_FILTER_NOTCH_FREQUENCY_OFFSET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357704
#define RSRFSIGGEN_ATTR_ARB_CFR_ENABLED                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359826
#define RSRFSIGGEN_ATTR_ARB_CFR_ALGORITHM                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359827
#define RSRFSIGGEN_ATTR_ARB_CFR_DCF_DELTA                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359828
#define RSRFSIGGEN_ATTR_ARB_CFR_OCF                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359829
#define RSRFSIGGEN_ATTR_ARB_CFR_FILTERING_MODE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359830
#define RSRFSIGGEN_ATTR_ARB_CFR_MAXIMUM_FILTER_ORDER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359831
#define RSRFSIGGEN_ATTR_ARB_CFR_CHANNEL_SPACING                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359832
#define RSRFSIGGEN_ATTR_ARB_CFR_STOP_BAND_FREQUENCY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359833
#define RSRFSIGGEN_ATTR_ARB_CFR_MAX_ITERATIONS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359834
#define RSRFSIGGEN_ATTR_ARB_CFR_RCF                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359835
#define RSRFSIGGEN_ATTR_ARB_CFR_SIGNAL_BANDWITH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359836
#define RSRFSIGGEN_ATTR_ARB_CFR_CANCELLATION_PULSE_BANDWIDTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363392
#define RSRFSIGGEN_ATTR_ARB_CFR_TRANSITION_BANDWIDTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363393
#define RSRFSIGGEN_ATTR_ARB_CFR_PF_REQ                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359837
#define RSRFSIGGEN_ATTR_ARB_CFR_MEASURE_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359838
#define RSRFSIGGEN_ATTR_ARB_CFR_WAVEFORM_CREATE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359839
#define RSRFSIGGEN_ATTR_ARB_ETHERNET_UPLOAD_MODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362772
#define RSRFSIGGEN_ATTR_ARB_ETHERNET_UPLOAD_STATUS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362773
#define RSRFSIGGEN_ATTR_ARB_ETHERNET_UPLOAD_STATISTIC_OCCURED_ERRORS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362775
#define RSRFSIGGEN_ATTR_ARB_ETHERNET_UPLOAD_STATISTIC_RX_CONTROL_FRAMES                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362776
#define RSRFSIGGEN_ATTR_ARB_ETHERNET_UPLOAD_STATISTIC_RX_DATA_BYTES                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362777
#define RSRFSIGGEN_ATTR_ARB_ETHERNET_UPLOAD_STATISTIC_RX_DATA_FRAMES                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362778
#define RSRFSIGGEN_ATTR_ARB_ETHERNET_UPLOAD_STATISTIC_RX_UPLOAD_SEGMENTS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362779
#define RSRFSIGGEN_ATTR_ARB_ETHERNET_UPLOAD_STATISTIC_TX_REPLY_FRAMES                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362780
#define RSRFSIGGEN_ATTR_ARB_ETHERNET_UPLOAD_WAVEFORM_COUNTER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362781
#define RSRFSIGGEN_ATTR_ARB_ETHERNET_UPLOAD_WAVEFORM_INFO                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362782
#define RSRFSIGGEN_ATTR_GPS_ENABLED                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347420
#define RSRFSIGGEN_ATTR_GPS_SET_TO_DEFAULT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347421
#define RSRFSIGGEN_ATTR_GPS_SET_TO_DEFAULT_RF_AND_LEVEL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347422
#define RSRFSIGGEN_ATTR_GPS_RF_BAND                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347423
#define RSRFSIGGEN_ATTR_GPS_FILTER                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347424
#define RSRFSIGGEN_ATTR_GPS_AGPS_TEST_SCENARIO                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347425
#define RSRFSIGGEN_ATTR_GPS_USE_BASEBAND_AB                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347426
#define RSRFSIGGEN_ATTR_GPS_SIMULATION_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347427
#define RSRFSIGGEN_ATTR_GPS_LOCALIZATION_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347428
#define RSRFSIGGEN_ATTR_GPS_PDOP                                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347429
#define RSRFSIGGEN_ATTR_GPS_NEXT_HANDOVER_TIME                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347430
#define RSRFSIGGEN_ATTR_GPS_SETTINGS_CATALOG                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347431
#define RSRFSIGGEN_ATTR_GPS_DELETE_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347432
#define RSRFSIGGEN_ATTR_GPS_RECALL_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347433
#define RSRFSIGGEN_ATTR_GPS_SAVE_SETTINGS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347434
#define RSRFSIGGEN_ATTR_GPS_TRIGGER_STATUS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347435
#define RSRFSIGGEN_ATTR_GPS_TRIGGER_ARM                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347436
#define RSRFSIGGEN_ATTR_GPS_TRIGGER_EXECUTE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347437
#define RSRFSIGGEN_ATTR_GPS_TRIGGER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347438
#define RSRFSIGGEN_ATTR_GPS_TRIGGER_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347439
#define RSRFSIGGEN_ATTR_GPS_TRIGGER_SIGNAL_DURATION_UNIT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347440
#define RSRFSIGGEN_ATTR_GPS_TRIGGER_SEQUENCE_LENGTH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347441
#define RSRFSIGGEN_ATTR_GPS_INTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347442
#define RSRFSIGGEN_ATTR_GPS_INTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347443
#define RSRFSIGGEN_ATTR_GPS_EXTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347444
#define RSRFSIGGEN_ATTR_GPS_EXTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347445
#define RSRFSIGGEN_ATTR_GPS_MARKER_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347446
#define RSRFSIGGEN_ATTR_GPS_MARKER_PULSE_DIVIDER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347447
#define RSRFSIGGEN_ATTR_GPS_MARKER_PULSE_FREQUENCY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347448
#define RSRFSIGGEN_ATTR_GPS_MARKER_PATTERN                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347449
#define RSRFSIGGEN_ATTR_GPS_MARKER_OFF_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347450
#define RSRFSIGGEN_ATTR_GPS_MARKER_ON_TIME                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347451
#define RSRFSIGGEN_ATTR_GPS_MARKER_PULSE_WIDTH                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347452
#define RSRFSIGGEN_ATTR_GPS_MARKER_DELAY                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347453
#define RSRFSIGGEN_ATTR_GPS_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347454
#define RSRFSIGGEN_ATTR_GPS_FIXED_MARKER_DELAY_MAXIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347455
#define RSRFSIGGEN_ATTR_GPS_FIXED_MARKER_DELAY_MINIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347456
#define RSRFSIGGEN_ATTR_GPS_CLOCK_SOURCE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347457
#define RSRFSIGGEN_ATTR_GPS_CLOCK_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347458
#define RSRFSIGGEN_ATTR_GPS_CHIP_CLOCK_MULTIPLIER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347459
#define RSRFSIGGEN_ATTR_GPS_CLOCK_SYNCHRONISATION_EXECUTE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347460
#define RSRFSIGGEN_ATTR_GPS_CLOCK_SYNCHRONISATION_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347461
#define RSRFSIGGEN_ATTR_GPS_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347462
#define RSRFSIGGEN_ATTR_GPS_LOCALIZATION_GEOGRAPHIC_LOCATION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347463
#define RSRFSIGGEN_ATTR_GPS_LOCALIZATION_WAYPOINT_FILE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347464
#define RSRFSIGGEN_ATTR_GPS_LOCALIZATION_READ_OUT_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347465
#define RSRFSIGGEN_ATTR_GPS_LOCALIZATION_POSITION_FORMAT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347466
#define RSRFSIGGEN_ATTR_GPS_LOCALIZATION_ALTITUDE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347467
#define RSRFSIGGEN_ATTR_GPS_LOCALIZATION_LATITUDE_DEGREES                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347468
#define RSRFSIGGEN_ATTR_GPS_LOCALIZATION_LATITUDE_MINUTES                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347469
#define RSRFSIGGEN_ATTR_GPS_LOCALIZATION_LATITUDE_SECONDS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347470
#define RSRFSIGGEN_ATTR_GPS_LOCALIZATION_LATITUDE_DIRECTION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347471
#define RSRFSIGGEN_ATTR_GPS_LOCALIZATION_LONGITUDE_DEGREES                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347472
#define RSRFSIGGEN_ATTR_GPS_LOCALIZATION_LONGITUDE_MINUTES                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347473
#define RSRFSIGGEN_ATTR_GPS_LOCALIZATION_LONGITUDE_SECONDS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347474
#define RSRFSIGGEN_ATTR_GPS_LOCALIZATION_LONGITUDE_DIRECTION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347475
#define RSRFSIGGEN_ATTR_GPS_LOCALIZATION_SATELLITE_ELEVATION_MASK                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347476
#define RSRFSIGGEN_ATTR_GPS_DATA_SOURCE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347477
#define RSRFSIGGEN_ATTR_GPS_DATA_LIST                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347478
#define RSRFSIGGEN_ATTR_GPS_PATTERN                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347479
#define RSRFSIGGEN_ATTR_GPS_ALMANAC_FILE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347480
#define RSRFSIGGEN_ATTR_GPS_ALMANAC_FILE_BEGINNING_WEEK                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347481
#define RSRFSIGGEN_ATTR_GPS_ALMANAC_FILE_BEGINNING_DAY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347482
#define RSRFSIGGEN_ATTR_GPS_ALMANAC_FILE_BEGINNING_MONTH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347483
#define RSRFSIGGEN_ATTR_GPS_ALMANAC_FILE_BEGINNING_YEAR                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347484
#define RSRFSIGGEN_ATTR_GPS_ALMANAC_FILE_END_DAY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347485
#define RSRFSIGGEN_ATTR_GPS_ALMANAC_FILE_END_MONTH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347486
#define RSRFSIGGEN_ATTR_GPS_ALMANAC_FILE_END_YEAR                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347487
#define RSRFSIGGEN_ATTR_GPS_TIME_OF_EPHEMERIS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347488
#define RSRFSIGGEN_ATTR_GPS_DATE                                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347489
#define RSRFSIGGEN_ATTR_GPS_GREENWICH_MEAN_TIME                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347490
#define RSRFSIGGEN_ATTR_GPS_ADJUST_TOTAL_POWER_TO_0_DB                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347491
#define RSRFSIGGEN_ATTR_GPS_TOTAL_POWER                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347492
#define RSRFSIGGEN_ATTR_GPS_USE_SPREADING                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347493
#define RSRFSIGGEN_ATTR_GPS_INITIAL_HDOP                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347494
#define RSRFSIGGEN_ATTR_GPS_INITIAL_PDOP                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347495
#define RSRFSIGGEN_ATTR_GPS_SATELLITE_TIME_SHIFT_SATELLITE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347496
#define RSRFSIGGEN_ATTR_GPS_SATELLITE_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347497
#define RSRFSIGGEN_ATTR_GPS_SATELLITE_SPACE_VEHICLE_ID                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347498
#define RSRFSIGGEN_ATTR_GPS_SATELLITE_RANGING_CODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347499
#define RSRFSIGGEN_ATTR_GPS_SATELLITE_TIME_SHIFT_IN_S                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347500
#define RSRFSIGGEN_ATTR_GPS_SATELLITE_POWER                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347501
#define RSRFSIGGEN_ATTR_GPS_SATELLITE_DOPPLER_SHIFT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347502
#define RSRFSIGGEN_ATTR_GPS_SATELLITE_ADDITIONAL_TIME_SHIFT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347503
#define RSRFSIGGEN_ATTR_GPS_SATELLITE_ADDITIONAL_POWER                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347504
#define RSRFSIGGEN_ATTR_GPS_SATELLITE_ADDITIONAL_DOPPLER_SHIFT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347505
#define RSRFSIGGEN_ATTR_GPS_SATELLITE_INITIAL_CARRIER_PHASE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347506
#define RSRFSIGGEN_ATTR_GPS_SATELLITE_RESULTING_FREQUENCY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347507
#define RSRFSIGGEN_ATTR_GPS_SATELLITE_RESULTING_CHIP_RATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347508
#define RSRFSIGGEN_ATTR_GPS_SATELLITE_RESULTING_P_CHIP_RATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347509
#define RSRFSIGGEN_ATTR_GPS_SATELLITE_DURATION                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347510
#define RSRFSIGGEN_ATTR_GPS_NMES_SET_TO_ALMANAC                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347511
#define RSRFSIGGEN_ATTR_GPS_NMES_POWER_OFFSET                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347512
#define RSRFSIGGEN_ATTR_GPS_NMES_TIME_SHIFT_CHIPS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347513
#define RSRFSIGGEN_ATTR_GPS_NMES_TIME_SHIFT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347514
#define RSRFSIGGEN_ATTR_GPS_NMES_CODE_ON_L2                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347515
#define RSRFSIGGEN_ATTR_GPS_NMES_L2_P_DATA_FLAG                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347516
#define RSRFSIGGEN_ATTR_GPS_NMES_FIT_INTERVAL_FLAG                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347517
#define RSRFSIGGEN_ATTR_GPS_NMES_SV_ACCURACY_URA_INDEX                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347518
#define RSRFSIGGEN_ATTR_GPS_NMES_SV_HEALTH                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347519
#define RSRFSIGGEN_ATTR_GPS_NMES_IODC                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347520
#define RSRFSIGGEN_ATTR_GPS_NMES_IODE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347521
#define RSRFSIGGEN_ATTR_GPS_NMES_TGD                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347522
#define RSRFSIGGEN_ATTR_GPS_NMES_TOC                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347523
#define RSRFSIGGEN_ATTR_GPS_NMES_AF2                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347524
#define RSRFSIGGEN_ATTR_GPS_NMES_AF1                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347525
#define RSRFSIGGEN_ATTR_GPS_NMES_AF0                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347526
#define RSRFSIGGEN_ATTR_GPS_NMES_M0                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347527
#define RSRFSIGGEN_ATTR_GPS_NMES_DELTAN                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347528
#define RSRFSIGGEN_ATTR_GPS_NMES_E                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347529
#define RSRFSIGGEN_ATTR_GPS_NMES_SQRTA                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347530
#define RSRFSIGGEN_ATTR_GPS_NMES_OMEGA0                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347531
#define RSRFSIGGEN_ATTR_GPS_NMES_I0                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347532
#define RSRFSIGGEN_ATTR_GPS_NMES_OMEGA                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347533
#define RSRFSIGGEN_ATTR_GPS_NMES_OMEGADOT                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347534
#define RSRFSIGGEN_ATTR_GPS_NMES_IDOT                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347535
#define RSRFSIGGEN_ATTR_GPS_NMES_CUC                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347536
#define RSRFSIGGEN_ATTR_GPS_NMES_CUS                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347537
#define RSRFSIGGEN_ATTR_GPS_NMES_CRC                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347538
#define RSRFSIGGEN_ATTR_GPS_NMES_CRS                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347539
#define RSRFSIGGEN_ATTR_GPS_NMES_CIC                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347540
#define RSRFSIGGEN_ATTR_GPS_NMES_CIS                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347541
#define RSRFSIGGEN_ATTR_GPS_NMES_SF1_RESERVED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347542
#define RSRFSIGGEN_ATTR_GPS_NMES_A0                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347543
#define RSRFSIGGEN_ATTR_GPS_NMES_A1                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347544
#define RSRFSIGGEN_ATTR_GPS_NMES_DELTA_TLS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347545
#define RSRFSIGGEN_ATTR_GPS_NMES_TOT                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347546
#define RSRFSIGGEN_ATTR_GPS_NMES_WNT                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347547
#define RSRFSIGGEN_ATTR_GPS_NMES_WNLSF                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347548
#define RSRFSIGGEN_ATTR_GPS_NMES_DN                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347549
#define RSRFSIGGEN_ATTR_GPS_NMES_DELTA_TLSF                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347550
#define RSRFSIGGEN_ATTR_GPS_NMES_ALPHA                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347551
#define RSRFSIGGEN_ATTR_GPS_NMES_BETA                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347552
#define RSRFSIGGEN_ATTR_GPS_NMES_AODO                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347553
#define RSRFSIGGEN_ATTR_GPS_NMES_SPACE_VEHICLE_CONFIG                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347554
#define RSRFSIGGEN_ATTR_GPS_ADG_SYNCHRONIZE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347555
#define RSRFSIGGEN_ATTR_GPS_ADG_NUMBER_OF_SATELLITES                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347556
#define RSRFSIGGEN_ATTR_GPS_ADG_POSITION_FORMAT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347557
#define RSRFSIGGEN_ATTR_GPS_ADG_ALTITUDE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347558
#define RSRFSIGGEN_ATTR_GPS_ADG_LATITUDE_DMS_DEGREES                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347559
#define RSRFSIGGEN_ATTR_GPS_ADG_LATITUDE_DMS_MINUTES                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347560
#define RSRFSIGGEN_ATTR_GPS_ADG_LATITUDE_DMS_SECONDS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347561
#define RSRFSIGGEN_ATTR_GPS_ADG_LATITUDE_DMS_DIRECTION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347562
#define RSRFSIGGEN_ATTR_GPS_ADG_LATITUDE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347563
#define RSRFSIGGEN_ATTR_GPS_ADG_LONGITUDE_DMS_DEGREES                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347564
#define RSRFSIGGEN_ATTR_GPS_ADG_LONGITUDE_DMS_MINUTES                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347565
#define RSRFSIGGEN_ATTR_GPS_ADG_LONGITUDE_DMS_SECONDS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347566
#define RSRFSIGGEN_ATTR_GPS_ADG_LONGITUDE_DMS_DIRECTION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347567
#define RSRFSIGGEN_ATTR_GPS_ADG_LONGITUDE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347568
#define RSRFSIGGEN_ATTR_GPS_ADG_UNCERTAINLY_RADIUS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347569
#define RSRFSIGGEN_ATTR_GPS_ADG_TIME_OF_ASSISTANCE_DATA                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347570
#define RSRFSIGGEN_ATTR_GPS_ADG_DURATION_OF_ASSISTANCE_DATA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347571
#define RSRFSIGGEN_ATTR_GPS_ADG_RESOLUTION_OF_ASSISTANCE_DATA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347572
#define RSRFSIGGEN_ATTR_GPS_ADG_GENERATE_ALMANAC_FILE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347574
#define RSRFSIGGEN_ATTR_GPS_ADG_GENERATE_NAVIGATION_FILE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347575
#define RSRFSIGGEN_ATTR_GPS_ADG_GENERATE_ACQUISITION_FILE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347576
#define RSRFSIGGEN_ATTR_GPS_ADG_GENERATE_IONOSPHERIC_FILE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347577
#define RSRFSIGGEN_ATTR_GPS_ADG_GENERATE_UTC_FILE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347578
#define RSRFSIGGEN_ATTR_GPS_ADG_SPACE_VEHICLE_ID                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347580
#define RSRFSIGGEN_ATTR_MCCW_ENABLED                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347592
#define RSRFSIGGEN_ATTR_MCCW_SET_TO_DEFAULT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347593
#define RSRFSIGGEN_ATTR_MCCW_NO_OF_CARRIERS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347594
#define RSRFSIGGEN_ATTR_MCCW_CARRIER_SPACING                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347595
#define RSRFSIGGEN_ATTR_MCCW_CLOCK_FREQUENCY                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347596
#define RSRFSIGGEN_ATTR_MCCW_OPTIMIZE_CREST_FACTOR_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347597
#define RSRFSIGGEN_ATTR_MCCW_CURRENT_CREST_FACTOR                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347598
#define RSRFSIGGEN_ATTR_MCCW_DESIRED_CREST_FACTOR                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347599
#define RSRFSIGGEN_ATTR_MCCW_EDIT_CARRIER_ACCEPT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347600
#define RSRFSIGGEN_ATTR_MCCW_EDIT_CARRIER_START                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347601
#define RSRFSIGGEN_ATTR_MCCW_EDIT_CARRIER_STOP                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347602
#define RSRFSIGGEN_ATTR_MCCW_EDIT_CARRIER_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347603
#define RSRFSIGGEN_ATTR_MCCW_EDIT_CARRIER_POWER_START                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347604
#define RSRFSIGGEN_ATTR_MCCW_EDIT_CARRIER_POWER_STEP                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347605
#define RSRFSIGGEN_ATTR_MCCW_EDIT_CARRIER_PHASE_START                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347606
#define RSRFSIGGEN_ATTR_MCCW_EDIT_CARRIER_PHASE_STEP                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347607
#define RSRFSIGGEN_ATTR_MCCW_TRIGGER_ARM_EXECUTE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353585
#define RSRFSIGGEN_ATTR_MCCW_EXECUTE_TRIGGER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347614
#define RSRFSIGGEN_ATTR_MCCW_TRIGGER_STATUS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353586
#define RSRFSIGGEN_ATTR_MCCW_TRIGGER_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347615
#define RSRFSIGGEN_ATTR_MCCW_TRIGGER_SOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347616
#define RSRFSIGGEN_ATTR_MCCW_TRIGGER_SOURCE_LEGACY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350990
#define RSRFSIGGEN_ATTR_MCCW_TRIGGER_SIGNAL_DURATION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353587
#define RSRFSIGGEN_ATTR_MCCW_TIME_BASED_TRIGGER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363396
#define RSRFSIGGEN_ATTR_MCCW_INTERNAL_TRIGGER_DELAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347617
#define RSRFSIGGEN_ATTR_MCCW_INTERNAL_TRIGGER_INHIBIT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347618
#define RSRFSIGGEN_ATTR_MCCW_EXTERNAL_TRIGGER_DELAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347619
#define RSRFSIGGEN_ATTR_MCCW_EXTERNAL_TRIGGER_INHIBIT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347620
#define RSRFSIGGEN_ATTR_MCCW_MARKER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347621
#define RSRFSIGGEN_ATTR_MCCW_MARKER_PULSE_DIVIDER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347622
#define RSRFSIGGEN_ATTR_MCCW_MARKER_PULSE_FREQUENCY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347623
#define RSRFSIGGEN_ATTR_MCCW_MARKER_PATTERN                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347624
#define RSRFSIGGEN_ATTR_MCCW_MARKER_OFF_TIME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347625
#define RSRFSIGGEN_ATTR_MCCW_MARKER_ON_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347626
#define RSRFSIGGEN_ATTR_MCCW_MARKER_DELAY                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347627
#define RSRFSIGGEN_ATTR_MCCW_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347628
#define RSRFSIGGEN_ATTR_MCCW_FIXED_MARKER_DELAY_MAXIMUM                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347629
#define RSRFSIGGEN_ATTR_MCCW_FIXED_MARKER_DELAY_MINIMUM                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347630
#define RSRFSIGGEN_ATTR_MCCW_CLOCK_SOURCE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347631
#define RSRFSIGGEN_ATTR_MCCW_CLOCK_SOURCE_LEGACY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351016
#define RSRFSIGGEN_ATTR_MCCW_CLOCK_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347632
#define RSRFSIGGEN_ATTR_MCCW_SAMPLE_CLOCK_MULTIPLIER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347633
#define RSRFSIGGEN_ATTR_MCCW_CLOCK_SYNCHRONISATION_EXECUTE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351048
#define RSRFSIGGEN_ATTR_MCCW_CLOCK_SYNCHRONISATION_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351049
#define RSRFSIGGEN_ATTR_MCCW_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351050
#define RSRFSIGGEN_ATTR_STEREO_ENABLED                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347634
#define RSRFSIGGEN_ATTR_STEREO_SET_TO_DEFAULT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347635
#define RSRFSIGGEN_ATTR_STEREO_DEVIATION                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347636
#define RSRFSIGGEN_ATTR_STEREO_AUDIO_SOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347637
#define RSRFSIGGEN_ATTR_STEREO_AUDIO_CATALOG                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347638
#define RSRFSIGGEN_ATTR_STEREO_AUDIO_SOURCE_FILE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347639
#define RSRFSIGGEN_ATTR_STEREO_EXTERNAL_CLOCK                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347640
#define RSRFSIGGEN_ATTR_STEREO_AUDIO_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347641
#define RSRFSIGGEN_ATTR_STEREO_AUDIO_LEVEL                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347642
#define RSRFSIGGEN_ATTR_STEREO_LF_GENERATOR_FREQUENCY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347643
#define RSRFSIGGEN_ATTR_STEREO_PREEMPHASIS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347644
#define RSRFSIGGEN_ATTR_STEREO_WITHOUT_INTERRUPTION_ENABLE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347645
#define RSRFSIGGEN_ATTR_STEREO_SETTINGS_CATALOG                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347646
#define RSRFSIGGEN_ATTR_STEREO_DELETE_SETTINGS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349895
#define RSRFSIGGEN_ATTR_STEREO_RECALL_SETTINGS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347647
#define RSRFSIGGEN_ATTR_STEREO_SAVE_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347648
#define RSRFSIGGEN_ATTR_STEREO_PILOT_ENABLE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347649
#define RSRFSIGGEN_ATTR_STEREO_PILOT_DEVIATION                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347650
#define RSRFSIGGEN_ATTR_STEREO_PILOT_PHASE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347651
#define RSRFSIGGEN_ATTR_STEREO_DS_ENABLE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347652
#define RSRFSIGGEN_ATTR_STEREO_DS_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347653
#define RSRFSIGGEN_ATTR_STEREO_DS_DEVIATION                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347654
#define RSRFSIGGEN_ATTR_STEREO_DS_PHASE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347655
#define RSRFSIGGEN_ATTR_STEREO_DS_DATA_RATE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347656
#define RSRFSIGGEN_ATTR_STEREO_DS_DATA_SET                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347657
#define RSRFSIGGEN_ATTR_STEREO_DS_GROUP_LIST_CATALOG                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347658
#define RSRFSIGGEN_ATTR_STEREO_DS_LOAD_GROUP_LIST                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347659
#define RSRFSIGGEN_ATTR_STEREO_DS_USER_GROUPS_INPUT_METHOD                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347660
#define RSRFSIGGEN_ATTR_STEREO_GROUPS_SET_TO_DEFAULT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347661
#define RSRFSIGGEN_ATTR_STEREO_GROUPS_SAVE_SETTINGS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347662
#define RSRFSIGGEN_ATTR_STEREO_GROUPS_SET_ACTIVE_GROUP_TO_DEFAULT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347663
#define RSRFSIGGEN_ATTR_STEREO_GROUPS_PROGRAM_IDENTIFICATION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347664
#define RSRFSIGGEN_ATTR_STEREO_GROUPS_PROGRAM_TYPE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347665
#define RSRFSIGGEN_ATTR_STEREO_GROUPS_TRAFFIC_PROGRAM_ENABLE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347666
#define RSRFSIGGEN_ATTR_STEREO_GROUP_ENABLE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347667
#define RSRFSIGGEN_ATTR_STEREO_GROUP_TYPE_NUMBER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347668
#define RSRFSIGGEN_ATTR_STEREO_GROUP_TRANSMIT_TIME                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347669
#define RSRFSIGGEN_ATTR_STEREO_GROUP_INPUT_METHOD                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347670
#define RSRFSIGGEN_ATTR_STEREO_GROUP_TYPE_VERSION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347671
#define RSRFSIGGEN_ATTR_STEREO_GROUP_PROGRAM_SERVICE_NAME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347672
#define RSRFSIGGEN_ATTR_STEREO_GROUP_DYNAMIC_PTY_ENABLE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347673
#define RSRFSIGGEN_ATTR_STEREO_GROUP_COMPRESSED_ENABLE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347674
#define RSRFSIGGEN_ATTR_STEREO_GROUP_ARTIFICAL_HEAD_ENABLE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347675
#define RSRFSIGGEN_ATTR_STEREO_GROUP_STEREO_ENABLE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347676
#define RSRFSIGGEN_ATTR_STEREO_GROUP_AF_COUNT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347680
#define RSRFSIGGEN_ATTR_STEREO_GROUP_TRAFFIC_ANNOUNCEMENT_ENABLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347677
#define RSRFSIGGEN_ATTR_STEREO_GROUP_MUSIC_VOICE_SWITCH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347678
#define RSRFSIGGEN_ATTR_STEREO_GROUP_DECODER_INFORMATION_DATA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347679
#define RSRFSIGGEN_ATTR_STEREO_GROUP_AF                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347681
#define RSRFSIGGEN_ATTR_STEREO_GROUP_TEXT_AB_FLAG                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347682
#define RSRFSIGGEN_ATTR_STEREO_GROUP_RADIO_TEXT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347683
#define RSRFSIGGEN_ATTR_STEREO_GROUP_DATE_TYPE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347684
#define RSRFSIGGEN_ATTR_STEREO_GROUP_USER_DATE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347685
#define RSRFSIGGEN_ATTR_GET_STEREO_GROUP_SYSTEM_DATE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347686
#define RSRFSIGGEN_ATTR_STEREO_GROUP_TIME_TYPE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347687
#define RSRFSIGGEN_ATTR_STEREO_GROUP_USER_TIME                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347688
#define RSRFSIGGEN_ATTR_STEREO_GROUP_LOCAL_OFFSET_TIME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347689
#define RSRFSIGGEN_ATTR_STEREO_GROUP_GET_SYSTEM_TIME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347690
#define RSRFSIGGEN_ATTR_STEREO_GROUP_AB_FLAG                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347691
#define RSRFSIGGEN_ATTR_STEREO_GROUP_PROGRAM_TYPE_NAME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347692
#define RSRFSIGGEN_ATTR_STEREO_GROUP_PROGRAM_IDENTIFICATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347693
#define RSRFSIGGEN_ATTR_STEREO_GROUP_PROGRAM_SERVICE_NAME_ENABLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347694
#define RSRFSIGGEN_ATTR_STEREO_GROUP_OTHER_NET_PROGRAM_SERVICE_NAME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347695
#define RSRFSIGGEN_ATTR_STEREO_GROUP_PROGRAM_ITEM_NUMBER_ENABLE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347696
#define RSRFSIGGEN_ATTR_STEREO_GROUP_PROGRAM_ITEM_NUMBER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347697
#define RSRFSIGGEN_ATTR_STEREO_GROUP_PROGRAM_TYPE_ENABLE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347698
#define RSRFSIGGEN_ATTR_STEREO_GROUP_PROGRAM_TYPE_NUMBER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347699
#define RSRFSIGGEN_ATTR_STEREO_GROUP_TA_TYPE_A_ENABLE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347700
#define RSRFSIGGEN_ATTR_STEREO_GROUP_TA_TYPE_B_ENABLE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347701
#define RSRFSIGGEN_ATTR_STEREO_GROUP_TRAFFIC_PROGRAM_ENABLE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347702
#define RSRFSIGGEN_ATTR_STEREO_GROUP_AF_ENABLE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347703
#define RSRFSIGGEN_ATTR_STEREO_GROUP_MF_ENABLE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347704
#define RSRFSIGGEN_ATTR_STEREO_GROUP_MF_COUNT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347705
#define RSRFSIGGEN_ATTR_STEREO_GROUP_OTHER_NET_AF_COUNT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347708
#define RSRFSIGGEN_ATTR_STEREO_GROUP_MF                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347706
#define RSRFSIGGEN_ATTR_STEREO_GROUP_MAPPED_TUNNING_FREQUENCY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347707
#define RSRFSIGGEN_ATTR_STEREO_GROUP_OTHER_NET_AF                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347709
#define RSRFSIGGEN_ATTR_STEREO_GROUP_LI_ENABLE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347710
#define RSRFSIGGEN_ATTR_STEREO_GROUP_LINKAGE_ACTUATOR                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347711
#define RSRFSIGGEN_ATTR_STEREO_GROUP_EXTENDED_GENERIC_INDICATOR                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347712
#define RSRFSIGGEN_ATTR_STEREO_GROUP_INTERNATIONAL_LINKAGE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347713
#define RSRFSIGGEN_ATTR_STEREO_GROUP_LINKAGE_NUMBER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347714
#define RSRFSIGGEN_ATTR_STEREO_GROUPS_HEX_TABLE_SET_TO_DEFAULT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347715
#define RSRFSIGGEN_ATTR_STEREO_GROUPS_HEX_TABLE_NUMBER_OF_ENTRIES                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347716
#define RSRFSIGGEN_ATTR_STEREO_GROUPS_HEX_CATALOG                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353246
#define RSRFSIGGEN_ATTR_STEREO_GROUPS_HEX_RECALL_SETTINGS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353247
#define RSRFSIGGEN_ATTR_STEREO_GROUPS_HEX_TABLE_BLOCK                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347717
#define RSRFSIGGEN_ATTR_STEREO_USER_MESSAGE_TABLE_NUMBER_OF_ENTRIES                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347718
#define RSRFSIGGEN_ATTR_STEREO_USER_MEASSAGE_TABLE_BLOCK                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347719
#define RSRFSIGGEN_ATTR_STEREO_TRIGGER_STATUS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347720
#define RSRFSIGGEN_ATTR_STEREO_TRIGGER_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347721
#define RSRFSIGGEN_ATTR_XMR_ENABLED                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347722
#define RSRFSIGGEN_ATTR_XMR_SET_TO_DEFAULT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347723
#define RSRFSIGGEN_ATTR_XMR_VERSION                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347724
#define RSRFSIGGEN_ATTR_XMR_PHYSICAL_LAYER_MODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347725
#define RSRFSIGGEN_ATTR_XMR_DATA_SOURCE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347726
#define RSRFSIGGEN_ATTR_XMR_DATA_SOURCE_DATA_LIST                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347727
#define RSRFSIGGEN_ATTR_XMR_DATA_SOURCE_PATTERN                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347728
#define RSRFSIGGEN_ATTR_XMR_NUMBER_OF_FRAMES                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347729
#define RSRFSIGGEN_ATTR_XMR_SETTINGS_CATALOG                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347730
#define RSRFSIGGEN_ATTR_XMR_DELETE_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347731
#define RSRFSIGGEN_ATTR_XMR_RECALL_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347732
#define RSRFSIGGEN_ATTR_XMR_SAVE_SETTINGS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347733
#define RSRFSIGGEN_ATTR_XMR_FAST_STORE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353235
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_DELAY                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347734
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_FILTER_TYPE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347735
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_FILTER_PARAMETER_ROOT_COSINE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347736
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_FILTER_PARAMETER_COSINE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347737
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_FILTER_PARAMETER_PURE_GAUSS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347738
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_FILTER_PARAMETER_GAUSS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347739
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_FILTER_PARAMETER_APCO25                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347740
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_FILTER_PARAMETER_SPLIT_PHASE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347741
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_FILTER_PARAMETER_LOWPASS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347742
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_FILTER_PARAMETER_LOWPASS_EVM                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347743
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_FILTER_SYMBOL_RATE_VARIATION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347744
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_TRIGGER_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347745
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_EXECUTE_TRIGGER                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347746
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_TRIGGER_SOURCE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347747
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_SIGNAL_DURATION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347748
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_INTERNAL_TRIGGER_DELAY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347749
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_INTERNAL_TRIGGER_INHIBIT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347750
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_EXTERNAL_TRIGGER_DELAY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347751
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_EXTERNAL_TRIGGER_INHIBIT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347752
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_MARKER_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347753
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_MARKER_PULSE_DIVIDER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347754
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_MARKER_PULSE_FREQUENCY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347755
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_MARKER_PATTERN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347756
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_MARKER_OFF_TIME                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347757
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_MARKER_ON_TIME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347758
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_MARKER_PERIOD                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347759
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_MARKER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347760
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347761
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_FIXED_MARKER_DELAY_MAXIMUM                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347762
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_FIXED_MARKER_DELAY_MINIMUM                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347763
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_CLOCK_SOURCE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347764
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_CLOCK_MODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347765
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_CLOCK_MULTIPLIER                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347766
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_CLOCK_SYNCHRONISATION_EXECUTE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347767
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_CLOCK_SYNCHRONISATION_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347768
#define RSRFSIGGEN_ATTR_XMR_SATELLITE_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347769
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_DELAY                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347770
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_LEVEL_AMSS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347771
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_LEVEL_MCM                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347772
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_COMPLIANT_FILTER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347773
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_FILTER_TYPE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347774
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_FILTER_PARAMETER_ROOT_COSINE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347775
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_FILTER_PARAMETER_COSINE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347776
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_FILTER_COSINE_CUT_OFF_FREQUENCY_SHIFT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347777
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_FILTER_PARAMETER_PURE_GAUSS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347778
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_FILTER_PARAMETER_GAUSS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347779
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_FILTER_PARAMETER_APCO25                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347780
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_FILTER_PARAMETER_SPLIT_PHASE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347781
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_FILTER_PARAMETER_LOWPASS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347782
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_FILTER_PARAMETER_LOWPASS_EVM                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347783
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_FILTER_SYMBOL_RATE_VARIATION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347784
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_TRIGGER_MODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347785
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_EXECUTE_TRIGGER                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347786
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_TRIGGER_SOURCE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347787
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_TRIGGER_SIGNAL_DURATION_UNIT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347788
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_SIGNAL_DURATION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347789
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_MARKER_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347790
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_MARKER_OFF_TIME                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347794
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_MARKER_ON_TIME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347795
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_MARKER_PERIOD                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347796
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_MARKER_MCM_POSITION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347797
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_MARKER_DELAY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347798
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_FIX_MARKER_DELAY_TO_CURRENT_RANGE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347799
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_CLOCK_SOURCE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347800
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_CLOCK_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347801
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_CLOCK_MULTIPLIER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347802
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_CLOCK_SYNCHRONISATION_EXECUTE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347803
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_CLOCK_SYNCHRONISATION_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347804
#define RSRFSIGGEN_ATTR_XMR_TERRESTRIAL_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347805
#define RSRFSIGGEN_ATTR_XMR_TRIGGER_STATUS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347806
#define RSRFSIGGEN_ATTR_XMR_TRIGGER_ARM                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347807
#define RSRFSIGGEN_ATTR_XMR_TRIGGER_EXECUTE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347808
#define RSRFSIGGEN_ATTR_SIRIUS_ENABLED                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347809
#define RSRFSIGGEN_ATTR_SIRIUS_SET_TO_DEFAULT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347810
#define RSRFSIGGEN_ATTR_SIRIUS_PHYSICAL_LAYER                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347811
#define RSRFSIGGEN_ATTR_SIRIUS_VERSION                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347812
#define RSRFSIGGEN_ATTR_SIRIUS_PHYSICAL_LAYER_TRANSMISSION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347813
#define RSRFSIGGEN_ATTR_SIRIUS_DATA_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347814
#define RSRFSIGGEN_ATTR_SIRIUS_DATA_SOURCE_DATA_LIST                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347815
#define RSRFSIGGEN_ATTR_SIRIUS_DATA_SOURCE_DATA_LIST_DATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347816
#define RSRFSIGGEN_ATTR_SIRIUS_DATA_SOURCE_PATTERN                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347817
#define RSRFSIGGEN_ATTR_SIRIUS_SETTINGS_CATALOG                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347818
#define RSRFSIGGEN_ATTR_SIRIUS_DELETE_SETTINGS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347819
#define RSRFSIGGEN_ATTR_SIRIUS_RECALL_SETTINGS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347820
#define RSRFSIGGEN_ATTR_SIRIUS_SAVE_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347821
#define RSRFSIGGEN_ATTR_SIRIUS_FAST_STORE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353226
#define RSRFSIGGEN_ATTR_SIRIUS_HDD_STREAMING_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347822
#define RSRFSIGGEN_ATTR_SIRIUS_HDD_STREAMING_BUFFER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347823
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_DELAY                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 347824
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_MODULATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347825
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_OVERLAY_ANGULAR_OFFSET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347826
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_FILTER_TYPE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347827
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_FILTER_PARAMETER_ROOT_COSINE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347828
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_FILTER_PARAMETER_COSINE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347829
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_FILTER_PARAMETER_GAUSS_PURE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347830
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_FILTER_PARAMETER_GAUSS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347831
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_FILTER_PARAMETER_APCO25                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347832
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_FILTER_PARAMETER_SPLIT_PHASE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347833
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_FILTER_PARAMETER_LOWPASS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347834
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_FILTER_PARAMETER_LOWPASS_EVM                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347835
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_FILTER_SYMBOL_RATE_VARIATION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347836
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_TRIGGER_STATUS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347837
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_TRIGGER_ARM                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347838
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_TRIGGER_EXECUTE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347839
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_TRIGGER_MODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347840
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_TRIGGER_SOURCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347841
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_TRIGGER_SIGNAL_DURATION                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347842
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_INTERNAL_TRIGGER_DELAY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347843
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_INTERNAL_TRIGGER_INHIBIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347844
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_EXTERNAL_TRIGGER_DELAY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347845
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_EXTERNAL_TRIGGER_INHIBIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347846
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_MARKER_MODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 347847
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_MARKER_PULSE_DIVIDER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 347848
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_MARKER_PULSE_FREQUENCY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 347849
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_MARKER_PATTERN                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347850
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_MARKER_PERIOD                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347851
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_MARKER_ON_TIME                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347852
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_MARKER_OFF_TIME                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347853
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_MARKER_DELAY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347854
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_FIX_MARKER_DELAY_TO_CURRENT_RANGE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347855
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_FIXED_MARKER_DELAY_MAXIMUM                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347856
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_FIXED_MARKER_DELAY_MINIMUM                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347857
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_CLOCK_SOURCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347858
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_CLOCK_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347859
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_CLOCK_MULTIPLIER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347860
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_CLOCK_SYNCHRONISATION_EXECUTE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347861
#define RSRFSIGGEN_ATTR_SIRIUS_SATELLITE_CLOCK_SYNCHRONISATION_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347862
#define RSRFSIGGEN_ATTR_XMR_SIRIUS_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347863
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_DELAY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347864
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_MODULATION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347865
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_OVERLAY_ANGULAR_OFFSET                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347866
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_FILTER_COMPLIANT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347867
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_FILTER_TYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347868
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_FILTER_PARAMETER_ROOT_COSINE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347869
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_FILTER_PARAMETER_COSINE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347870
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_FILTER_PARAMETER_GAUSS_PURE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347871
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_FILTER_PARAMETER_GAUSS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347872
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_FILTER_PARAMETER_APCO25                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347873
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_FILTER_PARAMETER_SPLIT_PHASE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347874
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_FILTER_SYMBOL_RATE_VARIATION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347875
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_FILTER_PARAMETER_LOWPASS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347876
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_FILTER_PARAMETER_LOWPASS_EVM                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347877
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_FILTER_COSINE_CUT_OFF_FREQUENCY_SHIFT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 347878
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_TRIGGER_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347879
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_TRIGGER_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347880
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_TRIGGER_SIGNAL_DURATION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 347881
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_INTERNAL_TRIGGER_DELAY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347882
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_INTERNAL_TRIGGER_INHIBIT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347883
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_EXTERNAL_TRIGGER_DELAY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347884
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_EXTERNAL_TRIGGER_INHIBIT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347885
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_MARKER_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 347886
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_MARKER_SYMBOL_POSITION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 347887
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_MARKER_PERIOD                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347888
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_MARKER_ON_TIME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 347889
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_MARKER_OFF_TIME                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 347890
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_MARKER_DELAY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347891
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_FIX_MARKER_DELAY_TO_CURRENT_RANGE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347892
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_FIXED_MARKER_DELAY_MAXIMUM                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347893
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_FIXED_MARKER_DELAY_MINIMUM                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347894
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_CLOCK_SOURCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 347895
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_CLOCK_MODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347896
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_CLOCK_MULTIPLIER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347897
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_CLOCK_SYNCHRONISATION_EXECUTE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 347898
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_CLOCK_SYNCHRONISATION_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 347899
#define RSRFSIGGEN_ATTR_SIRIUS_TERRESTRIAL_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER             RS_SPECIFIC_PUBLIC_ATTR_BASE + 347900
#define RSRFSIGGEN_ATTR_SIRIUS_TRIGGER_ARM_EXECUTE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353227
#define RSRFSIGGEN_ATTR_SIRIUS_TRIGGER_EXECUTE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353228
#define RSRFSIGGEN_ATTR_SIRIUS_TRIGGER_STATUS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353229
#define RSRFSIGGEN_ATTR_UWB_ENABLED                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 347901
#define RSRFSIGGEN_ATTR_UWB_TARGET_FREQUENCY                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 347902
#define RSRFSIGGEN_ATTR_EUTRA_ENABLED                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350159
#define RSRFSIGGEN_ATTR_EUTRA_DUPLEXING                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350160
#define RSRFSIGGEN_ATTR_EUTRA_LINK_DIRECTION                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350161
#define RSRFSIGGEN_ATTR_EUTRA_STANDARD                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357336
#define RSRFSIGGEN_ATTR_EUTRA_SEQUENCE_LENGTH                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350162
#define RSRFSIGGEN_ATTR_EUTRA_SEQUENCE_LENGTH_IN_SUBFRAMES                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363397
#define RSRFSIGGEN_ATTR_EUTRA_SET_TO_DEFAULT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350163
#define RSRFSIGGEN_ATTR_EUTRA_GENERATE_WAVEFORM_FILE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350164
#define RSRFSIGGEN_ATTR_EUTRA_TEST_MODEL_DL                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353295
#define RSRFSIGGEN_ATTR_EUTRA_TEST_MODEL_TDD                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353296
#define RSRFSIGGEN_ATTR_EUTRA_VERSION                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350165
#define RSRFSIGGEN_ATTR_EUTRA_USER_PLANE_DATA_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361913
#define RSRFSIGGEN_ATTR_EUTRA_SETTINGS_CATALOG                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350166
#define RSRFSIGGEN_ATTR_EUTRA_DELETE_SETTINGS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350167
#define RSRFSIGGEN_ATTR_EUTRA_RECALL_SETTINGS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350168
#define RSRFSIGGEN_ATTR_EUTRA_SAVE_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350169
#define RSRFSIGGEN_ATTR_EUTRA_FAST_STORE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353297
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_TEST_CASE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350170
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_SUBTEST                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353434
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_OPTION                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353435
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_APPLY_SETTINGS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350171
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_GENERAL_TEST_SPECIFICATION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 354437
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_GENERAL_TEST_SPECIFICATION_RELEASE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350172
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_GENERAL_TRIGGER_CONFIGURATION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350173
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_GENERAL_MARKER_CONFIGURATION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350174
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_GENERAL_SIGNAL_ROUTING                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350175
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_GENERAL_INSTRUMENT_SETUP                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350176
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_GENERAL_NUMBER_OF_RX_ANTENNAS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350177
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_GENERAL_NUMBER_OF_TX_ANTENNAS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353298
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_GENERAL_ANTENNA_SUBSET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350178
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_GENERAL_GENERATED_SIGNAL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350179
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_GENERAL_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350180
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_GENERAL_BASE_STATION_CLASS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353299
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_FREQUENCY_ALLOCATION_FREQUENCY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350181
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_FREQUENCY_ALLOCATION_BLOCKS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350182
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_DOMINANT_INTERFERER_PROPORTION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361914
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_RELATIVE_POWER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361915
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_RF_FREQUENCY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350183
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_FREQUENCY_OFFSET                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350184
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_CHANNEL_BANDWIDTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350185
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_OUTPUT_POWER_LEVEL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350186
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_DUPLEXING                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350187
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_TDD_UL_DL_CONFIGURATION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350188
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_SIGNAL_ADVANCE_N_TA_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350189
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_SPECIAL_SUBFRAME_CONFIGURATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350190
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_CELL_ID                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350191
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_UE_ID                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350192
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_UE_ID_MOVING_UE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350193
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_VRB_OFFSET                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350194
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_VRB_OFFSET_MOVING_UE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350195
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_POWER_LEVEL_UNIT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 354522
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_CYCLIC_PREFIX                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350197
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_PROPAGATION_CONDITIONS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350198
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_FRC                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350199
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_BURST_FORMAT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350200
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_TIMING_OFFSET_BASE_VALUE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350201
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_FRACTION_THROUGPUT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350202
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_ADDITIONALLY_CONFIGURE_PUCCH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350203
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_POWER_LEVEL_PUSCH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350204
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_POWER_LEVEL_PUCCH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350205
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_HIGH_SPEED_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350206
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_TRANSMIT_SRS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350207
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_ORTHOGONAL_COVER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350208
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_ACK_NACK_BITS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353300
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_ACK_NACK_PATTERN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353301
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_VIRTUAL_DOWNLINK_RF_FREQUENCY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355804
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_NPUSCH_FRC                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361916
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_NPRACH_PREAMBLE_FORMAT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361917
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_SUBCARRIER_SPACING                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361918
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_REPETITIONS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361919
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_CE_MODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361920
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_INTRACELL_POWER_LEVEL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361921
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_INTRACELL_FRC                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361922
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_INSTRACELL_UE_ID                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361923
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_CQI_PATTERN_PORT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353302
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_WS_PORT_ORTHOGONAL_COVER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353303
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_OFFSET_TO_CHANNEL_EDGE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350209
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_RF_FREQUENCY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350210
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_DUPLEXING                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350211
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_TDD_UL_DL_CONFIGURATION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350212
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_SIGNAL_ADVANCE_N_TA_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350213
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_CHANNEL_BANDWIDTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350214
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_POWER_LEVEL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350215
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_UE_ID                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350216
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_UE_ID_STATIONARY_UE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350217
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_FREQUENCY_SHIFT_M                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350218
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_VRB_OFFSET                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350219
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_VRB_OFFSET_STATIONARY_UE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350220
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_CELL_ID                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350221
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_RB_CENTER_FREQUENCY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350222
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_INTERFERER_TYPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350223
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_TEST_REQUIREMENT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350224
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_TRANSMIT_SRS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350225
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_PROPAGATION_CONDITIONS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350226
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_ORTHOGONAL_COVER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350227
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_TEST_MODEL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350228
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_NRB                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353304
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS_TEST_MODEL_CODES                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353436
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS2_PROPAGATION_CONDITIONS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350229
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS2_ORTHOGONAL_COVER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350230
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS2_POWER_LEVEL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350231
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS2_INTERFERER_TYPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350232
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS2_RF_FREQUENCY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350233
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS2_CHANNEL_BANDWIDTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353437
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS2_UE_ID                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361924
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS2_CELL_ID                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361925
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS2_DUPLEXING                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353438
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS3_PROPAGATION_CONDITIONS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350234
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS3_ORTHOGONAL_COVER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350235
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_IS3_POWER_LEVEL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350236
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_RTF_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350237
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_RTF_CONNECTOR                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350238
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_RTF_CONNECTOR_MOVING_UE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350239
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_RTF_CONNECTOR_STATIONARY_UE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350240
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_RTF_ADDITIONAL_USER_DELAY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350241
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_RTF_BASEBAND_SELECTOR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350242
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_RTF_BASEBAND_SELECTOR_MOVING_UE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350243
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_RTF_BASEBAND_SELECTOR_STATIONARY_UE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350244
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_RTF_SERIAL_RATE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350245
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_RTF_ACK_DEFINITION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350246
#define RSRFSIGGEN_ATTR_EUTRA_WIZARD_AWGN_POWER_LEVEL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350247
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350248
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_OUTPUT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350249
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_PREAMBLE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350250
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_GENERATE_SUMMARY_LOG                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 354512
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_DL_EXTENDED_INFORMATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350251
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_UL_EXTENDED_INFORMATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350252
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_DL_ALL_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353305
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_DL_ALL_DISABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353306
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_DL_ENCC_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353307
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_DL_PBCH_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353308
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_DL_PDSCH_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353309
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_DL_PMCH_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353310
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_DL_NWUS_ENABLE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361926
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_UL_ALL_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353311
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_UL_ALL_DISABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353312
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_UL_PUSCH_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353313
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_UL_PUSDRS_ENABLE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353439
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_UL_PUCDRS_ENABLE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353440
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_UL_SIDELINK_ENABLE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357337
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_UL_SIDELINK_DRS_ENABLE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357338
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_UL_SRS_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353441
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_UL_PUCCH_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354513
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_DL_LOGGING_POINT_ENABLE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350254
#define RSRFSIGGEN_ATTR_EUTRA_LOGFILES_UL_LOGGING_POINT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350255
#define RSRFSIGGEN_ATTR_EUTRA_DL_CARRIER_AGGREGATION_ENABLE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350256
#define RSRFSIGGEN_ATTR_EUTRA_DL_CARRIER_AGGREGATION_CELL_INDEX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350257
#define RSRFSIGGEN_ATTR_EUTRA_DL_CARRIER_AGGREGATION_PHYSICAL_CELL_ID                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350258
#define RSRFSIGGEN_ATTR_EUTRA_DL_CARRIER_AGGREGATION_CELL_BANDWIDTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350259
#define RSRFSIGGEN_ATTR_EUTRA_DL_CARRIER_AGGREGATION_CELL_BASEBAND                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350260
#define RSRFSIGGEN_ATTR_EUTRA_DL_CARRIER_AGGREGATION_CELL_DELTA_FREQUENCY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350261
#define RSRFSIGGEN_ATTR_EUTRA_DL_CARRIER_AGGREGATION_CELL_DUPLEXING                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355805
#define RSRFSIGGEN_ATTR_EUTRA_DL_CARRIER_AGGREGATION_CELL_TDD_UL_DL_CONFIGURATION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355806
#define RSRFSIGGEN_ATTR_EUTRA_DL_CARRIER_AGGREGATION_CELL_TDD_SPECIAL_SUBFRAME_CONFIG                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355807
#define RSRFSIGGEN_ATTR_EUTRA_DL_CARRIER_AGGREGATION_CELL_CIF_PRESENT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350262
#define RSRFSIGGEN_ATTR_EUTRA_DL_CARRIER_AGGREGATION_SCHEDCELL_INDEX                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350263
#define RSRFSIGGEN_ATTR_EUTRA_DL_CARRIER_AGGREGATION_CELL_PDSCH_START                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350264
#define RSRFSIGGEN_ATTR_EUTRA_DL_CARRIER_AGGREGATION_CELL_POWER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350265
#define RSRFSIGGEN_ATTR_EUTRA_DL_CARRIER_AGGREGATION_CELL_TIME_DELAY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 354438
#define RSRFSIGGEN_ATTR_EUTRA_DL_CARRIER_AGGREGATION_CELL_DELAY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350266
#define RSRFSIGGEN_ATTR_EUTRA_DL_CARRIER_AGGREGATION_CELL_ENABLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350267
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350268
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_RHO_A                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350269
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_UE_CATEGORY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350270
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_SC_RADIO_FRAME_ALLOCATION_PERIOD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350271
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_SC_RADIO_FRAME_ALLOCATION_OFFSET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350272
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_SC_SUBFRAME_ALLOCATION_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350273
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_SC_ALLOCATION_VALUE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350274
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_AREA_ID                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350275
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_NONMBSFN_REGION_LENGTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350276
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_NOTIFICATION_INDICATOR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350277
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_MCCH_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350278
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_MCCH_REPETITION_PERIOD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350279
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_MCCH_OFFSET                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350280
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_MCCH_MODIFICATION_PERIOD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350281
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_MCCH_MCS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350282
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_MCCH_MODULATION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350283
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_MCCH_TRANSPORT_BLOCK_SIZE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350284
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_MCCH_DATA_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350285
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_MCCH_DATA_LIST                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350286
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_MCCH_PATTERN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350287
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_ALLOCATION_VALUE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350288
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_NOTIFICATION_REPETITION_COEFFICIENT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350289
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_NOTIFICATION_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350290
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_NOTIFICATION_SUBFRAME_INDEX                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350291
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_AI_NOTIFICATION_PATTERN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350292
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_PMCH_COMMON_SUBFRAME_AP                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 354521
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_PMCH_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353314
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_PMCH_NUMBER_OF_PMCHS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350294
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_PMCH_SF_ALLOC_START                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350295
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_PMCH_SF_ALLOC_END                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350296
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_PMCH_MCS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350297
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_PMCH_MCS_TWO                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 354439
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_PMCH_MODULATION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 354139
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_PMCH_SCHEDULING_PERIOD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350298
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_PMCH_DATA_SOURCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350299
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_PMCH_DATA_LIST                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350300
#define RSRFSIGGEN_ATTR_EUTRA_DL_MBSFN_PMCH_PATTERN                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350301
#define RSRFSIGGEN_ATTR_EUTRA_DL_PHYSICAL_SETTINGS_CHANNEL_BANDWIDTH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350302
#define RSRFSIGGEN_ATTR_EUTRA_DL_PHYSICAL_SETTINGS_SAMPLING_RATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350303
#define RSRFSIGGEN_ATTR_EUTRA_DL_PHYSICAL_SETTINGS_FFT_SIZE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350304
#define RSRFSIGGEN_ATTR_EUTRA_DL_PHYSICAL_SETTINGS_OCCUPIED_SUBCARRIERS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350305
#define RSRFSIGGEN_ATTR_EUTRA_DL_PHYSICAL_SETTINGS_LEFT_GUARD_SUBCARRIERS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350306
#define RSRFSIGGEN_ATTR_EUTRA_DL_PHYSICAL_SETTINGS_RIGHT_GUARD_SUBCARRIERS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350307
#define RSRFSIGGEN_ATTR_EUTRA_DL_PHYSICAL_SETTINGS_RESOURCE_BLOCKS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350308
#define RSRFSIGGEN_ATTR_EUTRA_DL_PHYSICAL_SETTINGS_MAPPED_RESOURCE_BLOCKS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350309
#define RSRFSIGGEN_ATTR_EUTRA_DL_PHYSICAL_SETTINGS_OCCUPIED_BANDWIDTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350310
#define RSRFSIGGEN_ATTR_EUTRA_DL_K55_PDSCH_SCHEDULING                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350311
#define RSRFSIGGEN_ATTR_EUTRA_DL_MIMO_GLOBAL_CONFIGURATION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350312
#define RSRFSIGGEN_ATTR_EUTRA_DL_MIMO_NIOT_CONFIGURATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356040
#define RSRFSIGGEN_ATTR_EUTRA_DL_MIMO_SIMULATED_ANTENNA                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350313
#define RSRFSIGGEN_ATTR_EUTRA_DL_MIMO_SIMULATED_ANTENNA_A                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350314
#define RSRFSIGGEN_ATTR_EUTRA_DL_MIMO_SIMULATED_ANTENNA_B                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350315
#define RSRFSIGGEN_ATTR_EUTRA_DL_MIMO_APM_MAPPING_COORDINATES                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350316
#define RSRFSIGGEN_ATTR_EUTRA_DL_MIMO_CELL_SPECIFIC_APM_BASEBAND                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354140
#define RSRFSIGGEN_ATTR_EUTRA_DL_MIMO_CELL_SPECIFIC_APM_REAL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 354473
#define RSRFSIGGEN_ATTR_EUTRA_DL_MIMO_CELL_SPECIFIC_APM_IMAGINARY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 354474
#define RSRFSIGGEN_ATTR_EUTRA_DL_MIMO_APM_REAL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350317
#define RSRFSIGGEN_ATTR_EUTRA_DL_MIMO_APM_IMAGINARY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350318
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_ID                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350319
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_PHYSICAL_CELL_ID_GROUP                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350320
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_PHYSICAL_LAYER_ID                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350321
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_CYCLIC_PREFIX                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350322
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_TDD_CYCLIC_PREFIX                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353315
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_PDSCH_P_B                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350323
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_FFNC                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350324
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_PSYNC                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350325
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_SSYNC                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350326
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_PDSCH_RATIO                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350327
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_PDCCH_RATIO                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350328
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_PBCH_RATIO                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350329
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_PHICH_DURATION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350330
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_PHICH_N_G                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350331
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_RA_RNTI                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350332
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_PHICH_DURATION_CELL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355808
#define RSRFSIGGEN_ATTR_EUTRA_DL_CELL_PHICH_N_G_CELL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355809
#define RSRFSIGGEN_ATTR_EUTRA_DL_REFERENCE_FIRST_REFERENCE_SIGNAL_POSITION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350333
#define RSRFSIGGEN_ATTR_EUTRA_DL_REFERENCE_SUBCARRIER_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350334
#define RSRFSIGGEN_ATTR_EUTRA_DL_REFERENCE_USE_SECOND_SYMBOLS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350335
#define RSRFSIGGEN_ATTR_EUTRA_DL_REFERENCE_FIRST_REFERENCE_SYMBOL_POWER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350336
#define RSRFSIGGEN_ATTR_EUTRA_DL_REFERENCE_SECOND_REFERENCE_SYMBOL_POWER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350337
#define RSRFSIGGEN_ATTR_EUTRA_DL_REFERENCE_SIGNAL_POWER_RE_RELATIVE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353316
#define RSRFSIGGEN_ATTR_EUTRA_DL_REFERENCE_SHIFTING_SEQUENCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350338
#define RSRFSIGGEN_ATTR_EUTRA_DL_REFERENCE_ORTHOGONAL_SEQUENCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350339
#define RSRFSIGGEN_ATTR_EUTRA_DL_REFERENCE_PRS_MODULATION_SCHEME                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350340
#define RSRFSIGGEN_ATTR_EUTRA_DL_REFERENCE_SYMBOL_QPSK_SEQUENCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350341
#define RSRFSIGGEN_ATTR_EUTRA_DL_REFERENCE_SYMBOL_IQF_SEQUENCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350342
#define RSRFSIGGEN_ATTR_EUTRA_DL_SYNCHRONIZATION_FIRST_SLOT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350343
#define RSRFSIGGEN_ATTR_EUTRA_DL_SYNCHRONIZATION_P_S_SYNC_TX_ANTENNA                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350344
#define RSRFSIGGEN_ATTR_EUTRA_DL_SYNCHRONIZATION_PSYNC_MODULATION_SCHEME                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350345
#define RSRFSIGGEN_ATTR_EUTRA_DL_SYNCHRONIZATION_PSYNC_QPSK_SEQUENCE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350346
#define RSRFSIGGEN_ATTR_EUTRA_DL_SYNCHRONIZATION_PSYNC_IQF_SEQUENCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350347
#define RSRFSIGGEN_ATTR_EUTRA_DL_SYNCHRONIZATION_SSYNC_MODULATION_SCHEME                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350348
#define RSRFSIGGEN_ATTR_EUTRA_DL_SYNCHRONIZATION_SSYNC_QPSK_SEQUENCE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350349
#define RSRFSIGGEN_ATTR_EUTRA_DL_SYNCHRONIZATION_SSYNC_IQF_SEQUENCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350350
#define RSRFSIGGEN_ATTR_EUTRA_DL_SYNCHRONIZATION_PSYNC_POWER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350351
#define RSRFSIGGEN_ATTR_EUTRA_DL_SYNCHRONIZATION_SSYNC_POWER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350352
#define RSRFSIGGEN_ATTR_EUTRA_DL_NPRS_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359840
#define RSRFSIGGEN_ATTR_EUTRA_DL_NPRS_PARAMETER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359841
#define RSRFSIGGEN_ATTR_EUTRA_DL_NPRS_POWER                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359842
#define RSRFSIGGEN_ATTR_EUTRA_DL_NPRS_ID                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359843
#define RSRFSIGGEN_ATTR_EUTRA_DL_NPRS_SEQUENCE_INFO                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359844
#define RSRFSIGGEN_ATTR_EUTRA_DL_NPRS_BITMAP                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359845
#define RSRFSIGGEN_ATTR_EUTRA_DL_NPRS_VALID_SUBFRAME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359846
#define RSRFSIGGEN_ATTR_EUTRA_DL_NPRS_MUTING_INFO_A                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359847
#define RSRFSIGGEN_ATTR_EUTRA_DL_NPRS_MUTING_INFO_B                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359848
#define RSRFSIGGEN_ATTR_EUTRA_DL_NPRS_PERIOD                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359849
#define RSRFSIGGEN_ATTR_EUTRA_DL_NPRS_START_SUBRAME                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359850
#define RSRFSIGGEN_ATTR_EUTRA_DL_NPRS_NUMBER_OF_SUBFRAMES                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359851
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRS_ENABLED                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350353
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRS_CONFIGURATION_INDEX                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350354
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRS_T_PRS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350355
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRS_SUBFRAME_OFFSET_DELTA_PRS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350356
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRS_DL_SUBFRAMES                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350357
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRS_BANDWIDTH                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350358
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRS_POWER                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350359
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRS_MUTING_INFO                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353317
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_ENABLED                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353318
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_CONFIGURATION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353319
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_ANTENNA_PORTS_NUMBER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353320
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_POWER                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353321
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_SUBFRAME_OFFSET                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353322
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_SFI                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353323
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_PERIODICITY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353324
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_ZERO_POWER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353325
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_ZERO_POWER_SUBFRAME_OFFSET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353326
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_ZERO_POWER_SUBFRAME_CONFIG                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353327
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_ZERO_POWER_PERIODICITY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353328
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_SCRAMBLING_IDENTITY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356041
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_CELL_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356042
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_CELL_ANTENNA_PORTS_NUMBER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356043
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_CELL_POWER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356044
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_CELL_SUBFRAME_OFFSET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356045
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_CELL_SFI                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356046
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_CELL_PERIODICITY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356047
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_CDMTYPE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357339
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_RS_IN_DWPTS_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357340
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_NUMBER_OF_CSIRS_CONFIGURATIONS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357341
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_CELL_CONFIGURATION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356048
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_NZP_FREQUENCY_DENSITY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357342
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_NZP_TRANSMISSION_COMB                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357343
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_CELL_ZERO_POWER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356049
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_CELL_ZERO_POWER_SUBFRAME_OFFSET                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356050
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_CELL_ZERO_POWER_SUBFRAME_CONFIG                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356051
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_CELL_ZERO_POWER_PERIODICITY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356052
#define RSRFSIGGEN_ATTR_EUTRA_DL_TDD_CONFIGURATION_NUMBER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350360
#define RSRFSIGGEN_ATTR_EUTRA_DL_TDD_SPECIAL_CONFIGURATION_NUMBER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350361
#define RSRFSIGGEN_ATTR_EUTRA_DL_TDD_NUMBER_OF_SYMBOLS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359852
#define RSRFSIGGEN_ATTR_EUTRA_DL_NIOT_IDENTITY                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356053
#define RSRFSIGGEN_ATTR_EUTRA_DL_NIOT_CARRIER_ALLOCATION_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357344
#define RSRFSIGGEN_ATTR_EUTRA_DL_NB_IOT_CARRIER_ALLOCATION_LTE_CELL_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357345
#define RSRFSIGGEN_ATTR_EUTRA_DL_NB_IOT_CARRIER_ALLOCATION_PUNCTURE_INBAND_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357346
#define RSRFSIGGEN_ATTR_EUTRA_DL_NB_IOT_CARRIER_ALLOCATION_GAP_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359853
#define RSRFSIGGEN_ATTR_EUTRA_DL_NBIOT_CARRIER_ALLOCATION_GAP_THRESHOLD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359854
#define RSRFSIGGEN_ATTR_EUTRA_DL_NB_IOT_CARRIER_ALLOCATION_GAP_PERIOD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359855
#define RSRFSIGGEN_ATTR_EUTRA_DL_NB_IOT_CARRIER_ALLOCATION_GAP_DURATION_COEFFICIENT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359856
#define RSRFSIGGEN_ATTR_EUTRA_DL_NIOT_CARRIER_ALLOCATION_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356054
#define RSRFSIGGEN_ATTR_EUTRA_DL_NIOT_CARRIER_ALLOCATION_CRS_SEQUENCE_INFO                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356055
#define RSRFSIGGEN_ATTR_EUTRA_DL_NIOT_CARRIER_ALLOCATION_RB_INDEX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356056
#define RSRFSIGGEN_ATTR_EUTRA_DL_NIOT_CARRIER_ALLOCATION_RB_INDEX_GB                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356057
#define RSRFSIGGEN_ATTR_EUTRA_DL_NIOT_CARRIER_ALLOCATION_DELTA_FREQUENCY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356058
#define RSRFSIGGEN_ATTR_EUTRA_DL_NIOT_CARRIER_ALLOCATION_NCELL_ID                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356059
#define RSRFSIGGEN_ATTR_EUTRA_DL_NIOT_CARRIER_ALLOCATION_NCELL_ID_GROUP                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356060
#define RSRFSIGGEN_ATTR_EUTRA_DL_NIOT_CARRIER_ALLOCATION_SUBFRAME_NUMBER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356061
#define RSRFSIGGEN_ATTR_EUTRA_DL_NIOT_CARRIER_ALLOCATION_SUBFRAME_SELECT_ALL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356062
#define RSRFSIGGEN_ATTR_EUTRA_DL_NIOT_CARRIER_ALLOCATION_SUBFRAME_DESELECT_ALL                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356063
#define RSRFSIGGEN_ATTR_EUTRA_DL_NIOT_CARRIER_ALLOCATION_SUBFRAME_VALID                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356064
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_SEARCH_SPACE_COMMON_MAX_REPETITIONS_TYPE_1                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356065
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_SEARCH_SPACE_COMMON_MAX_REPETITIONS_TYPE_2                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356066
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_SEARCH_SPACE_COMMON_START_SUBFRAME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356067
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_SEARCH_SPACE_COMMON_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356068
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_SEARCH_SPACE_UE_MAX_REPETITIONS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356069
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_SEARCH_SPACE_UE_START_SUBFRAME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356070
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_SEARCH_SPACE_UE_OFFSET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356071
#define RSRFSIGGEN_ATTR_EUTRA_DL_NB_IOT_WAKE_UP_SIGNAL_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361927
#define RSRFSIGGEN_ATTR_EUTRA_DL_NB_IOT_WAKE_UP_SIGNAL_MAX_DURATION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361928
#define RSRFSIGGEN_ATTR_EUTRA_DL_NB_IOT_WAKE_UP_SIGNAL_POWER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361929
#define RSRFSIGGEN_ATTR_EUTRA_DL_NB_IOT_WAKE_UP_SIGNAL_START_SUBFRAME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361930
#define RSRFSIGGEN_ATTR_EUTRA_DL_NB_IOT_WAKE_UP_SIGNAL_TIME_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361931
#define RSRFSIGGEN_ATTR_EUTRA_DL_NB_IOT_WAKE_UP_SIGNAL_ACTUAL_DURATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361932
#define RSRFSIGGEN_ATTR_EUTRA_DL_NB_IOT_WAKE_UP_SIGNAL_PAGING_START_SUBFRAME                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361933
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_WIDEBAND_CONFIG                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357347
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_WIDEBAND_NUMBER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359857
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_BITMAP_SUBFRAMES                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356072
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_BITMAP_STARTING_SYMBOL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356073
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_BITMAP_SCHEDULING_INFO_SIB1_BR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356074
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_BITMAP_PBCH_REPETITION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356075
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_BITMAP_SELECT_ALL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362784
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_BITMAP_DESELECT_ALL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362785
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_BITMAP_SUBFRAME_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356076
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_BITMAP_SUBFRAME_VALID                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357348
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_NARROWBANDS_RA_HOPPING                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356077
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_NARROWBANDS_NUMBER_OF_EMTC                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356078
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_NARROWBANDS_HOPPING_NUMBER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356079
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_NARROWBANDS_HOPPING_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356080
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_NARROWBANDS_HOPPING_INTERVAL_CE_MODE_A                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356081
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_NARROWBANDS_HOPPING_INTERVAL_CE_MODE_B                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356082
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_NARROWBANDS_RA_STARTING_NB                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356083
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_NARROWBANDS_PAGING_HOPPING                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356084
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_NARROWBANDS_PAGING_STARTING_NB                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356085
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_SEARCH_SPACE_MPDCCH_MAX_1                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356086
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_SEARCH_SPACE_MPDCCH_MAX_2                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356087
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_SEARCH_SPACE_START_SUBFRAME                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356088
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_SEARCH_SPACE_PDSCH_MAX_A                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356089
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_SEARCH_SPACE_PDSCH_MAX_B                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356090
#define RSRFSIGGEN_ATTR_EUTRA_DL_DRS_ENABLED                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356091
#define RSRFSIGGEN_ATTR_EUTRA_DL_DRS_PERIODICITY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356092
#define RSRFSIGGEN_ATTR_EUTRA_DL_DRS_OFFSET                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356093
#define RSRFSIGGEN_ATTR_EUTRA_DL_DRS_DURATION                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356094
#define RSRFSIGGEN_ATTR_EUTRA_DL_DRS_PATTERN                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356095
#define RSRFSIGGEN_ATTR_EUTRA_DL_DRS_CSI_RS_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356096
#define RSRFSIGGEN_ATTR_EUTRA_DL_DRS_CSI_RS_ZERO_TX_POWER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356097
#define RSRFSIGGEN_ATTR_EUTRA_DL_DRS_CSI_RS_NON_ZERO_TX_POWER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356098
#define RSRFSIGGEN_ATTR_EUTRA_DL_DRS_CSI_RS_ZERO_POWER                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356099
#define RSRFSIGGEN_ATTR_EUTRA_DL_DRS_CSI_RS_SUBFRAME_CONFIG                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356100
#define RSRFSIGGEN_ATTR_EUTRA_DL_DRS_CSI_RS_PERIODICITY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356101
#define RSRFSIGGEN_ATTR_EUTRA_DL_DRS_CSI_RS_SUBFRAME_OFFSET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356102
#define RSRFSIGGEN_ATTR_EUTRA_DL_DRS_CSI_RS_SCRAMBLING_IDENTITY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356103
#define RSRFSIGGEN_ATTR_EUTRA_DL_DRS_CSI_RS_CONFIGURATION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356104
#define RSRFSIGGEN_ATTR_EUTRA_DL_DRS_CSI_RS_SUBFRAME_OFFSET_SSS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356105
#define RSRFSIGGEN_ATTR_EUTRA_DL_DRS_CSI_RS_Q_OFFSET                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356106
#define RSRFSIGGEN_ATTR_EUTRA_DL_NRS_POWER                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356107
#define RSRFSIGGEN_ATTR_EUTRA_DL_NRS_NSYNC_TX_ANTENNA                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356108
#define RSRFSIGGEN_ATTR_EUTRA_DL_NPSYNC_POWER                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356109
#define RSRFSIGGEN_ATTR_EUTRA_DL_NSSYNC_POWER                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356110
#define RSRFSIGGEN_ATTR_EUTRA_DL_SUBFRAME_SELECTION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350362
#define RSRFSIGGEN_ATTR_EUTRA_DL_CONFIGURABLE_SUBFRAMES                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350363
#define RSRFSIGGEN_ATTR_EUTRA_DL_BEHAVIOR_IN_UNSCHEDULED_RE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350364
#define RSRFSIGGEN_ATTR_EUTRA_DL_SUBFRAME_PBCH_MIB                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350365
#define RSRFSIGGEN_ATTR_EUTRA_DL_SUBFRAME_PBCH_SFN_OFFSET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350366
#define RSRFSIGGEN_ATTR_EUTRA_DL_SUBFRAME_PBCH_SFN_RESTART_PERIOD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353329
#define RSRFSIGGEN_ATTR_EUTRA_DL_SUBFRAME_PBCH_MIB_SPARE_BITS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355810
#define RSRFSIGGEN_ATTR_EUTRA_DL_RESET_FRAME_DATA                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350367
#define RSRFSIGGEN_ATTR_EUTRA_DL_DUMMY_DATA_MODULATION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350368
#define RSRFSIGGEN_ATTR_EUTRA_DL_DUMMY_DATA_SOURCE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350369
#define RSRFSIGGEN_ATTR_EUTRA_DL_DUMMY_DATA_POWER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350370
#define RSRFSIGGEN_ATTR_EUTRA_DL_DUMMY_DATA_PATTERN                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350371
#define RSRFSIGGEN_ATTR_EUTRA_DL_DUMMY_DATA_LIST                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350372
#define RSRFSIGGEN_ATTR_EUTRA_DL_DUMMY_DATA_OMIT_PRS_SF                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353330
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353331
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_3GPP_RELEASE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357349
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CHANNEL_CODING_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350373
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CHANNEL_CODING                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350374
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_UE_ID                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350375
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_UE_CATEGORY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350376
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_DATA_SOURCE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350377
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_DATA_PATTERN                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350378
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_DATA_LIST                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350379
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_SCRAMBLING_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350380
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_SUPPORT_TWO_HARQ_PROCESSES_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357350
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_P_A                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350381
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_EIMTA_RNTI                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354141
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_TIME_PLAN_VIEW_MODE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350382
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_TIME_PLAN_CELL_INDEX                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353332
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_TRANSMISSION_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350383
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_APM_PORT_MAPPING                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350384
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_APM_CONSTANT_CODEBOOK_INDEX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355811
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_APM_CODEBOOK_INDEX                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350385
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_APM_USE_ALTERNATIVE_CODEBOOKS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355812
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_APM_MAPPING_COORDINATES                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350386
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_APM_CELL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353333
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CARRIER_AGGREGATION_ENABLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350387
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_APERIODIC_SRS_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353334
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CSI_AWARENESS_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353335
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_MSC_TABLE_2                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 354142
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_TBS_ALTERNATIVE_INDEX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356111
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_PATTERN_INIT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362786
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_APM_REAL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350388
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_APM_IMAGINARY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350389
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_LAYER_APM_REAL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357352
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_LAYER_APM_IMAGINARY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357353
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CELL_TRANSMISSION_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353336
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CELL_DMRS_ALT_TABLE_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357354
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CELL_MSC_TABLE_2_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357355
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CELL_MODULATION_AND_CODING_TABLE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359858
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CELL_TRANSPORT_BLOCK_SIZE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359859
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CELL_SEMI_OPEN_LOOP_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357356
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CELL_UL_CARRIERS_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 354143
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_UL_VARY_UL_TX_POWER_AND_RBA                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353588
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CELL_DCI_SEQUENCE_MCS_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353589
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CELL_DCI_SEQUENCE_MCS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353590
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CELL_DCI_SEQUENCE_TARGET_CODE_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353591
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CELL_DCI_SEQUENCE_TARGET_MODULATION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353592
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CELL_DCI_SEQUENCE_REDUNDANCY_VERSION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353593
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_CELL_DCI_SEQUENCE_RLC_COUNTER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353594
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_UL_INSERT_TABLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353595
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_DL_INSERT_TABLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353596
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_UL_APPEND_TABLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353597
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_DL_APPEND_TABLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353598
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_UL_SELECT_TABLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353599
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_DL_SELECT_TABLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353600
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_UL_DELETE_TABLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353601
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_DL_DELETE_TABLE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353602
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_UL_RESET_DCI_TABLE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353603
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_DL_RESET_DCI_TABLE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353604
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_UL_SEQUENCE_LENGTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355813
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_DL_SEQUENCE_LENGTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355814
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_SCRAMBLING_USE_IDENTITIES_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357357
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_SCRAMBLING_IDENTITY_1                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357358
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_SCRAMBLING_IDENTITY_2                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357359
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_UL_DCI_NID                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353605
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_UL_DCI_PUSCH_TPC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353606
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_UL_DCI_SUBFRAMES                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353607
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_UL_DCI_UL_INDEX                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353608
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_UL_DCI_RBA                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353609
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_DL_DCI_HARQ_PROCESS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353610
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_DL_DCI_MAPPING_AND_QCL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357360
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_DL_DCI_TB1_NDI                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353611
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_DL_DCI_TB2_NDI                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353612
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_DL_DCI_REDUNDANCY_VERSION_TB1                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353613
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_DL_DCI_REDUNDANCY_VERSION_TB2                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353614
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_DL_DCI_TB1_RLC_COUNTER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353615
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_DL_DCI_TB2_RLC_COUNTER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353616
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_DL_DCI_TB1_MCS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353617
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_DL_DCI_TB2_MCS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353618
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_DL_DCI_SUBFRAME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353619
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_DL_DCI_CONFLICT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355815
#define RSRFSIGGEN_ATTR_EUTRA_DL_TABLE_UL_DCI_CONFLICT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355816
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_EPDCCH_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355817
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_EPDCCH_SET_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355818
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_EPDCCH_SET_TRANSMISSION_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355819
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_EPDCCH_SET_PRB_PAIRS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355820
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_EPDCCH_SET_RESOURCE_BLOCK_ASSIGNEMNT                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355821
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_EPDCCH_SET_ID                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355822
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_EPDCCH_SET_RELATIVE_POWER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355823
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_EPDCCH_SET_STARTING_NB                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356112
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_EPDCCH_SET_HOPPING                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356113
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_EPDCCH_SET_MPDCCH_MAX_REPETITIONS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356114
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_EPDCCH_SET_SEARCH_SPACE_START_SUBFRAME                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356115
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_SPS_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353337
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_SPS_CRNTI                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353338
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_SPS_START_SUBFRAME                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353339
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_SPS_END_SUBFRAME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353340
#define RSRFSIGGEN_ATTR_EUTRA_DL_USER_SPS_INTERVAL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353341
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTO_SEQUENCE_ARB_SEQUENCE_LENGTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353443
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTO_SEQUENCE_ADJUST_ARB_SEQUENCE_LENGTH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353444
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTO_SEQUENCE_APPLY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353620
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_DL_CONFIGURATION_DCI                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353445
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_UL_CONFIGURATION_DCI                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353446
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_DL_NUMBER_OF_HARQ_TRANSMISSIONS                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353621
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_UL_NUMBER_OF_HARQ_TRANSMISSIONS                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353622
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_DL_INITIATE_NDI                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353623
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_UL_INITIATE_NDI                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353624
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_DL_NUMBER_OF_HARQ_PROCESS_IDS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353625
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_DL_SKIP_HARQ_PROCESS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353626
#define RSRFSIGGEN_ATTR_EUTRA_DL_AUTOMATIC_SEQUENCE_DL_HARQ_USED_SUBFRAMES                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353627
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350390
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_SCRAMBLING_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350391
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PRECODING_SCHEME                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350392
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_NUMBER_OF_LAYERS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350393
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PCFICH_POWER                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350394
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PCFICH_SCRAMBLING_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350395
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PCFICH_CONTROL_REGION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350396
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PHICH_POWER                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350397
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PHICH_NUMBER_OF_GROUPS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350398
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PHICH_POWER_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350399
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PHICH_ACK_NACK_PATTERN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350400
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PHICH_ACK_NACK_PATTERN_CELL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357361
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PHICH_NUMBER_OF_GROUPS_CELL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357362
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PHICH_INDIVIDUAL_POWER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350401
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PHICH_INDIVIDUAL_POWER_CELL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357363
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_POWER                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350402
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_SCRAMBLING_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350403
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_NUMBER_OF_BITS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350404
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_AVAILABLE_REGS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350405
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_AVAILABLE_CCES                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350406
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_ALLOCATED_REGS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350407
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DUMMY_REGS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350408
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_FORMAT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350409
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_NUMBER_OF_PDCCH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353342
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DATA_SOURCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350410
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DUMMY_CCE_REGS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350411
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DUMMY_CCE_DATA_SOURCE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350412
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DATA_PATTERN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350413
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DATA_LIST                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350414
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DUMMY_CCE_DATA_PATTERN                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350415
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DUMMY_CCE_DATA_LIST                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350416
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_SELECTED_ITEM                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350417
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_APPEND                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350418
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_INSERT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350419
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_DELETE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350420
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_DOWN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350421
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_UP                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350422
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_RESET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350423
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_RESOLVE_CONFLICTS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350424
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_CONFLICTS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353343
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_USER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350425
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_UE_ID                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350426
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_CELL_INDEX                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350427
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_FORMAT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350428
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_PDCCH_FORMAT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350429
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_NUMBER_CCES                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350430
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_SEARCH_SPACE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350431
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_CCE_INDEX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350433
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_DUMMY_CCES                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350434
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_CONFLICT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350435
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_SCRAMBLING_IDENTITY                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350436
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_NUMBER_ITEMS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353344
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_PDCCH_TYPE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355824
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_FORM_CARRIER_INDICATOR_FIELD                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350437
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_UL_DL_CONFIG                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354514
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_MCSR                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350438
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_NEW_DATA_INDICATOR                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350439
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_NEW_DATA_INDICATOR1                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357364
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_NEW_DATA_INDICATOR2                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357365
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_REDUNDANCY_VERSION_1                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357366
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_REDUNDANCY_VERSION_2                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357367
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_TPC_PUSCH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350440
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_RESOURCE_ALLOCATION_HEADER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350441
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_RESOURCE_BLOCK_ASSIGNMENT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350442
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_TRANSPORT_BLOCK_SIZE_INDEX                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350443
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_HARQ_PROCESS_NUMBER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350444
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_HARQACK_RESOURCE_OFFSET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355825
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_REDUNDANCY_VERSION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350445
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350446
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_VRB_ASSIGNMENT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350447
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_PRACH_PREAMBLE_INDEX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350448
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_PRACH_MASK_INDEX                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350449
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_TPMI_PRECODING                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350450
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_PMI_CONFIRMATION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350451
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_DOWNLINK_POWER_OFFSET                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350452
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_SWAP_FLAG                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350453
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_MODULATION_SCHEME_1                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357368
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_MODULATION_SCHEME_2                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357369
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_PRECODING_INFORMATION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350454
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_GAP_VALUE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350455
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_TPC_COMMAND                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350456
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_UL_INDEX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350457
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_DOWNLINK_ASSIGMENT_INDEX                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350458
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_BIT_DATA                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350459
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_SRS_REQUEST                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353345
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_APLAYERID                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353346
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_PDSCH_RE_MAPPING                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355826
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_LAA_SUBFRAME                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356116
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_TB_MODULATION_AND_CODING_SCHEME                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350460
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_TB_NEW_DATA_INDICATOR                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350461
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_TB_REDUNDANCY_VERSION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350462
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_FORM_0_CSI_CQI_REQUEST                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350463
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_FORM_0_RESOURCE_ALLOCATION_TYPE                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350464
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_PUSCH_FREQ_HOPPING                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350465
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_RAHR                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350466
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_CYCLIC_SHIFT_FOR_DMRS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350467
#define RSRFSIGGEN_ATTR_EUTRA_DL_ENHANCED_PDCCH_DCI_CQI_REQUEST                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350468
#define RSRFSIGGEN_ATTR_EUTRA_DL_SUBFRAME_CYCLIC_PREFIX                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350469
#define RSRFSIGGEN_ATTR_EUTRA_DL_SUBFRAME_USED_ALLOCATIONS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350470
#define RSRFSIGGEN_ATTR_EUTRA_DL_SUBFRAME_USER_PHYSICAL_BITS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353347
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CODE_WORD                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350471
#define RSRFSIGGEN_ATTR_EUTRA_DL_CSI_AWARENESS_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353348
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CW_MODULATION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350472
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CW_VRB_GAP                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350473
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CW_RESOURCE_BLOCKS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350474
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CW_SYMBOL_COUNT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350475
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CW_RESOURCE_BLOCKS_OFFSET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350476
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CW_SYMBOL_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350477
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CW_AUTOMATIC_OFFSET_CALCULATION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350478
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CW_CHANNEL_CODING_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 354475
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CW_PHYSICAL_BITS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350479
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CW_DATA_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350480
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CW_DATA_PATTERN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350481
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CW_DATA_LIST                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350482
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CW_POWER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350483
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CW_CONTENT_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350484
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CW_NABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350485
#define RSRFSIGGEN_ATTR_EUTRA_DL_ALLOCATION_CW_CONFLICT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350486
#define RSRFSIGGEN_ATTR_EUTRA_DL_SCRAMBLING_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350487
#define RSRFSIGGEN_ATTR_EUTRA_DL_SCRAMBLING_UE_ID                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350488
#define RSRFSIGGEN_ATTR_EUTRA_DL_CHANNEL_CODING_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350489
#define RSRFSIGGEN_ATTR_EUTRA_DL_CHANNEL_CODING_TRANSPORT_BLOCK_SIZE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350490
#define RSRFSIGGEN_ATTR_EUTRA_DL_CHANNEL_CODING_REDUNDANCY_VERSION_INDEX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350491
#define RSRFSIGGEN_ATTR_EUTRA_DL_CHANNEL_CODING_SOFT_BUFFER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350492
#define RSRFSIGGEN_ATTR_EUTRA_DL_CHANNEL_CODING_TYPE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353349
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRECODING_SCHEME                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350493
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRECODING_TRANSMISSION_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350494
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRECODING_NUMBER_OF_LAYERS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350495
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRECODING_SCRAMBLING_IDENTITY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350496
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRECODING_ANTENNA_PORTS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350497
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRECODING_ANTENNA_PORTS_MAPPING                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350498
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRECODING_CODEBOOK_INDEX                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350499
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRECODING_COORDINATES                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350500
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRECODING_CYCLIC_DELAY_DIVERSITY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350501
#define RSRFSIGGEN_ATTR_EUTRA_DL_PRECODING_INDEX_CODEBOOK_INDEX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 354515
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_ALLOCATION_NUMBER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356117
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_ALLOCATIONS_NUMBER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356118
#define RSRFSIGGEN_ATTR_EUTRA_NB_IOT_DCI_ALLOCATION_WRAP_AROUND_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359860
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_ALLOCATION_USER                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356119
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_ALLOCATION_UEID                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356120
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_ALLOCATION_FORMAT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356121
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_ALLOCATION_SEARCH_SPACE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356122
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_ALLOCATION_START_SUFBRAME                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356123
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_ALLOCATION_NPDCCH_FORMAT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356124
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_ALLOCATION_NUMBER_NCCES                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356125
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_ALLOCATION_NCCE_INDEX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356126
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_ALLOCATION_CONFLICT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357370
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_CONTENT_BIT_DATA                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356127
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_CONTENT_TRANSPORT_BLOCK_SIZE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356128
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_CONTENT_RESOURCE_UNITS_NUMBER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356129
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_CONTENT_NPDSCH_SUBFRAMES                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356130
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_CONTENT_NPDSCH_REPETITIONS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356131
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_CONTENT_NPDCCH_REPETITIONS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356132
#define RSRFSIGGEN_ATTR_EUTRA_NB_IOT_DCI_CONTENT_DISTANCE_FROM_NPDCCH_TO_NPDSCH                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357371
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N0_SUBCARRIER_IDENTIFICATION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356133
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N0_RESOURCE_ASSIGNMENT_FIELD                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356134
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N0_SCHEDULING_DELAY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356135
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N0_MODULATION_CODING_SCHEME_                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356136
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N0_HARQ_PROCESS_NUMBER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357372
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N0_REDUNDANCY_VERSION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356137
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N0_NPUSCH_REPETITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356138
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N0_NEW_DATA_INDICATOR                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356139
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N0_SUBFRAMES_REPETITIONS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356140
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N1_NPDCCH_ORDER_INDICATOR                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356141
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N1_STARTING_NUMBER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356142
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N1_RESOURCE_ASSIGNMENT_FIELD                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356143
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N1_NPDSCH_REPETITION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356144
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N1_HARQ_ACK                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356145
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N1_SUBCARRIER_INDICATION_FIELD                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357373
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N2_PAGING                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356146
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N2_SYSTEM_INFO_MODIFICATION_EXTENDED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356147
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_DCI_FORMAT_N2_SYSTEM_INFO_MODIFICATION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356148
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_ALLOCATION_CONTENT_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356149
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_ALLOCATION_MODULATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356150
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_ALLOCATION_SUBFRAME_LIST                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356151
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_ALLOCATION_START_SYMBOL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356152
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_ALLOCATION_PHYSICAL_BITS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356153
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_ALLOCATION_DATA_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356154
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_ALLOCATION_DATA_LIST                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356155
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_ALLOCATION_PATTERN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356156
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_ALLOCATION_POWER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356157
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_ALLOCATION_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356158
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_ALLOCATION_CONFLICT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356159
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_PRECODING_SCHEME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356160
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_PRECODING_NUMBER_OF_LAYERS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356161
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_SCRAMBLING_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356162
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_SCRAMBLING_UEID                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356163
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_LEGACY_SCRAMBLING_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357374
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_SCRAMBLING_SYMBOL_ROTATION_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357375
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_CHANNEL_CODING_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356164
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_CHANNEL_CODING_NPDSCH_SUBFRAMES                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356166
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_CHANNEL_CODING_MIB                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356167
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_CHANNEL_CODING_SFN_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356168
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_CHANNEL_CODING_SCHEDULING_SIB1                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356169
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_CHANNEL_CODING_REPETITION_SIB1                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356170
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_CHANNEL_CODING_NCELL_ID                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356171
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_CHANNEL_CODING_STARTING_SIB1                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356172
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_CHANNEL_CODING_MIB_SPARE_BITS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356173
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_CHANNEL_CODING_TRANSPORT_BLOCK_SIZE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356174
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPBCH_CHANNEL_CODING_TRANSPORT_BLOCK_PAYLOAD                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356175
#define RSRFSIGGEN_ATTR_EUTRA_NIOT_NPDSCH_RESOURCE_ASSIGNMENT_FIELD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356176
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_ALLOCATION_NUMBER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356177
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_ALLOCATIONS_NUMBER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356178
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_WRAP_AROUND_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359861
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_USER                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356179
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_UEID                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356180
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_MPDCCH_SET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356181
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356182
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_SEARCH_SPACE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356183
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_START_SUFBRAME                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356184
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_MPDCCH_FORMAT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356185
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_NUMBER_ECCES                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356186
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_ECCE_INDEX                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356187
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_NUMBER_DUMMY_ECCES                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356188
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_CONFLICT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356189
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_CONTENT_BIT_DATA                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356190
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_CONTENT_FORMAT_3                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356191
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_CONTENT_TRANSPORT_BLOCK_SIZE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356192
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_CONTENT_MPDCCH_REPETITIONS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356193
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_CONTENT_PDSCH_REPETITIONS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356194
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_CONTENT_PDSCH_HOPPING                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356195
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_CONTENT_STARTING_REDUNDANCY_VERSION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356196
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_60AB_PUSCH_FREQUENCY_HOPPING                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356197
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_60AB_RESOURCE_BLOCK_ASSIGNMENT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356198
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_60AB_MCS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356199
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_60AB_REPETITION_NUMBER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356200
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_60AB_HARQ_PROCESS_NUMBER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356201
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_60AB_NEW_DATA_INDICATOR                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356202
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_60AB_REDUNDANCY_VERSION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356203
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_60AB_TPC_PUSCH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356204
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_60AB_UL_INDEX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356205
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_60AB_DAI                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356206
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_60AB_CSI_REQUEST                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356207
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_60AB_SRS_REQUEST                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356208
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_60AB_SUBFRAME_REPETITION_NUMBER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356209
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_61AB_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356210
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_61B_RESOURCE_BLOCK_ASSIGNEMENT_FLAG                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357376
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_61AB_APSI                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356211
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_61AB_TPMI_PRECODING                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356212
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_61AB_PMI_CONFIRMATION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356213
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_61AB_HARQACK_RESSOURCE_OFFSET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356214
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_61AB_PREAMBLE_INDEX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356215
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_61AB_PRACH_MASK_INDEX                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356216
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_61AB_STARTING_CE_LEVEL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356217
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_62_PAGING                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356218
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_DCI_FORMAT_62_DIINFO                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356219
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_ALLOCATION_CONTENT_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356220
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_ALLOCATION_MODULATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356221
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_ALLOCATION_START_SF                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356222
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_ALLOCATION_ABSOLUTE_SUBFRAMES                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356223
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_ALLOCATION_START_NB                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356224
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_ALLOCATION_START_SYMBOL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356225
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_ALLOCATION_NUMBER_OF_RB                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356226
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_ALLOCATION_OFFSET_VRB                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356227
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_ALLOCATION_PHYSICAL_BITS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356228
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_ALLOCATION_DATA_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356229
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_ALLOCATION_DATA_LIST                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356230
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_ALLOCATION_PATTERN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356231
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_ALLOCATION_POWER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356232
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_ALLOCATION_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356233
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_ALLOCATION_CONFLICT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356234
#define RSRFSIGGEN_ATTR_EUTRA_DL_EMTC_PDSCH_CODEWORD                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357377
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_PRECODING_SCHEME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356235
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_PRECODING_NUMBER_OF_LAYERS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356236
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_PRECODING_ANTENNA_PORTS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357378
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_PRECODING_ANTENNA_PORT_MAPPING                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357379
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_PRECODING_TRANSMISSION_SCHEME                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359862
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_PRECODING_MAPPING_COORDINATES                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357380
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_PRECODING_CODEBOOK_INDEX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357381
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_PRECODING_CYCLIC_DELAY_DIVERSITY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357382
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_PRECODING_SCRAMBLING_IDENTITY_N_SCID                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357383
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_PRECODING_MAPPING_TABLE_REAL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358621
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_PRECODING_MAPPING_TABLE_IMAGINARY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357385
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_SCRAMBLING_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356237
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_SCRAMBLING_UEID                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356238
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_CHANNEL_CODING_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356239
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_CHANNEL_CODING_TRANSPORT_BLOCK_SIZE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356241
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_CHANNEL_CODING_TRANSPORT_BLOCK_PAYLOAD                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356242
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_CHANNEL_CODING_MIB                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356243
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_CHANNEL_CODING_MIB_SPARE_BITS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356244
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_CHANNEL_CODING_SFN_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356245
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_CHANNEL_CODING_STARTING_SIB1                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356246
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_CHANNEL_CODING_REPETITIONS_SIB1_RB                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357386
#define RSRFSIGGEN_ATTR_EUTRA_EMTC_PDSCH_CHANNEL_CODING_SFN_RESTART_PERIOD                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357387
#define RSRFSIGGEN_ATTR_EUTRA_DL_LAA_CELL_INDEX                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356247
#define RSRFSIGGEN_ATTR_EUTRA_DL_LAA_NUMBER_OF_BURSTS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356248
#define RSRFSIGGEN_ATTR_EUTRA_DL_LAA_STARTING_SUBFRAME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356249
#define RSRFSIGGEN_ATTR_EUTRA_DL_LAA_STARTING_SYMBOL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356250
#define RSRFSIGGEN_ATTR_EUTRA_DL_LAA_BURST_DURATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356251
#define RSRFSIGGEN_ATTR_EUTRA_DL_LAA_NUMBER_OF_ENDING_SYMBOLS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356252
#define RSRFSIGGEN_ATTR_EUTRA_DL_LAA_ENDING_SUBFRAME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356253
#define RSRFSIGGEN_ATTR_EUTRA_DL_LAA_DCI_1C_MODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356254
#define RSRFSIGGEN_ATTR_EUTRA_DL_LAA_EPDCCH_FORMAT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356255
#define RSRFSIGGEN_ATTR_EUTRA_UL_NUMBER_OF_WIDEBANDS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357388
#define RSRFSIGGEN_ATTR_EUTRA_UL_CARRIER_AGGREGATION_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353447
#define RSRFSIGGEN_ATTR_EUTRA_UL_CARRIER_AGGREGATION_CELL_INDEX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353448
#define RSRFSIGGEN_ATTR_EUTRA_UL_CARRIER_AGGREGATION_PHYSICAL_CELL_ID                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353449
#define RSRFSIGGEN_ATTR_EUTRA_UL_CARRIER_AGGREGATION_CELL_BANDWIDTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353450
#define RSRFSIGGEN_ATTR_EUTRA_UL_CARRIER_AGGREGATION_CELL_DELTA_FREQUENCY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353451
#define RSRFSIGGEN_ATTR_EUTRA_UL_CARRIER_AGGREGATION_DUPLEXING                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353452
#define RSRFSIGGEN_ATTR_EUTRA_UL_CARRIER_AGGREGATION_UL_DL_CONFIGURATION_NUMBER                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353453
#define RSRFSIGGEN_ATTR_EUTRA_UL_CARRIER_AGGREGATION_SRS_SUBFRAME                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353454
#define RSRFSIGGEN_ATTR_EUTRA_UL_CARRIER_AGGREGATION_DMRS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353455
#define RSRFSIGGEN_ATTR_EUTRA_UL_CARRIER_AGGREGATION_SPECIAL_SUBFRAME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353456
#define RSRFSIGGEN_ATTR_EUTRA_UL_CARRIER_AGGREGATION_SRS_BANDWIDTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353457
#define RSRFSIGGEN_ATTR_EUTRA_UL_CARRIER_AGGREGATION_CELL_ENABLE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353458
#define RSRFSIGGEN_ATTR_EUTRA_UL_PHYSICAL_CHANNEL_BANDWIDTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350502
#define RSRFSIGGEN_ATTR_EUTRA_UL_PHYSICAL_RESOURCE_BLOCKS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350503
#define RSRFSIGGEN_ATTR_EUTRA_UL_PHYSICAL_FFT_SIZE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350504
#define RSRFSIGGEN_ATTR_EUTRA_UL_PHYSICAL_OCCUPIED_BANDWIDTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350505
#define RSRFSIGGEN_ATTR_EUTRA_UL_PHYSICAL_SAMPLING_RATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350506
#define RSRFSIGGEN_ATTR_EUTRA_UL_PHYSICAL_OCCUPIED_SUBCARRIERS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350507
#define RSRFSIGGEN_ATTR_EUTRA_UL_PHYSICAL_LEFT_GUARD_SUBCARRIERS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350508
#define RSRFSIGGEN_ATTR_EUTRA_UL_PHYSICAL_RIGHT_GUARD_SUBCARRIERS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350509
#define RSRFSIGGEN_ATTR_EUTRA_UL_CELL_ID                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350510
#define RSRFSIGGEN_ATTR_EUTRA_UL_PHYSICAL_CELL_ID_GROUP                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350511
#define RSRFSIGGEN_ATTR_EUTRA_UL_PHYSICAL_LAYER_ID                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350512
#define RSRFSIGGEN_ATTR_EUTRA_UL_CYCLIC_PREFIX                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350513
#define RSRFSIGGEN_ATTR_EUTRA_UL_CELL_TDD_CYCLIC_PREFIX                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353350
#define RSRFSIGGEN_ATTR_EUTRA_UL_SFN_OFFSET                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353351
#define RSRFSIGGEN_ATTR_EUTRA_UL_CELL_FFNC                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350514
#define RSRFSIGGEN_ATTR_EUTRA_UL_REFERENCE_SIGNAL_GROUP_HOPPING                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350515
#define RSRFSIGGEN_ATTR_EUTRA_UL_REFERENCE_SIGNAL_SEQUENCE_HOPPING                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350516
#define RSRFSIGGEN_ATTR_EUTRA_UL_REFERENCE_SIGNAL_DELTA_SEQUENCE_SHIFT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350517
#define RSRFSIGGEN_ATTR_EUTRA_UL_REFERENCE_SIGNAL_DMRS_INDEX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350518
#define RSRFSIGGEN_ATTR_EUTRA_UL_REFERENCE_SIGNAL_N_PRS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350519
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_CONFIGURATION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350520
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_PREAMBLE_SET                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350521
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_FREQUENCY_OFFSET                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350522
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_RESTRICTED_SET                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353352
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_NIOT_PREAMBLE_FORMAT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356256
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_NIOT_PERIODICITY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356509
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_NIOT_STARTING_TIME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356510
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_NIOT_REPETITIONS_NUMBER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356511
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_NIOT_SUBCARRIERS_NUMBER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356512
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356513
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_HOPPING_OFFSET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356514
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_RESTRICTED_SET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356515
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_CONFIGURATION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356516
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_FREQUENCY_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356517
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_HOPPING                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356518
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_REPETITIONS_NUMBER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356519
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_STARTING_SF_PERIODICITY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356520
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_FREQUENCY_HOPPING_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350523
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_NUMBER_OF_SUBBANDS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350524
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_HOPPING_OFFSET                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350525
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_EMTC_NARROWBAND_HOPPING                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356521
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_EMTC_HOPPING_OFFSET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356522
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_NUMBER_OF_RBS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350526
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_DELTA_SHIFT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350527
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_DELTA_OFFSET                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350528
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_N1CS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350529
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_N2RB                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350530
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_RANGE_N1_PUCCH_NORMAL_CP                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350531
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_RANGE_N1_PUCCH_EXTENDED_CP                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350532
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_RANGE_N2_PUCCH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350533
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_RANGE_N3_PUCCH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350534
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_RANGE_N4_PUCCH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357389
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_RANGE_N5_PUCCH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357390
#define RSRFSIGGEN_ATTR_EUTRA_UL_SRS_STRUCTURE_CONFIGURATION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350535
#define RSRFSIGGEN_ATTR_EUTRA_UL_SRS_STRUCTURE_TRANSMISSION_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351027
#define RSRFSIGGEN_ATTR_EUTRA_UL_SRS_STRUCTURE_CONFIGURATION_PERIOD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350536
#define RSRFSIGGEN_ATTR_EUTRA_UL_SRS_STRUCTURE_C_SRS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350537
#define RSRFSIGGEN_ATTR_EUTRA_UL_SRS_STRUCTURE_A_N_SRS_SIMULTANEOUS_TX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350538
#define RSRFSIGGEN_ATTR_EUTRA_UL_SRS_STRUCTURE_MAXUPPTS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350539
#define RSRFSIGGEN_ATTR_EUTRA_UL_RTFB_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350540
#define RSRFSIGGEN_ATTR_EUTRA_UL_RTFB_REDUNDANCY_VERSION_SEQUENCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350541
#define RSRFSIGGEN_ATTR_EUTRA_UL_RTFB_MAX_NUMBER_OF_TRANSMISSIONS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350542
#define RSRFSIGGEN_ATTR_EUTRA_UL_RTFB_INITIAL_TIMING_ADVANCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350543
#define RSRFSIGGEN_ATTR_EUTRA_UL_RTFB_ACK_DEFINITION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350544
#define RSRFSIGGEN_ATTR_EUTRA_UL_RTFB_ASSUME_ACK                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350545
#define RSRFSIGGEN_ATTR_EUTRA_UL_RTFB_CONNECTOR                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350546
#define RSRFSIGGEN_ATTR_EUTRA_UL_RTFB_DISTANCE_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350547
#define RSRFSIGGEN_ATTR_EUTRA_UL_RTFB_ADDITIONAL_USER_DELAY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350548
#define RSRFSIGGEN_ATTR_EUTRA_UL_RTFB_BASEBAND_SELECTOR                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350549
#define RSRFSIGGEN_ATTR_EUTRA_UL_RTFB_SERIAL_RATE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350550
#define RSRFSIGGEN_ATTR_EUTRA_UL_RTFB_BLOCK_ERROR_INSERTION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350551
#define RSRFSIGGEN_ATTR_EUTRA_UL_RTFB_BLOCK_ERROR_RATE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350552
#define RSRFSIGGEN_ATTR_EUTRA_UL_RTFB_DEBUG_REPORTS_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353353
#define RSRFSIGGEN_ATTR_EUTRA_UL_RTFB_LOGGING_OFFSET                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353459
#define RSRFSIGGEN_ATTR_EUTRA_UL_RTFB_IGNORE_TIMING_ADJUSTMENT_ENABLE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361934
#define RSRFSIGGEN_ATTR_EUTRA_UL_TDD_UL_DL_CONFIGURATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350553
#define RSRFSIGGEN_ATTR_EUTRA_UL_TDD_SPECIAL_SUBFRAME_CONFIG                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350554
#define RSRFSIGGEN_ATTR_EUTRA_UL_TDD_NUMBER_OF_SYMBOLS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359863
#define RSRFSIGGEN_ATTR_EUTRA_UL_EMTC_RETUNING_SYMBOLS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357391
#define RSRFSIGGEN_ATTR_EUTRA_UL_EMTC_WIDEBAND_CONFIG_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357392
#define RSRFSIGGEN_ATTR_EUTRA_UL_EMTC_VALID_SUBFRAME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357393
#define RSRFSIGGEN_ATTR_EUTRA_UL_EMTC_NB_IOT_VALID_SUBFRAME                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359864
#define RSRFSIGGEN_ATTR_EUTRA_UL_EMTC_NB_IOT_BITMAP_SUBFRAMES                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359865
#define RSRFSIGGEN_ATTR_EUTRA_UL_NDRS_GROUP_HOPPING_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357394
#define RSRFSIGGEN_ATTR_EUTRA_UL_NDRS_DELTA_SEQUENCE_SHIFT_FOR_NPUSCH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357395
#define RSRFSIGGEN_ATTR_EUTRA_UL_NDRS_THREE_TONE_CYCLIC_SHIFT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357396
#define RSRFSIGGEN_ATTR_EUTRA_UL_NDRS_SIX_TONE_CYCLIC_SHIFT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357397
#define RSRFSIGGEN_ATTR_EUTRA_UL_NDRS_USE_BASE_SEQUENCE_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357398
#define RSRFSIGGEN_ATTR_EUTRA_UL_NDRS_THREE_TONE_BASE_SEQUENCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357399
#define RSRFSIGGEN_ATTR_EUTRA_UL_NDRS_SIX_TONE_BASE_SEQUENCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357400
#define RSRFSIGGEN_ATTR_EUTRA_UL_NDRS_TWELVE_TONE_BASE_SEQUENCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357401
#define RSRFSIGGEN_ATTR_EUTRA_UL_SUBFRAME_SELECTION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350555
#define RSRFSIGGEN_ATTR_EUTRA_UL_RESET_FRAME_DATA                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350556
#define RSRFSIGGEN_ATTR_EUTRA_NUMBER_OF_SUBFRAMES_PUCCH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350557
#define RSRFSIGGEN_ATTR_EUTRA_NUMBER_OF_SUBFRAMES_PUSCH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350558
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_ENABLED                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350559
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_3GPP_RELEASE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350560
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_RNTI                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350561
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_POWER                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350562
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350563
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_OVERRIDE_CELL_ID                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359866
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_USER_SPECIFIC_CELL_ID                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359867
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_ANTENNA_OUTPUT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359868
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_RESTART_DATA                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350564
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_FRC_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350565
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_FRC_TYPE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350566
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_FRC_ALLOCATED_RESOURCE_BLOCKS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350567
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_FRC_MODULATION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350568
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_FRC_PAYLOAD_SIZE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350569
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_FRC_PHYSICAL_BITS_PER_SUBFRAME                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350570
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_FRC_DMRS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350571
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_FRC_VRB_OFFSET                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350572
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_FRC_CELL_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 354440
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_FRC_CELL_TYPE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 354441
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_FRC_CELL_ALLOCATED_RESOURCE_BLOCKS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 354460
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_CELL_FRC_MODULATION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354461
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_FRC_CELL_DMRS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 354462
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_FRC_CELL_PAYLOAD_SIZE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 354463
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_FRC_CELL_PHYSICAL_BITS_PER_SUBFRAME                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354464
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_FRC_CELL_VRB_OFFSET                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354465
#define RSRFSIGGEN_ATTR_EUTRA_UL_NIOT_FRC_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357402
#define RSRFSIGGEN_ATTR_EUTRA_UL_NIOT_FRC_TYPE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357403
#define RSRFSIGGEN_ATTR_EUTRA_UL_NIOT_FRC_SUBCARRIERS_SPACING                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357404
#define RSRFSIGGEN_ATTR_EUTRA_UL_NIOT_FRC_NUMBER_OF_ALLOCATED_SUBCARRIERS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357405
#define RSRFSIGGEN_ATTR_EUTRA_UL_NIOT_FRC_MODULATION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357406
#define RSRFSIGGEN_ATTR_EUTRA_UL_NIOT_FRC_NUMBER_OF_NPUSCH_REPETITIONS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357407
#define RSRFSIGGEN_ATTR_EUTRA_UL_NIOT_FRC_TRANSPORT_BLOCK_SIZE_INDEX                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357408
#define RSRFSIGGEN_ATTR_EUTRA_UL_NIOT_FRC_PAYLOAD_SIZE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357409
#define RSRFSIGGEN_ATTR_EUTRA_UL_NIOT_FRC_ALLOCATED_RESOURCE_UNITS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357410
#define RSRFSIGGEN_ATTR_EUTRA_UL_NIOT_FRC_TOTAL_NUMBER_OF_BITS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357411
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_AP_POWER_OFFSET                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 354442
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_AP_10_PUSCH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353628
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_AP_20_PUSCH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353629
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_AP_21_PUSCH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353630
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_AP_40_PUSCH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353631
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_AP_41_PUSCH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353632
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_AP_42_PUSCH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353633
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_AP_43_PUSCH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353634
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_AP_100_PUCCH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353635
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_AP_200_PUCCH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353636
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_AP_201_PUCCH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353637
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_AP_1000_PUCCH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357412
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_AP_1010_PUCCH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357413
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_AP_1020_PUCCH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357414
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_AP_DELAY                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357415
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NPUSCH_AND_SRS_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357416
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_DATA_SOURCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350573
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_DATA_PATTERN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350574
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_DATA_LIST                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350575
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_SCRAMBLING_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350576
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_TRANSMISSION_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353638
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_NUMBER_OF_ANTENNA_PORTS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353639
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CELL_DATA_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 354443
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CELL_DATA_PATTERN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 354444
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CELL_DATA_LIST                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 354445
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CELL_SCRAMBLING_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 354446
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CELL_TRANSMISSION_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354466
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CELL_NUMBER_OF_ANTENNA_PORTS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 354467
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350577
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_CHANNEL_INTERLEAVER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350578
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350579
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_I_HARQ_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350580
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_I_RI_OFFSET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350581
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_I_CQI_OFFSET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350582
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_O_CQI_MIN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353354
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_CELL_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 354447
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_CELL_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 354468
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_CELL_I_HARQ_OFFSET                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 354469
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_CELL_I_RI_OFFSET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 354470
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_CELL_I_CQI_OFFSET                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354471
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_CELL_O_CQI_MIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 354472
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_CELL_UPPTS_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357417
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_CELL_UPPTS_LESS_DMRS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357418
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_CELL_UPPTS_NUMBER_OF_SYMBOLS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357419
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUSCH_CCOD_CELL_PATTERN_INIT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362787
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUCCH_NUMBER_OF_ANTENNA_PORTS_FORMAT_3                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353640
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUCCH_NUMBER_OF_ANTENNA_PORTS_FORMAT_22A2B                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353641
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUCCH_NUMBER_OF_ANTENNA_PORTS_FORMAT_11A1B                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353642
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUCCH_NUMBER_OF_ANTENNA_PORTS_FORMAT_4                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357420
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PUCCH_NUMBER_OF_ANTENNA_PORTS_FORMAT_5                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357421
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_GROUP_HOPPING_DISABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357422
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_SUBCARRIER_SPACING                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356257
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_DELTA_FREQUENCY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356258
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_RESOURCE_BLOCK_INDEX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356259
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356260
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_TRANSMISSIONS_NUMBER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356261
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_SUGGESTED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356262
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_NPUSCH_FORMAT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356263
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_MODULATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356264
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_STARTING_SUBFRAME                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356265
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_STARTING_SLOT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356266
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_REPETITIONS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356267
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_RESOURCE_UNITS_NUMBER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356268
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_SUBCARRIER_INDICATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356269
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_SUBCARRIERS_NUMBER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356270
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_SLOTS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356271
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_STARTING_SUBCARRIER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356272
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_POWER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356273
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_ULSCH_PHYSICAL_BITS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356274
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_ULSCH_RESOURCE_UNIT_INDEX                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356275
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_ULSCH_TRANSPORT_BLOCK_SIZE_INDEX                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356276
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_ULSCH_TRANSPORT_BLOCK_SIZE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356277
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_ULSCH_REDUNDANCY_VERSION_INDEX                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356278
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_HARQ_ACK_BITS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356279
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_HARQ_ACK_PATTERN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356280
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NIOT_HARQ_CODED_BITS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356281
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NB_IOT_HARQ_MULTIPLY_SYMBOLS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359869
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_CE_LEVEL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356523
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_NARRORBANDS_NUMBER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356524
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_NARROWBAND_HOPPING_INTERVAL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356525
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_TRANSMISSIONS_NUMBER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356526
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_SUGGESTED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356527
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_CONTENT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356528
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_MODULATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356529
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_FORMAT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356530
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_START_SUBFRAME                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356531
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_REPETITIONS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356532
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_ABSOLUTE_SUBFRAMES                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356533
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_START_NARROWBAND                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356534
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_RESOURCE_BLOCKS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356535
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_OFFSET_VRB                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356536
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_POWER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356537
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_START_WIDEBAND                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357423
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_WIDEBAND_OFFSET_VRB                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357424
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_WIDEBAND_RESOURCE_BLOCKS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357425
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUSCH_DRS_CYCLIC_SHIFT_FILED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356538
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUSCH_DRS_N_DMRS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356539
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUSCH_HARQ_ACK_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356540
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUSCH_HARQ_ACK_BITS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356541
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUSCH_HARQ_ACK_PATTERN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356542
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUSCH_HARQ_ACK_CODED_BITS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356543
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUSCH_CQI_BITS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356544
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUSCH_CQI_PATTERN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356545
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUSCH_CQI_CODED_BITS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356546
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUSCH_ULSCH_PHYSICAL_BITS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356547
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUSCH_ULSCH_CODED_BITS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356548
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUSCH_ULSCH_TRANSPORT_BLOCK_SIZE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356549
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUSCH_ULSCH_REDUNDANCY_VERSION_INDEX                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356550
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUCCH_USED_ANTENNA_PORT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356551
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUCCH_RESOURCE_INDEX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356552
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUCCH_PATTERN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356553
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUCCH_CQI_BITS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356554
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUCCH_CQI_PATTERN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356555
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_EMTC_PUCCH_CODED_CQI_BITS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356556
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NPRACH_MODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356557
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NPRACH_RESOURCE_BLOCK_INDEX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356558
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NPRACH_DELTA_FREQUENCY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357426
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NPRACH_SUGESTED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356559
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NPRACH_PREAMBLE_ATTEMPTS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356560
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NPRACH_CONFIGURATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356561
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NPRACH_STARTING_SUBFRAME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356562
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NPRACH_REPETITIONS_NUMBER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356563
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NPRACH_N_INIT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356564
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NPRACH_N_START                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356565
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_NPRACH_POWER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356566
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PRACH_PREAMBLE_FORMAT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350583
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PRACH_POWER_RAMPING_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350584
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PRACH_POWER_RAMPING_TIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350585
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PRACH_NUMBER_OF_CONFIGURABLE_FRAMES                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350586
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PRACH_FREQUENCY_RESOURCE_INDEX                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350587
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PRACH_RB_OFFSET                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350588
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PRACH_NCS_CONFIGURATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350589
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PRACH_ROOT_SEQUENCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350590
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PRACH_SEQUENCE_INDEX                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350591
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PRACH_DELTA_T                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350592
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PRACH_POWER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350593
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_PRACH_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350594
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_PREAMBLE_ATTEMPTS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356567
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_SUGGESTED_ARB_SEQUENCE_LENGTH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357427
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_CE_LEVEL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356568
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_STARTING_SUBFRAME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356569
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_FREQUENCY_RESOURCE_INDEX                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356570
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_NCS_CONFIGURATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356571
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_LOGICAL_ROOT_SEQUENCE_INDEX                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356572
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_SEQUENCE_INDEX                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356573
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_DELTA_TIME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356574
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRACH_EMTC_POWER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356575
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_DRS_POWER_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350595
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_DRS_WITH_OCC_FOR_ONE_ANTENNA_PORT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353643
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350596
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_SIMULTANEOUS_TX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350597
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_POWER_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350598
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_CYCLIC_SHIFT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350599
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_FIRST_SRS_SUBFRAME                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350600
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_PERIODICITY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350601
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_LAST_SRS_SUBFRAME                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350602
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_I_SRS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350603
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_T_OFFSET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350604
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_T_SRS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350605
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_B_SRS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350606
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_TRANSMISSION_COMBINATION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350607
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_B_HOP                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350608
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_N_RRC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350609
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SYMBOL_IN_SUBFRAME                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350610
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_NUMBER_OF_RBS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350611
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_FREQUENCY_HOPPING_PATTERN                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350612
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_NUMBER_OF_ANTENNA_PORT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353644
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_DRS_CELL_POWER_OFFSET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 354448
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_DRS_CELL_WITH_OCC_FOR_ONE_ANTENNA_PORT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 354476
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_DRS_CELL_ENHANCED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357428
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_CELL_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 354449
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_CELL_TRANSMIT_TRIGGER_TYPE_0                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 354450
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_CELL_POWER_OFFSET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 354451
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_CELL_B_HOP                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 354477
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_CELL_CYCLIC_SHIFT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 354452
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_CELL_UPPTS_ADD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357429
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_CELL_I_SRS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 354478
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_CELL_T_OFFSET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 354479
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_CELL_T_SRS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 354480
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_CELL_B_SRS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 354481
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_CELL_TRANSMISSION_COMB_NUM_K_TC                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357430
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_CELL_TRANSMISSION_COMBINATION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 354482
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_CELL_N_RRC                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 354483
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_NUMBER_OF_TRANSMISSIONS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 354145
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_CELL_NUMBER_OF_ANTENNA_PORT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 354484
#define RSRFSIGGEN_ATTR_EUTRA_UL_UE_REFERENCE_SRS_SUBFRAMES_FOR_TRANSMISSION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 354453
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357431
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_MODE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357432
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_DATA_SOURCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357433
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_DATA_LIST                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357434
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_DATA_PATTERN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357435
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESTART_AT_EACH_SL_TRANSMISSION_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357436
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_COMMUNICATION_CONTROL_PERIOD                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357437
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_COMMUNICATION_OFFSET_INDICATOR                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357438
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_COMMUNICATION_PRB_START                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357439
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_COMMUNICATION_PRB_END                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357440
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_COMMUNICATION_PRB_NUMBER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357441
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_COMMUNICATION_SUBFRAME_BITMAP                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357442
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DISCOVER_CONTROL_PERIOD                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357443
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DISCOVERY_OFFSET_INDICATOR                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357444
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DISCOVERY_PRB_START                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357445
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DISCOVERY_PRB_END                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357446
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DISCOVERY_PRB_NUMBER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357447
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DISCOVERY_SUBFRAME_BITMAP                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357448
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DISCOVERY_NUMBER_OF_RETRANSMISSIONS                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357449
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DISCOVERY_NUMBER_OF_REPETITIONS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357450
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DISCOVERY_N1_PDSCH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357451
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DISCOVERY_N2_PDSCH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357452
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DISCOVERY_N3_PDSCH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357453
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DISCOVERY_SUBFRAME_INDEX                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357454
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DISCOVERY_PRB_INDEX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357455
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_V2X_OFFSET_INDICATOR                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357456
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_V2X_SUBFRAME_BITMAP_LENGTH                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357457
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_V2X_SUBFRAME_BITMAP_HIGH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357458
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_V2X_SUBFRAME_BITMAP_LOW                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357459
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_V2X_ADJACENCY_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357460
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_V2X_NUMBER_OF_SUBCHANNEL                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357461
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_V2X_SUBCHANNEL_SIZE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357462
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_V2X_START_RB_SUBCHANNEL                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357463
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DATA_OFFSET_INDICATOR                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357464
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DATA_PRB_START                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357465
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DATA_PRB_END                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357466
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DATA_PRB_NUMBER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357467
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DATA_SUBFRAME_BITMAP                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357468
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DATA_TRPT_SUBSET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357469
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DATA_HOPPING_PARAMETER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357470
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DATA__NUMBER_OF_SUBBANDS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357471
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_RESOURCE_DATA_RB_OFFSET                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357472
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SYNCHRONIZATION_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357473
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SYNCHRONIZATION_PSBCH_MIBSL_INCOVERAGE_FLAG                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357474
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SYNCHRONIZATION_SLSS_ID                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357475
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SYNCHRONIZATION_SLSS_SYNC_OFFSET_INDICATOR                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357476
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_NUMBER_OF_SCI_CONFIG                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357477
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_TRANSMISSION_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357478
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_PSCCH_PERIOD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357479
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_N_PSCCH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357480
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_START_SF                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357481
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_SUBCHANNEL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357482
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_SF                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357483
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_SCI_FORMAT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357484
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_BIT_DATA                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357485
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_MODULATION_AND_CODING_SCHEME                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357486
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_FORMAT_0_FREQUENCY_HOPPING_FLAG                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357487
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_FORMAT_0_RBA_AND_HOPPING_RA                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357488
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_FORMAT_0_TIME_RESOURCE_PATTERN                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357489
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_FORMAT_0_TIMING_ADVANCE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357490
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_FORMAT_0_GROUP_DESTINATION_ID                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357491
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_FORMAT_1_PRIORITY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357492
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_FORMAT_1_RESOURCE_RESERVATION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357493
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_FORMAT_1_FREQ_RES_LOCATION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357494
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_FORMAT_1_TIME_GAP                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357495
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_SCI_TABLE_FORMAT_1_RETRANSMISSION_INDEX                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357496
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ALLOCATION_NUMBER_OF_RETRANSMISSIONS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357497
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ALLOCATION_CONTENT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357498
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ALLOCATION_DISCOVERY_TYPE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357499
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ALLOCATION_PSDCH_PERIOD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357500
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ALLOCATION_N_PSDCH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357501
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ALLOCATION_SF                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357502
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ALLOCATION_MODULATION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357503
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ALLOCATION_PHYSICAL_BITS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357504
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ALLOCATION_POWER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357505
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ALLOCATION_STATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357506
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ALLOCATION_CONFLICT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357507
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ALLOCATION_DRS_CYCLIC_SHIFT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357508
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ALLOCATION_SCRAMBLING_STATE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358622
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ALLOCATION_CHANNEL_CODING_STATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357510
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ALLOCATION_CHANNEL_CODING_TRANSPORT_BLOCK_INDEX               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357511
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_ALLOCATION_CHANNEL_CODING_TRANSPORT_BLOCK_SIZE                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357512
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_REFERENCE_MEASUREMENT_CHANNEL_SELECT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359870
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_REFERENCE_MEASUREMENT_CHANNEL_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359871
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_REFERENCE_MEASUREMENT_CHANNEL_PAYLOAD_SIZE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359872
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_REFERENCE_MEASUREMENT_CHANNEL_PHYSICAL_BITS                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359873
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_REFERENCE_MEASUREMENT_CHANNEL_RESOURCE_BLOCKS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359874
#define RSRFSIGGEN_ATTR_EUTRA_UL_SIDELINK_REFERENCE_MEASUREMENT_CHANNEL_MODULATION_SCHEME               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359875
#define RSRFSIGGEN_ATTR_EUTRA_UL_SUBFRAME_CYCLIC_PREFIX                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350613
#define RSRFSIGGEN_ATTR_EUTRA_UL_USER_EQUIPMENT_CONTENT_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350614
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENABLED                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353355
#define RSRFSIGGEN_ATTR_EUTRA_UL_CONFLICT                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353356
#define RSRFSIGGEN_ATTR_EUTRA_UL_PHYSICAL_BITS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353357
#define RSRFSIGGEN_ATTR_EUTRA_UL_POWER                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353358
#define RSRFSIGGEN_ATTR_EUTRA_UL_VRB_OFFSET                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353359
#define RSRFSIGGEN_ATTR_EUTRA_UL_NUMBER_OF_RB                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353360
#define RSRFSIGGEN_ATTR_EUTRA_UL_USER_EQUIPMENT_CODEWORD_PHYSICAL_BITS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 354454
#define RSRFSIGGEN_ATTR_EUTRA_UL_PRB_OFFSET                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353361
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_MODULATION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350616
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_PHYSICAL_BITS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350617
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_POWER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350618
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350619
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_CONFLICT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350620
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_CELL_POWER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 354485
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_CELL_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 354486
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_CELL_CONFLICT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 354487
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_CELL_MODULATION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 354455
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_CELL_PHYSICAL_BITS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 354488
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_NUMBER_OF_RB                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350621
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_VRB_OFFSET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350622
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_PRB_OFFSET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350623
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_CELL_NUMBER_OF_RB                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 354489
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_CELL_VRB_OFFSET                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 354490
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUSCH_CELL_PRB_OFFSET                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 354491
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_N2_DMRS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350624
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_FREQUENCY_HOPPING_ENABLE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350625
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_INFORMATION_IN_HOPPING_BITS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350626
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_FREQUENCY_HOPPING_TYPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350627
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_FREQUENCY_HOPPING_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350628
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CODEWORD_NUMBER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353645
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_NUMBER_OF_USED_ANTENNA_PORT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353646
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_HARQ_ACK_NACK_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350629
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_HARQ_N_BUNDLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350630
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_HARQ_NUMBER_OF_ACK_NACK_BITS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350631
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_HARQ_PATTERN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350632
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_HARQ_NUMBER_OF_CODED_ACK_NACK_BITS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350633
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_ACK_NACK_PATTERN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350634
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_RI_NUMBER_OF_BITS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350635
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_RI_PATTERN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350636
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_RI_NUMBER_OF_CODED_BITS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350637
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CQI_NUMBER_OF_BITS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350638
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CQI_PATTERN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350639
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CQI_MAPED_TO                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353647
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CQI_NUMBER_OF_CODED_BITS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350640
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_ULSCH_NUMBER_OF_CODED_BITS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350641
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_TRANSPORT_BLOCK_SIZE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350642
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_REDUNDANCY_VERSION_INDEX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350643
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_DRS_CYCLIC_SHIFT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353648
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_FREQUENCY_HOPPING_ENABLE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 354492
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_INFORMATION_IN_HOPPING_BITS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354493
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_FREQUENCY_HOPPING_TYPE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 354456
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_CODEWORD_NUMBER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 354494
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_HARQ_ACK_NACK_MODE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354495
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_HARQ_N_BUNDLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 354496
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_HARQ_PATTERN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 354517
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_HARQ_NUMBER_OF_ACK_NACK_BITS                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 354497
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_RI_NUMBER_OF_BITS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 354498
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_RI_PATTERN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 354499
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_CQI_NUMBER_OF_BITS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354500
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_CQI_PATTERN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354501
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_CQI_MAPED_TO                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 354502
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_CQI_NUMBER_OF_CODED_BITS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 354503
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_DRS_CYCLIC_SHIFT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 354504
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_RI_NUMBER_OF_CODED_BITS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 354505
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_ULSCH_NUMBER_OF_CODED_BITS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 354457
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_HARQ_NUMBER_OF_CODED_ACK_NACK_BITS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354506
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_TRANSPORT_BLOCK_SIZE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 354458
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_REDUNDANCY_VERSION_INDEX                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 354459
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_PRECODING_NUMBER_OF_LAYERS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353649
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_PRECODING_SCHEME                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353650
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_PRECODING_CODEBOOK_INDEX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353651
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_PRECODING_ALTERNATIVE_CODEBOOKS_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355827
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_PRECODING_CELL_NUMBER_OF_LAYERS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 354507
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_PRECODING_CELL_SCHEME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 354508
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_PRECODING_CELL_NUMBER_OF_USED_ANTENNA_PORT              RS_SPECIFIC_PUBLIC_ATTR_BASE + 354509
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_PRECODING_CELL_CODEBOOK_INDEX                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 354510
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_N2_DMRS_LAYERS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353652
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_BIT_FOR_DMRS_MAPPING_TABLE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357513
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUSCH_CELL_N2_DMRS_LAYERS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 354511
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_FORMAT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350644
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_PHYSICAL_BITS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350645
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_POWER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350646
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350647
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_CONFLICT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350648
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_NUMBER_OF_RB                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350649
#define RSRFSIGGEN_ATTR_EUTRA_UL_PUCCH_PRB_OFFSET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350650
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_N_PUCCH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350651
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUCCH_HARQ_PATTERN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350652
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUCCH_ACK_NACK_PATTERN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350653
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUCCH_CQI_NUMBER_OF_BITS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350654
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUCCH_CQI_NUMBER_OF_CODED_BITS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350655
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUCCH_CQI_PATTERN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350656
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUCCH_M_RB                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357514
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUCCH_N_OC                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357515
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUCCH_DRS_CYCLIC_SHIFT_FIELD                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357516
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUCCH_DRS_N1_DMRS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357517
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUCCH_DRS_N2_DMRS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357518
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUCCH_NUMBER_OF_ACK_NACK_SR_BITS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350657
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUCCH_NUMBER_OF_CODED_ACK_NACK_SR_BITS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350658
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_PUCCH_NUMBER_OF_USED_ANTENNA_PORTS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353653
#define RSRFSIGGEN_ATTR_EUTRA_UL_ENHANCED_N_PUCCH_ANTENNA                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 354518
#define RSRFSIGGEN_ATTR_EUTRA_TIME_DOMAIN_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350659
#define RSRFSIGGEN_ATTR_EUTRA_TIME_DOMAIN_TRANSITION_TIME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350660
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_TYPE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350661
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350662
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_COSINE_ROLL_OFF_FACTOR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350663
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_COSINE_CUT_OFF_FREQUENCY_SHIFT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350664
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_ROOT_COSINE_ROLL_OFF_FACTOR                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350665
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_GAUSS_PURE_BT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350666
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_GAUSS_FSK_BT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350667
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_APCO25_ROLL_OFF_FACTOR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350668
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_SPLIT_PHASE_BT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350669
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_LOWPASS_ACP_CUT_OFF_FREQUENCY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350670
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_LOWPASS_EVM_CUT_OFF_FREQUNECY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350671
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_LOAD_USER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350672
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_IMPULSE_LENGTH_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350673
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_IMPULSE_LENGTH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350674
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_UPSAMPLING_FACTOR_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350675
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_UPSAMPLING_FACTOR                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350676
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_AUTO                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355828
#define RSRFSIGGEN_ATTR_EUTRA_SAMPLE_RATE_VARIATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350677
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_LTE_OPTIMIZATION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350678
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_LTE_ROLL_OFF_FACTOR                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350679
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_LTE_CUT_OFF_FREQUENCY_SHIFT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350680
#define RSRFSIGGEN_ATTR_EUTRA_FILTER_LTE_CUT_OFF_FREQUENCY_FACTOR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350681
#define RSRFSIGGEN_ATTR_EUTRA_CLIPPING_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350682
#define RSRFSIGGEN_ATTR_EUTRA_CLIPPING_LEVEL                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350683
#define RSRFSIGGEN_ATTR_EUTRA_CLIPPING_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350684
#define RSRFSIGGEN_ATTR_EUTRA_POWER_OFFSET_RELATIVE_TO_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350685
#define RSRFSIGGEN_ATTR_EUTRA_POWER_LEVEL_REFERENCE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350686
#define RSRFSIGGEN_ATTR_EUTRA_REFERENCE_UE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350687
#define RSRFSIGGEN_ATTR_EUTRA_REFERENCE_SUBFRAME                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350688
#define RSRFSIGGEN_ATTR_EUTRA_REFERENCE_CHANNEL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350689
#define RSRFSIGGEN_ATTR_EUTRA_TRIGGER_STATUS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350690
#define RSRFSIGGEN_ATTR_EUTRA_TRIGGER_ARM                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350691
#define RSRFSIGGEN_ATTR_EUTRA_TRIGGER_EXECUTE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350692
#define RSRFSIGGEN_ATTR_EUTRA_SIGNAL_ADVANCE_N_TA_OFFSET                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350693
#define RSRFSIGGEN_ATTR_EUTRA_TRIGGER_DELAY_UNIT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353362
#define RSRFSIGGEN_ATTR_EUTRA_TRIGGER_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350694
#define RSRFSIGGEN_ATTR_EUTRA_TRIGGER_SOURCE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350695
#define RSRFSIGGEN_ATTR_EUTRA_TRIGGER_SOURCE_LEGACY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351018
#define RSRFSIGGEN_ATTR_EUTRA_TRIGGER_SIGNAL_DURATION_UNIT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350696
#define RSRFSIGGEN_ATTR_EUTRA_TRIGGER_SIGNAL_DURATION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350697
#define RSRFSIGGEN_ATTR_EUTRA_TIME_BASED_TRIGGER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363400
#define RSRFSIGGEN_ATTR_EUTRA_INTERNAL_TRIGGER_DELAY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350698
#define RSRFSIGGEN_ATTR_EUTRA_INTERNAL_TRIGGER_INHIBIT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350699
#define RSRFSIGGEN_ATTR_EUTRA_INTERNAL_TRIGGER_TIME_DELAY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353363
#define RSRFSIGGEN_ATTR_EUTRA_INTERNAL_TRIGGER_ACTUAL_TIME_DELAY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353364
#define RSRFSIGGEN_ATTR_EUTRA_EXTERNAL_TRIGGER_DELAY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350700
#define RSRFSIGGEN_ATTR_EUTRA_EXTERNAL_TRIGGER_INHIBIT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350701
#define RSRFSIGGEN_ATTR_EUTRA_EXTERNAL_TRIGGER_TIME_DELAY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 354519
#define RSRFSIGGEN_ATTR_EUTRA_EXTERNAL_TRIGGER_ACTUAL_TIME_DELAY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354520
#define RSRFSIGGEN_ATTR_EUTRA_MARKER_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350702
#define RSRFSIGGEN_ATTR_EUTRA_MARKER_ON_TIME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350703
#define RSRFSIGGEN_ATTR_EUTRA_MARKER_OFF_TIME                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350704
#define RSRFSIGGEN_ATTR_EUTRA_MARKER_RISE_OFFSET                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350705
#define RSRFSIGGEN_ATTR_EUTRA_MARKER_FALL_OFFSET                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350706
#define RSRFSIGGEN_ATTR_EUTRA_MARKER_PERIOD                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350707
#define RSRFSIGGEN_ATTR_EUTRA_MARKER_DELAY                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350708
#define RSRFSIGGEN_ATTR_EUTRA_MARKER_DELAY_IN_MICROSECONDS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361935
#define RSRFSIGGEN_ATTR_EUTRA_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350709
#define RSRFSIGGEN_ATTR_EUTRA_FIXED_MARKER_DELAY_MAXIMUM                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350710
#define RSRFSIGGEN_ATTR_EUTRA_FIXED_MARKER_DELAY_MINIMUM                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350711
#define RSRFSIGGEN_ATTR_EUTRA_CLOCK_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350712
#define RSRFSIGGEN_ATTR_EUTRA_CLOCK_SOURCE_LEGACY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351020
#define RSRFSIGGEN_ATTR_EUTRA_CLOCK_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350713
#define RSRFSIGGEN_ATTR_EUTRA_CLOCK_MULTIPLIER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350714
#define RSRFSIGGEN_ATTR_EUTRA_CLOCK_CUSTOM_EXTERNAL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350715
#define RSRFSIGGEN_ATTR_EUTRA_CLOCK_SYNCHRONISATION_EXECUTE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350716
#define RSRFSIGGEN_ATTR_EUTRA_CLOCK_SYNCHRONISATION_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350717
#define RSRFSIGGEN_ATTR_EUTRA_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350718
#define RSRFSIGGEN_ATTR_EUTRA_NOTCH_FILTER_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357705
#define RSRFSIGGEN_ATTR_EUTRA_NOTCH_FILTER_CLOCK_FREQUENCY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357706
#define RSRFSIGGEN_ATTR_EUTRA_NOTCH_FILTER_NUMBER_OF_NOTCHES                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357707
#define RSRFSIGGEN_ATTR_EUTRA_NOTCH_FILTER_APPLY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357708
#define RSRFSIGGEN_ATTR_EUTRA_NOTCH_FILTER_NOTCH_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357709
#define RSRFSIGGEN_ATTR_EUTRA_NOTCH_FILTER_NOTCH_BANDWIDTH_RELATIVE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357710
#define RSRFSIGGEN_ATTR_EUTRA_NOTCH_FILTER_NOTCH_BANDWIDTH_ABSOLUTE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357711
#define RSRFSIGGEN_ATTR_EUTRA_NOTCH_FILTER_NOTCH_FREQUENCY_OFFSET                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357712
#define RSRFSIGGEN_ATTR_EUTRA_ARB_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362788
#define RSRFSIGGEN_ATTR_EUTRA_ARB_DWELL_TIME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362789
#define RSRFSIGGEN_ATTR_EUTRA_ARB_MAX_SHIFT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362790
#define RSRFSIGGEN_ATTR_EUTRA_ARB_STEPS                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362791
#define RSRFSIGGEN_ATTR_TETRA_ENABLED                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348447
#define RSRFSIGGEN_ATTR_TETRA_SET_TO_DEFAULT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348448
#define RSRFSIGGEN_ATTR_TETRA_TEST_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348449
#define RSRFSIGGEN_ATTR_TETRA_LINK_DIRECTION                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348450
#define RSRFSIGGEN_ATTR_TETRA_CHANNEL_TYPE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348451
#define RSRFSIGGEN_ATTR_TETRA_SEQUENCE_LENGTH_SYMBOLS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348452
#define RSRFSIGGEN_ATTR_TETRA_DL_BURST_TYPE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348453
#define RSRFSIGGEN_ATTR_TETRA_MODULATION_TYPE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348454
#define RSRFSIGGEN_ATTR_TETRA_GENERATE_WAVEFORM_FILE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348455
#define RSRFSIGGEN_ATTR_TETRA_SETTINGS_CATALOG                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348456
#define RSRFSIGGEN_ATTR_TETRA_DELETE_SETTINGS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348457
#define RSRFSIGGEN_ATTR_TETRA_RECALL_SETTINGS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348458
#define RSRFSIGGEN_ATTR_TETRA_SAVE_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348459
#define RSRFSIGGEN_ATTR_TETRA_FAST_STORE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353230
#define RSRFSIGGEN_ATTR_TETRA_POWER_RAMP_FUNCTION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348460
#define RSRFSIGGEN_ATTR_TETRA_POWER_RAMP_TIME                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348461
#define RSRFSIGGEN_ATTR_TETRA_POWER_RAMP_RISE_OFFSET                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348462
#define RSRFSIGGEN_ATTR_TETRA_POWER_RAMP_FALL_OFFSET                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348463
#define RSRFSIGGEN_ATTR_TETRA_POWER_RAMP_LEVEL_ATTENUATION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348464
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_FREQUENCY_CARRIER_BANDWIDTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348465
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_FREQUENCY_MAIN_CARRIER_NUMBER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348466
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_FREQUENCY_FREQUENCY_BAND                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348467
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_FREQUENCY_OFFSET                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348468
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_FREQUENCY_DUPLEX_SPACING                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348469
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_FREQUENCY_REVERSE_OPERATION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348470
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_FREQUENCY_CODED_RF_FREQUENCY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348471
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_CONTENTS_SYSTEM_CODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348472
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_CONTENTS_SHARING_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348473
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_CONTENTS_TS_RESERVED_FRAMES                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348474
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_CONTENTS_UPLANE_DTX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348475
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_CONTENTS_FRAME_18_EXTENSION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348476
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_NEIGHBOUR_DNWRKBROADCAST_BROADCAST                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348477
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_NEIGHBOUR_DNWRKBROADCAST_ENQUIRY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348478
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_NEIGHBOUR_CELL_SERVICE_LEVEL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348479
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_NEIGHBOUR_LATE_ENTRY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348480
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_NEIGHBOUR_MS_TXPWR_MAX_CELL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348481
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_NEIGHBOUR_ACCESS_PARAMETER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348482
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_NEIGHBOUR_TX_ON                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348483
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_NEIGHBOUR_TX_BURST_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 348484
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_NEIGHBOUR_T1_T4_BURST_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348485
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_NEIGHBOUR_LOOP_BACK                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348486
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_NEIGHBOUR_ERROR_CORRECTION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348487
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_SCRAMBLING_BASE_COLOUR_CODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348488
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_SCRAMBLING_MOBILE_COUNTRY_CODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348489
#define RSRFSIGGEN_ATTR_TETRA_BROADCAST_SCRAMBLING_MOBILE_NETWORK_CODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348490
#define RSRFSIGGEN_ATTR_TETRA_SLOT_LEVEL                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348491
#define RSRFSIGGEN_ATTR_TETRA_SLOT_ATTENUATION                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348492
#define RSRFSIGGEN_ATTR_TETRA_SLOT_LOGICAL_CHANNEL_TYPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348493
#define RSRFSIGGEN_ATTR_TETRA_SLOT_DATA_SOURCE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348494
#define RSRFSIGGEN_ATTR_TETRA_SLOT_DATA_SOURCE_PATTERN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348495
#define RSRFSIGGEN_ATTR_TETRA_SLOT_DATA_SOURCE_DATA_LIST                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348496
#define RSRFSIGGEN_ATTR_TETRA_SLOT_DATA                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348497
#define RSRFSIGGEN_ATTR_TETRA_SLOT_DATA_PATTERN                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 348498
#define RSRFSIGGEN_ATTR_TETRA_SLOT_DATA_DATA_LIST                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348499
#define RSRFSIGGEN_ATTR_TETRA_SLOT_SCRAMBLING                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348500
#define RSRFSIGGEN_ATTR_TETRA_SLOT_DATA_TRAINING_SEQUENCE_TSC                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348501
#define RSRFSIGGEN_ATTR_TETRA_SLOT_TSC_USER_DEFINED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348502
#define RSRFSIGGEN_ATTR_TETRA_SLOT_BURST_TYPE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348503
#define RSRFSIGGEN_ATTR_TETRA_SLOT_AACH_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348504
#define RSRFSIGGEN_ATTR_TETRA_SLOT_AACH_ACCESS_ASSIGN_HEADER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348505
#define RSRFSIGGEN_ATTR_TETRA_SLOT_AACH_ACCESS_ASSIGN_FIELD1                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348506
#define RSRFSIGGEN_ATTR_TETRA_SLOT_AACH_ACCESS_ASSIGN_FIELD2                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348507
#define RSRFSIGGEN_ATTR_TETRA_SLOT_AUTO_CODING                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353231
#define RSRFSIGGEN_ATTR_TETRA_FILTER_TYPE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348508
#define RSRFSIGGEN_ATTR_TETRA_FILTER_CUT_OFF_FREQUENCY_SHIFT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348509
#define RSRFSIGGEN_ATTR_TETRA_FILTER_PARAMETER_ROOT_COSINE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348510
#define RSRFSIGGEN_ATTR_TETRA_FILTER_PARAMETER_COSINE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348511
#define RSRFSIGGEN_ATTR_TETRA_FILTER_PARAMETER_GAUSS_PURE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348512
#define RSRFSIGGEN_ATTR_TETRA_FILTER_PARAMETER_GAUSS_FSK                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348513
#define RSRFSIGGEN_ATTR_TETRA_FILTER_PARAMETER_APCO25                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348514
#define RSRFSIGGEN_ATTR_TETRA_FILTER_PARAMETER_SPLIT_PHASE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348515
#define RSRFSIGGEN_ATTR_TETRA_FILTER_PARAMETER_LOWPASS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348516
#define RSRFSIGGEN_ATTR_TETRA_FILTER_PARAMETER_LOWPASS_EVM                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348517
#define RSRFSIGGEN_ATTR_TETRA_FILTER_OVERSAMPLING                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348518
#define RSRFSIGGEN_ATTR_TETRA_FILTER_OVERSAMPLING_AUTO                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348519
#define RSRFSIGGEN_ATTR_TETRA_FILTER_IMPULSE_LENGTH_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348520
#define RSRFSIGGEN_ATTR_TETRA_FILTER_IMPULSE_LENGTH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348521
#define RSRFSIGGEN_ATTR_TETRA_SAMPLE_RATE_VARIATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348522
#define RSRFSIGGEN_ATTR_TETRA_CLIPPING_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348523
#define RSRFSIGGEN_ATTR_TETRA_CLIPPING_LEVEL                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348524
#define RSRFSIGGEN_ATTR_TETRA_CLIPPING_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348525
#define RSRFSIGGEN_ATTR_TETRA_TRIGGER_STATUS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348526
#define RSRFSIGGEN_ATTR_TETRA_TRIGGER_ARM                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348527
#define RSRFSIGGEN_ATTR_TETRA_TRIGGER_EXECUTE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348528
#define RSRFSIGGEN_ATTR_TETRA_TRIGGER_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348529
#define RSRFSIGGEN_ATTR_TETRA_TRIGGER_SOURCE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348530
#define RSRFSIGGEN_ATTR_TETRA_TRIGGER_SOURCE_LEGACY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350992
#define RSRFSIGGEN_ATTR_TETRA_TRIGGER_SIGNAL_DURATION_UNIT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348531
#define RSRFSIGGEN_ATTR_TETRA_TRIGGER_SIGNAL_DURATION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348532
#define RSRFSIGGEN_ATTR_TETRA_INTERNAL_TRIGGER_DELAY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348533
#define RSRFSIGGEN_ATTR_TETRA_INTERNAL_TRIGGER_INHIBIT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348534
#define RSRFSIGGEN_ATTR_TETRA_EXTERNAL_TRIGGER_DELAY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348535
#define RSRFSIGGEN_ATTR_TETRA_EXTERNAL_TRIGGER_INHIBIT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348536
#define RSRFSIGGEN_ATTR_TETRA_MARKER_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348537
#define RSRFSIGGEN_ATTR_TETRA_MARKER_PULSE_DIVIDER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348538
#define RSRFSIGGEN_ATTR_TETRA_MARKER_PULSE_FREQUENCY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348539
#define RSRFSIGGEN_ATTR_TETRA_MARKER_PATTERN                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348540
#define RSRFSIGGEN_ATTR_TETRA_MARKER_ON_TIME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348541
#define RSRFSIGGEN_ATTR_TETRA_MARKER_OFF_TIME                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348542
#define RSRFSIGGEN_ATTR_TETRA_MARKER_DELAY                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348543
#define RSRFSIGGEN_ATTR_TETRA_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 348544
#define RSRFSIGGEN_ATTR_TETRA_FIXED_MARKER_DELAY_MAXIMUM                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348545
#define RSRFSIGGEN_ATTR_TETRA_FIXED_MARKER_DELAY_MINIMUM                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348546
#define RSRFSIGGEN_ATTR_TETRA_CLOCK_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348547
#define RSRFSIGGEN_ATTR_TETRA_CLOCK_SOURCE_LEGACY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351022
#define RSRFSIGGEN_ATTR_TETRA_CLOCK_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348548
#define RSRFSIGGEN_ATTR_TETRA_CLOCK_MULTIPLIER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348549
#define RSRFSIGGEN_ATTR_TETRA_CLOCK_SYNCHRONISATION_EXECUTE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348550
#define RSRFSIGGEN_ATTR_TETRA_CLOCK_SYNCHRONISATION_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348551
#define RSRFSIGGEN_ATTR_TETRA_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348552
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ENABLED                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351307
#define RSRFSIGGEN_ATTR_SATNAV_GPS_UPDATE_RF_FREQUENCY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351309
#define RSRFSIGGEN_ATTR_SATNAV_GPS_RF_BAND                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351310
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TEST_SCENARIO                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351311
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SIMULATION_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351312
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SET_TO_DEFAULT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351308
#define RSRFSIGGEN_ATTR_SATNAV_GPS_FAST_STORING                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351313
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SETTINGS_CATALOG                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351314
#define RSRFSIGGEN_ATTR_SATNAV_GPS_DELETE_SETTINGS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351315
#define RSRFSIGGEN_ATTR_SATNAV_GPS_RECALL_SETTINGS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351316
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAVE_SETTINGS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351317
#define RSRFSIGGEN_ATTR_SATNAV_GPS_GNSS_ENABLED_GALILEO                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352096
#define RSRFSIGGEN_ATTR_SATNAV_GPS_GNSS_ENABLED_GLONASS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351319
#define RSRFSIGGEN_ATTR_SATNAV_GPS_GNSS_ENABLED_BEIDOU                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351318
#define RSRFSIGGEN_ATTR_SATNAV_GPS_GNSS_USE_COMMON_RF_FREQUENCY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351320
#define RSRFSIGGEN_ATTR_SATNAV_GPS_GNSS_P_CODE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351321
#define RSRFSIGGEN_ATTR_SATNAV_GPS_GNSS_ANTI_SPOOFING                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351322
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ALMANAC_FILE_GPS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351323
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ALMANAC_FILE_GALILEO                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351325
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ALMANAC_FILE_GLONASS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351327
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ALMANAC_WEEK_NUMBER_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351329
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ALMANAC_WEEK_NUMBER_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351330
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ALMANAC_WEEK_SPAN_BEGIN_GPS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351331
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ALMANAC_WEEK_SPAN_BEGIN_GALILEO                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351332
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ALMANAC_WEEK_SPAN_END_GPS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351333
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ALMANAC_WEEK_SPAN_END_GALILEO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351334
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ALMANAC_TOAP_WEEK_NUMBER_GPS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351335
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ALMANAC_TOAP_WEEK_NUMBER_GALILEO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351336
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ALMANAC_TOAP_TIME_OF_WEEK_GPS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351337
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ALMANAC_TOAP_TIME_OF_WEEK_GALILEO                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351338
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ALMANAC_TOAP_DATE_GLONASS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351339
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ALMANAC_TOAP_TIME_GLONASS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351340
#define RSRFSIGGEN_ATTR_SATNAV_GPS_RINEX_FILE_GPS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351341
#define RSRFSIGGEN_ATTR_SATNAV_GPS_RINEX_ENABLED_GPS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352559
#define RSRFSIGGEN_ATTR_SATNAV_GPS_RINEX_FILE_GALILEO                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351343
#define RSRFSIGGEN_ATTR_SATNAV_GPS_RINEX_ENABLED_GALILEO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352560
#define RSRFSIGGEN_ATTR_SATNAV_GPS_RINEX_FILE_GLONASS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351345
#define RSRFSIGGEN_ATTR_SATNAV_GPS_RINEX_ENABLED_GLONASS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352561
#define RSRFSIGGEN_ATTR_SATNAV_GPS_RINEX_UTC                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351347
#define RSRFSIGGEN_ATTR_SATNAV_GPS_RINEX_UPDATE_FREQUENCY_GLONASS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351348
#define RSRFSIGGEN_ATTR_SATNAV_GPS_RINEX_IMPORT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351349
#define RSRFSIGGEN_ATTR_SATNAV_GPS_GNSS_VALID_SATELLITES_GPS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352623
#define RSRFSIGGEN_ATTR_SATNAV_GPS_GNSS_VALID_SATELLITES_GALILEO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352624
#define RSRFSIGGEN_ATTR_SATNAV_GPS_GNSS_VALID_SATELLITES_GLONASS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352625
#define RSRFSIGGEN_ATTR_SATNAV_GPS_GNSS_VALID_SATELLITES_BEIDOU                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352626
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TRIGGER_STATUS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351350
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TRIGGER_ARM                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351351
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TRIGGER_EXECUTE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351352
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TRIGGER_MODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351353
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TRIGGER_SOURCE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351354
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351355
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TRIGGER_SIGNAL_DURATION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351356
#define RSRFSIGGEN_ATTR_SATNAV_GPS_EXTERNAL_TRIGGER_DELAY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351357
#define RSRFSIGGEN_ATTR_SATNAV_GPS_EXTERNAL_TRIGGER_INHIBIT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351358
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MARKER_MODE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351359
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MARKER_PULSE_DIVIDER                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351360
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MARKER_PULSE_FREQUENCY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351361
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MARKER_PATTERN                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351362
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MARKER_OFF_TIME                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351363
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MARKER_ON_TIME                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351364
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MARKER_PULSE_WIDTH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351365
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MARKER_DELAY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351366
#define RSRFSIGGEN_ATTR_SATNAV_GPS_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351367
#define RSRFSIGGEN_ATTR_SATNAV_GPS_FIXED_MARKER_DELAY_MAXIMUM                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351368
#define RSRFSIGGEN_ATTR_SATNAV_GPS_FIXED_MARKER_DELAY_MINIMUM                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351369
#define RSRFSIGGEN_ATTR_SATNAV_GPS_CLOCK_SYNCHRONIZATION_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351370
#define RSRFSIGGEN_ATTR_SATNAV_GPS_CLOCK_SOURCE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351371
#define RSRFSIGGEN_ATTR_SATNAV_GPS_CLOCK_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351372
#define RSRFSIGGEN_ATTR_SATNAV_GPS_CHIP_CLOCK_MULTIPLIER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351373
#define RSRFSIGGEN_ATTR_SATNAV_GPS_USER_ENVIRONMENT_VEHICLE_TYPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351375
#define RSRFSIGGEN_ATTR_SATNAV_GPS_USER_ENVIRONMENT_VEHICLE_PREDEFINED_CATALOG                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351376
#define RSRFSIGGEN_ATTR_SATNAV_GPS_USER_ENVIRONMENT_VEHICLE_USER_CATALOG                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351377
#define RSRFSIGGEN_ATTR_SATNAV_GPS_USER_ENVIRONMENT_VEHICLE_LOAD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351378
#define RSRFSIGGEN_ATTR_SATNAV_GPS_LOC_CATALOG                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351380
#define RSRFSIGGEN_ATTR_SATNAV_GPS_LOC_SELECT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351381
#define RSRFSIGGEN_ATTR_SATNAV_GPS_LOC_WAYPOINT_FILE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351382
#define RSRFSIGGEN_ATTR_SATNAV_GPS_LOC_YAW                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351386
#define RSRFSIGGEN_ATTR_SATNAV_GPS_LOC_FROM_MOTION_YAW                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351387
#define RSRFSIGGEN_ATTR_SATNAV_GPS_LOC_PITCH                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351388
#define RSRFSIGGEN_ATTR_SATNAV_GPS_LOC_FROM_MOTION_PITCH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351389
#define RSRFSIGGEN_ATTR_SATNAV_GPS_LOC_ROLL                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351390
#define RSRFSIGGEN_ATTR_SATNAV_GPS_LOC_CONSTANT_RATE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351391
#define RSRFSIGGEN_ATTR_SATNAV_GPS_LOC_START_ROLL_ANGLE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351392
#define RSRFSIGGEN_ATTR_SATNAV_GPS_LOC_SMOOTH_MOVEMENT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351393
#define RSRFSIGGEN_ATTR_SATNAV_GPS_OBSCURATION_TYPE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351394
#define RSRFSIGGEN_ATTR_SATNAV_GPS_OBSCURATION_NEAR_ENVIRONMENT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351395
#define RSRFSIGGEN_ATTR_SATNAV_GPS_OBSCURATION_PHYSICAL_MODEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351396
#define RSRFSIGGEN_ATTR_SATNAV_GPS_OBSCURATION_RECEIVER_OFFSET_X                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351397
#define RSRFSIGGEN_ATTR_SATNAV_GPS_OBSCURATION_RECEIVER_OFFSET_Y                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351398
#define RSRFSIGGEN_ATTR_SATNAV_GPS_OBSCURATION_RECEIVER_HEIGHT_OFFSET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351399
#define RSRFSIGGEN_ATTR_SATNAV_GPS_OBSCURATION_MAP_ORIENTATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351400
#define RSRFSIGGEN_ATTR_SATNAV_GPS_OBSCURATION_OBSTACLES_PREDEFINED_CATALOG                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351401
#define RSRFSIGGEN_ATTR_SATNAV_GPS_OBSCURATION_ROADSIDE_PREDEFINED_CATALOG                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351402
#define RSRFSIGGEN_ATTR_SATNAV_GPS_OBSCURATION_OBSTACLES_USER_CATALOG                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351403
#define RSRFSIGGEN_ATTR_SATNAV_GPS_OBSCURATION_ROADSIDE_USER_CATALOG                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351404
#define RSRFSIGGEN_ATTR_SATNAV_GPS_OBSCURATION_AREA_INSERT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351557
#define RSRFSIGGEN_ATTR_SATNAV_GPS_OBSCURATION_AREA_DELETE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351558
#define RSRFSIGGEN_ATTR_SATNAV_GPS_OBSCURATION_AREA_REFERENCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351559
#define RSRFSIGGEN_ATTR_SATNAV_GPS_OBSCURATION_AREA_LENGTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351560
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_ENABLED_GPS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352431
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_ENABLED_GALILEO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352432
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_ENABLED_GLONASS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352433
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_ENABLED_BEIDOU                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352434
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_TAP_GPS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352435
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_TAP_GALILEO                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352436
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_TAP_GLONASS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352437
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_TAP_BEIDOU                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352438
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_CARRIER_PHASE_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352439
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_CARRIER_PHASE_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352440
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_CARRIER_PHASE_GLONASS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352441
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_CARRIER_PHASE_BEIDOU                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352442
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_DOPPLER_SHIFT_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352443
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_DOPPLER_SHIFT_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352444
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_DOPPLER_SHIFT_GLONASS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352445
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_DOPPLER_SHIFT_BEIDOU                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352446
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_POWER_GPS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352447
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_POWER_GALILEO                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352448
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_POWER_GLONASS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352449
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_POWER_BEIDOU                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352450
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_DELAY_GPS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352451
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_DELAY_GALILEO                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352452
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_DELAY_GLONASS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352453
#define RSRFSIGGEN_ATTR_SATNAV_GPS_MPATH_DELAY_BEIDOU                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352454
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ANTENNA_PREDEFINED_CATALOG                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351405
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ANTENNA_USER_CATALOG                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351406
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ANTENNA_LOAD                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351407
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ANTENNA_LIST                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351408
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ANTENNA_ID                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351409
#define RSRFSIGGEN_ATTR_SATNAV_GPS_NAVIGATION_DATA_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351410
#define RSRFSIGGEN_ATTR_SATNAV_GPS_NAVIGATION_DATA_LIST                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351411
#define RSRFSIGGEN_ATTR_SATNAV_GPS_NAVIGATION_SYSTEM_TIME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351413
#define RSRFSIGGEN_ATTR_SATNAV_GPS_NAVIGATION_WEEK_NUMBER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351414
#define RSRFSIGGEN_ATTR_SATNAV_GPS_NAVIGATION_TIME_OF_WEEK                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351415
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_LEAP_SECOND_SYNCHRONIZE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351418
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_LEAP_SECOND_CURRENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351419
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_LEAP_SECOND_SIMULATE_TRANSITION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351420
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_UTC_REFERENCE_DATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351421
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_UTC_A0                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351422
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_UTC_A1                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351423
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_PARAMETERS_A0_GPS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351424
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_PARAMETERS_A0_GALILEO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351425
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_PARAMETERS_A0_GLONASS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351426
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_PARAMETERS_A1_GPS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351427
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_PARAMETERS_A1_GALILEO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351428
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_PARAMETERS_A1_GLONASS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351429
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_PARAMETERS_T_OT_GPS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351430
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_PARAMETERS_T_OT_GALILEO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351431
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_PARAMETERS_T_OT_GLONASS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351432
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_PARAMETERS_WN_OT_GPS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351433
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_PARAMETERS_WN_OT_GALILEO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351434
#define RSRFSIGGEN_ATTR_SATNAV_GPS_TCON_PARAMETERS_WN_OT_GLONASS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351435
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_POWER_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351436
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_REFERENCE_POWER                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351437
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_REFERENCE_SATELLITE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351438
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_TOTAL_POWER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351439
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_REFERENCE_STANDARD                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351440
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_REFERENCE_SIGNAL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351441
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_REFERENCE_DISTANCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351442
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_ELEVATION_MASK                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351443
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_HDOP                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351444
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_PDOP                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351445
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_OPTIMAL_CONSTELLATION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351446
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_TUNING_INTRA_ZERO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351447
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_TUNING_INTRA_SET_TO_STANDARD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351448
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_TUNING_INTRA_CA_P                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351449
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_TUNING_INTER_ZERO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351450
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_TUNING_INTER_SET_TO_STANDARD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351451
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_TUNING_INTER_CA_E1DEF                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351452
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_TUNING_INTER_CA_RCA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351453
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_TUNING_INTER_CA_TO_GEO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352586
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ATMOSPHERIC_TROPOSPHERIC_MODEL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351454
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ATMOSPHERIC_IONOSPHERIC_MODEL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351455
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ATMOSPHERIC_GPS_ALPHA                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351456
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ATMOSPHERIC_KLOBUCHAR_ALPHA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352698
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ATMOSPHERIC_GPS_BETA                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351457
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ATMOSPHERIC_KLOBUCHAR_BETA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352699
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ATMOSPHERIC_GALILEO_ALPHA                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351561
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ATMOSPHERIC_GALILEO_SF                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351459
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_CONFIGURATION_EPHEMERIS_PROJECTION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351460
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_CONFIGURATION_NUMBER_OF_SATELLITES                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351461
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351462
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_STANDARD                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351463
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_SIGNALS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351464
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_SPACE_VEHICLE_ID                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351465
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_POWER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351466
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_STANDARD_CHIP_RATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351467
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MODULATION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351468
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_DURATION                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351469
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_PSEUDORANGE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351470
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_PSEUDORANGE_BIAS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351471
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_TIME_SHIFT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351472
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_INITIAL_CARRIER_PHASE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351473
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_RESULTING_START_FREQUENCY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351474
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_RESULTING_START_CHIP_RATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351475
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_NAVIGATION_PAGES                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351476
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_NAVIGATION_REAL_TIME_PROJECTION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351477
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_SET_TO_ALMANAC                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351478
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_PROJECT_NAVIGATION_MESSAGE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351479
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_CODE_ON_L2                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351480
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_L2_P_DATA_FLAG                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351481
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_FIT_INTERVAL_FLAG                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351482
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_URA_INDEX                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351483
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_SV_HEALTH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351484
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_IODC                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351485
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_IODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351486
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_TOE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351487
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_M0                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351488
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_N_DELTA                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351489
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_ECCENTRICITY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351490
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_SQRTA                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351491
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_OMEGA0                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351492
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_I0                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351493
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_OMEGA                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351494
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_OMEGA_DOT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351495
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_IDOT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351496
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_CUC                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351497
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_CUS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351498
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_CRC                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351499
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_CRS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351500
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_CIC                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351501
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_CIS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351502
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_SF1_RESERVED_1                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351503
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_SF1_RESERVED_2                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351504
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_SF1_RESERVED_3                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351505
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_SF1_RESERVED_4                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351506
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_AODO                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351507
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_MESSAGE_SV_CONFIG                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351508
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_CLOCK_TGD                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351509
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_CLOCK__TOC                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351510
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_CLOCK_AF0                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351511
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_CLOCK_AF1                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351512
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_CLOCK_AF2                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351513
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351515
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_SYNCHRONIZE_ALL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351516
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_SYNCHRONIZE_SVID_GPS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351517
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_SYNCHRONIZE_SVID_GALILEO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351518
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_SYNCHRONIZE_SVID_GLONASS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351519
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_REF_SYNCHRONIZE_LOCATION_GPS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351520
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_REF_SYNCHRONIZE_LOCATION_GALILEO                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351521
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_REF_SYNCHRONIZE_LOCATION_GLONASS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351522
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_REF_UNCERTAINLY_RADIUS_GPS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351529
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_REF_UNCERTAINLY_RADIUS_GALILEO                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351530
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_REF_UNCERTAINLY_RADIUS_GLONASS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351531
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_SYNCHRONIZE_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351532
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_SYNCHRONIZE_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351533
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_SYNCHRONIZE_GLONASS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351534
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_TIME_BASIS_GPS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351535
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_TIME_BASIS_GALILEO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351536
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_TIME_BASIS_GLONASS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351537
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_WEEK_NUMBER_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351538
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_WEEK_NUMBER_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351539
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_WEEK_NUMBER_GLONASS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351540
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_TIME_OF_WEEK_GPS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351541
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_TIME_OF_WEEK_GALILEO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351542
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_TIME_OF_WEEK_GLONASS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351543
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_DURATION_GPS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351544
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_DURATION_GALILEO                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351545
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_DURATION_GLONASS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351546
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_RESOLUTION_GPS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351547
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_TOA_RESOLUTION_GALILEO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351548
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_SVID_ENABLED_GPS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351549
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_SVID_ENABLED_GALILEO                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351550
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_SVID_ENABLED_GLONASS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351551
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_GENERATE_ALMANAC_FILE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351552
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_GENERATE_NAVIGATION_FILE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351553
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_GENERATE_ACQUISITION_FILE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351554
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_GENERATE_IONOSPHERIC_FILE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351555
#define RSRFSIGGEN_ATTR_SATNAV_GPS_ADG_GENERATE_UTC_FILE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351556
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_GLOBAL_SIGNAL_COUPLING                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352587
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_GLOBAL_SIGNAL_GPS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352588
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_GLOBAL_SIGNAL_GALILEO                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352589
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_GLOBAL_SIGNAL_GLONASS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352590
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_GLOBAL_SIGNAL_BEIDOU                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352591
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_GLOBAL_POWER_GPS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352592
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_GLOBAL_POWER_GALILEO                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352593
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_GLOBAL_POWER_GLONASS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352594
#define RSRFSIGGEN_ATTR_SATNAV_GPS_SAT_GLOBAL_POWER_BEIDOU                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352595
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ENABLED                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351562
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SET_TO_DEFAULT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351563
#define RSRFSIGGEN_ATTR_SATNAV_GAL_UPDATE_RF_FREQUENCY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351564
#define RSRFSIGGEN_ATTR_SATNAV_GAL_RF_BAND                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351565
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TEST_SCENARIO                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351566
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SIMULATION_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351567
#define RSRFSIGGEN_ATTR_SATNAV_GAL_FAST_STORING                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351568
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SETTINGS_CATALOG                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351569
#define RSRFSIGGEN_ATTR_SATNAV_GAL_DELETE_SETTINGS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351570
#define RSRFSIGGEN_ATTR_SATNAV_GALILEO_RECALL_SETTINGS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351571
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAVE_SETTINGS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351572
#define RSRFSIGGEN_ATTR_SATNAV_GAL_GNSS_ENABLED_GPS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351573
#define RSRFSIGGEN_ATTR_SATNAV_GAL_GNSS_ENABLED_GLONASS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351574
#define RSRFSIGGEN_ATTR_SATNAV_GAL_GNSS_ENABLED_BEIDOU                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352097
#define RSRFSIGGEN_ATTR_SATNAV_GAL_GNSS_USE_COMMON_RF_FREQUENCY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351575
#define RSRFSIGGEN_ATTR_SATNAV_GAL_GNSS_P_CODE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351576
#define RSRFSIGGEN_ATTR_SATNAV_GAL_GNSS_ANTI_SPOOFING                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351577
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ALMANAC_FILE_GPS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351578
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ALMANAC_FILE_GALILEO                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351579
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ALMANAC_FILE_GLONASS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351580
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ALMANAC_WEEK_NUMBER_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351581
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ALMANAC_WEEK_NUMBER_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351582
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ALMANAC_WEEK_SPAN_BEGIN_GPS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351583
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ALMANAC_WEEK_SPAN_BEGIN_GALILEO                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351584
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ALMANAC_WEEK_SPAN_END_GPS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351585
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ALMANAC_WEEK_SPAN_END_GALILEO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351586
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ALMANAC_TOAP_WEEK_NUMBER_GPS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351587
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ALMANAC_TOAP_WEEK_NUMBER_GALILEO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351588
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ALMANAC_TOAP_TIME_OF_WEEK_GPS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351589
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ALMANAC_TOAP_TIME_OF_WEEK_GALILEO                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351590
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ALMANAC_TOAP_DATE_GLONASS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351591
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ALMANAC_TOAP_TIME_GLONASS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351592
#define RSRFSIGGEN_ATTR_SATNAV_GAL_RINEX_FILE_GPS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351593
#define RSRFSIGGEN_ATTR_SATNAV_GAL_RINEX_ENABLED_GPS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352562
#define RSRFSIGGEN_ATTR_SATNAV_GAL_RINEX_FILE_GALILEO                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352563
#define RSRFSIGGEN_ATTR_SATNAV_GAL_RINEX_ENABLED_GALILEO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352564
#define RSRFSIGGEN_ATTR_SATNAV_GAL_RINEX_FILE_GLONASS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351595
#define RSRFSIGGEN_ATTR_SATNAV_GAL_RINEX_ENABLED_GLONASS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352565
#define RSRFSIGGEN_ATTR_SATNAV_GAL_RINEX_UTC                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351596
#define RSRFSIGGEN_ATTR_SATNAV_GAL_RINEX_UPDATE_FREQUENCY_GLONASS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351597
#define RSRFSIGGEN_ATTR_SATNAV_GAL_RINEX_IMPORT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351598
#define RSRFSIGGEN_ATTR_SATNAV_GAL_GNSS_VALID_SATELLITES_GPS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352633
#define RSRFSIGGEN_ATTR_SATNAV_GAL_GNSS_VALID_SATELLITES_GALILEO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352634
#define RSRFSIGGEN_ATTR_SATNAV_GAL_GNSS_VALID_SATELLITES_GLONASS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352635
#define RSRFSIGGEN_ATTR_SATNAV_GAL_GNSS_VALID_SATELLITES_BEIDOU                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352636
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TRIGGER_STATUS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351599
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TRIGGER_ARM                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351600
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TRIGGER_EXECUTE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351601
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TRIGGER_MODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351602
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TRIGGER_SOURCE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351603
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351604
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TRIGGER_SIGNAL_DURATION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351605
#define RSRFSIGGEN_ATTR_SATNAV_GAL_EXTERNAL_TRIGGER_DELAY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351606
#define RSRFSIGGEN_ATTR_SATNAV_GAL_EXTERNAL_TRIGGER_INHIBIT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351607
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MARKER_MODE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351608
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MARKER_PULSE_DIVIDER                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351609
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MARKER_PULSE_FREQUENCY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351610
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MARKER_PATTERN                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351611
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MARKER_OFF_TIME                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351612
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MARKER_ON_TIME                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351613
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MARKER_PULSE_WIDTH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351614
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MARKER_DELAY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351615
#define RSRFSIGGEN_ATTR_SATNAV_GAL_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351616
#define RSRFSIGGEN_ATTR_SATNAV_GAL_FIXED_MARKER_DELAY_MAXIMUM                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351617
#define RSRFSIGGEN_ATTR_SATNAV_GAL_FIXED_MARKER_DELAY_MINIMUM                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351618
#define RSRFSIGGEN_ATTR_SATNAV_GAL_CLOCK_SYNCHRONIZATION_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351619
#define RSRFSIGGEN_ATTR_SATNAV_GAL_CLOCK_SOURCE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351620
#define RSRFSIGGEN_ATTR_SATNAV_GAL_CLOCK_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351621
#define RSRFSIGGEN_ATTR_SATNAV_GAL_CHIP_CLOCK_MULTIPLIER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351622
#define RSRFSIGGEN_ATTR_SATNAV_GAL_USER_ENVIRONMENT_VEHICLE_TYPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351623
#define RSRFSIGGEN_ATTR_SATNAV_GAL_USER_ENVIRONMENT_VEHICLE_PREDEFINED_CATALOG                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351624
#define RSRFSIGGEN_ATTR_SATNAV_GAL_USER_ENVIRONMENT_VEHICLE_USER_CATALOG                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351625
#define RSRFSIGGEN_ATTR_SATNAV_GAL_USER_ENVIRONMENT_VEHICLE_LOAD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351626
#define RSRFSIGGEN_ATTR_SATNAV_GAL_LOC_CATALOG                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351627
#define RSRFSIGGEN_ATTR_SATNAV_GAL_LOC_SELECT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351628
#define RSRFSIGGEN_ATTR_SATNAV_GAL_LOC_WAYPOINT_FILE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351629
#define RSRFSIGGEN_ATTR_SATNAV_GAL_LOC_YAW                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351630
#define RSRFSIGGEN_ATTR_SATNAV_GAL_LOC_FROM_MOTION_YAW                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351631
#define RSRFSIGGEN_ATTR_SATNAV_GAL_LOC_PITCH                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351632
#define RSRFSIGGEN_ATTR_SATNAV_GAL_LOC_FROM_MOTION_PITCH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351633
#define RSRFSIGGEN_ATTR_SATNAV_GAL_LOC_ROLL                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351634
#define RSRFSIGGEN_ATTR_SATNAV_GAL_LOC_CONSTANT_RATE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351635
#define RSRFSIGGEN_ATTR_SATNAV_GAL_LOC_START_ROLL_ANGLE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351636
#define RSRFSIGGEN_ATTR_SATNAV_GAL_LOC_SMOOTH_MOVEMENT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351637
#define RSRFSIGGEN_ATTR_SATNAV_GAL_OBSCURATION_TYPE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351638
#define RSRFSIGGEN_ATTR_SATNAV_GAL_OBSCURATION_NEAR_ENVIRONMENT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351639
#define RSRFSIGGEN_ATTR_SATNAV_GAL_OBSCURATION_PHYSICAL_MODEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351640
#define RSRFSIGGEN_ATTR_SATNAV_GAL_OBSCURATION_RECEIVER_OFFSET_X                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351641
#define RSRFSIGGEN_ATTR_SATNAV_GAL_OBSCURATION_RECEIVER_OFFSET_Y                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351642
#define RSRFSIGGEN_ATTR_SATNAV_GAL_OBSCURATION_RECEIVER_HEIGHT_OFFSET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351643
#define RSRFSIGGEN_ATTR_SATNAV_GAL_OBSCURATION_MAP_ORIENTATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351644
#define RSRFSIGGEN_ATTR_SATNAV_GAL_OBSCURATION_OBSTACLES_PREDEFINED_CATALOG                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351645
#define RSRFSIGGEN_ATTR_SATNAV_GAL_OBSCURATION_ROADSIDE_PREDEFINED_CATALOG                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351646
#define RSRFSIGGEN_ATTR_SATNAV_GAL_OBSCURATION_OBSTACLES_USER_CATALOG                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351647
#define RSRFSIGGEN_ATTR_SATNAV_GAL_OBSCURATION_ROADSIDE_USER_CATALOG                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351648
#define RSRFSIGGEN_ATTR_SATNAV_GAL_OBSCURATION_AREA_INSERT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351649
#define RSRFSIGGEN_ATTR_SATNAV_GAL_OBSCURATION_AREA_DELETE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351650
#define RSRFSIGGEN_ATTR_SATNAV_GAL_OBSCURATION_AREA_REFERENCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351651
#define RSRFSIGGEN_ATTR_SATNAV_GAL_OBSCURATION_AREA_LENGTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351652
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_ENABLED_GPS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352463
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_ENABLED_GALILEO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352464
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_ENABLED_GLONASS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352465
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_ENABLED_BEIDOU                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352466
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_TAP_GPS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352467
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_TAP_GALILEO                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352468
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_TAP_GLONASS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352469
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_TAP_BEIDOU                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352470
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_CARRIER_PHASE_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352471
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_CARRIER_PHASE_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352472
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_CARRIER_PHASE_GLONASS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352473
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_CARRIER_PHASE_BEIDOU                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352474
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_DOPPLER_SHIFT_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352475
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_DOPPLER_SHIFT_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352476
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_DOPPLER_SHIFT_GLONASS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352477
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_DOPPLER_SHIFT_BEIDOU                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352478
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_POWER_GPS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352479
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_POWER_GALILEO                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352480
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_POWER_GLONASS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352481
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_POWER_BEIDOU                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352482
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_DELAY_GPS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352483
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_DELAY_GALILEO                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352484
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_DELAY_GLONASS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352485
#define RSRFSIGGEN_ATTR_SATNAV_GAL_MPATH_DELAY_BEIDOU                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352486
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ANTENNA_PREDEFINED_CATALOG                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351653
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ANTENNA_USER_CATALOG                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351654
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ANTENNA_LOAD                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351655
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ANTENNA_LIST                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351656
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ANTENNA_ID                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351657
#define RSRFSIGGEN_ATTR_SATNAV_GAL_NAVIGATION_DATA_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351658
#define RSRFSIGGEN_ATTR_SATNAV_GAL_NAVIGATION_DATA_LIST                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351659
#define RSRFSIGGEN_ATTR_SATNAV_GAL_NAVIGATION_SYSTEM_TIME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351660
#define RSRFSIGGEN_ATTR_SATNAV_GAL_NAVIGATION_WEEK_NUMBER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351661
#define RSRFSIGGEN_ATTR_SATNAV_GAL_NAVIGATION_TIME_OF_WEEK                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351662
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_LEAP_SECOND_SYNCHRONIZE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351663
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_LEAP_SECOND_CURRENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351664
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_LEAP_SECOND_SIMULATE_TRANSITION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351665
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_UTC_REFERENCE_DATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351666
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_UTC_A0                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351667
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_UTC_A1                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351668
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_PARAMETERS_A0_GPS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351669
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_PARAMETERS_A0_GALILEO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351670
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_PARAMETERS_A0_GLONASS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351671
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_PARAMETERS_A1_GPS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351672
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_PARAMETERS_A1_GALILEO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351673
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_PARAMETERS_A1_GLONASS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351674
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_PARAMETERS_T_OT_GPS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351675
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_PARAMETERS_T_OT_GALILEO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351676
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_PARAMETERS_T_OT_GLONASS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351677
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_PARAMETERS_WN_OT_GPS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351678
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_PARAMETERS_WN_OT_GALILEO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351679
#define RSRFSIGGEN_ATTR_SATNAV_GAL_TCON_PARAMETERS_WN_OT_GLONASS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351680
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_POWER_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351681
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_REFERENCE_POWER                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351682
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_REFERENCE_SATELLITE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351683
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_TOTAL_POWER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351684
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_REFERENCE_STANDARD                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351685
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_REFERENCE_SIGNAL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351686
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_REFERENCE_DISTANCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351687
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_ELEVATION_MASK                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351688
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_HDOP                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351689
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_PDOP                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351690
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_OPTIMAL_CONSTELLATION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351691
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_TUNING_INTRA_ZERO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351692
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_TUNING_INTRA_SET_TO_STANDARD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351693
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_TUNING_INTRA_CA_P                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351694
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_TUNING_INTER_ZERO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351695
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_TUNING_INTER_SET_TO_STANDARD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351696
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_TUNING_INTER_CA_E1DEF                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351697
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_TUNING_INTER_CA_RCA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351698
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_TUNING_INTER_CA_TO_GEO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352637
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ATMOSPHERIC_TROPOSPHERIC_MODEL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351699
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ATMOSPHERIC_IONOSPHERIC_MODEL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351700
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ATMOSPHERIC_GPS_ALPHA                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351701
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ATMOSPHERIC_KLOBUCHAR_ALPHA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352700
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ATMOSPHERIC_GPS_BETA                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351702
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ATMOSPHERIC_KLOBUCHAR_BETA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352701
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ATMOSPHERIC_GALILEO_ALPHA                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351703
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ATMOSPHERIC_GALILEO_SF                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351704
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_CONFIGURATION_EPHEMERIS_PROJECTION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351705
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_CONFIGURATION_NUMBER_OF_SATELLITES                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351706
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351707
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_STANDARD                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351708
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_SIGNALS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351709
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_SPACE_VEHICLE_ID                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351710
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_POWER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351711
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_STANDARD_CHIP_RATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351712
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MODULATION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351713
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_DURATION                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351714
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_PSEUDORANGE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351715
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_PSEUDORANGE_BIAS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351716
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_TIME_SHIFT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351717
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_INITIAL_CARRIER_PHASE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351718
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_RESULTING_START_FREQUENCY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351719
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_RESULTING_START_CHIP_RATE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351720
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_NAVIGATION_PAGES                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351721
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_NAVIGATION_REAL_TIME_PROJECTION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351722
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_SET_TO_ALMANAC                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351723
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_PROJECT_NAVIGATION_MESSAGE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351724
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_CODE_ON_L2                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351725
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_L2_P_DATA_FLAG                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351726
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_FIT_INTERVAL_FLAG                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351727
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_URA_INDEX                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351728
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_SV_HEALTH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351729
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_IODC                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351730
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_IODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351731
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_TOE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351732
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_M0                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351733
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_N_DELTA                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351734
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_ECCENTRICITY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351735
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_SQRTA                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351736
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_OMEGA0                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351737
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_I0                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351738
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_OMEGA                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351739
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_OMEGA_DOT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351740
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_IDOT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351741
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_CUC                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351742
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_CUS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351743
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_CRC                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351744
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_CRS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351745
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_CIC                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351746
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_CIS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351747
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_SF1_RESERVED_1                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351748
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_SF1_RESERVED_2                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351749
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_SF1_RESERVED_3                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351750
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_SF1_RESERVED_4                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351751
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_AODO                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351752
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_MESSAGE_SV_CONFIG                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351753
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_CLOCK_TGD                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351754
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_CLOCK__TOC                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351755
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_CLOCK_AF0                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351756
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_CLOCK_AF1                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351757
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_CLOCK_AF2                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351758
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351759
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_SYNCHRONIZE_ALL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351760
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_SYNCHRONIZE_SVID_GPS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351761
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_SYNCHRONIZE_SVID_GALILEO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351762
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_SYNCHRONIZE_SVID_GLONASS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351763
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_REF_SYNCHRONIZE_LOCATION_GPS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351764
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_REF_SYNCHRONIZE_LOCATION_GALILEO                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351765
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_REF_SYNCHRONIZE_LOCATION_GLONASS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351766
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_REF_UNCERTAINLY_RADIUS_GPS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351767
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_REF_UNCERTAINLY_RADIUS_GALILEO                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351768
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_REF_UNCERTAINLY_RADIUS_GLONASS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351769
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_SYNCHRONIZE_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351770
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_SYNCHRONIZE_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351771
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_SYNCHRONIZE_GLONASS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351772
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_TIME_BASIS_GPS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351773
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_TIME_BASIS_GALILEO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351774
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_TIME_BASIS_GLONASS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351775
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_WEEK_NUMBER_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351776
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_WEEK_NUMBER_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351777
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_WEEK_NUMBER_GLONASS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351778
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_TIME_OF_WEEK_GPS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351779
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_TIME_OF_WEEK_GALILEO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351780
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_TIME_OF_WEEK_GLONASS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351781
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_DURATION_GPS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351782
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_DURATION_GALILEO                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351783
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_DURATION_GLONASS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351784
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_RESOLUTION_GPS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351785
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_TOA_RESOLUTION_GALILEO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351786
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_SVID_ENABLED_GPS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351787
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_SVID_ENABLED_GALILEO                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351788
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_SVID_ENABLED_GLONASS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351789
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_GENERATE_ALMANAC_FILE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351790
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_GENERATE_NAVIGATION_FILE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351791
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_GENERATE_ACQUISITION_FILE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351792
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_GENERATE_IONOSPHERIC_FILE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351793
#define RSRFSIGGEN_ATTR_SATNAV_GAL_ADG_GENERATE_UTC_FILE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351794
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_GLOBAL_SIGNAL_COUPLING                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352596
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_GLOBAL_SIGNAL_GPS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352597
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_GLOBAL_SIGNAL_GALILEO                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352598
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_GLOBAL_SIGNAL_GLONASS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352599
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_GLOBAL_SIGNAL_BEIDOU                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352600
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_GLOBAL_POWER_GPS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352601
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_GLOBAL_POWER_GALILEO                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352602
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_GLOBAL_POWER_GLONASS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352603
#define RSRFSIGGEN_ATTR_SATNAV_GAL_SAT_GLOBAL_POWER_BEIDOU                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352604
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ENABLED                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351795
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SET_TO_DEFAULT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351796
#define RSRFSIGGEN_ATTR_SATNAV_GLON_UPDATE_RF_FREQUENCY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351797
#define RSRFSIGGEN_ATTR_SATNAV_GLON_RF_BAND                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351798
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TEST_SCENARIO                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351799
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SIMULATION_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351800
#define RSRFSIGGEN_ATTR_SATNAV_GLON_FAST_STORING                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351801
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SETTINGS_CATALOG                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351802
#define RSRFSIGGEN_ATTR_SATNAV_GLON_DELETE_SETTINGS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351803
#define RSRFSIGGEN_ATTR_SATNAV_GLON_RECALL_SETTINGS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351804
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAVE_SETTINGS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351805
#define RSRFSIGGEN_ATTR_SATNAV_GLON_GNSS_ENABLED_GPS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351806
#define RSRFSIGGEN_ATTR_SATNAV_GLON_GNSS_ENABLED_GALILEO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351807
#define RSRFSIGGEN_ATTR_SATNAV_GLON_GNSS_ENABLED_BEIDOU                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352098
#define RSRFSIGGEN_ATTR_SATNAV_GLON_GNSS_USE_COMMON_RF_FREQUENCY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351808
#define RSRFSIGGEN_ATTR_SATNAV_GLON_GNSS_P_CODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351809
#define RSRFSIGGEN_ATTR_SATNAV_GLON_GNSS_ANTI_SPOOFING                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351810
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ALMANAC_FILE_GPS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351811
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ALMANAC_FILE_GALILEO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351812
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ALMANAC_FILE_GLONASS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351813
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ALMANAC_WEEK_NUMBER_GALILEO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351814
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ALMANAC_WEEK_NUMBER_GPS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351815
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ALMANAC_WEEK_SPAN_BEGIN_GPS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351816
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ALMANAC_WEEK_SPAN_BEGIN_GALILEO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351817
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ALMANAC_WEEK_SPAN_END_GPS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351818
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ALMANAC_WEEK_SPAN_END_GALILEO                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351819
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ALMANAC_TOAP_WEEK_NUMBER_GPS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351820
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ALMANAC_TOAP_WEEK_NUMBER_GALILEO                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351821
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ALMANAC_TOAP_TIME_OF_WEEK_GPS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351822
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ALMANAC_TOAP_TIME_OF_WEEK_GALILEO                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351823
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ALMANAC_TOAP_DATE_GLONASS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351824
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ALMANAC_TOAP_TIME_GLONASS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351825
#define RSRFSIGGEN_ATTR_SATNAV_GLON_RINEX_FILE_GPS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351826
#define RSRFSIGGEN_ATTR_SATNAV_GLON_RINEX_FILE_GALILEO                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351827
#define RSRFSIGGEN_ATTR_SATNAV_GLON_RINEX_FILE_GLONASS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351828
#define RSRFSIGGEN_ATTR_SATNAV_GLON_RINEX_UTC                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351829
#define RSRFSIGGEN_ATTR_SATNAV_GLON_RINEX_UPDATE_FREQUENCY_GLONASS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351830
#define RSRFSIGGEN_ATTR_SATNAV_GLON_RINEX_IMPORT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351831
#define RSRFSIGGEN_ATTR_SATNAV_GLON_GNSS_VALID_SATELLITES_GPS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352644
#define RSRFSIGGEN_ATTR_SATNAV_GLON_GNSS_VALID_SATELLITES_GALILEO                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352645
#define RSRFSIGGEN_ATTR_SATNAV_GLON_GNSS_VALID_SATELLITES_GLONASS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352646
#define RSRFSIGGEN_ATTR_SATNAV_GLON_GNSS_VALID_SATELLITES_BEIDOU                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352647
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TRIGGER_STATUS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351832
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TRIGGER_ARM                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351833
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TRIGGER_EXECUTE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351834
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TRIGGER_MODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351835
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TRIGGER_SOURCE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351836
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351837
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TRIGGER_SIGNAL_DURATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351838
#define RSRFSIGGEN_ATTR_SATNAV_GLON_EXTERNAL_TRIGGER_DELAY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351839
#define RSRFSIGGEN_ATTR_SATNAV_GLON_EXTERNAL_TRIGGER_INHIBIT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351840
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MARKER_MODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351841
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MARKER_PULSE_DIVIDER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351842
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MARKER_PULSE_FREQUENCY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351843
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MARKER_PATTERN                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351844
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MARKER_OFF_TIME                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351845
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MARKER_ON_TIME                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351846
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MARKER_PULSE_WIDTH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351847
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MARKER_DELAY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351848
#define RSRFSIGGEN_ATTR_SATNAV_GLON_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351849
#define RSRFSIGGEN_ATTR_SATNAV_GLON_FIXED_MARKER_DELAY_MAXIMUM                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351850
#define RSRFSIGGEN_ATTR_SATNAV_GLON_FIXED_MARKER_DELAY_MINIMUM                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351851
#define RSRFSIGGEN_ATTR_SATNAV_GLON_CLOCK_SYNCHRONIZATION_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351852
#define RSRFSIGGEN_ATTR_SATNAV_GLON_CLOCK_SOURCE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351853
#define RSRFSIGGEN_ATTR_SATNAV_GLON_CLOCK_MODE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351854
#define RSRFSIGGEN_ATTR_SATNAV_GLON_CHIP_CLOCK_MULTIPLIER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351855
#define RSRFSIGGEN_ATTR_SATNAV_GLON_USER_ENVIRONMENT_VEHICLE_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351856
#define RSRFSIGGEN_ATTR_SATNAV_GLON_USER_ENVIRONMENT_VEHICLE_PREDEFINED_CATALOG                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351857
#define RSRFSIGGEN_ATTR_SATNAV_GLON_USER_ENVIRONMENT_VEHICLE_USER_CATALOG                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351858
#define RSRFSIGGEN_ATTR_SATNAV_GLON_USER_ENVIRONMENT_VEHICLE_LOAD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351859
#define RSRFSIGGEN_ATTR_SATNAV_GLON_LOC_CATALOG                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351860
#define RSRFSIGGEN_ATTR_SATNAV_GLON_LOC_SELECT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351861
#define RSRFSIGGEN_ATTR_SATNAV_GLON_LOC_WAYPOINT_FILE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351862
#define RSRFSIGGEN_ATTR_SATNAV_GLON_LOC_YAW                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351863
#define RSRFSIGGEN_ATTR_SATNAV_GLON_LOC_FROM_MOTION_YAW                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351864
#define RSRFSIGGEN_ATTR_SATNAV_GLON_LOC_PITCH                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351865
#define RSRFSIGGEN_ATTR_SATNAV_GLON_LOC_FROM_MOTION_PITCH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351866
#define RSRFSIGGEN_ATTR_SATNAV_GLON_LOC_ROLL                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351867
#define RSRFSIGGEN_ATTR_SATNAV_GLON_LOC_CONSTANT_RATE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351868
#define RSRFSIGGEN_ATTR_SATNAV_GLON_LOC_START_ROLL_ANGLE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351869
#define RSRFSIGGEN_ATTR_SATNAV_GLON_LOC_SMOOTH_MOVEMENT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351870
#define RSRFSIGGEN_ATTR_SATNAV_GLON_OBSCURATION_TYPE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351871
#define RSRFSIGGEN_ATTR_SATNAV_GLON_OBSCURATION_NEAR_ENVIRONMENT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351872
#define RSRFSIGGEN_ATTR_SATNAV_GLON_OBSCURATION_PHYSICAL_MODEL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351873
#define RSRFSIGGEN_ATTR_SATNAV_GLON_OBSCURATION_RECEIVER_OFFSET_X                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351874
#define RSRFSIGGEN_ATTR_SATNAV_GLON_OBSCURATION_RECEIVER_OFFSET_Y                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351875
#define RSRFSIGGEN_ATTR_SATNAV_GLON_OBSCURATION_RECEIVER_HEIGHT_OFFSET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351876
#define RSRFSIGGEN_ATTR_SATNAV_GLON_OBSCURATION_MAP_ORIENTATION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351877
#define RSRFSIGGEN_ATTR_SATNAV_GLON_OBSCURATION_OBSTACLES_PREDEFINED_CATALOG                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351878
#define RSRFSIGGEN_ATTR_SATNAV_GLON_OBSCURATION_ROADSIDE_PREDEFINED_CATALOG                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351879
#define RSRFSIGGEN_ATTR_SATNAV_GLON_OBSCURATION_OBSTACLES_USER_CATALOG                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351880
#define RSRFSIGGEN_ATTR_SATNAV_GLON_OBSCURATION_ROADSIDE_USER_CATALOG                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351881
#define RSRFSIGGEN_ATTR_SATNAV_GLON_OBSCURATION_AREA_INSERT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351882
#define RSRFSIGGEN_ATTR_SATNAV_GLON_OBSCURATION_AREA_DELETE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351883
#define RSRFSIGGEN_ATTR_SATNAV_GLON_OBSCURATION_AREA_REFERENCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351884
#define RSRFSIGGEN_ATTR_SATNAV_GLON_OBSCURATION_AREA_LENGTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351885
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_ENABLED_GPS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352495
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_ENABLED_GALILEO                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352496
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_ENABLED_GLONASS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352497
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_ENABLED_BEIDOU                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352498
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_TAP_GPS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352499
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_TAP_GALILEO                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352500
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_TAP_GLONASS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352501
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_TAP_BEIDOU                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352502
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_CARRIER_PHASE_GPS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352503
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_CARRIER_PHASE_GALILEO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352504
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_CARRIER_PHASE_GLONASS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352505
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_CARRIER_PHASE_BEIDOU                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352506
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_DOPPLER_SHIFT_GPS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352507
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_DOPPLER_SHIFT_GALILEO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352508
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_DOPPLER_SHIFT_GLONASS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352509
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_DOPPLER_SHIFT_BEIDOU                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352510
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_POWER_GPS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352511
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_POWER_GALILEO                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352512
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_POWER_GLONASS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352513
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_POWER_BEIDOU                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352514
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_DELAY_GPS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352515
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_DELAY_GALILEO                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352516
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_DELAY_GLONASS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352517
#define RSRFSIGGEN_ATTR_SATNAV_GLON_MPATH_DELAY_BEIDOU                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352518
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ANTENNA_PREDEFINED_CATALOG                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351886
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ANTENNA_USER_CATALOG                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351887
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ANTENNA_LOAD                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351888
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ANTENNA_LIST                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351889
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ANTENNA_ID                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351890
#define RSRFSIGGEN_ATTR_SATNAV_GLON_NAVIGATION_DATA_SOURCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351891
#define RSRFSIGGEN_ATTR_SATNAV_GLON_NAVIGATION_DATA_LIST                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351892
#define RSRFSIGGEN_ATTR_SATNAV_GLON_NAVIGATION_SYSTEM_TIME                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351893
#define RSRFSIGGEN_ATTR_SATNAV_GLON_NAVIGATION_WEEK_NUMBER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351894
#define RSRFSIGGEN_ATTR_SATNAV_GLON_NAVIGATION_TIME_OF_WEEK                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351895
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_LEAP_SECOND_SYNCHRONIZE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351896
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_LEAP_SECOND_CURRENT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351897
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_LEAP_SECOND_SIMULATE_TRANSITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351898
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_UTC_REFERENCE_DATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351899
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_UTC_A0                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351900
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_UTC_A1                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351901
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_PARAMETERS_A0_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351902
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_PARAMETERS_A0_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351903
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_PARAMETERS_A0_GLONASS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351904
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_PARAMETERS_A1_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351905
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_PARAMETERS_A1_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351906
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_PARAMETERS_A1_GLONASS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351907
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_PARAMETERS_T_OT_GPS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351908
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_PARAMETERS_T_OT_GALILEO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351909
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_PARAMETERS_T_OT_GLONASS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351910
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_PARAMETERS_WN_OT_GPS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351911
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_PARAMETERS_WN_OT_GALILEO                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351912
#define RSRFSIGGEN_ATTR_SATNAV_GLON_TCON_PARAMETERS_WN_OT_GLONASS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351913
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_POWER_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351914
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_REFERENCE_POWER                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351915
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_REFERENCE_SATELLITE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351916
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_TOTAL_POWER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351917
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_REFERENCE_STANDARD                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351918
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_REFERENCE_SIGNAL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351919
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_REFERENCE_DISTANCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351920
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_ELEVATION_MASK                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 351921
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_HDOP                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351922
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_PDOP                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351923
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_OPTIMAL_CONSTELLATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351924
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_TUNING_INTRA_ZERO                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351925
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_TUNING_INTRA_SET_TO_STANDARD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351926
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_TUNING_INTRA_CA_P                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351927
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_TUNING_INTER_ZERO                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351928
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_TUNING_INTER_SET_TO_STANDARD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351929
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_TUNING_INTER_CA_E1DEF                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351930
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_TUNING_INTER_CA_RCA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351931
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_TUNING_INTER_CA_TO_GEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352648
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ATMOSPHERIC_TROPOSPHERIC_MODEL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351932
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ATMOSPHERIC_IONOSPHERIC_MODEL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351933
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ATMOSPHERIC_GPS_ALPHA                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351934
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ATMOSPHERIC_KLOBUCHAR_ALPHA                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352702
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ATMOSPHERIC_GPS_BETA                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351935
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ATMOSPHERIC_KLOBUCHAR_BETA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352703
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ATMOSPHERIC_GALILEO_ALPHA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351936
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ATMOSPHERIC_GALILEO_SF                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351937
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_CONFIGURATION_EPHEMERIS_PROJECTION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351938
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_CONFIGURATION_NUMBER_OF_SATELLITES                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351939
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351940
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_STANDARD                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351941
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_SIGNALS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 351942
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_SPACE_VEHICLE_ID                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351943
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_POWER                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351944
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_STANDARD_CHIP_RATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351945
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_MODULATION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351946
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_DURATION                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351947
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_PSEUDORANGE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351948
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_PSEUDORANGE_BIAS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351949
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_TIME_SHIFT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351950
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_INITIAL_CARRIER_PHASE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 351951
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_RESULTING_START_FREQUENCY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351952
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_RESULTING_START_CHIP_RATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351953
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_MESSAGE_NAVIGATION_PAGES                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351954
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_NAVIGATION_REAL_TIME_PROJECTION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351955
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_MESSAGE_SET_TO_ALMANAC                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 351956
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_MESSAGE_PROJECT_NAVIGATION_MESSAGE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 351957
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_MESSAGE_URA_INDEX                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351961
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351992
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_SYNCHRONIZE_ALL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351993
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_SYNCHRONIZE_SVID_GPS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351994
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_SYNCHRONIZE_SVID_GALILEO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351995
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_SYNCHRONIZE_SVID_GLONASS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351996
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_REF_SYNCHRONIZE_LOCATION_GPS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351997
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_REF_SYNCHRONIZE_LOCATION_GALILEO                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351998
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_REF_SYNCHRONIZE_LOCATION_GLONASS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351999
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_REF_UNCERTAINLY_RADIUS_GPS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352000
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_REF_UNCERTAINLY_RADIUS_GALILEO                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352001
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_REF_UNCERTAINLY_RADIUS_GLONASS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352002
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_SYNCHRONIZE_GPS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352003
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_SYNCHRONIZE_GALILEO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352004
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_SYNCHRONIZE_GLONASS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352005
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_TIME_BASIS_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352006
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_TIME_BASIS_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352007
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_TIME_BASIS_GLONASS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352008
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_WEEK_NUMBER_GPS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352009
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_WEEK_NUMBER_GALILEO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352010
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_WEEK_NUMBER_GLONASS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352011
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_TIME_OF_WEEK_GPS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352012
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_TIME_OF_WEEK_GALILEO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352013
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_TIME_OF_WEEK_GLONASS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352014
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_DURATION_GPS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352015
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_DURATION_GALILEO                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352016
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_DURATION_GLONASS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352017
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_RESOLUTION_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352018
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_TOA_RESOLUTION_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352019
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_SVID_ENABLED_GPS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352020
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_SVID_ENABLED_GALILEO                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352021
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_SVID_ENABLED_GLONASS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352022
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_GENERATE_ALMANAC_FILE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352023
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_GENERATE_NAVIGATION_FILE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352024
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_GENERATE_ACQUISITION_FILE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352025
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_GENERATE_IONOSPHERIC_FILE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352026
#define RSRFSIGGEN_ATTR_SATNAV_GLON_ADG_GENERATE_UTC_FILE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352027
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_GLOBAL_SIGNAL_COUPLING                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352605
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_GLOBAL_SIGNAL_GPS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352606
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_GLOBAL_SIGNAL_GALILEO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352607
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_GLOBAL_SIGNAL_GLONASS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352608
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_GLOBAL_SIGNAL_BEIDOU                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352609
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_GLOBAL_POWER_GPS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352610
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_GLOBAL_POWER_GALILEO                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352611
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_GLOBAL_POWER_GLONASS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352612
#define RSRFSIGGEN_ATTR_SATNAV_GLON_SAT_GLOBAL_POWER_BEIDOU                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352613
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352099
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_RF_BAND                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352100
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SIMULATION_MODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352101
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SET_TO_DEFAULT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352102
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_FAST_STORING                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352103
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SETTINGS_CATALOG                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352104
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_DELETE_SETTINGS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352105
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_RECALL_SETTINGS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352107
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAVE_SETTINGS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352109
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_GNSS_ENABLED_GPS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352111
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_GNSS_ENABLED_GALILEO                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352112
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_GNSS_ENABLED_GLONASS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352113
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_GNSS_USE_COMMON_RF_FREQUENCY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352114
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_GNSS_P_CODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352115
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_GNSS_ANTI_SPOOFING                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352116
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_FILE_BEIDOU                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352117
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_FILE_GPS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352119
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_FILE_GALILEO                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352121
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_FILE_GLONASS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352123
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_WEEK_NUMBER_BEIDOU                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352125
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_WEEK_NUMBER_GPS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352126
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_WEEK_NUMBER_GALILEO                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352127
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_WEEK_SPAN_BEGIN_BEIDOU                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352128
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_WEEK_SPAN_BEGIN_GPS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352129
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_WEEK_SPAN_BEGIN_GALILEO                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352130
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_WEEK_SPAN_END_BEIDOU                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352131
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_WEEK_SPAN_END_GPS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352132
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_WEEK_SPAN_END_GALILEO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352133
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_TOAP_WEEK_NUMBER_BEIDOU                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352134
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_TOAP_WEEK_NUMBER_GPS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352135
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_TOAP_WEEK_NUMBER_GALILEO                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352136
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_TOAP_TIME_OF_WEEK_BEIDOU                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352137
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_TOAP_TIME_OF_WEEK_GPS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352138
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_TOAP_TIME_OF_WEEK_GALILEO                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352139
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_TOAP_DATE_GLONASS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352140
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ALMANAC_TOAP_TIME_GLONASS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352141
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_RINEX_FILE_BEIDOU                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352142
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_RINEX_ENABLED_BEIDOU                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352566
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_RINEX_FILE_GPS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352144
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_RINEX_ENABLED_GPS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352567
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_RINEX_FILE_GALILEO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352146
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_RINEX_ENABLED_GALILEO                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352568
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_RINEX_FILE_GLONASS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352148
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_RINEX_ENABLED_GLONASS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352569
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_RINEX_UTC                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352150
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_RINEX_UPDATE_FREQUENCY_GLONASS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352151
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_RINEX_IMPORT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352152
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_GNSS_VALID_SATELLITES_GPS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352655
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_GNSS_VALID_SATELLITES_GALILEO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352656
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_GNSS_VALID_SATELLITES_GLONASS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352657
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_GNSS_VALID_SATELLITES_BEIDOU                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352658
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TRIGGER_STATUS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352153
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TRIGGER_ARM                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352154
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TRIGGER_EXECUTE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352155
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TRIGGER_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352156
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TRIGGER_SOURCE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352157
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352158
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TRIGGER_SIGNAL_DURATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352159
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_EXTERNAL_TRIGGER_DELAY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352160
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_EXTERNAL_TRIGGER_INHIBIT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352161
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MARKER_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352162
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MARKER_PULSE_DIVIDER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352163
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MARKER_PULSE_FREQUENCY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352164
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MARKER_PATTERN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352165
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MARKER_OFF_TIME                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352166
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MARKER_ON_TIME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352167
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MARKER_PULSE_WIDTH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352168
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MARKER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352169
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352170
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_FIXED_MARKER_DELAY_MAXIMUM                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352171
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_FIXED_MARKER_DELAY_MINIMUM                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352172
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_CLOCK_SYNCHRONIZATION_MODE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352173
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_CLOCK_SOURCE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352174
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_CLOCK_MODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352175
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_CHIP_CLOCK_MULTIPLIER                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352176
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_USER_ENVIRONMENT_VEHICLE_TYPE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352177
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_USER_ENVIRONMENT_VEHICLE_PREDEFINED_CATALOG                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352178
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_USER_ENVIRONMENT_VEHICLE_USER_CATALOG                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352179
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_USER_ENVIRONMENT_VEHICLE_LOAD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352180
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_LOC_CATALOG                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352182
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_LOC_SELECT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352183
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_LOC_WAYPOINT_FILE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352184
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_LOC_YAW                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352188
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_LOC_FROM_MOTION_YAW                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352189
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_LOC_PITCH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352190
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_LOC_FROM_MOTION_PITCH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352191
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_LOC_ROLL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352192
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_LOC_CONSTANT_RATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352193
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_LOC_START_ROLL_ANGLE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352194
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_LOC_SMOOTH_MOVEMENT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352195
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_OBSCURATION_TYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352196
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_OBSCURATION_NEAR_ENVIRONMENT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352197
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_OBSCURATION_PHYSICAL_MODEL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352198
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_OBSCURATION_RECEIVER_OFFSET_X                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352199
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_OBSCURATION_RECEIVER_OFFSET_Y                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352200
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_OBSCURATION_RECEIVER_HEIGHT_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352201
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_OBSCURATION_MAP_ORIENTATION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352202
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_OBSCURATION_OBSTACLES_PREDEFINED_CATALOG                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352203
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_OBSCURATION_ROADSIDE_PREDEFINED_CATALOG                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352204
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_OBSCURATION_OBSTACLES_USER_CATALOG                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352205
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_OBSCURATION_ROADSIDE_USER_CATALOG                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352206
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_OBSCURATION_AREA_INSERT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352207
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_OBSCURATION_AREA_DELETE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352208
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_OBSCURATION_AREA_REFERENCE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352209
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_OBSCURATION_AREA_LENGTH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352210
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_ENABLED_GPS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352535
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_ENABLED_GALILEO                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352536
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_ENABLED_GLONASS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352537
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_ENABLED_BEIDOU                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352538
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_TAP_GPS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352539
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_TAP_GALILEO                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352540
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_TAP_GLONASS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352541
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_TAP_BEIDOU                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352542
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_CARRIER_PHASE_GPS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352543
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_CARRIER_PHASE_GALILEO                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352544
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_CARRIER_PHASE_GLONASS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352545
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_CARRIER_PHASE_BEIDOU                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352546
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_DOPPLER_SHIFT_GPS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352547
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_DOPPLER_SHIFT_GALILEO                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352548
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_DOPPLER_SHIFT_GLONASS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352549
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_DOPPLER_SHIFT_BEIDOU                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352550
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_POWER_GPS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352551
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_POWER_GALILEO                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352552
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_POWER_GLONASS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352553
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_POWER_BEIDOU                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352554
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_DELAY_GPS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352555
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_DELAY_GALILEO                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352556
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_DELAY_GLONASS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352557
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_MPATH_DELAY_BEIDOU                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352558
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ANTENNA_PREDEFINED_CATALOG                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352211
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ANTENNA_USER_CATALOG                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352212
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ANTENNA_LOAD                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352213
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ANTENNA_LIST                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352215
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ANTENNA_ID                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352216
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_NAVIGATION_DATA_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352218
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_NAVIGATION_DATA_LIST                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352219
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_NAVIGATION_SYSTEM_TIME                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352221
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_NAVIGATION_WEEK_NUMBER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352222
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_NAVIGATION_TIME_OF_WEEK                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352223
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_LEAP_SECOND_SYNCHRONIZE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352226
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_LEAP_SECOND_CURRENT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352227
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_LEAP_SECOND_SIMULATE_TRANSITION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352228
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_UTC_REFERENCE_DATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352229
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_UTC_A0                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352230
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_UTC_A1                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352231
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_PARAMETERS_A0_BEIDOU                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352232
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_PARAMETERS_A0_GPS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352233
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_PARAMETERS_A0_GALILEO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352234
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_PARAMETERS_A0_GLONASS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352235
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_PARAMETERS_A1_BEIDOU                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352236
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_PARAMETERS_A1_GPS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352237
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_PARAMETERS_A1_GALILEO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352238
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_PARAMETERS_A1_GLONASS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352239
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_PARAMETERS_T_OT_BEIDOU                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352240
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_PARAMETERS_T_OT_GPS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352241
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_PARAMETERS_T_OT_GALILEO                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352242
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_PARAMETERS_T_OT_GLONASS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352243
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_PARAMETERS_WN_OT_BEIDOU                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352244
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_PARAMETERS_WN_OT_GPS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352245
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_PARAMETERS_WN_OT_GALILEO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352246
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_TCON_PARAMETERS_WN_OT_GLONASS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352247
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_POWER_MODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352248
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_REFERENCE_POWER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352249
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_REFERENCE_SATELLITE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352250
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_TOTAL_POWER                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352251
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_REFERENCE_STANDARD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352252
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_REFERENCE_SIGNAL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352253
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_REFERENCE_DISTANCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352254
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_ELEVATION_MASK                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352255
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_HDOP                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352256
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_PDOP                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352257
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_OPTIMAL_CONSTELLATION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352258
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_TUNING_INTRA_ZERO                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352259
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_TUNING_INTRA_SET_TO_STANDARD                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352260
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_TUNING_INTRA_CA_P                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352261
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_TUNING_INTER_ZERO                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352262
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_TUNING_INTER_SET_TO_STANDARD                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352263
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_TUNING_INTER_CA_E1DEF                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352264
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_TUNING_INTER_CA_RCA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352265
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_TUNING_INTER_CA_TO_GEO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352659
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ATMOSPHERIC_TROPOSPHERIC_MODEL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352266
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ATMOSPHERIC_IONOSPHERIC_MODEL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352267
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ATMOSPHERIC_BEIDOU_ALPHA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352268
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ATMOSPHERIC_KLOBUCHAR_ALPHA                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352704
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ATMOSPHERIC_BEIDOU_BETA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352269
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ATMOSPHERIC_KLOBUCHAR_BETA                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352705
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ATMOSPHERIC_GALILEO_ALPHA                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352270
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ATMOSPHERIC_GALILEO_SF                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352271
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_CONFIGURATION_EPHEMERIS_PROJECTION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352272
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_CONFIGURATION_NUMBER_OF_SATELLITES                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352273
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352274
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_STANDARD                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352275
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_SIGNALS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352276
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_SPACE_VEHICLE_ID                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352277
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_POWER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352278
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_STANDARD_CHIP_RATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352279
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MODULATION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352280
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_ORBIT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352706
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_DURATION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352281
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_PSEUDORANGE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352282
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_PSEUDORANGE_BIAS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352283
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_TIME_SHIFT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352284
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_INITIAL_CARRIER_PHASE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352285
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_RESULTING_START_FREQUENCY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352286
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_RESULTING_START_CHIP_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352287
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_NAVIGATION_PAGES                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352288
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_NAVIGATION_REAL_TIME_PROJECTION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352289
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_SET_TO_ALMANAC                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352290
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_PROJECT_NAVIGATION_MESSAGE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352291
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_URA_INDEX                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352292
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_SV_HEALTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352293
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_IODC                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352294
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_IODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352295
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_TOE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352296
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_M0                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352297
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_N_DELTA                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352298
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_ECCENTRICITY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352299
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_SQRTA                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352300
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_OMEGA0                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352301
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_I0                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352302
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_OMEGA                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352303
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_OMEGA_DOT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352304
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_IDOT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352305
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_CUC                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352306
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_CUS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352307
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_CRC                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352308
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_CRS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352309
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_CIC                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352310
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_MESSAGE_CIS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352311
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_CLOCK_TGD                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352312
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_CLOCK_TGD_UNSCALED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361521
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_CLOCK_TOC                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352313
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_CLOCK_TOC_UNSCALED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361522
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_CLOCK_AF0                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352314
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_CLOCK_AF0_UNSCALED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361523
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_CLOCK_AF1                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352315
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_CLOCK_AF1_UNSCALED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361524
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_CLOCK_AF2                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352316
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_CLOCK_AF2_UNSCALED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361525
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_MODE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352318
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_SYNCHRONIZE_ALL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352319
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_SYNCHRONIZE_SVID_GPS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352320
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_SYNCHRONIZE_SVID_BEIDOU                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352321
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_SYNCHRONIZE_SVID_GALILEO                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352322
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_SYNCHRONIZE_SVID_GLONASS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352323
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_REF_SYNCHRONIZE_LOCATION_BEIDOU                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352324
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_REF_SYNCHRONIZE_LOCATION_GPS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352325
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_REF_SYNCHRONIZE_LOCATION_GALILEO                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352326
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_REF_SYNCHRONIZE_LOCATION_GLONASS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352327
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_REF_UNCERTAINLY_RADIUS_BEIDOU                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352336
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_REF_UNCERTAINLY_RADIUS_GPS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352337
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_REF_UNCERTAINLY_RADIUS_GALILEO                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352338
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_REF_UNCERTAINLY_RADIUS_GLONASS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352339
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_SYNCHRONIZE_BEIDOU                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352340
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_SYNCHRONIZE_GPS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352341
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_SYNCHRONIZE_GALILEO                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352342
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_SYNCHRONIZE_GLONASS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352343
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_TIME_BASIS_BEIDOU                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352344
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_TIME_BASIS_GPS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352345
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_TIME_BASIS_GALILEO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352346
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_TIME_BASIS_GLONASS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352347
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_WEEK_NUMBER_BEIDOU                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352348
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_WEEK_NUMBER_GPS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352349
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_WEEK_NUMBER_GALILEO                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352350
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_WEEK_NUMBER_GLONASS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352351
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_TIME_OF_WEEK_BEIDOU                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352352
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_TIME_OF_WEEK_GPS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352353
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_TIME_OF_WEEK_GALILEO                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352354
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_TIME_OF_WEEK_GLONASS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352355
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_DURATION_BEIDOU                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352356
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_DURATION_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352357
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_DURATION_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352358
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_DURATION_GLONASS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352359
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_RESOLUTION_BEIDOU                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352360
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_RESOLUTION_GPS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352361
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_TOA_RESOLUTION_GALILEO                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352362
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_SVID_ENABLED_BEIDOU                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352363
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_SVID_ENABLED_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352364
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_SVID_ENABLED_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352365
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_SVID_ENABLED_GLONASS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352366
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_GENERATE_ALMANAC_FILE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352367
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_GENERATE_NAVIGATION_FILE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352369
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_GENERATE_ACQUISITION_FILE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352371
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_GENERATE_IONOSPHERIC_FILE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352373
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_ADG_GENERATE_UTC_FILE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352375
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_GLOBAL_SIGNAL_COUPLING                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352614
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_GLOBAL_SIGNAL_GPS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352615
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_GLOBAL_SIGNAL_GALILEO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352616
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_GLOBAL_SIGNAL_GLONASS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352617
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_GLOBAL_SIGNAL_BEIDOU                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352618
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_GLOBAL_POWER_GPS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352619
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_GLOBAL_POWER_GALILEO                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352620
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_GLOBAL_POWER_GLONASS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352621
#define RSRFSIGGEN_ATTR_SATNAV_BEIDOU_SAT_GLOBAL_POWER_BEIDOU                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352622
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_BEIDOU_SVID_LIST_VALID                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361936
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GALILEO_SVID_LIST_VALID                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361937
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GLONASS_SVID_LIST_VALID                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361938
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GPS_SVID_LIST_VALID                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361939
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_NAVIC_SVID_LIST_VALID                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361940
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_QZSS_SVID_LIST_VALID                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361941
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_SVID_LIST_VALID                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361942
#define RSRFSIGGEN_ATTR_QUERY_GNSS_CENTRAL_RF_FREQUENCY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361526
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ENABLED                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361943
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SET_TO_DEFAULT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361944
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SETTINGS_CATALOG                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361945
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SAVE_SETTINGS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361946
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOAD_SETTINGS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361947
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_DELETE_SETTINGS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361948
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_PREDEFINED_SCENARIO_CATALOG                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361949
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOAD_PREDEFINED_SCENARIO                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361950
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SCENARIO                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361951
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIMULATION_CONFIG_INFO                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361952
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TEST_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361953
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SCALED_VALUES_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361954
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_PSEUDORANGE_ERRORS_CATALOG                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362792
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIMULATED_ORBIT_GLONASS_XN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361957
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIMULATED_ORBIT_GLONASS_YN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361958
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIMULATED_ORBIT_GLONASS_ZN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361959
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIMULATED_ORBIT_GLONASS_XN_DOT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361960
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIMULATED_ORBIT_GLONASS_YN_DOT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361961
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIMULATED_ORBIT_GLONASS_ZN_DOT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361962
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIMULATED_ORBIT_GLONASS_XN_DOT_DOT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361963
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIMULATED_ORBIT_GLONASS_YN_DOT_DOT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361964
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIMULATED_ORBIT_GLONASS_ZN_DOT_DOT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361965
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_BEIDOU_SIMULATED_CLOCK_AF_GROUP_DELAY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361968
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_CONFLICT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358624
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_OUTPUT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358625
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_LOCK_STATE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358626
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_OUTPUT_RESET                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358627
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_STREAM_CONFLICT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358628
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_VEHICLE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361969
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_ANTENNA                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361970
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_RF_BAND                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358629
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_MAX_NUMBER_OF_CHANNELS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358630
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_NUMBER_OF_BASEBANDS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358631
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_ALLOCATED_BASEBAND_SOURCE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358632
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_BASEBANDS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358633
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_MAX_CHANNELS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361572
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_L1_BAND_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361573
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_L2_BAND_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361574
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_L5_BAND_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361575
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_OUTPUTS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361576
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_BBMM_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358634
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_STREAM_RF_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358635
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_TYPE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358636
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_VEHICLE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358637
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_ANTENNA                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358638
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_MAP_AXIS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358639
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SHOW_TRACKS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358640
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SHOW_SV_ID                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358641
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_TRAJECTORY_SYSTEM                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358642
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SHOW_ECHOES                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358643
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_STREAM                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358644
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_NUMBER_OF_CHANNELS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358645
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_ACTIVE_CHANNELS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358646
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_BEIDOU_L1_BAND_B1C                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361971
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_BEIDOU_L1_BAND_B1I                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361972
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_BEIDOU_L2_BAND_B2I                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361973
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_BEIDOU_L2_BAND_B3I                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361974
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_BEIDOU_L5_BAND_B2A                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361975
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_BEIDOU_L5_BAND_B2B                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363401
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_BEIDOU_L5_BAND_B2I                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361976
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GALILEO_L1_BAND_E1OS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358649
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GALILEO_L1_BAND_E1PRS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363109
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GALILEO_L2_BAND_E6S                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361577
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GALILEO_L2_BAND_E6PRS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363110
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GALILEO_L5_BAND_E5A                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358650
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GALILEO_L5_BAND_E5B                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358651
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GLONASS_L1_BAND_CA                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358652
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GLONASS_L2_BAND_CA                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358653
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GLONASS_L1_BAND_CDMA                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362793
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GLONASS_L2_BAND_CDMA                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362794
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GLONASS_L5_BAND_CDMA                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362795
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_QZSS_L1_BAND_CA                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358654
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_QZSS_L2_BAND_L2C                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361977
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GZSS_L5_BAND_L5S                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361978
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_QZSS_L1_BAND_C                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362796
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_SBAS_L1_BAND_CA                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358655
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_SBAS_L5_BAND_EL5S                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361979
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GPS_L5_BAND_L5S                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358656
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GPS_L2_BAND_CA                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358657
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GPS_L2_BAND_L2C                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358658
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GPS_L2_BAND_P                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358659
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GPS_L2_BAND_M                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363111
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GPS_L2_BAND_PY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363112
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GPS_L1_BAND_P                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358660
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GPS_L1_BAND_CA                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358661
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GPS_L1_BAND_C                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362797
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GPS_L1_BAND_M                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363113
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_GPS_L1_BAND_PY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363114
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MONITOR_SIGNAL_NAVIC_L5_BAND_SPS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361980
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TROPOSPHERIC_MODEL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358662
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_IONOSPHERIC_MODEL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358663
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_IONOSPHERIC_SOLAR_FLUX                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358664
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_IONOSPHERIC_SUNSPOT_NUMBER                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358665
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_IONOSPHERIC_UMSN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358666
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_IONOSPHERIC_MOPS_FILE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358667
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_IONOSPHERIC_MOPS_DISPLAY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358669
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_IONOSPHERIC_MOPS_EXPORT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358670
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MOPS_IMPORT_ADD_EMS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358672
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MOPS_IMPORT_ADD_NSTB                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358674
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MOPS_IMPORT_ADD_GRID                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358676
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MOPS_IMPORT_ADD_DIRECTORY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358678
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MOPS_IMPORT_LIST                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358679
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MOPS_IMPORT_EXECUTE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358680
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MOPS_IMPORT_REMOVE_ALL_FILES                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358681
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MOPS_IMPORT_REMOVE_FILE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361981
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_IONOSPHERIC_KLOBUCHAR_ALPHA_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358682
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_IONOSPHERIC_KLOBUCHAR_BETA_UNSCALED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358683
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GPS_CNAV_IONOSPHERIC_ALPHA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358688
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GPS_CNAV_IONOSPHERIC_ALPHA_UNSCALED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358689
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GPS_CNAV_IONOSPHERIC_BETA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358700
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GPS_CNAV_IONOSPHERIC_BETA_UNSCALED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358701
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GPS_LNAV_IONOSPHERIC_ALPHA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358690
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GPS_LNAV_IONOSPHERIC_ALPHA_UNSCALED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358691
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GPS_LNAV_IONOSPHERIC_BETA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358702
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GPS_LNAV_IONOSPHERIC_BETA_UNSCALED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358703
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GALILEO_IONOSPHERIC_AI                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358692
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GALILEO_IONOSPHERIC_AI_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358693
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GALILEO_INAV_IONOSPHERIC_AI                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358694
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GALILEO_INAV_IONOSPHERIC_AI_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358695
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_BEIDOU_IONOSPHERIC_ALPHA                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358686
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_BEIDOU_IONOSPHERIC_ALPHA_UNSCALED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358687
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_BEIDOU_IONOSPHERIC_BETA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358698
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_BEIDOU_IONOSPHERIC_BETA_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358699
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_BEIDOU_DNAV_IONOSPHERIC_ALPHA                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361982
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_BEIDOU_DNAV_IONOSPHERIC_ALPHA_UNSCALED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361983
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_BEIDOU_DNAV_IONOSPHERIC_BETA                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361984
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_BEIDOU_DNAV_IONOSPHERIC_BETA_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361985
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_BEIDOU_CNAV_IONOSPHERIC_ALPHA                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361986
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_BEIDOU_CNAV_IONOSPHERIC_ALPHA_UNSCALED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361987
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_BEIDOU_CNAV_IONOSPHERIC_BETA                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361988
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_BEIDOU_CNAV_IONOSPHERIC_BETA_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361989
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_QZSS_IONOSPHERIC_ALPHA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358684
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_QZSS_IONOSPHERIC_ALPHA_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358685
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_QZSS_IONOSPHERIC_BETA                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358696
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_QZSS_IONOSPHERIC_BETA_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358697
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_QZSS_NAV_IONOSPHERIC_ALPHA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361990
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_QZSS_NAV_IONOSPHERIC_ALPHA_UNSCALED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361991
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_QZSS_NAV_IONOSPHERIC_BETA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361992
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_QZSS_NAV_IONOSPHERIC_BETA_UNSCALED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361993
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_QZSS_CNAV_IONOSPHERIC_ALPHA                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361994
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_QZSS_CNAV_IONOSPHERIC_ALPHA_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361995
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_QZSS_CNAV_IONOSPHERIC_BETA                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361996
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_QZSS_CNAV_IONOSPHERIC_BETA_UNSCALED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361997
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_NAVIC_IONOSPHERIC_ALPHA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361578
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_NAVIC_IONOSPHERIC_ALPHA_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361579
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_NAVIC_IONOSPHERIC_BETA                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361580
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_NAVIC_IONOSPHERIC_BETA_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361581
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_IONOSPHERIC_GALILEO_FNAV_SF                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358704
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_IONOSPHERIC_GALILEO_INAV_SF                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358705
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADG_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358706
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADG_DATA_FORMAT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358707
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADG_CREATE_ACQUISITION_FILE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358723
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADG_CREATE_ALMANAC_FILE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358725
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADG_CREATE_UTC_FILE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358727
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADG_CREATE_NAVIGATION_FILE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358729
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADG_CREATE_IONOSPHERIC_FILE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358731
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_IODNAV                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358734
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_IODNAV                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358735
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_L5_HEALTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361582
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_S_HEALTH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361583
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_IODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358736
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_AODO                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362798
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_IODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361584
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_IODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358737
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_IODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358738
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_NAV_TOE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358739
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_TOE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358740
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_TOE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361585
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_TOE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361586
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_TOE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358741
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_TOE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358742
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_TOE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361998
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_TOE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358743
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_TOE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358744
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_TOE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358745
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_NAV_TOE_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358746
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_TOE_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358747
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_TOE_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361587
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_TOE_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358748
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_TOE_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358749
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_TOE_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361999
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_TOE_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358750
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_TOE_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358751
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_TOE_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358752
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_TOE_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361588
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_SQRTA                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358753
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_SQRTA                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361589
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_SQRTA                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361590
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_SQRTA                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358754
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_SQRTA                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358755
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_SQRTA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362000
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_SQRTA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358756
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_SQRTA                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358757
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_SQRTA                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358758
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_SQRTA_UNSCALED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358759
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_SQRTA_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361591
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_SQRTA_UNSCALED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358760
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_SQRTA_UNSCALED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358761
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_SQRTA_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362001
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_SQRTA_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358762
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_SQRTA_UNSCALED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358763
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_SQRTA_UNSCALED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358764
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_SQRTA_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361592
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_ECCENTRICITY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358765
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_ECCENTRICITY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361593
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_ECCENTRICITY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361594
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_ECCENTRICITY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358766
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_ECCENTRICITY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358767
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_ECCENTRICITY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362002
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_ECCENTRICITY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358768
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_ECCENTRICITY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358769
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_ECCENTRICITY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358770
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_ECCENTRICITY_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358771
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_ECCENTRICITY_UNSCALED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358772
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_ECCENTRICITY_UNSCALED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358773
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_ECCENTRICITY_UNSCALED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362003
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_ECCENTRICITY_UNSCALED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358774
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_ECCENTRICITY_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358775
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_ECCENTRICITY_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358776
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_ECCENTRICITY_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361595
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_ECCENTRICITY_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361596
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_INCLINATION_ANGLE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358777
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_INCLINATION_ANGLE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361597
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_INCLINATION_ANGLE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361598
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_INCLINATION_ANGLE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358778
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_INCLINATION_ANGLE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358779
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_INCLINATION_ANGLE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362004
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_INCLINATION_ANGLE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358780
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_INCLINATION_ANGEL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358781
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_INCLINATION_ANGEL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358782
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_INCLINATION_ANGLE_UNSCALED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358783
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_INCLINATION_ANGLE_UNSCALED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361599
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_INCLINATION_ANGLE_UNSCALED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358784
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_INCLINATION_ANGLE_UNSCALED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358785
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_INCLINATION_ANGLE_UNSCALED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362005
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_INCLINATION_ANGLE_UNSCALED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358786
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_INCLINATION_ANGEL_UNSCALED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358787
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_INCLINATION_ANGEL_UNSCALED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358788
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_INCLINATION_ANGLE_UNSCALED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361600
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_OMEGA0                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358789
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_OMEGA0                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361601
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_OMEGA0                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361602
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_OMEGA0                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358790
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_OMEGA0                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358791
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_OMEGA0                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362006
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_OMEGA0                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358792
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_OMEGA0                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358793
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_OMEGA0                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358794
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_OMEGA0_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358795
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_OMEGA0_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361603
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_OMEGA0_UNSCALED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358796
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_OMEGA0_UNSCALED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358797
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_OMEGA0_UNSCALED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362007
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_OMEGA0_UNSCALED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358798
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_OMEGA0_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358799
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_OMEGA0_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358800
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_OMEGA0_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361604
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_OMEGA                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358801
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_OMEGA                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361605
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_OMEGA                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361606
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_OMEGA                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358802
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_OMEGA                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358803
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_OMEGA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362008
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_OMEGA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358804
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_OMEGA                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358805
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_OMEGA                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358806
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_OMEGA_UNSCALED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358807
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_OMEGA_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361607
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_OMEGA_UNSCALED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358808
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_OMEGA_UNSCALED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358809
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_OMEGA_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362009
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_OMEGA_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358810
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_OMEGA_UNSCALED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358811
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_OMEGA_UNSCALED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358812
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_OMEGA_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361608
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_M0                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358813
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_M0                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361609
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_M0                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361610
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_M0                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358814
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_M0                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358815
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_M0                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362010
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_M0                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358816
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_M0                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358817
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_M0                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358818
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_M0_UNSCALED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358819
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_M0_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361611
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_M0_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358820
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_M0_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358821
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_M0_UNSCALED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362011
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_M0_UNSCALED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358822
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_M0_UNSCALED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358823
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_M0_UNSCALED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358824
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_M0_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361612
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_IDOT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358825
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_IDOT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361613
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_IDOT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361614
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_IDOT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358826
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_IDOT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358827
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_IDOT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362012
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_IDOT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358828
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_IDOT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358829
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_IDOT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358830
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_IDOT_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358831
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_IDOT_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358832
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_IDOT_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358833
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_IDOT_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362013
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_IDOT_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358834
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_IDOT_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358835
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_IDOT_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 358836
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_IDOT_UNSCALED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361615
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_IDOT_UNSCALED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361616
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_OMEGADOT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358837
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_OMEGADOT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361617
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_OMEGADOT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361618
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_OMEGADOT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358838
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_OMEGADOT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358839
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_OMEGADOT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362014
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_OMEGADOT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358840
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_OMEGADOT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358841
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_OMEGADOT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 358842
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_OMEGADOT_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358843
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_OMEGADOT_UNSCALED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361619
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_OMEGADOT_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358844
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_OMEGADOT_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358845
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_OMEGADOT_UNSCALED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362015
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_OMEGADOT_UNSCALED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358846
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_OMEGADOT_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358847
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_OMEGADOT_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358848
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_OMEGADOT_UNSCALED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361620
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_DELTA_OMEGA_DOT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358849
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_DELTA_OMEGA_DOT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361621
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_DELTA_OMEGA_DOT_UNSCALED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358850
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_DELTA_OMEGA_DOT_UNSCALED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361622
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_DELTA_N                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358851
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_DELTA_N                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361623
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_DELTA_N                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361624
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_DELTA_N                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358852
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_DELTA_N                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358853
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_DELTA_N                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362016
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_DELTA_N                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358854
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_DELTA_N                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358855
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_DELTA_N                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358856
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_DELTA_N_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358857
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_DELTA_N_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361625
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_DELTA_N_UNSCALED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358858
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_DELTA_N_UNSCALED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 358859
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_DELTA_N_UNSCALED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362017
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_DELTA_N_UNSCALED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358860
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_DELTA_N_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358861
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_DELTA_N_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358862
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_DELTA_N_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361626
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_DELTA_N_DOT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358863
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_DELTA_N_DOT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362018
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_DELTA_N_DOT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361627
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_DELTA_N_DOT_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358864
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_DELTA_N_DOT_UNSCALED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362019
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_DELTA_N_DOT_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361628
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_A_DOT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358865
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_A_DOT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362020
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_A_DOT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361629
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_A_DOT_UNSCALED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358866
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_A_DOT_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362021
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_A_DOT_UNSCALED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361630
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_DELTA_A                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358867
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_DELTA_A                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362022
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_DELTA_A                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361631
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_DELTA_A_UNSCALED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358868
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_DELTA_A_UNSCALED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362023
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_DELTA_A_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361632
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_T_INTERVAL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358869
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GLONASS_TB_INDEX                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358871
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_GLONASS_TB_INDEX_UNSCALED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358872
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_XN                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358873
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_XN_UNSCALED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358874
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_YN                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358875
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_YN_UNSCALED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358876
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_ZN                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358877
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_ZN_UNSCALED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358878
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_XN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358879
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_XN_UNSCALED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358880
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_YN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358881
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_YN_UNSCALED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358882
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_ZN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 358883
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_ZN_UNSCALED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 358884
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_CDMA_FIELD_M                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362799
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_XN_DOT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358885
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_XN_DOT_UNSCALED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358886
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_YN_DOT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358887
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_YN_DOT_UNSCALED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358888
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_ZN_DOT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358889
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_ZN_DOT_UNSCALED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358890
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_XN_DOT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358891
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_XN_DOT_UNSCALED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358892
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_YN_DOT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358893
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_YN_DOT_UNSCALED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358894
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_ZN_DOT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 358895
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_ZN_DOT_UNSCALED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 358896
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_XN_DOT_DOT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358897
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_XN_DOT_DOT_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358898
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_YN_DOT_DOT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358899
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_YN_DOT_DOT_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358900
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_ZN_DOT_DOT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358901
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_ZN_DOT_DOT_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358902
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_XN_DOT_DOT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358903
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_XN_DOT_DOT_UNSCALED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358904
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_YN_DOT_DOT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358905
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_YN_DOT_DOT_UNSCALED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358906
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_ZN_DOT_DOT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 358907
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_ZN_DOT_DOT_UNSCALED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358908
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_CUC                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358909
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_CUC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361633
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_CUC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361635
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_CUC                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358910
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_CUC                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358911
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_CUC                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362024
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_CUC                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358912
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_CUC                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358913
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_CUC                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358914
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_CUC_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358915
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_CUC_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361634
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_CUC_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361636
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_CUC_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358916
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_CUC_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358917
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_CUC_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362025
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_CUC_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358918
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_CUC_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358919
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_CUC_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358920
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_CUS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358921
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_CUS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361637
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_CUS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361639
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_CUS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358922
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_CUS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358923
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_CUS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362026
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_CUS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358924
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_CUS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358925
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_CUS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358926
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_CUS_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358927
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_CUS_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361638
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_CUS_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361640
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_CUS_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358928
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_CUS_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358929
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_CUS_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362027
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_CUS_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358930
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_CUS_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358931
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_CUS_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358932
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_CRC                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358933
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_CRC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361641
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_CRC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361643
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_CRC                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358934
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_CRC                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358935
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_CRC                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362028
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_CRC                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358936
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_CRC                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358937
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_CRC                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358938
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_CRC_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358939
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_CRC_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361642
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_CRC_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361644
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_CRC_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358940
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_CRC_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358941
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_CRC_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362029
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_CRC_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358942
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_CRC_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358943
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_CRC_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358944
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_CRS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358945
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_CRS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361645
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_CRS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361647
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_CRS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358946
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_CRS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358947
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_CRS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362030
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_CRS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358948
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_CRS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358949
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_CRS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358950
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_CRS_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358951
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_CRS_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361646
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_CRS_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361648
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_CRS_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358952
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_CRS_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358953
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_CRS_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362031
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_CRS_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358954
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_CRS_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358955
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_CRS_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358956
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_CIC                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358961
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_CIC                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358962
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_CIC                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358957
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_CIC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361651
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_CIC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361649
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_CIC                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358958
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_CIC                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358959
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_CIC                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362032
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_CIC                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358960
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_CIC_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358963
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_CIC_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361652
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_CIC_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361650
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_CIC_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358964
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_CIC_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358965
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_CIC_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362033
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_CIC_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358966
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_CIC_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358967
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_CIC_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358968
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_CIS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358969
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_CIS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361653
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_CIS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361654
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_CIS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358970
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_CIS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358971
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_CIS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362034
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_CIS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358972
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_CIS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358973
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_CIS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358974
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_CIS_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358975
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_CIS_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361655
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_CIS_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358976
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_CIS_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358977
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_CIS_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362035
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_CIS_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358978
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_CIS_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358979
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_CIS_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358980
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_CIS_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361656
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_BROADCAST_GROUP_DELAY_A                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361657
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_BROADCAST_GROUP_DELAY_A                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361658
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_BROADCAST_GROUP_DELAY_B                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361659
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_BROADCAST_GROUP_DELAY_A_UNSCALED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361660
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_BROADCAST_GROUP_DELAY_A_UNSCALED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361661
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_BROADCAST_GROUP_DELAY_B_UNSCALED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361662
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_TOC                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358982
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_TOC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362036
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_TOC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361664
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_TOC                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358983
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_TOC                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 358984
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_TOC                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362037
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_TOC                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358985
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_TOC                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358986
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_TOC                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 358987
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_TOC_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358988
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_TOC_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362038
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_TOC_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361666
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_TOC_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358989
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_TOC_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 358990
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_TOC_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362039
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_TOC_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358991
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_TOC_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358992
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_TOC_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 358993
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_TGD                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362040
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_TGD                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362041
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_TGD                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362042
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_TGD1                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362043
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_TGD2                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362044
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_TGD                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362045
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_TGD                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362046
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_TGD                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361668
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_TGD_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362047
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_TGD_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362048
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_TGD_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362049
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_TGD1_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362050
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_TGD2_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362051
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_TGD_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362052
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_TGD_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362053
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_TGD_UNSCALED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361670
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_TAU                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 358996
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_TAU_UNSCALED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 358997
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_GAMMA_N                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 358998
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_GAMMA_N_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 358999
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_DELTA_TN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359000
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GLONASS_DELTA_TN_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359001
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_NAV_AF                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359002
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_AF                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359003
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_AF                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362054
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_AF                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361672
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_AF                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359004
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_AF                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359005
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_AF                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359006
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_AF                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362055
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_AF                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359007
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_AF                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359008
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_SBAS_NAV_AF_UNSCALED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359009
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_NAV_AF_UNSCALED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359010
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_QZSS_CNAV_AF_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361673
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_NAVIC_NAV_AF_UNSCALED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361674
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_FNAV_AF_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359011
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GALILEO_INAV_AF_UNSCALED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359012
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_DNAV_AF_UNSCALED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359013
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_BEIDOU_CNAV_AF_UNSCALED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362056
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_CNAV_AF_UNSCALED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359014
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ORBIT_GPS_LNAV_AF_UNSCALED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359015
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GPS_ALERT_FLAG                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359016
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_BEIDOU_ALERT_FLAG                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359877
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_QZSS_ALERT_FLAG                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361675
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GPS_L1_HEALTH_FLAG                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359017
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_QZSS_L1_HEALTH_FLAG                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361676
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GPS_L2_HEALTH_FLAG                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359018
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_QZSS_L2_HEALTH_FLAG                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361677
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GPS_L5_HEALTH_FLAG                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359019
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_QZSS_L5_HEALTH_FLAG                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361678
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GPS_URA                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359020
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GPS_NED0                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359021
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_QZSS_NED0                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361679
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GPS_NED1                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359022
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_QZSS_NED1                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361680
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GPS_NED2                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359023
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_QZSS_NED2                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361681
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GPS_WNOP                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359024
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GPS_TOP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359025
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GPS_TOP_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359026
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GPS_IS_FLAG                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359027
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_QZSS_IS_FLAG                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361682
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GPS_L2C_PHASING                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359028
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_QZSS_L2C_PHASING                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361683
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_QZSS_CNAV_URA                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361684
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GPS_ANTI_SPOOFING_FLAG                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359031
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GPS_AODO                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359036
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GALILEO_FNAV_SISA                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359038
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GALILEO_INAV_SISA                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359039
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GALILEO_E1BDVS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359040
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GALILEO_E5ADVS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359041
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GALILEO_E5BDVS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359042
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GALILEO_E1BHS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359043
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GALILEO_E5AHS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359044
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GALILEO_E5BHS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359045
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GLONASS_SATELLITE_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359046
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GLONASS_P                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359047
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GLONASS_AGE_OF_EMPHEMERIS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359048
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GLONASS_TB_ALIGNMENT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359049
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ADDITIONAL_DATA_GLONASS_EN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359050
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SAR_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359878
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SAR_SPARE_DATA                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359879
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SAR_RLM                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359880
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_START_TIME_BASIS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359051
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_WEEK_NUMBER                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359059
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_TIME_OF_WEEK                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359060
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_LEAP_AUTO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359061
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_UTC_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359068
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_UTCS_WNOT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359070
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_UTCS_TOT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359073
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_UTCS_TOT_UNSCALED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359074
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_UTCS_INTEGER_OFFSET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359076
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_UTCS_A0                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359079
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_UTCS_A0_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359080
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_UTCS_A1                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359083
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_UTCS_A1_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359084
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GLONASS_UTC_SU_A1                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362057
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GLONASS_UTC_SU_A1_UNSCALED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362058
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GLONASS_UTC_SU_A0                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362059
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GLONASS_UTC_SU_A0_UNSCALED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362060
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GLONASS_UTC_SU_TIME_OF_WEEK                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362061
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GLONASS_UTC_SU_TIME_OF_WEEK_UNSCALED                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362062
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GLONASS_UTC_SU_WEEK_NUMBER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362063
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_APPLIES_TIME_SETTINGS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361685
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_ISC_QZSS_L1CA                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361690
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_ISC_QZSS_L1CA_UNSCALED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361691
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_ISC_QZSS_L2C                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361692
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_ISC_QZSS_L2C_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361693
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_ISC_QZSS_L5I                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361694
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_ISC_QZSS_L5I_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361695
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_ISC_QZSS_L5Q                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361696
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_ISC_QZSS_L5Q_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361697
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_ISC_GPS_L1CA                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361698
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_ISC_GPS_L1CA_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361699
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_ISC_GPS_L2C                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361700
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_ISC_GPS_L2C_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361701
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_ISC_GPS_L5I                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361702
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_ISC_GPS_L5I_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361703
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_ISC_GPS_L5Q                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361704
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_ISC_GPS_L5Q_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362064
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_QZSS_WNOT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359086
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_FNAV_WNOT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359087
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_INAV_WNOT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359088
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GLONASS_WNOT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359089
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_WNOT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359090
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_CNAV_WNOT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359091
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_LNAV_WNOT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359092
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_QZSS_TOT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359095
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_QZSS_TOT_UNSCALED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359096
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_FNAV_TOT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359097
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_FNAV_TOT_UNSCALED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359098
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_INAV_TOT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359099
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_INAV_TOT_UNSCALED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359100
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GLONASS_TOT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359101
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GLONASS_TOT_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359102
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_TOT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359103
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_TOT_UNSCALED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359104
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_CNAV_TOT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359105
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_CNAV_TOT_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359106
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_LNAV_TOT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359107
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_LNAV_TOT_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359108
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_A2                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359109
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_A2_UNSCALED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359110
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_QZSS_A1                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359113
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_QZSS_A1_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359114
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_FNAV_A1                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359115
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_FNAV_A1_UNSCALED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359116
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_INAV_A1                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359117
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_INAV_A1_UNSCALED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359118
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GLONASS_A1                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359119
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GLONASS_A1_UNSCALED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359120
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_A1                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359121
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_A1_UNSCALED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359122
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_CNAV_A1                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359123
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_CNAV_A1_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359124
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_LNAV_A1                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359125
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_LNAV_A1_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359126
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_QZSS_A0                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359129
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_QZSS_A0_UNSCALED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359130
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_FNAV_A0                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359131
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_FNAV_A0_UNSCALED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359132
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_INAV_A0                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359133
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_INAV_A0_UNSCALED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359134
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GLONASS_A0                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359135
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GLONASS_A0_UNSCALED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359136
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_A0                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359137
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_A0_UNSCALED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359138
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_CNAV_A0                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359139
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_CNAV_A0_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359140
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_LNAV_A0                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359141
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_LNAV_A0_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359142
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GPS_WNOT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359143
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_FNAV_GPS_WNOT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359144
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_INAV_GPS_WNOT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359145
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GPS_TOT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359146
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GPS_TOT_UNSCALED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359147
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_FNAV_GPS_TOT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359148
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_FNAV_GPS_TOT_UNSCALED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359149
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_INAV_GPS_TOT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359150
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_INAV_GPS_TOT_UNSCALED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359151
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GLONASS_GPS_A0                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359152
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GLONASS_GPS_A0_UNSCALED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359153
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_FNAV_GPS_A0                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359154
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_FNAV_GPS_A0_UNSCALED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359155
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_INAV_GPS_A0                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359156
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_INAV_GPS_A0_UNSCALED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359157
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GPS_A0                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359158
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GPS_A0_UNSCALED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359159
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_FNAV_GPS_A1                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359160
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_FNAV_GPS_A1_UNSCALED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359161
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_INAV_GPS_A1                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359162
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GALILEO_INAV_GPS_A1_UNSCALED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359163
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GPS_A1                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359164
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GPS_A1_UNSCALED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359165
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GALILEO_WNOT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359166
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GALILEO_TOT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359167
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GALILEO_TOT_UNSCALED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359168
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GALILEO_TOT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359169
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GALILEO_TOT_UNSCALED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359170
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GALILEO_A0                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359171
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GALILEO_A0_UNSCALED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359172
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GALILEO_A0                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359173
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GALILEO_A0_UNSCALED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359174
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GALILEO_A1                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359175
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GALILEO_A1_UNSCALED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359176
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GALILEO_A1                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359177
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GALILEO_A1_UNSCALED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359178
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GALILEO_A2                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359179
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GALILEO_A2_UNSCALED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359180
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GLONASS_WNOT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359181
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GLONASS_TOT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359182
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GLONASS_TOT_UNSCALED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359183
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GLONASS_TOT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359184
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GLONASS_TOT_UNSCALED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359185
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GLONASS_A0                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359186
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GLONASS_A0_UNSCALED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359187
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GLONASS_A0                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359188
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GLONASS_A0_UNSCALED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359189
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GLONASS_A1                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359190
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_GLONASS_A1_UNSCALED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359191
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GLONASS_A1                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359192
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GLONASS_A1_UNSCALED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359193
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GLONASS_A2                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359194
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_GLONASS_A2_UNSCALED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359195
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_GPS_A0                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361705
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_GPS_A0_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361706
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_GPS_A1                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361707
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_GPS_A1_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361708
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_GPS_A2                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361709
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_GPS_A2_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361710
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_GPS_TOT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361711
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_GPS_TOT_UNSCALED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361712
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_GPS_WNOT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361713
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_UTC_A0                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361714
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_UTC_A0_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361715
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_UTC_A1                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361716
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_UTC_A1_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361717
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_UTC_A2                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361718
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_UTC_A2_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361719
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_UTC_TOT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361720
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_UTC_TOT_UNSCALED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361721
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_NAVIC_UTC_WNOT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361722
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_QZSS_UTC_A0                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361723
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_QZSS_UTC_A0_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361724
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_QZSS_UTC_A1                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361725
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_QZSS_UTC_A1_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361726
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_QZSS_UTC_A2                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361727
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_QZSS_UTC_A2_UNSCALED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361728
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_QZSS_UTC_TOT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361729
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_QZSS_UTC_TOT_UNSCALED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361730
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_QZSS_UTC_WNOT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361731
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GALILEO_A1                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362065
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GALILEO_A1_UNSCALED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362066
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GALILEO_A0                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362067
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GALILEO_A0_UNSCALED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362068
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GALILEO_TOT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362069
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GALILEO_TOT_UNSCALED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362070
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GLONASS_A1                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362071
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GLONASS_A1_UNSCALED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362072
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GLONASS_A0                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362073
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GLONASS_A0_UNSCALED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362074
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GLONASS_TOT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362075
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GLONASS_TOT_UNSCALED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362076
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GPS_A1                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362077
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GPS_A1_UNSCALED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362078
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GPS_A0                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362079
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GPS_A0_UNSCALED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362080
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GPS_TOT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362081
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_GPS_TOT_UNSCALED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362082
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_UTC_A1                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362083
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_UTC_A1_UNSCALED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362084
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_UTC_A0                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362085
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_UTC_A0_UNSCALED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362086
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_UTC_TOT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362087
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_UTC_TOT_UNSCALED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362088
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_BEIDOU_CNAV_UTC_WNOT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362089
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_GPS_CNAV_UTC_A2_UNSCALED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362090
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_LEAP_SECONDS_BEFORE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361732
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_CONVERSION_LEAP_SECONDS_AFTER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361733
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_L1_BAND_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359196
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_L2_BAND_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359197
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_L5_BAND_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359198
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SYSTEM_SBAS_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359200
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359201
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1C_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362091
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359202
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B3I_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362092
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2A_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362093
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2I_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362094
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2B_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363402
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5B_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359203
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5A_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359204
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1OS_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359205
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1PRS_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363115
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6PRS_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363116
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359206
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359207
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_SYSTEM_L1_BAND_CDMA_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362800
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_SYSTEM_L2_BAND_CDMA_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362801
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_SYSTEM_L5_BAND_CDMA_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362802
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359208
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_CDMA_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362803
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L1_BAND_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359209
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L5_BAND_EL5S_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362095
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_CA_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359210
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_P_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359211
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_CDMA_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362804
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_M_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363117
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_PY_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363118
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_CA_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359212
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_P_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359213
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_L2C_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359214
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_M_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363119
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_PY_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363120
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L2_BAND_L2C_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361734
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L5_BAND_L5S_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361735
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6S_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361736
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L5_BAND_L5S_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359215
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_NAVIC_L5_BAND_SPS_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361737
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_POWER_REFERENCE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359216
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L1_BAND_CA_POWER_OFFSET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359221
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L5_BAND_EL5S_POWER_OFFSET                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362096
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1PRS_POWER_OFFSET                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363121
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5B_POWER_OFFSET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359222
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5A_POWER_OFFSET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359223
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E1OS_POWER_OFFSET                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359224
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6S_POWER_OFFSET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361738
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6PRS_POWER_OFFSET                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363122
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_NAVIC_L5_BAND_SPS_POWER_OFFSET                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361739
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CA_POWER_OFFSET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359225
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CA_POWER_OFFSET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359226
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CDMA_POWER_OFFSET                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362805
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CDMA_POWER_OFFSET                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362806
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L5_BAND_CDMA_POWER_OFFSET                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362807
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_CA_POWER_OFFSET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359227
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_C_POWER_OFFSET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362808
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L2_BAND_L2C_POWER_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361740
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L5_BAND_L5S_POWER_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361741
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1C_POWER_OFFSET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362097
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1L_POWER_OFFSET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359228
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B2L_POWER_OFFSET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359229
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B3I_POWER_OFFSET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362098
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2A_POWER_OFFSET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362099
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2I_POWER_OFFSET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362100
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2B_POWER_OFFSET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363403
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_CA_POWER_OFFSET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359230
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_P_POWER_OFFSET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359231
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_C_POWER_OFFSET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362809
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_M_POWER_OFFSET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363123
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_PY_POWER_OFFSET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363124
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_CA_POWER_OFFSET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359232
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_P_POWER_OFFSET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359233
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_L2C_POWER_OFFSET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359234
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_M_POWER_OFFSET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363125
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_PY_POWER_OFFSET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363126
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L5_BAND_L5S_POWER_OFFSET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359235
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_GPS_L1_BAND_CA_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362101
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_GPS_L1_BAND_P_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362102
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_GPS_L1_BAND_C_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362810
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_GPS_L1_BAND_M_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363127
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_GPS_L1_BAND_PY_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363128
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_GPS_L2_BAND_CA_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362103
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_GPS_L2_BAND_L2C_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362104
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_GPS_L2_BAND_P_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362105
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_GPS_L2_BAND_M_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363129
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_GPS_L2_BAND_PY_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363130
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_GPS_L5_BAND_L5S_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362106
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L1_BAND_CA_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359239
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_SBAS_L5_BAND_EL5S_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362107
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_CA_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359240
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_QZSS_L1_BAND_C_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362811
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_QZSS_L5_BAND_L5S_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362108
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_SVID_L5_BAND_E5B_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359241
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_SVID_L5_BAND_E5A_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359242
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_SVID_L2_BAND_E6S_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361742
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E10S_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359243
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_SVID_L1_BAND_E1PRS_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363131
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_SVID_L2_BAND_E6PRS_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363132
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CA_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359244
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CA_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359245
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CDMA_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362812
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CDMA_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362813
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L5_BAND_CDMA_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362814
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_BEIDOU_L1_BAND_B1C_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362109
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1L_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359246
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B2L_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359247
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_BEIDOU_L2_BAND_B3I_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362110
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_BEIDOU_L5_BAND_B2A_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362111
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_BEIDOU_L5_BAND_B2I_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362112
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SVID_BEIDOU_L5_BAND_B2B_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363404
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_NAVIC_L5_BAND_SPS_SVID_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361743
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L2_BAND_L2C_SVID_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361744
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L5_BAND_L5S_SVID_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361745
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_FREQUENCY_NUMBER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359238
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L1_BAND_CA_PILOT_PRIMARY_CODE_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359248
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L1_BAND_CA_DATA_PRIMARY_CODE_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359249
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L5_BAND_EL5S_DATA_PRIMARY_CODE_ENABLED                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362113
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_CA_PILOT_PRIMARY_CODE_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359250
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_CA_DATA_PRIMARY_CODE_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359251
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_C_DATA_PRIMARY_CODE_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362815
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_C_PILOT_PRIMARY_CODE_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362816
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L2_BAND_L2C_DATA_PRIMARY_CODE_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361746
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L2_BAND_L2C_PILOT_PRIMARY_CODE_ENABLED                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361747
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L5_BAND_L5S_DATA_PRIMARY_CODE_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361748
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L5_BAND_L5S_PILOT_PRIMARY_CODE_ENABLED                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361749
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_NAVIC_L5_BAND_SPS_DATA_PRIMARY_CODE_ENABLED                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361750
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1OS_PILOT_PRIMARY_CODE_ENABLED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359256
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1OS_DATA_PRIMARY_CODE_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362114
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1PRS_DATA_PRIMARY_CODE_ENABLED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363133
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6S_PILOT_PRIMARY_CODE_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359252
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6S_DATA_PRIMARY_CODE_ENABLED                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361751
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6PRS_DATA_PRIMARY_CODE_ENABLED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363134
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5B_PILOT_PRIMARY_CODE_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361752
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5B_DATA_PRIMARY_CODE_ENABLED                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359253
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5A_PILOT_PRIMARY_CODE_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359254
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5A_DATA_PRIMARY_CODE_ENABLED                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359255
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CA_DATA_PRIMARY_CODE_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359257
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CA_PILOT_PRIMARY_CODE_ENABLED                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359258
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CA_DATA_PRIMARY_CODE_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359259
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CA_PILOT_PRIMARY_CODE_ENABLED                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359260
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CDMA_DATA_PRIMARY_CODE_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362817
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CDMA_PILOT_PRIMARY_CODE_ENABLED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362818
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CDMA_PILOT_PRIMARY_CODE_ENABLED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362819
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L5_BAND_CDMA_DATA_PRIMARY_CODE_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362820
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L5_BAND_CDMA_PILOT_PRIMARY_CODE_ENABLED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362821
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1C_DATA_PRIMARY_CODE_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362115
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1C_PILOT_PRIMARY_CODE_ENABLED                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362116
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1L_DATA_PRIMARY_CODE_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359261
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1L_PILOT_PRIMARY_CODE_ENABLED                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359262
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B2L_DATA_PRIMARY_CODE_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359263
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B2L_PILOT_PRIMARY_CODE_ENABLED                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359264
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B3I_DATA_PRIMARY_CODE_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362117
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2A_DATA_PRIMARY_CODE_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362118
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2A_PILOT_PRIMARY_CODE_ENABLED                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362119
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2I_DATA_PRIMARY_CODE_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362120
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2B_DATA_PRIMARY_CODE_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363405
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_CA_DATA_PRIMARY_CODE_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362121
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_CA_PILOT_PRIMARY_CODE_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362122
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_C_DATA_PRIMARY_CODE_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362822
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_C_PILOT_PRIMARY_CODE_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362823
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_M_DATA_PRIMARY_CODE_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363135
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_PY_DATA_PRIMARY_CODE_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363136
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L5_BAND_L5S_PILOT_PRIMATE_CODE_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362123
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_P_DATA_PRIMARY_CODE_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359265
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_P_PILOT_PRIMARY_CODE_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359266
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_L2C_DATA_PRIMARY_CODE_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359267
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_L2C_PILOT_PRIMARY_CODE_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359268
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_P_DATA_PRIMARY_CODE_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359269
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_P_PILOT_PRIMARY_CODE_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359270
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_CA_DATA_PRIMARY_CODE_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359271
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_CA_PILOT_PRIMARY_CODE_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359272
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_M_DATA_PRIMARY_CODE_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363137
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_PY_DATA_PRIMARY_CODE_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363138
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L5_BAND_L5S_DATA_PRIMARY_CODE_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359273
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L5_BAND_L5S_PILOT_PRIMARY_CODE_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359274
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1C_PILOT_SECONDARY_CODE_ENABLED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362124
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1L_DATA_SECONDARY_CODE_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359275
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1L_PILOT_SECONDARY_CODE_ENABLED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359276
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B2L_DATA_SECONDARY_CODE_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359277
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B2L_PILOT_SECONDARY_CODE_ENABLED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359278
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B3I_DATA_SECONDARY_CODE_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362125
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2A_DATA_SECONDARY_CODE_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362126
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2A_PILOT_SECONDARY_CODE_ENABLED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362127
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2I_DATA_SECONDARY_CODE_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362128
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1OS_DATA_SECONDARY_CODE_ENABLED             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359279
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1OS_PILOT_SECONDARY_CODE_ENABLED            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359280
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1PRS_DATA_SECONDARY_CODE_ENABLED            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363139
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6S_PILOT_SECONDARY_CODE_ENABLED             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361753
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6PRS_DATA_SECONDARY_CODE_ENABLED            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363140
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5A_DATA_SECONDARY_CODE_ENABLED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359281
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5A_PILOT_SECONDARY_CODE_ENABLED             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359282
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5B_DATA_SECONDARY_CODE_ENABLED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359283
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5B_PILOT_SECONDARY_CODE_ENABLED             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359284
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_C_PILOT_SECONDARY_CODE_ENABLED                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362824
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L5_BAND_L5S_DATA_SECONDARY_CODE_ENABLED                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361754
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L5_BAND_L5S_PILOT_SECONDARY_CODE_ENABLED                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361755
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_C_PILOT_SECONDARY_CODE_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362825
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_M_DATA_SECONDARY_CODE_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363141
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_PY_DATA_SECONDARY_CODE_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363142
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_M_DATA_SECONDARY_CODE_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363143
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_PY_DATA_SECONDARY_CODE_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363144
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L5_BAND_L5S_DATA_SECONDARY_CODE_ENABLED                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362129
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CDMA_DATA_SECONDARY_CODE_ENABLED             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362826
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CDMA_PILOT_SECONDARY_CODE_ENABLED            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362827
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L5_BAND_CDMA_DATA_SECONDARY_CODE_ENABLED             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362828
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L5_BAND_CDMA_PILOT_SECONDARY_CODE_ENABLED            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362829
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L1_BAND_CA_NAV_MESSAGE_CONTROL                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359285
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L5_BAND_EL5S_NAV_MESSAGE_CONTROL                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362130
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_CA_NAV_MESSAGE_CONTROL                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359286
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L2_BAND_L2C_NAV_MESSAGE_CONTROL                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361756
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L5_BAND_L5S_NAV_MESSAGE_CONTROL                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361757
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1OS_NAV_MESSAGE_CONTROL                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359287
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1PRS_NAV_MESSAGE_CONTROL                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363145
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6S_NAV_MESSAGE_CONTROL                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361758
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6PRS_NAV_MESSAGE_CONTROL                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363146
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5A_NAV_MESSAGE_CONTROL                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359288
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5B_NAV_MESSAGE_CONTROL                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359289
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_NAVIC_L5_BAND_SPS_NAV_MESSAGE_CONTROL                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361759
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CA_NAV_MESSAGE_CONTROL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359290
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CA_NAV_MESSAGE_CONTROL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359291
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CDMA_NAV_MESSAGE_CONTROL                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362830
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CDMA_NAV_MESSAGE_CONTROL                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362831
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L5_BAND_CDMA_NAV_MESSAGE_CONTROL                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362832
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1C_NAV_MESSAGE_CONTROL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362131
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1L_NAV_MESSAGE_CONTROL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359292
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B3I_NAV_MESSAGE_CONTROL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362132
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B2L_NAV_MESSAGE_CONTROL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359293
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2A_NAV_MESSAGE_CONTROL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362133
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2I_NAV_MESSAGE_CONTROL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362134
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2B_NAV_MESSAGE_CONTROL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363406
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_CA_NAV_MESSAGE_CONTROL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359294
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_P_NAV_MESSAGE_CONTROL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359295
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_C_NAV_MESSAGE_CONTROL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362833
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_M_NAV_MESSAGE_CONTROL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363147
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_PY_NAV_MESSAGE_CONTROL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363148
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_L2C_NAV_MESSAGE_CONTROL                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359296
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_P_NAV_MESSAGE_CONTROL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359297
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_CA_NAV_MESSAGE_CONTROL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359298
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_M_NAV_MESSAGE_CONTROL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363149
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_PY_NAV_MESSAGE_CONTROL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363150
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L5_BAND_L5S_NAV_MESSAGE_CONTROL                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359299
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_CA_NAV_MESSAGE_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362135
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_P_NAV_MESSAGE_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362136
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_C_NAV_MESSAGE_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362834
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_M_NAV_MESSAGE_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363151
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_PY_NAV_MESSAGE_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363152
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_L2C_NAV_MESSAGE_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362138
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_P_NAV_MESSAGE_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362139
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_M_NAV_MESSAGE_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363153
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_PY_NAV_MESSAGE_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363154
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L5_BAND_L5S_NAV_MESSAGE_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362140
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L1_BAND_CA_NAV_MESSAGE_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362141
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L5_BAND_EL5S_NAV_MESSAGE_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362142
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_CA_NAV_MESSAGE_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362143
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_C_NAV_MESSAGE_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362835
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_C_NAV_MESSAGE_CONTROL                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362836
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L2_BAND_L2C_NAV_MESSAGE_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362144
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L5_BAND_L5S_NAV_MESSAGE_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362145
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1OS_NAV_MESSAGE_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362146
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1PRS_NAV_MESSAGE_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363155
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6S_NAV_MESSAGE_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359300
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6PRS_NAV_MESSAGE_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363156
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5A_NAV_MESSAGE_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362147
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5B_NAV_MESSAGE_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362148
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_NAVIC_L5_BAND_SPS_NAV_MESSAGE_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361760
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CA_NAV_MESSAGE_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362149
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CA_NAV_MESSAGE_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362150
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CDMA_NAV_MESSAGE_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362837
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CDMA_NAV_MESSAGE_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362838
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L5_BAND_CDMA_NAV_MESSAGE_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362839
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1C_NAV_MESSAGE_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362151
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1I_NAV_MESSAGE_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362152
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B3I_NAV_MESSAGE_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362153
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2A_NAV_MESSAGE_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362154
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2I_NAV_MESSAGE_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362155
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2B_NAV_MESSAGE_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363407
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_C_NAV_MESSAGE_TYPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362840
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L1_BAND_CA_NAV_MESSAGE_TYPE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361761
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L5_BAND_EL5S_NAV_MESSAGE_TYPE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362156
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_CA_NAV_MESSAGE_TYPE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359301
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_C_NAV_MESSAGE_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362841
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1OS_NAV_MESSAGE_TYPE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359302
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1PRS_NAV_MESSAGE_TYPE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363157
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6S_NAV_MESSAGE_TYPE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361762
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6PRS_NAV_MESSAGE_TYPE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363158
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5A_NAV_MESSAGE_TYPE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359303
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5B_NAV_MESSAGE_TYPE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359304
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_NAVIC_L5_BAND_SPS_NAV_MESSAGE_TYPE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361763
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L2_BAND_L2C_NAV_MESSAGE_TYPE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361764
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L5_BAND_L5S_NAV_MESSAGE_TYPE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361765
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CA_NAV_MESSAGE_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359305
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CA_NAV_MESSAGE_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359306
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CDMA_NAV_MESSAGE_TYPE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362842
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CDMA_NAV_MESSAGE_TYPE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362843
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L5_BAND_CDMA_NAV_MESSAGE_TYPE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362844
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1C_NAV_MESSAGE_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362157
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1L_NAV_MESSAGE_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359307
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B3I_NAV_MESSAGE_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362158
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B2L_NAV_MESSAGE_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359308
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2A_NAV_MESSAGE_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362159
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2I_NAV_MESSAGE_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362160
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2B_NAV_MESSAGE_TYPE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363408
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_CA_NAV_MESSAGE_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359309
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_P_NAV_MESSAGE_TYPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359310
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_M_NAV_MESSAGE_TYPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363159
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_PY_NAV_MESSAGE_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363160
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_L2C_NAV_MESSAGE_TYPE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359311
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_P_NAV_MESSAGE_TYPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359312
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_CA_NAV_MESSAGE_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359313
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_M_NAV_MESSAGE_TYPE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363161
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_PY_NAV_MESSAGE_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363162
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L5_BAND_L5S_NAV_MESSAGE_TYPE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359314
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L1_BAND_CA_NAV_MESSAGE_PATTERN                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361766
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L5_BAND_EL5S_NAV_MESSAGE_PATTERN                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362161
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_CA_NAV_MESSAGE_PATTERN                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361767
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_C_NAV_MESSAGE_PATTERN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362845
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L2_BAND_L2C_NAV_MESSAGE_PATTERN                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361768
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L5_BAND_L5S_NAV_MESSAGE_PATTERN                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361769
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_NAVIC_L5_BAND_SPS_NAV_MESSAGE_PATTERN                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361770
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_CA_NAV_MESSAGE_PATTERN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361771
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_P_NAV_MESSAGE_PATTERN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361772
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_C_NAV_MESSAGE_PATTERN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362846
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_M_NAV_MESSAGE_PATTERN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363163
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_PY_NAV_MESSAGE_PATTERN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363164
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_CA_NAV_MESSAGE_PATTERN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361773
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_L2C_NAV_MESSAGE_PATTERN                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361774
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_P_NAV_MESSAGE_PATTERN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361775
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_M_NAV_MESSAGE_PATTERN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363165
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_PY_NAV_MESSAGE_PATTERN                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363166
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L5_BAND_L5S_NAV_MESSAGE_PATTERN                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361776
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CA_NAV_MESSAGE_PATTERN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361777
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CA_NAV_MESSAGE_PATTERN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361778
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CDMA_NAV_MESSAGE_PATTERN                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362847
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CDMA_NAV_MESSAGE_PATTERN                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362848
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L5_BAND_CDMA_NAV_MESSAGE_PATTERN                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362849
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1OS_NAV_MESSAGE_PATTERN                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361779
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1PRS_NAV_MESSAGE_PATTERN                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363167
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6S_NAV_MESSAGE_PATTERN                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361780
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6PRS_NAV_MESSAGE_PATTERN                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363168
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5A_NAV_MESSAGE_PATTERN                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361781
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5B_NAV_MESSAGE_PATTERN                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361782
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1C_NAV_MESSAGE_PATTERN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361783
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1I_NAV_MESSAGE_PATTERN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361784
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B3I_NAV_MESSAGE_PATTERN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361785
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2A_NAV_MESSAGE_PATTERN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361786
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2I_NAV_MESSAGE_PATTERN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361787
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2B_NAV_MESSAGE_PATTERN                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363409
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L1_BAND_CA_NAV_MESSAGE_DATA_LIST                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361788
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_SBAS_L5_BAND_EL5S_NAV_MESSAGE_DATA_LIST                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362162
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_CA_NAV_MESSAGE_DATA_LIST                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361790
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L1_BAND_C_NAV_MESSAGE_DATA_LIST                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362850
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L2_BAND_L2C_NAV_MESSAGE_DATA_LIST                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361792
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_QZSS_L5_BAND_L5S_NAV_MESSAGE_DATA_LIST                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361794
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_NAVIC_L5_BAND_SPS_NAV_MESSAGE_DATA_LIST                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361796
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_CA_NAV_MESSAGE_DATA_LIST                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361798
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_C_NAV_MESSAGE_DATA_LIST                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362851
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_P_NAV_MESSAGE_DATA_LIST                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361800
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_M_NAV_MESSAGE_DATA_LIST                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363169
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L1_BAND_PY_NAV_MESSAGE_DATA_LIST                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363170
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_CA_NAV_MESSAGE_DATA_LIST                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361802
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_L2C_NAV_MESSAGE_DATA_LIST                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361804
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_P_NAV_MESSAGE_DATA_LIST                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361806
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_M_NAV_MESSAGE_DATA_LIST                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363171
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L2_BAND_PY_NAV_MESSAGE_DATA_LIST                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363172
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GPS_L5_BAND_L5S_NAV_MESSAGE_DATA_LIST                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361808
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CA_NAV_MESSAGE_DATA_LIST                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361810
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CA_NAV_MESSAGE_DATA_LIST                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361812
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CDMA_NAV_MESSAGE_DATA_LIST                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362852
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CDMA_NAV_MESSAGE_DATA_LIST                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362853
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L5_BAND_CDMA_NAV_MESSAGE_DATA_LIST                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362854
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1OS_NAV_MESSAGE_DATA_LIST                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361814
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1OS_OSNMA_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363410
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L1_BAND_E1PRS_NAV_MESSAGE_DATA_LIST                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363173
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6S_NAV_MESSAGE_DATA_LIST                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361816
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L2_BAND_E6PRS_NAV_MESSAGE_DATA_LIST                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363174
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5A_NAV_MESSAGE_DATA_LIST                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361818
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GALILEO_L5_BAND_E5B_NAV_MESSAGE_DATA_LIST                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361820
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1C_NAV_MESSAGE_DATA_LIST                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361822
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L1_BAND_B1I_NAV_MESSAGE_DATA_LIST                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361824
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L2_BAND_B3I_NAV_MESSAGE_DATA_LIST                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361826
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2A_NAV_MESSAGE_DATA_LIST                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361828
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2I_NAV_MESSAGE_DATA_LIST                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361830
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_BEIDOU_L5_BAND_B2B_NAV_MESSAGE_DATA_LIST                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363411
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CA_MEANDRING                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359315
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CA_MEANDRING                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359316
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L1_BAND_CA_TIME_SIGNAL_COMPONENT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359317
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SIGNAL_GLONASS_L2_BAND_CA_TIME_SIGNAL_COMPONENT                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359318
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SV_SELECTION_MODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362163
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SV_SELECTION_EARTH_OBSCURATION_REFERENCE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362164
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SV_SELECTION_EARTH_OBSCURATION_OFFSET                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362165
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SV_SELECTION_MAX_NUMBER_OF_CHANNELS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362166
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SV_SELECTION_REFERENCE_VEHICLE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362167
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_HIL_LATENCY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359323
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_HIL_SYSTEM_LATENCY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359325
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_HIL_INTERFACE_TYPE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359326
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_HIL_UDP_PORT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359327
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_HIL_ELAPSED_TIME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359328
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_NUMBER_OF_VEHICLES                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362168
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_POSITIONING                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359329
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_CATALOG                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359330
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_SELECT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359331
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_REFERENCE_FRAME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359332
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_COORDINATES_FORMAT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359333
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_ATTITUDE_BEHAVIOUR                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359338
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_ATTITUDE_YAW                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359339
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_ATTITUDE_PITCH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359340
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_ATTITUDE_ROLL                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359341
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_ATTITUDE_SPIN_RATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359342
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_WAYPOINTS_FILE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359343
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_WAYPOINTS_TRAJECTORY_LENGTH                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362855
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_TRAJECTORY_DURATION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359345
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_RO_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359346
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_SMOOTH_MOVEMENT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359347
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_PREDEFINED_VEHICLES                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359348
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_USER_VEHICLES                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359349
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_LOCATION_VEHICLE_FILE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359350
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_PREDEFINED_ENVIRONMENT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361832
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_PHYSICAL_MODEL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361833
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_MODEL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362169
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_FULL_SET_TO_TRAJECTORY_LENGTH                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362856
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_RPL_SET_TO_TRAJECTORY_LENGTH                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362857
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_VERTICAL_PREDEFINED_ENVIRONMENT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361834
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_VERTICAL_PHYSICAL_MODEL                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361835
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_VERTICAL_PREDEFINED_CATALOG                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361836
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_VERTICAL_USER_CATALOG                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361837
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_VERTICAL_LOAD_FILE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361838
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_VERTICAL_MAP_ORIENTATION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361840
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_VERTICAL_START_REC_X_OFFSET                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361841
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_VERTICAL_START_REC_Y_OFFSET                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361842
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_VERTICAL_START_REC_HEIGHT_OFFSET               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361843
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_ROADSIDE_PREDEFINED_ENVIRONMENT                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361844
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_ROADSIDE_PHYSICAL_MODEL                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361845
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_ROADSIDE_PREDEFINED_CATALOG                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361846
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_ROADSIDE_USER_CATALOG                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361847
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_ROADSIDE_LOAD_FILE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361848
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_ROADSIDE_REPETITION_ENABLED                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361850
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_ROADSIDE_REPETITION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361851
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_ROADSIDE_RECEIVER_HEIGHT_OFFSET                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361852
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_ROADSIDE_SET_LENGTH_TO_INFINITE                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361853
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_ROADSIDE_DISPLAY                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361854
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_GROUND_SEA_MATERIAL_PROPERTY                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361865
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_GROUND_SEA_POWER_LOSS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361866
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_GROUND_SEA_SURFACE_TYPE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361867
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_GROUND_SEA_PERMITIVITY                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361868
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_GROUND_SEA_CONDUCTIVITY                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361869
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_GROUND_SEA_HEIGHT1                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361870
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_GROUND_SEA_HEIGHT2                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361871
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_GROUND_SEA_DISTANCE1                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361872
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_GROUND_SEA_DISTANCE2                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361873
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_GROUND_SEA_ALTITUDE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361874
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_GROUND_SEA_ORIENTATION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361875
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_FULL_PREDEFINED_ENVIRONMENT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361855
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_FULL_REFERENCE_SCALE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361856
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_FULL_REPETITION_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361857
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_FULL_REPETITION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361858
#define RSRFSIGGEN_ATTR_QUERY_SATNAV_GNSS_RECEIVER_ENVIRONMENT_FULL_AREAS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361859
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_FULL_AREA_APPEND                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361860
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_FULL_AREA_INSERT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361861
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_FULL_AREA_DELETE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361862
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_FULL_AREA_REFERENCE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361863
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_FULL_AREA_LENGTH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361864
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_LAND_MOBILE_PREDEFINED_CATALOG                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361876
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_LAND_MOBILE_USER_CATALOG                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361877
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_LAND_MOBILE_LOAD_FILE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361878
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_STATIC_MULTIPATH_STANDARD                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362170
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_STATIC_MULTIPATH_SVID                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362171
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_STATIC_MULTIPATH_COPY_TARGET_STANDARD          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362172
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_STATIC_MULTIPATH_COPY_TARGET_SVID              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362173
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RECEIVER_ENVIRONMENT_STATIC_MULTIPATH_COPY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362174
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ANTENNA_COUNT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359352
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ANTENNA_VIEW                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359353
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ANTENNA_VISUALIZE_3D                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359354
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ANTENNA_PREDEFINED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359355
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_USER_ANTENNA_CATALOG                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362175
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_BODY_PREDEFINED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359356
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_USER_BODY_CATALOG                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362176
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ANTENNA_FILE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359357
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_BODY_FILE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359359
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ANTENNA_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359361
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ANTENNA_DELTA_BANK                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359362
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ANTENNA_DELTA_HEADING                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359363
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ANTENNA_DELTA_ELEVATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359364
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ANTENNA_DELTA_X                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359365
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ANTENNA_DELTA_Y                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359366
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ANTENNA_DELTA_Z                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359367
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RT_PDOP                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359368
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RT_HDOP                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363175
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RT_VDOP                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363176
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RT_STREAM_ACTIVE_SYSTEMS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362193
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RT_STREAM_ACTIVE_GPS_SIGNALS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362195
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RT_STREAM_ACTIVE_GALILEO_SIGNALS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362196
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RT_STREAM_ACTIVE_GLONASS_SIGNALS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362197
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RT_STREAM_ACTIVE_BEIDOU_SIGNALS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362198
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RT_STREAM_ACTIVE_QZSS_SIGNALS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362199
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RT_STREAM_ACTIVE_SBAS_SIGNALS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362200
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RT_STREAM_ACTIVE_NAVIC_SIGNALS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362201
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363177
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_PROTOCOL                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363178
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_PORT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363179
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_PASSWORD                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363180
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_USER_ID                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363181
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_NUMBER_OF_BASE_STATIONS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363182
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_BASE_MOUNTPOINT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363183
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_BASE_LOCATION_SELECT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363184
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_BASE_LOCATION_CATALOG                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363185
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_BASE_LOCATION_SYNC_TO_RECEIVER_POSITION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363186
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_BASE_LOCATION_REFERENCE_FRAME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363187
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_BASE_LOCATION_COORDINATES_FORMAT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363188
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_ANTENNA_ACTIVE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363193
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_ANTENNA_PATTERN_FILE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363194
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_ANTENNA_BODY_MASK_FILE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363195
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_ANTENNA_ORIENTATION_DELTA_BANK                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363196
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_ANTENNA_ORIENTATION_DELTA_HEADING                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363197
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_ANTENNA_ORIENTATION_DELTA_ELEVATION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363198
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_ANTENNA_DELTA_X                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363199
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_ANTENNA_DELTA_Y                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363200
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_RTK_ANTENNA_DELTA_Z                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363201
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_MODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359374
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_OFFLINE_GENERATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359375
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_OFFLINE_ABORT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359376
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_RT_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359377
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_OFFLINE_TIME_OFFSET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359378
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_OFFLINE_TIME_DURATION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359379
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_OFFLINE_PROGRESS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359380
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_DESTINATION_DIRECTORY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359381
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_FILE_TIMESTAMP                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359382
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_FILE_FORMAT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359383
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_U_MOTION_FILE_FORMAT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359384
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359385
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_U_MOTION_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359386
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_STEP                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359387
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_U_MOTION_STEP                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359388
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_SELECT_ALL_SVID                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359389
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_U_MOTION_SELECT_ALL_SVID                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359390
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_SELECT_NONE_SVID                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359391
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_U_MOTION_SELECT_NONE_SVID                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359392
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_ACCELERATION_ECEF                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359393
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_POSITION_ECEF                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359394
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_VELOCITY_ECEF                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359395
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_AZIMUTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359396
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_CLOCK_BIAS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359397
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_CLOCK_RANGE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362858
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_CLOCK_PHASE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359398
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_DOPPLER_SHIFT                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359399
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_ELEVATION                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359400
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_IONOSPHERIC_DELAY                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359401
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_PSEUDORANGE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359402
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_PSEUDORANGE_RATE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359403
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_PSEUDORANGE_BIAS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359404
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_PSEUDORANGE_BIAS_RATE                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359405
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_RANGE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359406
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_RANGE_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359407
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_SIGNAL_LEVEL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359408
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_SATELLITE_PARAMETER_TROPOSPHERIC_DELAY                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359409
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_ACCELERATION_ECEF                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359410
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_JERK_ECEF                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359411
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_POSITIONAL_ECEF                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359412
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_VELOCITY_ECEF                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359413
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_ATTITUDE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359414
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_ATTITUDE_ACCELERATION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359415
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_ATTITUDE_JERK                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359416
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_ATTITUDE_RATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359417
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_GEOMETRIC_DOP                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359418
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_HORIZONTAL_DOP                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359419
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_POSITIONAL_DOP                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359420
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_VERTICAL_DOP                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359421
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_TIME_DOP                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359422
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_GROUND_SPEED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359423
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_ANTENNA_OFFSET                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359424
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_NUMBER_OF_VISIBLE_SVS                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359425
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_POSITION_ENU                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359426
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_POSITION_LLA                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359427
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_LOGGING_PARAMETER_U_MOTION_VELOCITY_LOCAL_NED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359428
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TRIGGER_STATUS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359429
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TRIGGER_ARM                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359430
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TRIGGER_EXECUTE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359431
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TRIGGER_MODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359432
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TRIGGER_SOURCE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359433
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TRIGGER_SEQUENCE_LENGTH                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359434
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359435
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ALL_EXTERNAL_TRIGGERS_DELAY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362202
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_ALL_EXTERNAL_TRIGGERS_INHIBIT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362203
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_TIME_BASED_TRIGGER                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363414
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_INTERNAL_TRIGGER_DELAY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359436
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_INTERNAL_TRIGGER_INHIBIT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359437
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_EXTERNAL_TRIGGER_DELAY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359438
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MARKER_MODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362204
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MARKER_PULSE_WIDTH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359441
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MARKER_PULSE_DIVIDER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362205
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MARKER_PULSE_FREQUENCY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362206
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MARKER_PATTERN                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362207
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MARKER_ON_TIME                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359440
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MARKER_OFF_TIME                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359439
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MARKER_HIGH_PRECISION_PPS_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361880
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_MARKER_HIGH_PRECISION_PPS_ADDITIONAL_DELAY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361881
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_AWGN_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359881
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_AWGN_AUTO_CONFIGURATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361882
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_AWGN_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359882
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_AWGN_SYSTEM_BANDWIDTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 359883
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_AWGN_CARRIER_NOISE_DENSITY_RATIO                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359884
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_AWGN_CENTER_FREQUENCY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361883
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_AWGN_REFERENCE_FREQUENCY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359885
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_AWGN_CW_FREQUENCY_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359886
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_AWGN_TARGET_FREQUENCY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362208
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_AWGN_JS_RATIO                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359887
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_SYSTEM                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362859
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_SIMULATED_ORBIT_XG                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362214
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_SIMULATED_ORBIT_YG                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362215
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_SIMULATED_ORBIT_ZG                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362216
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_SIMULATED_ORBIT_XG_DOT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362217
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_SIMULATED_ORBIT_YG_DOT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362218
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_SIMULATED_ORBIT_ZG_DOT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362219
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_SIMULATED_ORBIT_XG_DOT_DOT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362220
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_SIMULATED_ORBIT_YG_DOT_DOT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362221
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_SIMULATED_ORBIT_ZG_DOT_DOT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362222
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_ALMANAC_PERIOD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362223
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_ALMANAC_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362224
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_C_E_COVARIANCE_MATRIX_PERIOD                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362225
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_C_E_COVARIANCE_MATRIX_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362226
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_DEGRADATION_FACTOR_PERIOD                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362227
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_DEGRADATION_FACTOR_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362228
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_FC_DEGRADATION_FACTOR_PERIOD                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362229
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_FC_DEGRADATION_FACTOR_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362230
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_FAST_CORRECTION_PERIOD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362231
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_FAST_CORRECTION_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362232
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_IONOSPHERIC_GRID_PERIOD                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362233
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_IONOSPHERIC_GRID_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362234
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_LONG_TERM_CORRECTION_PERIOD                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362235
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_LONG_TERM_CORRECTION_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362236
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_PRN_MASK_PERIOD                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362237
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_PRN_MASK_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362238
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_RINEX_PERIOD                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362239
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_RINEX_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362240
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_SERVICE_PERIOD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362241
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_SERVICE_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362242
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_UTC_OFFSET_PERIOD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362243
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_UTC_OFFSET_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362244
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_EGNOS_SVID_PRN_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362245
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_ALMANAC_PERIOD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362246
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_ALMANAC_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362247
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_C_E_COVARIANCE_MATRIX_PERIOD                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362248
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_C_E_COVARIANCE_MATRIX_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362249
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_DEGRADATION_FACTOR_PERIOD                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362250
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_DEGRADATION_FACTOR_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362251
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_FC_DEGRADATION_PERIOD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362252
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_FC_DEGRADATION_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362253
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_FAST_CORRECTION_PERIOD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362254
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_FAST_CORRECTION_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362255
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_IONOSPHERIC_GRID_PERIOD                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362256
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_IONOSPHERIC_GRID_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362257
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_LONG_TERM_CORRECTION_PERIOD                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362258
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_LONG_TERM_CORRECTION_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362259
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_PRN_MASK_PERIOD                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362260
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_PRN_MASK_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362261
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_RINEX_PERIOD                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362262
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_RINEX_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362263
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_SERVICE_PERIOD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362264
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_SERVICE_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362265
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_UTC_OFFSET_PERIOD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362266
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_UTC_OFFSET_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362267
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_GAGAN_SVID_PRN_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362268
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_ALMANAC_PERIOD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362269
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_ALMANAC_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362270
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_C_E_COVARIANCE_MATRIX_PERIOD                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362271
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_C_E_COVARIANCE_MATRIX_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362272
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_DEGRADATION_FACTOR_PERIOD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362273
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_DEGRADATION_FACTOR_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362274
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_FC_DEGRADATION_FACTOR_PERIOD                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362275
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_FC_DEGRADATON_FACTOR_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362276
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_FAST_CORRECTION_PERIOD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362277
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_FAST_CORRECTION_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362278
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_IONOSPHERIC_GRID_PERIOD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362279
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_IONOSPHERIC_GRID_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362280
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_LONG_TERM_CORRECTION_PERIOD                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362281
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_LONG_TERM_CORRECTION_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362282
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_PRN_MASK_PERIOD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362283
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_PRN_MASK_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362284
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_RINEX_PERIOD                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362285
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_RINEX_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362286
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_SERVICE_PERIOD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362287
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_SERVICE_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362288
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_UTC_OFFSET_PERIOD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362289
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_UTC_OFFSET_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362290
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_MSAS_SVID_PRN_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362291
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_ALMANAC_PERIOD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362292
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_ALMANAC_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362293
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_C_E_COVARIANCE_MATRIX_PERIOD                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362294
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_C_E_COVARIANCE_MATRIX_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362295
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_DEGRADATION_FACTOR_PERIOD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362296
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_DEGRADATION_FACTOR_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362297
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_FC_DEGRADATION_FACTOR_PERIOD                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362298
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_FC_DEGRADATION_FACTOR_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362299
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_FAST_CORRECTION_PERIOD                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362300
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_FAST_CORRECTION_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362301
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_IONOSPHERIC_GRID_PERIOD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362302
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_IONOSPHERIC_GRID_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362303
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_LONG_TERM_CORRECTION_PERIOD                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362304
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_LONG_TERM_CORRECTION_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362305
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_PRN_MASK_PERIOD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362306
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_PRN_MASK_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362307
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_RINEX_PERIOD                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362308
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_RINEX_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362309
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_SERVICE_PERIOD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362310
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_SERVICE_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362311
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_UTC_OFFSET_PERIOD                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362312
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_UTC_OFFSET_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362313
#define RSRFSIGGEN_ATTR_SATNAV_GNSS_SBAS_WAAS_SV_ID_PRN_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362314
#define RSRFSIGGEN_ATTR_SATNAV_CLOCK_SOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362315
#define RSRFSIGGEN_ATTR_SATNAV_CLOCK_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362316
#define RSRFSIGGEN_ATTR_NFC_ENABLED                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352377
#define RSRFSIGGEN_ATTR_NFC_SET_TO_DEFAULT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352378
#define RSRFSIGGEN_ATTR_NFC_TECHNOLOGY                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352379
#define RSRFSIGGEN_ATTR_NFC_DIVISOR                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352380
#define RSRFSIGGEN_ATTR_NFC_DESIRED_VOLTAGE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352719
#define RSRFSIGGEN_ATTR_NFC_TRANSMISSION_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352381
#define RSRFSIGGEN_ATTR_NFC_VERSION                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352720
#define RSRFSIGGEN_ATTR_NFC_UNMODULATED_PARTS_VOLTAGE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352721
#define RSRFSIGGEN_ATTR_NFC_AUTOMATICALLY_ADJUST                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352722
#define RSRFSIGGEN_ATTR_NFC_WAVEFORM_CREATE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352723
#define RSRFSIGGEN_ATTR_NFC_SETTINGS_CATALOG                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352724
#define RSRFSIGGEN_ATTR_NFC_DELETE_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352725
#define RSRFSIGGEN_ATTR_NFC_RECALL_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352727
#define RSRFSIGGEN_ATTR_NFC_SAVE_SETTINGS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352729
#define RSRFSIGGEN_ATTR_NFC_FAST_STORE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352731
#define RSRFSIGGEN_ATTR_NFC_MODULATION_BIT_RATE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352382
#define RSRFSIGGEN_ATTR_NFC_MODULATION_SLOPE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352383
#define RSRFSIGGEN_ATTR_NFC_MODULATION_RLC_CURVE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352384
#define RSRFSIGGEN_ATTR_NFC_MODULATION_INVERSE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352385
#define RSRFSIGGEN_ATTR_NFC_MODULATION_TFALL                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352386
#define RSRFSIGGEN_ATTR_NFC_MODULATION_TRISE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352387
#define RSRFSIGGEN_ATTR_NFC_MODULATION_TLOW                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352388
#define RSRFSIGGEN_ATTR_NFC_MODULATION_OVERSHOOT_RISING_SLOPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352389
#define RSRFSIGGEN_ATTR_NFC_MODULATION_UNDERSHOOT_FALLING_SLOPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352390
#define RSRFSIGGEN_ATTR_NFC_MODULATION_DEPTH                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352391
#define RSRFSIGGEN_ATTR_NFC_MODULATION_INDEX                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352392
#define RSRFSIGGEN_ATTR_NFC_MODULATION_SAMPLE_RATE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352393
#define RSRFSIGGEN_ATTR_NFC_MODULATION_BASEBAND_OUTPUT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352394
#define RSRFSIGGEN_ATTR_NFC_PREDEFINED_SEQUENCE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352395
#define RSRFSIGGEN_ATTR_NFC_PREDEFINED_SEQUENCE_CONFIGURE_MARKER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352396
#define RSRFSIGGEN_ATTR_NFC_PREDEFINED_SEQUENCE_APPLY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352397
#define RSRFSIGGEN_ATTR_NFC_SEQUENCE_APPEND                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352398
#define RSRFSIGGEN_ATTR_NFC_SEQUENCE_INSERT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352399
#define RSRFSIGGEN_ATTR_NFC_SEQUENCE_REMOVES                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352400
#define RSRFSIGGEN_ATTR_NFC_SEQUENCE_COPY                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352401
#define RSRFSIGGEN_ATTR_NFC_SEQUENCE_PASTE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352402
#define RSRFSIGGEN_ATTR_NFC_SEQUENCE_TOTAL_NUMBER_OF_SAMPLES                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352732
#define RSRFSIGGEN_ATTR_NFC_SEQUENCE_TOTAL_SEQUENCE_DURATION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352733
#define RSRFSIGGEN_ATTR_NFC_SEQUENCE_START_TIME                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352403
#define RSRFSIGGEN_ATTR_NFC_SEQUENCE_COMMAND_TYPE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352404
#define RSRFSIGGEN_ATTR_NFC_SEQUENCE_REPETITION                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352405
#define RSRFSIGGEN_ATTR_NFC_SEQUENCE_POWER_OFFSET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352406
#define RSRFSIGGEN_ATTR_NFC_SEQUENCE_DURATION                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352407
#define RSRFSIGGEN_ATTR_NFC_SEQUENCE_SAMPLES                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352408
#define RSRFSIGGEN_ATTR_NFC_FRAME_NFCID1_SIZE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352409
#define RSRFSIGGEN_ATTR_NFC_FRAME_SEL_CMD                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352410
#define RSRFSIGGEN_ATTR_NFC_FRAME_SEL_PAR_UPPER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352411
#define RSRFSIGGEN_ATTR_NFC_FRAME_SEL_PAR_LOWER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352412
#define RSRFSIGGEN_ATTR_NFC_FRAME_NFCID0_HEX                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352413
#define RSRFSIGGEN_ATTR_NFC_FRAME_NFCID1_HEX                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352734
#define RSRFSIGGEN_ATTR_NFC_FRAME_NFCID2_HEX                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352735
#define RSRFSIGGEN_ATTR_NFC_FRAME_BLOCK_SELECTION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352414
#define RSRFSIGGEN_ATTR_NFC_FRAME_BYTE_SELECTION                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352415
#define RSRFSIGGEN_ATTR_NFC_FRAME_DATA_SOURCE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352416
#define RSRFSIGGEN_ATTR_NFC_FRAME_DATA_LIST                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352417
#define RSRFSIGGEN_ATTR_NFC_FRAME_PATTERN                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352418
#define RSRFSIGGEN_ATTR_NFC_FRAME_GLOBAL_BLOCK_SELECTION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352419
#define RSRFSIGGEN_ATTR_NFC_FRAME_BLOCK_NUMBER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352420
#define RSRFSIGGEN_ATTR_NFC_FRAME_PACKET_SELECTION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352421
#define RSRFSIGGEN_ATTR_NFC_FRAME_ADVANCED_PROTOCOL_FEATURE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352422
#define RSRFSIGGEN_ATTR_NFC_FRAME_DID                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352423
#define RSRFSIGGEN_ATTR_NFC_FRAME_CID                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352424
#define RSRFSIGGEN_ATTR_NFC_FRAME_CID_SUPPORTED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352736
#define RSRFSIGGEN_ATTR_NFC_FRAME_BLOCK_TYPE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352425
#define RSRFSIGGEN_ATTR_NFC_FRAME_CHAINING                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352426
#define RSRFSIGGEN_ATTR_NFC_FRAME_DID_FOLLOWING                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352427
#define RSRFSIGGEN_ATTR_NFC_FRAME_DATA_LENGTH                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352428
#define RSRFSIGGEN_ATTR_NFC_FRAME_LENGTH_REDUCTION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352429
#define RSRFSIGGEN_ATTR_NFC_FRAME_GENERAL_DATA                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352430
#define RSRFSIGGEN_ATTR_NFC_FRAME_A_CHECK                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352737
#define RSRFSIGGEN_ATTR_NFC_FRAME_A_UPDATE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352738
#define RSRFSIGGEN_ATTR_NFC_FRAME_B_CHECK                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352739
#define RSRFSIGGEN_ATTR_NFC_FRAME_B_UPDATE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352740
#define RSRFSIGGEN_ATTR_NFC_FRAME_E_CHECK                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352741
#define RSRFSIGGEN_ATTR_NFC_FRAME_E_UPDATE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352742
#define RSRFSIGGEN_ATTR_NFC_FRAME_APPLICATION_DATA                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352743
#define RSRFSIGGEN_ATTR_NFC_FRAME_APPLICATION_CODING                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352744
#define RSRFSIGGEN_ATTR_NFC_FRAME_APPLICATION_FAMILY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352745
#define RSRFSIGGEN_ATTR_NFC_FRAME_AID                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352746
#define RSRFSIGGEN_ATTR_NFC_FRAME_AID_LENGTH                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352747
#define RSRFSIGGEN_ATTR_NFC_FRAME_AN_SELECTION                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352748
#define RSRFSIGGEN_ATTR_NFC_FRAME_BCC_ERROR                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352749
#define RSRFSIGGEN_ATTR_NFC_FRAME_BIT_FRAME_ANTICOLLISION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352750
#define RSRFSIGGEN_ATTR_NFC_FRAME_BIT_FRAME_SDD                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352751
#define RSRFSIGGEN_ATTR_NFC_FRAME_DLP2                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352752
#define RSRFSIGGEN_ATTR_NFC_FRAME_DLP4                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352753
#define RSRFSIGGEN_ATTR_NFC_FRAME_DLP8                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352754
#define RSRFSIGGEN_ATTR_NFC_FRAME_DL_POLL                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352755
#define RSRFSIGGEN_ATTR_NFC_FRAME_DPL2                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352756
#define RSRFSIGGEN_ATTR_NFC_FRAME_DPL4                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352757
#define RSRFSIGGEN_ATTR_NFC_FRAME_DPL8                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352758
#define RSRFSIGGEN_ATTR_NFC_FRAME_DPPCD                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352759
#define RSRFSIGGEN_ATTR_NFC_FRAME_DPP                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352760
#define RSRFSIGGEN_ATTR_NFC_FRAME_DPTL                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352761
#define RSRFSIGGEN_ATTR_NFC_FRAME_DRI                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352762
#define RSRFSIGGEN_ATTR_NFC_FRAME_DSI                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352763
#define RSRFSIGGEN_ATTR_NFC_FRAME_DID_SUPPORTED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352764
#define RSRFSIGGEN_ATTR_NFC_FRAME_DW_SELECTION                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352765
#define RSRFSIGGEN_ATTR_NFC_FRAME_EXTENDED_ATQB                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352766
#define RSRFSIGGEN_ATTR_NFC_FRAME_EXTENDED_SENSBRES                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352767
#define RSRFSIGGEN_ATTR_NFC_FRAME_MAXIMUM_FRAME_SIZE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352768
#define RSRFSIGGEN_ATTR_NFC_FRAME_FWI                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352769
#define RSRFSIGGEN_ATTR_NFC_FRAME_IB_NUMBER                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352770
#define RSRFSIGGEN_ATTR_NFC_FRAME_MBLI                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352771
#define RSRFSIGGEN_ATTR_NFC_FRAME_SIZE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352772
#define RSRFSIGGEN_ATTR_NFC_FRAME_MI_CHAINED                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352773
#define RSRFSIGGEN_ATTR_NFC_FRAME_MINIMUM_TR0                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352774
#define RSRFSIGGEN_ATTR_NFC_FRAME_MINIMUM_TR1                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352775
#define RSRFSIGGEN_ATTR_NFC_FRAME_MINIMUM_TR2                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352776
#define RSRFSIGGEN_ATTR_NFC_FRAME_NFCID2_FORMAT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352777
#define RSRFSIGGEN_ATTR_NFC_FRAME_NACK                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352778
#define RSRFSIGGEN_ATTR_NFC_FRAME_NAD                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352779
#define RSRFSIGGEN_ATTR_NFC_FRAME_NUMBER_OF_BLOCKS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352780
#define RSRFSIGGEN_ATTR_NFC_FRAME_NAD_FOLLOWING                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352781
#define RSRFSIGGEN_ATTR_NFC_FRAME_NFCID1_COMPLETE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352782
#define RSRFSIGGEN_ATTR_NFC_FRAME_NUMBER_OF_APPLICATIONS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352783
#define RSRFSIGGEN_ATTR_NFC_FRAME_NUMBER_OF_SLOTS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352784
#define RSRFSIGGEN_ATTR_NFC_FRAME_NUMBER_OF_SERVICES                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352785
#define RSRFSIGGEN_ATTR_NFC_FRAME_NAD_SUPPORTED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352787
#define RSRFSIGGEN_ATTR_NFC_FRAME_PAD0                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352788
#define RSRFSIGGEN_ATTR_NFC_FRAME_PAD1                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352789
#define RSRFSIGGEN_ATTR_NFC_FRAME_PAD2                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352790
#define RSRFSIGGEN_ATTR_NFC_FRAME_TYPE_PDU                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352791
#define RSRFSIGGEN_ATTR_NFC_FRAME_WTX_POWER_LEVEL_INDICATOR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352792
#define RSRFSIGGEN_ATTR_NFC_FRAME_POWER_LEVEL_INDICATOR                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352793
#define RSRFSIGGEN_ATTR_NFC_FRAME_PNI                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352794
#define RSRFSIGGEN_ATTR_NFC_FRAME_PUPI                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352795
#define RSRFSIGGEN_ATTR_NFC_FRAME_REQUEST_CODE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352796
#define RSRFSIGGEN_ATTR_NFC_FRAME_RTOX                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352797
#define RSRFSIGGEN_ATTR_NFC_FRAME_SYSTEM_CODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352798
#define RSRFSIGGEN_ATTR_NFC_FRAME_SEGMENT_SELECTION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352799
#define RSRFSIGGEN_ATTR_NFC_FRAME_SELECT_CL                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352800
#define RSRFSIGGEN_ATTR_NFC_FRAME_SEN_REQUIRED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352801
#define RSRFSIGGEN_ATTR_NFC_FRAME_SF1                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352802
#define RSRFSIGGEN_ATTR_NFC_FRAME_SF2                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352803
#define RSRFSIGGEN_ATTR_NFC_FRAME_SFGI                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352804
#define RSRFSIGGEN_ATTR_NFC_FRAME_SLOT_NUMBER                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352805
#define RSRFSIGGEN_ATTR_NFC_FRAME_SECTOR_NUMBER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353377
#define RSRFSIGGEN_ATTR_NFC_FRAME_SSN_REQUIRED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352806
#define RSRFSIGGEN_ATTR_NFC_FRAME_T1T_CONFIGURED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352807
#define RSRFSIGGEN_ATTR_NFC_FRAME_HISTORICAL_BYTES                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352808
#define RSRFSIGGEN_ATTR_NFC_FRAME_APPLICATIONS_IN_PICC                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352809
#define RSRFSIGGEN_ATTR_NFC_FRAME_TSN                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352810
#define RSRFSIGGEN_ATTR_NFC_FRAME_UID                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352811
#define RSRFSIGGEN_ATTR_NFC_FRAME_UID_COMPLETE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352812
#define RSRFSIGGEN_ATTR_NFC_FRAME_UID_SIZE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352813
#define RSRFSIGGEN_ATTR_NFC_FRAME_WAITING_TIME                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352814
#define RSRFSIGGEN_ATTR_NFC_FRAME_WTXM                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352815
#define RSRFSIGGEN_ATTR_NFC_FRAME_K_PARAMETER                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352816
#define RSRFSIGGEN_ATTR_NFC_FRAME_SAME_BIT_RATE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352817
#define RSRFSIGGEN_ATTR_NFC_FRAME_PROTOCOL_CONFIGURED_FOR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352818
#define RSRFSIGGEN_ATTR_NFC_FRAME_CFG_TYPE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352819
#define RSRFSIGGEN_ATTR_NFC_FRAME_ATTENTION_TIMEOUT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352820
#define RSRFSIGGEN_ATTR_NFC_AP_GENERIC_BIT_ORIENTED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352821
#define RSRFSIGGEN_ATTR_NFC_AP_GENERIC_BIT_ORIENTED_LENGTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352822
#define RSRFSIGGEN_ATTR_NFC_AP_GENERIC_SHORT_FRAME_DATA                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352823
#define RSRFSIGGEN_ATTR_NFC_AP_GENERIC_SHORT_FRAME_LENGTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352824
#define RSRFSIGGEN_ATTR_NFC_AP_GENERIC_TYPE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352825
#define RSRFSIGGEN_ATTR_NFC_AP_GENERIC_DATA                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352826
#define RSRFSIGGEN_ATTR_NFC_AP_GENERIC_PAYLOAD_LENGTH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352827
#define RSRFSIGGEN_ATTR_NFC_AP_GENERIC_DATA_LENGTH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352828
#define RSRFSIGGEN_ATTR_NFC_AP_GENERIC_EOD_PRESENT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352829
#define RSRFSIGGEN_ATTR_NFC_FP_GENERIC_DATA                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352830
#define RSRFSIGGEN_ATTR_NFC_FP_GENERIC_PAYLOAD_LENGTH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352831
#define RSRFSIGGEN_ATTR_NFC_FP_GENERIC_DATA_LENGTH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352832
#define RSRFSIGGEN_ATTR_NFC_BP_GENERIC_DATA                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352833
#define RSRFSIGGEN_ATTR_NFC_BP_GENERIC_PAYLOAD_LENGTH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352834
#define RSRFSIGGEN_ATTR_NFC_BP_GENERIC_DATA_LENGTH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352835
#define RSRFSIGGEN_ATTR_NFC_SERVICE_CODE_LIST_CONFIGURATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352836
#define RSRFSIGGEN_ATTR_NFC_SERVICE_NUMBER_OF_SERVICES                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352837
#define RSRFSIGGEN_ATTR_NFC_BLOCK_DATA                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352838
#define RSRFSIGGEN_ATTR_NFC_BLOCK_NUMBER                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352839
#define RSRFSIGGEN_ATTR_NFC_BLOCK_LENGTH                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352840
#define RSRFSIGGEN_ATTR_NFC_BLOCK_STATUS_INFORMATION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352841
#define RSRFSIGGEN_ATTR_NFC_BLOCK_SERVICE_CODE_LIST_ORDER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352842
#define RSRFSIGGEN_ATTR_NFC_CLIPPING_ENABLED                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352843
#define RSRFSIGGEN_ATTR_NFC_CLIPPING_LEVEL                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352844
#define RSRFSIGGEN_ATTR_NFC_TRIGGER_STATUS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352845
#define RSRFSIGGEN_ATTR_NFC_TRIGGER_ARM                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352846
#define RSRFSIGGEN_ATTR_NFC_TRIGGER_EXECUTE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352847
#define RSRFSIGGEN_ATTR_NFC_TRIGGER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352848
#define RSRFSIGGEN_ATTR_NFC_TRIGGER_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352850
#define RSRFSIGGEN_ATTR_NFC_TRIGGER_SIGNAL_DURATION_UNIT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352852
#define RSRFSIGGEN_ATTR_NFC_TRIGGER_SIGNAL_DURATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352853
#define RSRFSIGGEN_ATTR_NFC_INTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352854
#define RSRFSIGGEN_ATTR_NFC_INTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352855
#define RSRFSIGGEN_ATTR_NFC_EXTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352856
#define RSRFSIGGEN_ATTR_NFC_EXTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352857
#define RSRFSIGGEN_ATTR_NFC_MARKER_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352858
#define RSRFSIGGEN_ATTR_NFC_MARKER_PULSE_DIVIDER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352859
#define RSRFSIGGEN_ATTR_NFC_MARKER_PULSE_FREQUENCY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352860
#define RSRFSIGGEN_ATTR_NFC_MARKER_PATTERN                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352861
#define RSRFSIGGEN_ATTR_NFC_MARKER_ON_TIME                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352862
#define RSRFSIGGEN_ATTR_NFC_MARKER_OFF_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352863
#define RSRFSIGGEN_ATTR_NFC_MARKER_DELAY                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352864
#define RSRFSIGGEN_ATTR_NFC_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352865
#define RSRFSIGGEN_ATTR_NFC_FIXED_MARKER_DELAY_MAXIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352866
#define RSRFSIGGEN_ATTR_NFC_FIXED_MARKER_DELAY_MINIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352867
#define RSRFSIGGEN_ATTR_NFC_CLOCK_SOURCE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352869
#define RSRFSIGGEN_ATTR_NFC_CLOCK_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352871
#define RSRFSIGGEN_ATTR_NFC_CLOCK_MULTIPLIER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352872
#define RSRFSIGGEN_ATTR_NFC_CLOCK_SYNCHRONISATION_EXECUTE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352873
#define RSRFSIGGEN_ATTR_NFC_CLOCK_SYNCHRONISATION_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352874
#define RSRFSIGGEN_ATTR_NFC_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352875
#define RSRFSIGGEN_ATTR_GBAS_ENABLED                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352905
#define RSRFSIGGEN_ATTR_GBAS_MODE                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359888
#define RSRFSIGGEN_ATTR_GBAS_SET_TO_DEFAULT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352906
#define RSRFSIGGEN_ATTR_GBAS_WAVEFORM_CREATE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352907
#define RSRFSIGGEN_ATTR_GBAS_MULTIPLE_FREQUENCY_CHANNELS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352908
#define RSRFSIGGEN_ATTR_GBAS_GATED_POWER_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352909
#define RSRFSIGGEN_ATTR_GBAS_SAMPLE_RATE_VARIATION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352910
#define RSRFSIGGEN_ATTR_GBAS_VERSION                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352911
#define RSRFSIGGEN_ATTR_GBAS_MODULATION_TYPE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352912
#define RSRFSIGGEN_ATTR_GBAS_SAMPLE_RATE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359889
#define RSRFSIGGEN_ATTR_GBAS_SCATI_HEADER_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353378
#define RSRFSIGGEN_ATTR_GBAS_NUMBER_OF_FRAMES                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359890
#define RSRFSIGGEN_ATTR_GBAS_SETTINGS_CATALOG                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352913
#define RSRFSIGGEN_ATTR_GBAS_DELETE_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352914
#define RSRFSIGGEN_ATTR_GBAS_RECALL_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352916
#define RSRFSIGGEN_ATTR_GBAS_SAVE_SETTINGS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352918
#define RSRFSIGGEN_ATTR_GBAS_FAST_STORE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352920
#define RSRFSIGGEN_ATTR_GBAS_VDB_APPEND                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352921
#define RSRFSIGGEN_ATTR_GBAS_VDB_ENABLED                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352922
#define RSRFSIGGEN_ATTR_GBAS_VDB_ID                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352923
#define RSRFSIGGEN_ATTR_GBAS_VDB_SSID                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352924
#define RSRFSIGGEN_ATTR_GBAS_VDB_FREQUENCY_NUMBER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352925
#define RSRFSIGGEN_ATTR_GBAS_VDB_DATA                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352926
#define RSRFSIGGEN_ATTR_GBAS_VDB_DATA_LIST                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352927
#define RSRFSIGGEN_ATTR_GBAS_VDB_DATA_PATTERN                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352928
#define RSRFSIGGEN_ATTR_GBAS_VDB_APPLICATION_DATA                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359891
#define RSRFSIGGEN_ATTR_GBAS_VDB_NUMBER_OF_FRAMES                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352929
#define RSRFSIGGEN_ATTR_GBAS_VDB_INSERT                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352930
#define RSRFSIGGEN_ATTR_GBAS_VDB_DELETE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352931
#define RSRFSIGGEN_ATTR_GBAS_VDB_RID                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359892
#define RSRFSIGGEN_ATTR_SBAS_VDB_GROUND_STATION_SSID                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359893
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352932
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_POWER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352933
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_1_SLOT_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359894
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_2_SLOT_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359895
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_4_SLOT_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359896
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_11_SLOT_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359897
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_1_FRAME_OFFSET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359898
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_2_FRAME_OFFSET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359899
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_4_FRAME_OFFSET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359900
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_11_FRAME_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359901
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_1_LINKED_PAIR_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359902
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_11_LINKED_PAIR_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359903
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_1_NUMBER_OF_BYTES                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359904
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_2_NUMBER_OF_BYTES                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359905
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_4_NUMBER_OF_BYTES                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359906
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_11_NUMBER_OF_BYTES                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359907
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_1_FRAME_CYCLE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359908
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_11_FRAME_CYCLE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359909
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_2_REPETITION_FRAME                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359910
#define RSRFSIGGEN_ATTR_GBAS_VDB_SCHEDULING_MESSAGE_TYPE_4_REPETITION_FRAME                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359911
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352934
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_GS_REFERENCE_RECEIVERS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352935
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_GS_ACCURACY_DESIGNATOR                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352936
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_GS_CONTINUITY_DESIGNATOR                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352937
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_LOCAL_MAGNETIC_VARIATION                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352938
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_SIGMA_VERT_IONO_GRADIENT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352939
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_REFRACTIVITY_INDEX                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352940
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_SCALE_HEIGHT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352941
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_REFRACTIVITY_UNCERTAINTY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352942
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_REFERENCE_LOCATION_FORMAT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360714
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADDITIONAL_DATA_BLOCK_1_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359912
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADDITIONAL_DATA_BLOCK_3_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359913
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADDITIONAL_DATA_BLOCK_4_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359914
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_1_POSITIONING_SERVICE_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359915
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_1_MAXIMUM_USE_DISTANCE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359916
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_1_KMD_E_C_GPS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359917
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_1_KMD_E_C_GLONASS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359918
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_1_REFERENCE_STATION_DATA_SELECTOR                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359919
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_1_KMD_E_POS_GPS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359920
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_1_KMD_E_POS_GLONASS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359921
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_3_KMD_E_D_GPS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359922
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_3_KMD_E_D_GLONASS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359923
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_3_SIGMA_VERT_IONO_GRADIENT_ID                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359924
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_4_SLOT_GROUP_DEFINITION_A_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359925
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_4_SLOT_GROUP_DEFINITION_B_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359926
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_4_SLOT_GROUP_DEFINITION_C_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359927
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_4_SLOT_GROUP_DEFINITION_D_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359928
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_4_SLOT_GROUP_DEFINITION_E_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359929
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_4_SLOT_GROUP_DEFINITION_F_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359930
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_4_SLOT_GROUP_DEFINITION_G_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359931
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_2_ADB_4_SLOT_GROUP_DEFINITION_H_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359932
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352945
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352946
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_GLIDE_PATH_ANGLE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352947
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_TCH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352948
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_TCH_UNIT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352949
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_LTP_FTP_HEIGHT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352950
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_AIRPORT_ID                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352951
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_RUNWAY_NUMBER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352952
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_RUNWAY_LETTER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352953
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_APROACH_PERFORMANCE_DESIGNATOR                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352954
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_ROUTE_INDICATOR                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 352955
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_REFERENCE_PATH_ID                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352956
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_LTP_FTP_LOCATION_FORMAT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360715
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_DELTA_FPAP_LOCATION_FORMAT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360716
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_COURSE_WIDTH_AT_TRESHOLD                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352961
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_DELTA_LENGTH_OFFSET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352962
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_VERTICAL_ALERT_LIMIT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352963
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_LATERAL_ALERT_LIMIT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352964
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_REFERENCE_PATH_DATA                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359933
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FAS_DATA_BLOCKS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359934
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FDB_GLIDE_PATH_ANGLE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359935
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FDB_AIRPORT_ID                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359936
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FDB_TCH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359937
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FDB_RUNWAY_NUMBER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359938
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FDB_RUNWAY_LETTER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359939
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FDB_ROUTE_INDICATOR                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359940
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FDB_REFERENCE_PATH_ID                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359941
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FDB_REFERENCE_PATH_DATA                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359942
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FDB_DERP_LOCATION_FORMAT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360717
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_FDB_DP_LOCATION_FORMAT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360718
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_TAP_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352965
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_TAP_REFERENCE_PATH_DATA_SELECTOR                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 352966
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_TAP_REFERENCE_PATH_ID                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 352967
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_TAP_NUMBER_OF_PATH_POINTS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352968
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_TAP_FAS_RPDS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352969
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_TAP_VERTICAL_ALERT_LIMIT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352970
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_TAP_LATERAL_ALERT_LIMIT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 352971
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_TAP_WAYPOINT_SELECTED_FILE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352972
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_TAP_WAYPOINT_PREDEFINED_FILE_CATALOG                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352973
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_TAP_WAYPOINT_PREDEFINED_FILE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352974
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_TAP_WAYPOINT_USER_DEFINED_FILE_CATALOG                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 352976
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_TYPE_4_TAP_WAYPOINT_USER_DEFINED_FILE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 352977
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_DIFFERENTIAL_GNSS_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352979
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_DIFFERENTIAL_GNSS_SELECTED_FILE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352980
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_DIFFERENTIAL_GNSS_PREDEFINED_FILE_CATALOG                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352981
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_DIFFERENTIAL_GNSS_PREDEFINED_FILE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352982
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_DIFFERENTIAL_GNSS_USER_DEFINED_FILE_CATALOG                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 352984
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_DIFFERENTIAL_GNSS_USER_DEFINED_FILE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 352985
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_DIFFERENTIAL_GNSS_MESSAGE_TYPE_1_ENABLED                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359949
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_DIFFERENTIAL_GNSS_MESSAGE_TYPE_11_ENABLED                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359950
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_DIFFERENTIAL_GNSS_SCAT_I_FILE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359951
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_DIFFERENTIAL_GNSS_SPR_FILE_CATALOG                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359952
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_DIFFERENTIAL_GNSS_SPR_FILE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359953
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_DIFFERENTIAL_GNSS_SUS_FILE_CATALOG                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359955
#define RSRFSIGGEN_ATTR_GBAS_VDB_MESSAGE_DIFFERENTIAL_GNSS_SUS_FILE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359956
#define RSRFSIGGEN_ATTR_GBAS_FILTER_TYPE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 352987
#define RSRFSIGGEN_ATTR_GBAS_FILTER_COSINE_ROLL_OFF_FACTOR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352988
#define RSRFSIGGEN_ATTR_GBAS_FILTER_COSINE_CUT_OFF_FREQUENCY_SHIFT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352989
#define RSRFSIGGEN_ATTR_GBAS_FILTER_ROOT_COSINE_ROLL_OFF_FACTOR                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352990
#define RSRFSIGGEN_ATTR_GBAS_FILTER_GAUSS_PURE__ROLL_OFF_FACTOR                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 352991
#define RSRFSIGGEN_ATTR_GBAS_FILTER_GAUSS_ROLL_OFF_FACTOR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 352992
#define RSRFSIGGEN_ATTR_GBAS_FILTER_APCO25_ROLL_OFF_FACTOR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352993
#define RSRFSIGGEN_ATTR_GBAS_FILTER_SPLIT_PHASE_BT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 352994
#define RSRFSIGGEN_ATTR_GBAS_FILTER_LOWPASS_ACP_CUT_OFF_FREQUENCY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352995
#define RSRFSIGGEN_ATTR_GBAS_FILTER_LOWPASS_EVM_CUT_OFF_FREQUNECY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 352996
#define RSRFSIGGEN_ATTR_GBAS_CLIPPING_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 352997
#define RSRFSIGGEN_ATTR_GBAS_CLIPPING_LEVEL                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 352998
#define RSRFSIGGEN_ATTR_GBAS_CLIPPING_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 352999
#define RSRFSIGGEN_ATTR_GBAS_TRIGGER_STATUS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353000
#define RSRFSIGGEN_ATTR_GBAS_TRIGGER_ARM                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353001
#define RSRFSIGGEN_ATTR_GBAS_TRIGGER_EXECUTE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353002
#define RSRFSIGGEN_ATTR_GBAS_TRIGGER_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353003
#define RSRFSIGGEN_ATTR_GBAS_TRIGGER_SOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353004
#define RSRFSIGGEN_ATTR_GBAS_TRIGGER_SIGNAL_DURATION_UNIT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353005
#define RSRFSIGGEN_ATTR_GBAS_TRIGGER_SIGNAL_DURATION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353006
#define RSRFSIGGEN_ATTR_GBAS_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353007
#define RSRFSIGGEN_ATTR_GBAS_EXTERNAL_TRIGGER_DELAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353008
#define RSRFSIGGEN_ATTR_GBAS_EXTERNAL_TRIGGER_INHIBIT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353009
#define RSRFSIGGEN_ATTR_GBAS_INTERNAL_TRIGGER_DELAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359958
#define RSRFSIGGEN_ATTR_GBAS_INTERNAL_TRIGGER_INHIBIT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359959
#define RSRFSIGGEN_ATTR_GBAS_MARKER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353010
#define RSRFSIGGEN_ATTR_GBAS_MARKER_ON_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353011
#define RSRFSIGGEN_ATTR_GBAS_MARKER_OFF_TIME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353012
#define RSRFSIGGEN_ATTR_GBAS_MARKER_PULSE_DIVIDER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353013
#define RSRFSIGGEN_ATTR_GBAS_MARKER_PULSE_FREQUENCY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353014
#define RSRFSIGGEN_ATTR_GBAS_MARKER_PATTERN                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353015
#define RSRFSIGGEN_ATTR_GBAS_MARKER_DELAY                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353016
#define RSRFSIGGEN_ATTR_GBAS_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353017
#define RSRFSIGGEN_ATTR_GBAS_FIXED_MARKER_DELAY_MAXIMUM                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353018
#define RSRFSIGGEN_ATTR_GBAS_FIXED_MARKER_DELAY_MINIMUM                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353019
#define RSRFSIGGEN_ATTR_GBAS_CLOCK_SOURCE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353020
#define RSRFSIGGEN_ATTR_GBAS_CLOCK_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353021
#define RSRFSIGGEN_ATTR_GBAS_CLOCK_MULTIPLIER                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353022
#define RSRFSIGGEN_ATTR_GBAS_CLOCK_SYNCHRONISATION_EXECUTE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353023
#define RSRFSIGGEN_ATTR_GBAS_CLOCK_SYNCHRONISATION_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353024
#define RSRFSIGGEN_ATTR_ILS_ENABLED                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353847
#define RSRFSIGGEN_ATTR_ILS_SET_TO_DEFAULT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353848
#define RSRFSIGGEN_ATTR_ILS_COMPONENT                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353849
#define RSRFSIGGEN_ATTR_ILS_SETTINGS_CATALOG                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353850
#define RSRFSIGGEN_ATTR_ILS_DELETE_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353851
#define RSRFSIGGEN_ATTR_ILS_RECALL_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353853
#define RSRFSIGGEN_ATTR_ILS_SAVE_SETTINGS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353855
#define RSRFSIGGEN_ATTR_ILS_FAST_STORE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353857
#define RSRFSIGGEN_ATTR_ILS_GLIDE_SLOPE_CARRIER_FREQUENCY_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353858
#define RSRFSIGGEN_ATTR_ILS_GLIDE_SLOPE_CARRIER_FREQUENCY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353859
#define RSRFSIGGEN_ATTR_ILS_GLIDE_SLOPE_ICAO_CHANNEL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353860
#define RSRFSIGGEN_ATTR_ILS_GLIDE_SLOPE_DDM_POLARITY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353861
#define RSRFSIGGEN_ATTR_ILS_GLIDE_SLOPE_SIGNAL_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353862
#define RSRFSIGGEN_ATTR_ILS_GLIDE_SLOPE_LEFT_FREQUENCY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353863
#define RSRFSIGGEN_ATTR_ILS_GLIDE_SLOPE_RIGHT_FREQUENCY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353864
#define RSRFSIGGEN_ATTR_ILS_GLIDE_SLOPE_PHASE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353865
#define RSRFSIGGEN_ATTR_ILS_GLIDE_SLOPE_SUM_OF_DEPTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353866
#define RSRFSIGGEN_ATTR_ILS_GLIDE_SLOPE_FLY                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353867
#define RSRFSIGGEN_ATTR_ILS_GLIDE_SLOPE_DDM_STEP                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353868
#define RSRFSIGGEN_ATTR_ILS_GLIDE_SLOPE_DDM_CURRENT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353869
#define RSRFSIGGEN_ATTR_ILS_GLIDE_SLOPE_DDM_DEPTH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353870
#define RSRFSIGGEN_ATTR_ILS_GLIDE_SLOPE_DDM_LOGARITHMICS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353871
#define RSRFSIGGEN_ATTR_ILS_GLIDE_SLOPE_DDM_PERCENT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353872
#define RSRFSIGGEN_ATTR_ILS_GLIDE_SLOPE_DDM_COUPLING                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353873
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_CARRIER_FREQUENCY_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353874
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_CARRIER_FREQUENCY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353875
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_ICAO_CHANNEL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353876
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_DDM_POLARITY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353877
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_SIGNAL_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353878
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_LEFT_FREQUENCY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353879
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_RIGHT_FREQUENCY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353880
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_PHASE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353881
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_SUM_OF_DEPTH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353882
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_FLY                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353883
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_DDM_STEP                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353884
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_DDM_CURRENT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353885
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_DDM_DEPTH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353886
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_DDM_LOGARITHMICS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353887
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_DDM_PERCENT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353888
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_DDM_COUPLING                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353889
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_COM_ID_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353890
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_COM_ID_CODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353891
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_COM_ID_FREQUENCY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353892
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_COM_ID_PERIOD                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353893
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_COM_ID_DEPTH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353894
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_COM_ID_TIME_SCHEMA                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353895
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_COM_ID_DOT_LENGTH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353896
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_COM_ID_SYMBOL_SPACE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353897
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_COM_ID_DASH_LENGTH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353898
#define RSRFSIGGEN_ATTR_ILS_LOCALIZER_COM_ID_LETTER_SPACE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353899
#define RSRFSIGGEN_ATTR_ILS_MARKER_BEACONS_CARRIER_FREQUENCY_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353900
#define RSRFSIGGEN_ATTR_ILS_MARKER_BEACONS_CARRIER_FREQUENCY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353901
#define RSRFSIGGEN_ATTR_ILS_MARKER_BEACONS_MARKER_FREQUENCY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353902
#define RSRFSIGGEN_ATTR_ILS_MARKER_BEACONS_MARKER_DEPTH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353903
#define RSRFSIGGEN_ATTR_ILS_MARKER_BEACONS_COM_ID_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353904
#define RSRFSIGGEN_ATTR_ILS_MARKER_BEACONS_COM_ID_CODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353905
#define RSRFSIGGEN_ATTR_ILS_MARKER_BEACONS_COM_ID_FREQUENCY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353906
#define RSRFSIGGEN_ATTR_ILS_MARKER_BEACONS_COM_ID_PERIOD                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353907
#define RSRFSIGGEN_ATTR_ILS_MARKER_BEACONS_COM_ID_DEPTH                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353908
#define RSRFSIGGEN_ATTR_ILS_MARKER_BEACONS_COM_ID_TIME_SCHEMA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353909
#define RSRFSIGGEN_ATTR_ILS_MARKER_BEACONS_COM_ID_DOT_LENGTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353910
#define RSRFSIGGEN_ATTR_ILS_MARKER_BEACONS_COM_ID_SYMBOL_SPACE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353911
#define RSRFSIGGEN_ATTR_ILS_MARKER_BEACONS_COM_ID_DASH_LENGTH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353912
#define RSRFSIGGEN_ATTR_ILS_MARKER_BEACONS_COM_ID_LETTER_SPACE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353913
#define RSRFSIGGEN_ATTR_ILS_TRIGGER_STATUS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353914
#define RSRFSIGGEN_ATTR_ILS_TRIGGER_ARM                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353915
#define RSRFSIGGEN_ATTR_ILS_TRIGGER_EXECUTE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353916
#define RSRFSIGGEN_ATTR_ILS_TRIGGER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353917
#define RSRFSIGGEN_ATTR_ILS_TRIGGER_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353918
#define RSRFSIGGEN_ATTR_ILS_TRIGGER_SIGNAL_DURATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353919
#define RSRFSIGGEN_ATTR_ILS_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353920
#define RSRFSIGGEN_ATTR_ILS_INTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353921
#define RSRFSIGGEN_ATTR_ILS_INTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353922
#define RSRFSIGGEN_ATTR_ILS_EXTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353923
#define RSRFSIGGEN_ATTR_ILS_EXTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353924
#define RSRFSIGGEN_ATTR_ILS_CLOCK_SOURCE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353925
#define RSRFSIGGEN_ATTR_ILS_CLOCK_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353926
#define RSRFSIGGEN_ATTR_ILS_CLOCK_MULTIPLIER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353927
#define RSRFSIGGEN_ATTR_ILS_CLOCK_SYNCHRONISATION_EXECUTE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353928
#define RSRFSIGGEN_ATTR_ILS_CLOCK_SYNCHRONISATION_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353929
#define RSRFSIGGEN_ATTR_VOR_ENABLED                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353930
#define RSRFSIGGEN_ATTR_VOR_SET_TO_DEFAULT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353931
#define RSRFSIGGEN_ATTR_VOR_SETTINGS_CATALOG                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353932
#define RSRFSIGGEN_ATTR_VOR_DELETE_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353933
#define RSRFSIGGEN_ATTR_VOR_RECALL_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353935
#define RSRFSIGGEN_ATTR_VOR_SAVE_SETTINGS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353937
#define RSRFSIGGEN_ATTR_VOR_FAST_STORE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353939
#define RSRFSIGGEN_ATTR_VOR_CARRIER_FREQUENCY_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353940
#define RSRFSIGGEN_ATTR_VOR_CARRIER_FREQUENCY                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353941
#define RSRFSIGGEN_ATTR_VOR_ICAO_CHANNEL                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353942
#define RSRFSIGGEN_ATTR_VOR_SIGNAL_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353943
#define RSRFSIGGEN_ATTR_VOR_VARIABLE_REFERENCE_FREQUENCY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353944
#define RSRFSIGGEN_ATTR_VOR_VARIABLE_DEPTH                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353945
#define RSRFSIGGEN_ATTR_VOR_SUBCARRIER_FREQUENCY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353946
#define RSRFSIGGEN_ATTR_VOR_SUBCARRIER_DEPTH                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353947
#define RSRFSIGGEN_ATTR_VOR_FREQUENCY_DEVIATION                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353948
#define RSRFSIGGEN_ATTR_VOR_POSITION_BEARING_ANGLE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353949
#define RSRFSIGGEN_ATTR_VOR_POSITION_BEARING_ANGLE_DIRECTION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353950
#define RSRFSIGGEN_ATTR_VOR_COM_ID_ENABLED                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353951
#define RSRFSIGGEN_ATTR_VOR_COM_ID_CODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353952
#define RSRFSIGGEN_ATTR_VOR_COM_ID_FREQUENCY                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353953
#define RSRFSIGGEN_ATTR_VOR_COM_ID_PERIOD                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353954
#define RSRFSIGGEN_ATTR_VOR_COM_ID_DEPTH                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353955
#define RSRFSIGGEN_ATTR_VOR_COM_ID_TIME_SCHEMA                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353956
#define RSRFSIGGEN_ATTR_VOR_COM_ID_DOT_LENGTH                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353957
#define RSRFSIGGEN_ATTR_VOR_COM_ID_SYMBOL_SPACE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353958
#define RSRFSIGGEN_ATTR_VOR_COM_ID_DASH_LENGTH                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353959
#define RSRFSIGGEN_ATTR_VOR_COM_ID_LETTER_SPACE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353960
#define RSRFSIGGEN_ATTR_VOR_TRIGGER_STATUS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353961
#define RSRFSIGGEN_ATTR_VOR_TRIGGER_ARM                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353962
#define RSRFSIGGEN_ATTR_VOR_TRIGGER_EXECUTE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353963
#define RSRFSIGGEN_ATTR_VOR_TRIGGER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353964
#define RSRFSIGGEN_ATTR_VOR_TRIGGER_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353965
#define RSRFSIGGEN_ATTR_VOR_TRIGGER_SIGNAL_DURATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353966
#define RSRFSIGGEN_ATTR_VOR_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353967
#define RSRFSIGGEN_ATTR_VOR_INTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353968
#define RSRFSIGGEN_ATTR_VOR_INTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353969
#define RSRFSIGGEN_ATTR_VOR_EXTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353970
#define RSRFSIGGEN_ATTR_VOR_EXTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353971
#define RSRFSIGGEN_ATTR_VOR_CLOCK_SOURCE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353972
#define RSRFSIGGEN_ATTR_VOR_CLOCK_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353973
#define RSRFSIGGEN_ATTR_VOR_CLOCK_MULTIPLIER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353974
#define RSRFSIGGEN_ATTR_VOR_CLOCK_SYNCHRONISATION_EXECUTE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353975
#define RSRFSIGGEN_ATTR_VOR_CLOCK_SYNCHRONISATION_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353976
#define RSRFSIGGEN_ATTR_DME_ENABLED                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353977
#define RSRFSIGGEN_ATTR_DME_MODE                                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354124
#define RSRFSIGGEN_ATTR_DME_SET_TO_DEFAULT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353978
#define RSRFSIGGEN_ATTR_DME_SETTINGS_CATALOG                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353979
#define RSRFSIGGEN_ATTR_DME_DELETE_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353980
#define RSRFSIGGEN_ATTR_DME_RECALL_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353982
#define RSRFSIGGEN_ATTR_DME_SAVE_SETTINGS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353984
#define RSRFSIGGEN_ATTR_DME_FAST_STORE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353986
#define RSRFSIGGEN_ATTR_DME_CHANNEL_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353987
#define RSRFSIGGEN_ATTR_DME_CARRIER_FREQUENCY                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353988
#define RSRFSIGGEN_ATTR_DME_ICAO_CHANNEL                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353989
#define RSRFSIGGEN_ATTR_DME_RANGE_DISTANCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353990
#define RSRFSIGGEN_ATTR_DME_RANGE_DISTANCE_UNIT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355107
#define RSRFSIGGEN_ATTR_DME_PULSE_SQUITTER                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353991
#define RSRFSIGGEN_ATTR_DME_PULSE_REPETITION_RATE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353992
#define RSRFSIGGEN_ATTR_DME_REPLY_EFFICIENCY                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353993
#define RSRFSIGGEN_ATTR_DME_PULSE_INPUT_SOURCE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353994
#define RSRFSIGGEN_ATTR_DME_PULSE_INPUT_DELAY                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353995
#define RSRFSIGGEN_ATTR_DME_PULSE_INPUT_SEARCH_TRIGGER_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353996
#define RSRFSIGGEN_ATTR_DME_PULSE_INPUT_TRIGGER_LEVEL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353997
#define RSRFSIGGEN_ATTR_DME_PULSE_SHAPE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353998
#define RSRFSIGGEN_ATTR_DME_PULSE_RISE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353999
#define RSRFSIGGEN_ATTR_DME_PULSE_WIDTH                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354000
#define RSRFSIGGEN_ATTR_DME_PULSE_FALL                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 354001
#define RSRFSIGGEN_ATTR_DME_PULSE_SPACING                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 354002
#define RSRFSIGGEN_ATTR_DME_SINGLE_PULSE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 354003
#define RSRFSIGGEN_ATTR_DME_PULSE_PAIR_SPACING_TOLERANCE_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355831
#define RSRFSIGGEN_ATTR_DME_PULSE_PAIR_SPACING_TOLERANCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 354004
#define RSRFSIGGEN_ATTR_DME_ANALYSIS_ENABLED                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 354005
#define RSRFSIGGEN_ATTR_DME_ANALYSIS_EXPECTED_REPLY_DELAY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 354006
#define RSRFSIGGEN_ATTR_DME_ANALYSIS_GATE_LENGTH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354007
#define RSRFSIGGEN_ATTR_DME_ANALYSIS_MEASUREMENT_TIME                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 354008
#define RSRFSIGGEN_ATTR_DME_ANALYSIS_GATE_COUNT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 354009
#define RSRFSIGGEN_ATTR_DME_ANALYSIS_PEAK_LEVEL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 354010
#define RSRFSIGGEN_ATTR_DME_ANALYSIS_PEAK_LEVEL_AVAILABLE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 354011
#define RSRFSIGGEN_ATTR_DME_ANALYSIS_RANGE_DISTANCE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 354012
#define RSRFSIGGEN_ATTR_DME_ANALYSIS_REPLY_DELAY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354013
#define RSRFSIGGEN_ATTR_DME_ANALYSIS_REPLY_DELAY_VALID                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 354014
#define RSRFSIGGEN_ATTR_DME_ANALYSIS_REPLY_EFFICIENCY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 354015
#define RSRFSIGGEN_ATTR_DME_ANALYSIS_REPLY_EFFICIENCY_VALID                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 354016
#define RSRFSIGGEN_ATTR_DME_ANALYSIS_PULSE_REPETITION_RATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 354017
#define RSRFSIGGEN_ATTR_DME_ANALYSIS_PULSE_REPETITION_RATE_VALID                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354018
#define RSRFSIGGEN_ATTR_DME_COM_ID_ENABLED                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 354019
#define RSRFSIGGEN_ATTR_DME_COM_ID_PRESET                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 354020
#define RSRFSIGGEN_ATTR_DME_COM_ID_PAIR_OF_PULSE_PAIRS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 354021
#define RSRFSIGGEN_ATTR_DME_COM_ID_PULSE_PAIR_SPACING                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 354022
#define RSRFSIGGEN_ATTR_DME_COM_ID_CODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354023
#define RSRFSIGGEN_ATTR_DME_COM_ID_RATE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354024
#define RSRFSIGGEN_ATTR_DME_COM_ID_PERIOD                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 354025
#define RSRFSIGGEN_ATTR_DME_COM_ID_TIME_SCHEMA                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 354026
#define RSRFSIGGEN_ATTR_DME_COM_ID_DOT_LENGTH                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 354027
#define RSRFSIGGEN_ATTR_DME_COM_ID_SYMBOL_SPACE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 354028
#define RSRFSIGGEN_ATTR_DME_ID_DASH_LENGTH                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 354029
#define RSRFSIGGEN_ATTR_DME_COM_ID_LETTER_SPACE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 354030
#define RSRFSIGGEN_ATTR_DME_ADJUSTMENT_FACTORS_NORMALIZE_SETUP                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 354031
#define RSRFSIGGEN_ATTR_DME_ADJUSTMENT_FACTORS_POWER_SENSOR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 354032
#define RSRFSIGGEN_ATTR_DME_ADJUSTMENT_FACTORS_INTERNAL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354033
#define RSRFSIGGEN_ATTR_DME_ADJUSTMENT_FACTORS_USED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 354034
#define RSRFSIGGEN_ATTR_DME_ADJUSTMENT_FACTORS_TRIGGER_SEARCH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 354129
#define RSRFSIGGEN_ATTR_DME_TRIGGER_STATUS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 354035
#define RSRFSIGGEN_ATTR_DME_TRIGGER_ARM                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354036
#define RSRFSIGGEN_ATTR_DME_TRIGGER_EXECUTE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 354037
#define RSRFSIGGEN_ATTR_DME_TRIGGER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 354038
#define RSRFSIGGEN_ATTR_DME_TRIGGER_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 354039
#define RSRFSIGGEN_ATTR_DME_TRIGGER_SIGNAL_DURATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 354040
#define RSRFSIGGEN_ATTR_DME_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 354041
#define RSRFSIGGEN_ATTR_DME_INTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 354042
#define RSRFSIGGEN_ATTR_DME_INTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 354043
#define RSRFSIGGEN_ATTR_DME_EXTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 354044
#define RSRFSIGGEN_ATTR_DME_EXTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 354045
#define RSRFSIGGEN_ATTR_DME_CLOCK_SOURCE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 354046
#define RSRFSIGGEN_ATTR_DME_CLOCK_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 354047
#define RSRFSIGGEN_ATTR_DME_CLOCK_MULTIPLIER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 354048
#define RSRFSIGGEN_ATTR_DME_CLOCK_SYNCHRONISATION_EXECUTE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 354049
#define RSRFSIGGEN_ATTR_DME_CLOCK_SYNCHRONISATION_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 354050
#define RSRFSIGGEN_ATTR_DME_MARKER_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354125
#define RSRFSIGGEN_ATTR_DME_MARKER_WIDTH                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 354126
#define RSRFSIGGEN_ATTR_DME_MARKER_DELAY                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 354127
#define RSRFSIGGEN_ATTR_DME_MARKER_PROCESSING_DELAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 354128
#define RSRFSIGGEN_ATTR_POWER_SWEEP_ENABLED                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353379
#define RSRFSIGGEN_ATTR_POWER_SWEEP_SET_TO_DEFAULT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353380
#define RSRFSIGGEN_ATTR_POWER_SWEEP_GENERATE_WAVEFORM_FILE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353381
#define RSRFSIGGEN_ATTR_POWER_SWEEP_SETTINGS_CATALOG                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353383
#define RSRFSIGGEN_ATTR_POWER_SWEEP_DELETE_SETTINGS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353384
#define RSRFSIGGEN_ATTR_POWER_SWEEP_RECALL_SETTINGS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353386
#define RSRFSIGGEN_ATTR_POWER_SWEEP_SAVE_SETTINGS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353388
#define RSRFSIGGEN_ATTR_POWER_SWEEP_FAST_STORE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353390
#define RSRFSIGGEN_ATTR_POWER_SWEEP_TRIGGER_STATUS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353391
#define RSRFSIGGEN_ATTR_POWER_SWEEP_TRIGGER_ARM                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353392
#define RSRFSIGGEN_ATTR_POWER_SWEEP_TRIGGER_EXECUTE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353393
#define RSRFSIGGEN_ATTR_POWER_SWEEP_TRIGGER_MODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353394
#define RSRFSIGGEN_ATTR_POWER_SWEEP_TRIGGER_SOURCE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353395
#define RSRFSIGGEN_ATTR_POWER_SWEEP_TRIGGER_SIGNAL_DURATION_UNIT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353396
#define RSRFSIGGEN_ATTR_POWER_SWEEP_TRIGGER_SIGNAL_DURATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353397
#define RSRFSIGGEN_ATTR_POWER_SWEEP_EXTERNAL_TRIGGER_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353398
#define RSRFSIGGEN_ATTR_POWER_SWEEP_INTERNAL_TRIGGER_DELAY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353399
#define RSRFSIGGEN_ATTR_POWER_SWEEP_INTERNAL_TRIGGER_INHIBIT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353400
#define RSRFSIGGEN_ATTR_POWER_SWEEP_EXTERNAL_TRIGGER_DELAY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353401
#define RSRFSIGGEN_ATTR_POWER_SWEEP_EXTERNAL_TRIGGER_INHIBIT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353402
#define RSRFSIGGEN_ATTR_POWER_SWEEP_MARKER_MODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353403
#define RSRFSIGGEN_ATTR_POWER_SWEEP_MARKER_DELAY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353404
#define RSRFSIGGEN_ATTR_POWER_SWEEP_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353405
#define RSRFSIGGEN_ATTR_POWER_SWEEP_FIXED_MARKER_DELAY_MAXIMUM                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353406
#define RSRFSIGGEN_ATTR_POWER_SWEEP_FIXED_MARKER_DELAY_MINIMUM                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353407
#define RSRFSIGGEN_ATTR_POWER_SWEEP_CLOCK_SOURCE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353408
#define RSRFSIGGEN_ATTR_POWER_SWEEP_CLOCK_MODE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353409
#define RSRFSIGGEN_ATTR_POWER_SWEEP_CLOCK_MULTIPLIER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353410
#define RSRFSIGGEN_ATTR_POWER_SWEEP_CLOCK_SYNCHRONISATION_EXECUTE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353411
#define RSRFSIGGEN_ATTR_POWER_SWEEP_CLOCK_SYNCHRONISATION_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353412
#define RSRFSIGGEN_ATTR_POWER_SWEEP_ATTENUATION                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353413
#define RSRFSIGGEN_ATTR_POWER_SWEEP_RF_BLANKING_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353414
#define RSRFSIGGEN_ATTR_POWER_SWEEP_RF_BLANKING_TIME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353415
#define RSRFSIGGEN_ATTR_POWER_SWEEP_CONSTANT_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353416
#define RSRFSIGGEN_ATTR_POWER_SWEEP_FALL_TIME                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353417
#define RSRFSIGGEN_ATTR_POWER_SWEEP_LEVEL                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353418
#define RSRFSIGGEN_ATTR_POWER_SWEEP_PRESWEEP_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353419
#define RSRFSIGGEN_ATTR_POWER_SWEEP_PRESWEEP_TIME                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353420
#define RSRFSIGGEN_ATTR_POWER_SWEEP_PRESWEEP_POWER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353421
#define RSRFSIGGEN_ATTR_POWER_SWEEP_RANGE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353422
#define RSRFSIGGEN_ATTR_POWER_SWEEP_RESOLUTION                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353423
#define RSRFSIGGEN_ATTR_POWER_SWEEP_SAMPLE_RATE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353424
#define RSRFSIGGEN_ATTR_POWER_SWEEP_SHAPE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353425
#define RSRFSIGGEN_ATTR_POWER_SWEEP_SLOPE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353426
#define RSRFSIGGEN_ATTR_POWER_SWEEP_DWELL_TIME_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353427
#define RSRFSIGGEN_ATTR_POWER_SWEEP_DWELL_TIME                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353428
#define RSRFSIGGEN_ATTR_POWER_SWEEP_STEP_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353429
#define RSRFSIGGEN_ATTR_POWER_SWEEP_STEP_SIZE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353430
#define RSRFSIGGEN_ATTR_POWER_SWEEP_START_LEVEL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353431
#define RSRFSIGGEN_ATTR_POWER_SWEEP_STOP_LEVEL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353432
#define RSRFSIGGEN_ATTR_POWER_SWEEP_TIME                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353433
#define RSRFSIGGEN_ATTR_PROGRESS_MULTI_CODER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353654
#define RSRFSIGGEN_ATTR_PROGRESS_MULTI_CODER_CARRIER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353655
#define RSRFSIGGEN_ATTR_PROGRESS_MULTI_CODER_SEGMENT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353656
#define RSRFSIGGEN_ATTR_PROGRESS_MULTI_CODER_DIGITAL_MODULATION_FILTER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353657
#define RSRFSIGGEN_ATTR_OFDM_ENABLED                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355009
#define RSRFSIGGEN_ATTR_OFDM_SET_TO_DEFAULT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355010
#define RSRFSIGGEN_ATTR_OFDM_SET_TO_MODULATION_DEFAULT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355011
#define RSRFSIGGEN_ATTR_OFDM_SYMBOL_RATE_VARIATION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355012
#define RSRFSIGGEN_ATTR_OFDM_MODULATION_TYPE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355013
#define RSRFSIGGEN_ATTR_OFDM_OUTPUT_PATH                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359960
#define RSRFSIGGEN_ATTR_OFDM_DFT_S_ENABLED                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362860
#define RSRFSIGGEN_ATTR_OFDM_SETTINGS_CATALOG                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355014
#define RSRFSIGGEN_ATTR_OFDM_RECALL_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355015
#define RSRFSIGGEN_ATTR_OFDM_DELETE_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355017
#define RSRFSIGGEN_ATTR_OFDM_SAVE_SETTINGS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355019
#define RSRFSIGGEN_ATTR_OFDM_GENERATE_WAVEFORM_FILE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355021
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_NUMBER_OF_ALLOCATIONS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355023
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_MODULATION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355024
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_NUMBER_OF_SUBCARRIERS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355025
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_NUMBER_OF_SYMBOLS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355026
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_SUBCARRIER_OFFSET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355027
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_SYMBOL_OFFSET                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355028
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_PHYSICAL_BITS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355029
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_DATA_SOURCE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355030
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_DATA_LIST                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355031
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_BIT_PATTERN                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355032
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_CUSTOM_IQ_FILE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356282
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_POWER                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355033
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_CONTENT_TYPE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355034
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_STATE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355035
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_CONFLICT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355036
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_CUSTOM_CONSTELLATION_MODULATION_ORDER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363202
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_SPLIT_PATTERN_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363203
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_SPLIT_PATTERN_SCS_SIZE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363204
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_SPLIT_PATTERN_SCS_STEP                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363205
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_SPLIT_PATTERN_SYMBOL_SIZE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363206
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_SPLIT_PATTERN_SYMBOL_STEP                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363207
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_ZADOFF_CHU_CYCLIC_SHIFT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363208
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_ZADOFF_CHU_SEQUENCE_LENGTH                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363209
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_ZADOFF_CHU_SEQUENCE_NUMBER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363210
#define RSRFSIGGEN_ATTR_OFDM_SPREADING_FACTOR                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355037
#define RSRFSIGGEN_ATTR_OFDM_CODEBOOK_SIZE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355038
#define RSRFSIGGEN_ATTR_OFDM_CODEBOOK_NUMBER_OF_LAYERS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355039
#define RSRFSIGGEN_ATTR_OFDM_LAYER_MAPPING_USER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355040
#define RSRFSIGGEN_ATTR_OFDM_LAYER_MAPPING_POWER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355041
#define RSRFSIGGEN_ATTR_OFDM_LAYER_MAPPING_STATE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355042
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_CONSTELLATION_POINT_REAL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363211
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_CONSTELLATION_POINT_IMAGINARY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363212
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_CONSTELLATION_POINT_MAGNITUDE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363213
#define RSRFSIGGEN_ATTR_OFDM_ALLOCATION_CONSTELLATION_POINT_PHASE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363214
#define RSRFSIGGEN_ATTR_OFDM_USER_DATA_SOURCE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355043
#define RSRFSIGGEN_ATTR_OFDM_USER_DATA_LIST                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355044
#define RSRFSIGGEN_ATTR_OFDM_USER_BIT_PATTERN                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355045
#define RSRFSIGGEN_ATTR_OFDM_USER_POWER                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355046
#define RSRFSIGGEN_ATTR_OFDM_USER_STATE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355047
#define RSRFSIGGEN_ATTR_OFDM_FILTER_TYPE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355048
#define RSRFSIGGEN_ATTR_OFDM_FILTER_ROLLOFF_FACTOR                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355049
#define RSRFSIGGEN_ATTR_OFDM_FILTER_LENGTH                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355050
#define RSRFSIGGEN_ATTR_OFDM_FILTER_STOPBAND_ATTENUATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355051
#define RSRFSIGGEN_ATTR_OFDM_FILTER_WINDOWING                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355052
#define RSRFSIGGEN_ATTR_OFDM_FILTER_CUT_TRANSIENT_RESPONSE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355053
#define RSRFSIGGEN_ATTR_OFDM_USER_FILTER_LENGTH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355054
#define RSRFSIGGEN_ATTR_OFDM_USER_FILTER_CATALOG                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355055
#define RSRFSIGGEN_ATTR_OFDM_USER_FILTER_LOAD                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355057
#define RSRFSIGGEN_ATTR_OFDM_TRIGGER_STATUS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355058
#define RSRFSIGGEN_ATTR_OFDM_TRIGGER_ARM                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355059
#define RSRFSIGGEN_ATTR_OFDM_TRIGGER_EXECUTE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355060
#define RSRFSIGGEN_ATTR_OFDM_TRIGGER_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355061
#define RSRFSIGGEN_ATTR_OFDM_TRIGGER_SOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355062
#define RSRFSIGGEN_ATTR_OFDM_TRIGGER_SIGNAL_DURATION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355063
#define RSRFSIGGEN_ATTR_OFDM_TRIGGER_SIGNAL_DURATION_UNIT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355064
#define RSRFSIGGEN_ATTR_OFDM_TIME_BASED_TRIGGER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363417
#define RSRFSIGGEN_ATTR_OFDM_INTERNAL_TRIGGER_DELAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355065
#define RSRFSIGGEN_ATTR_OFDM_INTERNAL_TRIGGER_INHIBIT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355066
#define RSRFSIGGEN_ATTR_OFDM_INTERNAL_TRIGGER_TIME_DELAY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355067
#define RSRFSIGGEN_ATTR_OFDM_INTERNAL_TRIGGER_ACTUAL_TIME_DELAY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355068
#define RSRFSIGGEN_ATTR_OFDM_EXTERNAL_TRIGGER_DELAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355069
#define RSRFSIGGEN_ATTR_OFDM_EXTERNAL_TRIGGER_DELAY_UNIT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355070
#define RSRFSIGGEN_ATTR_OFDM_EXTERNAL_TRIGGER_TIME_DELAY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355071
#define RSRFSIGGEN_ATTR_OFDM_EXTERNAL_TRIGGER_INHIBIT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355072
#define RSRFSIGGEN_ATTR_OFDM_EXTERNAL_TRIGGER_ACTUAL_DELAY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355073
#define RSRFSIGGEN_ATTR_OFDM_MARKER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355074
#define RSRFSIGGEN_ATTR_OFDM_MARKER_USER_PERIOD                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355075
#define RSRFSIGGEN_ATTR_OFDM_MARKER_OFF_TIME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355076
#define RSRFSIGGEN_ATTR_OFDM_MARKER_ON_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355077
#define RSRFSIGGEN_ATTR_OFDM_MARKER_RISE_OFFSET                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355078
#define RSRFSIGGEN_ATTR_OFDM_MARKER_FALL_OFFSET                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355079
#define RSRFSIGGEN_ATTR_OFDM_MARKER_DELAY                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355080
#define RSRFSIGGEN_ATTR_OFDM_FIX_MARKER_DELAY_TO_CURRENT_RANGE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355081
#define RSRFSIGGEN_ATTR_OFDM_FIXED_MARKER_DELAY_MAXIMUM                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355082
#define RSRFSIGGEN_ATTR_OFDM_FIXED_MARKER_DELAY_MINIMUM                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355083
#define RSRFSIGGEN_ATTR_OFDM_CLOCK_SOURCE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355084
#define RSRFSIGGEN_ATTR_OFDM_CLOCK_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355085
#define RSRFSIGGEN_ATTR_OFDM_CLOCK_MULTIPLIER                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355086
#define RSRFSIGGEN_ATTR_OFDM_CLOCK_SYNCHRONISATION_EXECUTE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355087
#define RSRFSIGGEN_ATTR_OFDM_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355088
#define RSRFSIGGEN_ATTR_OFDM_NUMBER_OF_SUBCARRIERS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355089
#define RSRFSIGGEN_ATTR_OFDM_OCCUPIED_NUMBER_OF_SUBCARRIERS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355090
#define RSRFSIGGEN_ATTR_OFDM_SUBCARRIER_SPACING                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355091
#define RSRFSIGGEN_ATTR_OFDM_SEQUENCE_LENGTH                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355092
#define RSRFSIGGEN_ATTR_OFDM_CYCLIC_PREFIX_LENGTH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355093
#define RSRFSIGGEN_ATTR_OFDM_ALTERNATIVE_CYCLIC_PREFIX_LENGTH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356283
#define RSRFSIGGEN_ATTR_OFDM_CP_NUMBER_OF_SYMBOLS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356284
#define RSRFSIGGEN_ATTR_OFDM_ALTERNATIVE_CP_NUMBER_OF_SYMBOLS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356285
#define RSRFSIGGEN_ATTR_OFDM_SAMPLE_RATE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355094
#define RSRFSIGGEN_ATTR_OFDM_OCCUPIED_BANDWIDTH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355095
#define RSRFSIGGEN_ATTR_OFDM_LEFT_GUARD_SUBCARRIERS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355096
#define RSRFSIGGEN_ATTR_OFDM_RIGHT_GUARD_SUBCARRIERS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355097
#define RSRFSIGGEN_ATTR_OFDM_CYCLIC_SUFFIX_LENGTH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363418
#define RSRFSIGGEN_ATTR_OFDM_DC_MODE                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363419
#define RSRFSIGGEN_ATTR_OFDM_MODULATION_UFMC_NSUBBANDS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355098
#define RSRFSIGGEN_ATTR_OFDM_MODULATION_FOFDM_NSUBBANDS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355099
#define RSRFSIGGEN_ATTR_OFDM_MODULATION_FOFDM_NTX_BLOCKS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355100
#define RSRFSIGGEN_ATTR_OFDM_MODULATION_SUBCARRIERS_PER_SUBBAND                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355101
#define RSRFSIGGEN_ATTR_OFDM_MODULATION_FILTER_PREEQUAL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355102
#define RSRFSIGGEN_ATTR_OFDM_MODULATION_DATA_BLOCK_SIZE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355103
#define RSRFSIGGEN_ATTR_OFDM_NOTCH_FILTER_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357713
#define RSRFSIGGEN_ATTR_OFDM_NOTCH_FILTER_CLOCK_FREQUENCY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357714
#define RSRFSIGGEN_ATTR_OFDM_NOTCH_FILTER_NUMBER_OF_NOTCHES                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357715
#define RSRFSIGGEN_ATTR_OFDM_NOTCH_FILTER_APPLY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357716
#define RSRFSIGGEN_ATTR_OFDM_NOTCH_FILTER_NOTCH_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357717
#define RSRFSIGGEN_ATTR_OFDM_NOTCH_FILTER_NOTCH_BANDWIDTH_RELATIVE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357718
#define RSRFSIGGEN_ATTR_OFDM_NOTCH_FILTER_NOTCH_BANDWIDTH_ABSOLUTE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357719
#define RSRFSIGGEN_ATTR_OFDM_NOTCH_FILTER_NOTCH_FREQUENCY_OFFSET                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357720
#define RSRFSIGGEN_ATTR_REG_ENABLED                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356286
#define RSRFSIGGEN_ATTR_REG_SET_TO_DEFAULT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356287
#define RSRFSIGGEN_ATTR_REG_RADAR_RX_POWER                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356288
#define RSRFSIGGEN_ATTR_REG_ANALYZER_EXTERNAL_ATTENUATOR                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356289
#define RSRFSIGGEN_ATTR_REG_ANALYZER_REFERENCE_LEVEL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356290
#define RSRFSIGGEN_ATTR_REG_ANALYZER_REFERENCE_LEVEL_APPLY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356291
#define RSRFSIGGEN_ATTR_REG_ANALYZER_REFERENCE_LEVEL_STATUS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356292
#define RSRFSIGGEN_ATTR_REG_UNIT_ANGLE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356293
#define RSRFSIGGEN_ATTR_REG_UNIT_LENGTH                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356294
#define RSRFSIGGEN_ATTR_REG_UNIT_TIME                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356295
#define RSRFSIGGEN_ATTR_REG_UNIT_VELOCITY                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356296
#define RSRFSIGGEN_ATTR_REG_RECALL_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356298
#define RSRFSIGGEN_ATTR_REG_SAVE_SETTINGS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356300
#define RSRFSIGGEN_ATTR_REG_TEST_SETUP                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356302
#define RSRFSIGGEN_ATTR_REG_TEST_OTA_ANTENNA_RX_GAIN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356303
#define RSRFSIGGEN_ATTR_REG_TEST_OTA_ANTENNA_TX_GAIN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356304
#define RSRFSIGGEN_ATTR_REG_TEST_OTA_RANGE_OFFSET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356305
#define RSRFSIGGEN_ATTR_REG_RUT_RADAR_TX_POWER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356306
#define RSRFSIGGEN_ATTR_REG_RUT_RADAR_ANTENNA_TX_GAIN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356307
#define RSRFSIGGEN_ATTR_REG_RUT_RADAR_ANTENNA_RX_GAIN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356308
#define RSRFSIGGEN_ATTR_REG_RUT_SYSTEM_LOSS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356309
#define RSRFSIGGEN_ATTR_REG_SIMULATION_SYSTEM_LATENCY_CALIBRATION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356310
#define RSRFSIGGEN_ATTR_REG_SIMULATION_SYSTEM_LATENCY_BZ                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356311
#define RSRFSIGGEN_ATTR_REG_SIMULATION_USE_UNDERRANGE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356312
#define RSRFSIGGEN_ATTR_REG_SIMULATION_CALIBRATION_SUCCESSFUL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356313
#define RSRFSIGGEN_ATTR_REG_SIMULATION_CORRECTION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356314
#define RSRFSIGGEN_ATTR_REG_SIMULATION_MIN_RANGE_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356315
#define RSRFSIGGEN_ATTR_REG_SIMULATION_PRF                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356316
#define RSRFSIGGEN_ATTR_REG_SIMULATION_SCAN_PERIOD                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362317
#define RSRFSIGGEN_ATTR_REG_SIMULATION_PRI                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362318
#define RSRFSIGGEN_ATTR_REG_SIMULATION_LEVEL                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356317
#define RSRFSIGGEN_ATTR_REG_SIMULATION_DEDICATED_LEVEL_APPLY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356318
#define RSRFSIGGEN_ATTR_REG_SIMULATION_DEDICATED_LEVEL_UPDATED_STATUS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356319
#define RSRFSIGGEN_ATTR_REG_SIMULATION_DEDICATED_LEVEL_VALID_STATUS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356320
#define RSRFSIGGEN_ATTR_REG_SIMULATION_DEDICATED_FREQUENCY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356321
#define RSRFSIGGEN_ATTR_REG_SIMULATION_DEDICATED_CONNECTOR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356322
#define RSRFSIGGEN_ATTR_REG_SIMULATION_ANALYZER_FREQUENCY_APPLY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356323
#define RSRFSIGGEN_ATTR_REG_SIMULATION_ANALYZER_FREQUENCY_STATUS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357519
#define RSRFSIGGEN_ATTR_REG_SIMULATION_RESTART_SYNCHRONIZATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356325
#define RSRFSIGGEN_ATTR_REG_OBJECT_COPY_SOURCE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356326
#define RSRFSIGGEN_ATTR_REG_OBJECT_COPY_DESTINATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356327
#define RSRFSIGGEN_ATTR_REG_OBJECT_COPY                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356328
#define RSRFSIGGEN_ATTR_REG_OBJECT_NAME                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356329
#define RSRFSIGGEN_ATTR_REG_OBJECT_TYPE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356330
#define RSRFSIGGEN_ATTR_REG_OBJECT_SIMULATION_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356331
#define RSRFSIGGEN_ATTR_REG_OBJECT_RADAR_RX_POWER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356332
#define RSRFSIGGEN_ATTR_REG_OBJECT_RADAR_RX_POWER_START                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356333
#define RSRFSIGGEN_ATTR_REG_OBJECT_RADAR_RX_POWER_END                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356334
#define RSRFSIGGEN_ATTR_REG_OBJECT_TIMETOEND                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356335
#define RSRFSIGGEN_ATTR_REG_OBJECT_START_RANGE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356336
#define RSRFSIGGEN_ATTR_REG_OBJECT_END_RANGE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356337
#define RSRFSIGGEN_ATTR_REG_OBJECT_PHASE_OFFSET                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356338
#define RSRFSIGGEN_ATTR_REG_OBJECT_VELOCITY                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356339
#define RSRFSIGGEN_ATTR_REG_OBJECT_DIRECTION                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356340
#define RSRFSIGGEN_ATTR_REG_OBJECT_HOLD_OFF                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356341
#define RSRFSIGGEN_ATTR_REG_OBJECT_FIRST_ECHO_TO_PULSE_NUMBER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356342
#define RSRFSIGGEN_ATTR_REG_OBJECT_RADAR_RX_POWER_DEDICATED_                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356343
#define RSRFSIGGEN_ATTR_REG_OBJECT_USER_LIST_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357520
#define RSRFSIGGEN_ATTR_REG_OBJECT_USER_LIST_CATALOG                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357521
#define RSRFSIGGEN_ATTR_REG_OBJECT_USER_LIST_SELECTED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357522
#define RSRFSIGGEN_ATTR_REG_OBJECT_RCS_MODEL                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356344
#define RSRFSIGGEN_ATTR_REG_OBJECT_RCS_MEAN                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356345
#define RSRFSIGGEN_ATTR_REG_OBJECT_RCS_PEAK                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362319
#define RSRFSIGGEN_ATTR_REG_OBJECT_RCS_TEST_COVERAGE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362320
#define RSRFSIGGEN_ATTR_REG_OBJECT_RCS_SIMULATION_PERIOD                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362321
#define RSRFSIGGEN_ATTR_REG_OBJECT_RCS_UPDATE_INTERVAL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362322
#define RSRFSIGGEN_ATTR_REG_OBJECT_RECALL                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356347
#define RSRFSIGGEN_ATTR_REG_OBJECT_SAVE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356349
#define RSRFSIGGEN_ATTR_REG_OBJECT_PREVIEW_DIAGRAM_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356351
#define RSRFSIGGEN_ATTR_REG_OBJECT_PREVIEW_DIAGRAM_TYPE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356352
#define RSRFSIGGEN_ATTR_REG_RESTART_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357523
#define RSRFSIGGEN_ATTR_REG_RESTART_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357524
#define RSRFSIGGEN_ATTR_REG_RESTART_EXECUTE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357525
#define RSRFSIGGEN_ATTR_REG_RESTART_ARM_EXECUTE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362323
#define RSRFSIGGEN_ATTR_REG_RESTART_STATUS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357526
#define RSRFSIGGEN_ATTR_REG_RESTART_SYNCHRONIZATION_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357527
#define RSRFSIGGEN_ATTR_REG_RESTART_STOP_TIME_ATTENUATION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357528
#define RSRFSIGGEN_ATTR_EXTSEQ_ENABLED                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356353
#define RSRFSIGGEN_ATTR_EXTSEQ_ERROR                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356354
#define RSRFSIGGEN_ATTR_EXTSEQ_MODE                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356355
#define RSRFSIGGEN_ATTR_EXTSEQ_PRESET                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356356
#define RSRFSIGGEN_ATTR_EXTSEQ_POWER_RAMPING_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357529
#define RSRFSIGGEN_ATTR_EXTSEQ_SEQUENCER_COUNT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362324
#define RSRFSIGGEN_ATTR_EXTSEQ_ARCHIVE_LOAD                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356358
#define RSRFSIGGEN_ATTR_EXTSEQ_ARCHIVE_STORE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356360
#define RSRFSIGGEN_ATTR_EXTSEQ_CATALOG_SETTINGS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356362
#define RSRFSIGGEN_ATTR_EXTSEQ_LOAD_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356363
#define RSRFSIGGEN_ATTR_EXTSEQ_STORE_SETTINGS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356365
#define RSRFSIGGEN_ATTR_EXTSEQ_DELETE_SETTINGS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356367
#define RSRFSIGGEN_ATTR_EXTSEQ_USER_FILE_SELECT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356370
#define RSRFSIGGEN_ATTR_EXTSEQ_USER_HOPPING_FILE_SELECT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356373
#define RSRFSIGGEN_ATTR_EXTSEQ_USER_HOPPING_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356375
#define RSRFSIGGEN_ATTR_EXTSEQ_USER_ATTENUATION_FILE_SELECT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356377
#define RSRFSIGGEN_ATTR_EXTSEQ_USER_ATTENUATION_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356379
#define RSRFSIGGEN_ATTR_EXTSEQ_PULSE_FILE_COMMENT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356381
#define RSRFSIGGEN_ATTR_EXTSEQ_PULSE_FILE_TIMESTAMP                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356382
#define RSRFSIGGEN_ATTR_EXTSEQ_PULSE_FILE_SELECT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356383
#define RSRFSIGGEN_ATTR_EXTSEQ_PULSE_STATISTICS_SYSTEM_TIME                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362861
#define RSRFSIGGEN_ATTR_EXTSEQ_PULSE_STATISTICS_EXECUTED_PDWS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362862
#define RSRFSIGGEN_ATTR_EXTSEQ_DIRECTION_FINDING_FILE_COMMENT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356386
#define RSRFSIGGEN_ATTR_EXTSEQ_DIRECTION_FINDING_FILE_TIMESTAMP                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356387
#define RSRFSIGGEN_ATTR_EXTSEQ_DIRECTION_FINDING_FILE_SELECT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356388
#define RSRFSIGGEN_ATTR_EXTSEQ_DIRECTION_FINDING_STATISTICS_SYSTEM_TIME                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362863
#define RSRFSIGGEN_ATTR_EXTSEQ_DIRECTION_FINDING_STATISTICS_EXECUTED_PDWS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362864
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_RESTART                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356390
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_RESET_SYSTEM_TIME                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356391
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_PDW_FORMAT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362325
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_STREAM_SYSTEM_TIME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356392
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_STREAM_DROPPED_PDWS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356393
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_STREAM_EXECUTED_PDWS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356394
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_STREAM_WRITE_COUNT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356395
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_STREAM_READ_COUNT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356396
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_STREAM_BUFFER_FILLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356397
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_STREAM_BUFFER_REMAIN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356398
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_CATALOG                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362865
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_WAVEFORM_LIST_FILE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356400
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_WAVEFORM_LIST_SAVE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356402
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_WAVEFORM_LIST_SEGMENT_APPEND                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356404
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_WAVEFORM_LIST_SEGMENT_DELETE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356405
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_WAVEFORM_TAG                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357530
#define RSRFSIGGEN_ATTR_EXTSEQ_RTCI_WAVEFORM_STREAMING_RATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357531
#define RSRFSIGGEN_ATTR_EXTSEQ_ADVANCED_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362326
#define RSRFSIGGEN_ATTR_EXTSEQ_ADVANCED_TRIGGER_DELAY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362327
#define RSRFSIGGEN_ATTR_EXTSEQ_ADVANCED_FREQUENCY_OFFSET                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362328
#define RSRFSIGGEN_ATTR_EXTSEQ_ADVANCED_PHASE_OFFSET                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362329
#define RSRFSIGGEN_ATTR_EXTSEQ_ADVANCED_ATTENUATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362330
#define RSRFSIGGEN_ATTR_EXTSEQ_STREAM_COUNT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362331
#define RSRFSIGGEN_ATTR_EXTSEQ_STREAM_OUTPUT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362332
#define RSRFSIGGEN_ATTR_EXTSEQ_STREAM_MAXIMUM_NUMBER_OF_SEQUENCERS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362333
#define RSRFSIGGEN_ATTR_EXTSEQ_STREAM_SEQUENCERS_ASSIGNED_TO_STREAM                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362334
#define RSRFSIGGEN_ATTR_EXTSEQ_AGILE_SEQUENCING_OPERATION_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362866
#define RSRFSIGGEN_ATTR_EXTSEQ_AGILE_SEQUENCING_DROP                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362867
#define RSRFSIGGEN_ATTR_EXTSEQ_AGILE_SEQUENCING_EXECUTED_ADWS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362868
#define RSRFSIGGEN_ATTR_EXTSEQ_AGILE_SEQUENCING_WRITE_COUNT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362869
#define RSRFSIGGEN_ATTR_EXTSEQ_AGILE_SEQUENCING_READ_COUNT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362870
#define RSRFSIGGEN_ATTR_EXTSEQ_AGILE_SEQUENCING_BUFFER_REMAIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362871
#define RSRFSIGGEN_ATTR_EXTSEQ_AGILE_SEQUENCING_BUFFER_FILLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362872
#define RSRFSIGGEN_ATTR_EXTSEQ_AGILE_SEQUENCING_WAVEFORM_FILE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362873
#define RSRFSIGGEN_ATTR_EXTSEQ_AGILE_SEQUENCING_WAVEFORM_SAVE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362874
#define RSRFSIGGEN_ATTR_EXTSEQ_AGILE_SEQUENCING_WAVEFORM_SEGMENT_APPEND                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362875
#define RSRFSIGGEN_ATTR_EXTSEQ_AGILE_SEQUENCING_WAVEFORM_SEGMENT_DELETE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362876
#define RSRFSIGGEN_ATTR_EXTSEQ_AGILE_SEQUENCING_WAVEFORM_CATALOG                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362877
#define RSRFSIGGEN_ATTR_EXTSEQ_AGILE_SEQUENCING_WAVEFORM_FILE_CATALOG                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362878
#define RSRFSIGGEN_ATTR_EXTSEQ_AGILE_SEQUENCING_WAVEFORM_LIST_CATALOG                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362879
#define RSRFSIGGEN_ATTR_EXTSEQ_AGILE_SEQUENCING_DESIRED_ARB_SAMPLE_RATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362880
#define RSRFSIGGEN_ATTR_EXTSEQ_NETWORK_BUSY                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356408
#define RSRFSIGGEN_ATTR_EXTSEQ_NETWORK_IP_ADDRESS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356409
#define RSRFSIGGEN_ATTR_EXTSEQ_NETWORK_SEQUENCER_IP_ADDRESS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362335
#define RSRFSIGGEN_ATTR_EXTSEQ_NETWORK_ADDRESS_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356410
#define RSRFSIGGEN_ATTR_EXTSEQ_NETWORK_MAC_ADDRESS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356411
#define RSRFSIGGEN_ATTR_EXTSEQ_NETWORK_PORT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356412
#define RSRFSIGGEN_ATTR_EXTSEQ_NETWORK_PROTOCOL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356413
#define RSRFSIGGEN_ATTR_EXTSEQ_NETWORK_RESTART                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356414
#define RSRFSIGGEN_ATTR_EXTSEQ_NETWORK_STATUS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356415
#define RSRFSIGGEN_ATTR_EXTSEQ_NETWORK_SEQUENCER_STATUS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362336
#define RSRFSIGGEN_ATTR_EXTSEQ_NETWORK_HOSTNAME                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356416
#define RSRFSIGGEN_ATTR_EXTSEQ_NETWORK_SEQUENCER_HOSTNAME                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362337
#define RSRFSIGGEN_ATTR_EXTSEQ_NETWORK_WORKGROUP                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356417
#define RSRFSIGGEN_ATTR_EXTSEQ_NETWORK_SUBNET_MASK                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356418
#define RSRFSIGGEN_ATTR_EXTSEQ_NETWORK_SOCKET_STATE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357532
#define RSRFSIGGEN_ATTR_EXTSEQ_NETWORK_SEQUENCER_SOCKET_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362338
#define RSRFSIGGEN_ATTR_EXTSEQ_TRIGGER_ARM                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356419
#define RSRFSIGGEN_ATTR_EXTSEQ_TRIGGER_EXECUTE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356420
#define RSRFSIGGEN_ATTR_EXTSEQ_TRIGGER_GENERATION_STATUS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356421
#define RSRFSIGGEN_ATTR_EXTSEQ_TRIGGER_DELAY_UNIT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356422
#define RSRFSIGGEN_ATTR_EXTSEQ_TRIGGER_SYNCHRONIZE_OUTPUT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356423
#define RSRFSIGGEN_ATTR_EXTSEQ_TRIGGER_EXTERNAL_DELAY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356424
#define RSRFSIGGEN_ATTR_EXTSEQ_TRIGGER_EXTERNAL_INHIBIT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356425
#define RSRFSIGGEN_ATTR_EXTSEQ_TRIGGER_ACTUAL_DELAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356426
#define RSRFSIGGEN_ATTR_EXTSEQ_TRIGGER_OTHER_TIME_DELAY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356427
#define RSRFSIGGEN_ATTR_EXTSEQ_TRIGGER_SOURCE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356428
#define RSRFSIGGEN_ATTR_EXTSEQ_TRIGGER_SEQUENCE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356429
#define RSRFSIGGEN_ATTR_EXTSEQ_TIME_BASED_TRIGGER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363422
#define RSRFSIGGEN_ATTR_EXTSEQ_EXTERNAL_TRIGGER_DISABLE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362339
#define RSRFSIGGEN_ATTR_EXTSEQ_EXTERNAL_TRIGGER_DELAY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356430
#define RSRFSIGGEN_ATTR_EXTSEQ_EXTERNAL_TRIGGER_INHIBIT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356431
#define RSRFSIGGEN_ATTR_EXTSEQ_EXTERNAL_TRIGGER_EVENT_DELAY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356432
#define RSRFSIGGEN_ATTR_EXTSEQ_EXTERNAL_TRIGGER_TIME_DELAY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356433
#define RSRFSIGGEN_ATTR_EXTSEQ_MARKER_X_DELAY                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356434
#define RSRFSIGGEN_ATTR_EXTSEQ_MARKER_DURATION                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356435
#define RSRFSIGGEN_ATTR_EXTSEQ_MARKER_PRE_MARKER_TIME                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362340
#define RSRFSIGGEN_ATTR_EXTSEQ_MARKER_POST_MARKER_TIME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362341
#define RSRFSIGGEN_ATTR_EXTSEQ_MARKER_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356436
#define RSRFSIGGEN_ATTR_EXTSEQ_CLOCK_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356437
#define RSRFSIGGEN_ATTR_EXTSEQ_CLOCK_SOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356438
#define RSRFSIGGEN_ATTR_PLAYBACK_DEFINITION_FILE_CATALOG                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363423
#define RSRFSIGGEN_ATTR_PLAYBACK_COMMENT                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363424
#define RSRFSIGGEN_ATTR_PLAYBACK_COMMENT_ADVANCED_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363425
#define RSRFSIGGEN_ATTR_PLAYBACK_DATE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363426
#define RSRFSIGGEN_ATTR_PLAYBACK_DATE_ADVANCED_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363427
#define RSRFSIGGEN_ATTR_PLAYBACK_DEFINITION_FILE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363428
#define RSRFSIGGEN_ATTR_PLAYBACK_DEFINITION_FILE_ADVANCED_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363429
#define RSRFSIGGEN_ATTR_PLAYBACK_STATISTICS_SYSTEM_TIME                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363430
#define RSRFSIGGEN_ATTR_PLAYBACK_STATISTICS_EXECUTED_PDWS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363542
#define RSRFSIGGEN_ATTR_ONEWEB_ENABLED                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356685
#define RSRFSIGGEN_ATTR_ONEWEB_PRESET                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356686
#define RSRFSIGGEN_ATTR_ONEWEB_MODE                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356687
#define RSRFSIGGEN_ATTR_ONEWEB_DUPLEXING                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356688
#define RSRFSIGGEN_ATTR_ONEWEB_LINK_DIRECTION                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356689
#define RSRFSIGGEN_ATTR_ONEWEB_SEQUENCE_LENGTH                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356690
#define RSRFSIGGEN_ATTR_ONEWEB_CATALOG_SETTINGS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356691
#define RSRFSIGGEN_ATTR_ONEWEB_LOAD_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356692
#define RSRFSIGGEN_ATTR_ONEWEB_STORE_SETTINGS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356694
#define RSRFSIGGEN_ATTR_ONEWEB_STORE_WAVEFORM                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356696
#define RSRFSIGGEN_ATTR_ONEWEB_LOAD_REFERENCE_SIGNALS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356699
#define RSRFSIGGEN_ATTR_ONEWEB_FILTER_TYPE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356701
#define RSRFSIGGEN_ATTR_ONEWEB_FILTER_APCO25                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356702
#define RSRFSIGGEN_ATTR_ONEWEB_FILTER_COSINE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356703
#define RSRFSIGGEN_ATTR_ONEWEB_FILTER_COSINE_CUTOFF_FREQUENCY_SHIFT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357533
#define RSRFSIGGEN_ATTR_ONEWEB_FILTER_GAUSS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356704
#define RSRFSIGGEN_ATTR_ONEWEB_FILTER_PURE_GAUSS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356705
#define RSRFSIGGEN_ATTR_ONEWEB_FILTER_LTE_OPTIMIZATION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357534
#define RSRFSIGGEN_ATTR_ONEWEB_FILTER_LTE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356706
#define RSRFSIGGEN_ATTR_ONEWEB_FILTER_LTE_CUTOFF_FREQUENCY_FACTOR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357535
#define RSRFSIGGEN_ATTR_ONEWEB_FILTER_LTE_CUTOFF_FREQUENCY_SHIFT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357536
#define RSRFSIGGEN_ATTR_ONEWEB_FILTER_LOAD_USER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357537
#define RSRFSIGGEN_ATTR_ONEWEB_FILTER_ROOT_COSINE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356707
#define RSRFSIGGEN_ATTR_ONEWEBFILTER_LOW_PASS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357539
#define RSRFSIGGEN_ATTR_ONEWEB_FILTER_LOW_PASS_EVM                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357540
#define RSRFSIGGEN_ATTR_ONEWEB_FILTER_SPLIT_PHASE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356708
#define RSRFSIGGEN_ATTR_ONEWEB_SAMPLE_RATE_VARIATION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356709
#define RSRFSIGGEN_ATTR_ONEWEB_CLIPPING_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356710
#define RSRFSIGGEN_ATTR_ONEWEB_CLIPPING_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356711
#define RSRFSIGGEN_ATTR_ONEWEB_CLIPPING_LEVEL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356712
#define RSRFSIGGEN_ATTR_ONEWEB_TRIGGER_ARM                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356713
#define RSRFSIGGEN_ATTR_ONEWEB_TRIGGER_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356714
#define RSRFSIGGEN_ATTR_ONEWEB_TRIGGER_GENERATION_STATUS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356715
#define RSRFSIGGEN_ATTR_ONEWEB_TRIGGER_EXECUTE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356716
#define RSRFSIGGEN_ATTR_ONEWEB_TRIGGER_DELAY_UNIT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356717
#define RSRFSIGGEN_ATTR_ONEWEB_TRIGGER_SOURCE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356718
#define RSRFSIGGEN_ATTR_ONEWEB_TRIGGER_SIGNAL_DURATION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356719
#define RSRFSIGGEN_ATTR_ONEWEB_TRIGGER_SIGNAL_DURATION_UNIT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356720
#define RSRFSIGGEN_ATTR_ONEWEB_TRIGGER_SYNCHRONIZE_OUTPUT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356721
#define RSRFSIGGEN_ATTR_ONEWEB_INTERNAL_TRIGGER_DELAY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356722
#define RSRFSIGGEN_ATTR_ONEWEB_INTERNAL_TRIGGER_INHIBIT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356723
#define RSRFSIGGEN_ATTR_ONEWEB_INTERNAL_TRIGGER_TIME_DELAY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356724
#define RSRFSIGGEN_ATTR_ONEWEB_INTERNAL_TRIGGER_ACTUAL_TIME_DELAY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356725
#define RSRFSIGGEN_ATTR_ONEWEB_EXTERNAL_TRIGGER_DELAY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356726
#define RSRFSIGGEN_ATTR_ONEWEB_EXTERNAL_TRIGGER_INHIBIT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356727
#define RSRFSIGGEN_ATTR_ONEWEB_EXTERNAL_TRIGGER_EVENT_DELAY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356728
#define RSRFSIGGEN_ATTR_ONEWEB_EXTERNAL_TRIGGER_TIME_DELAY                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356729
#define RSRFSIGGEN_ATTR_ONEWEB_MARKER_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356730
#define RSRFSIGGEN_ATTR_ONEWEB_MARKER_USER_PERIOD                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356731
#define RSRFSIGGEN_ATTR_ONEWEB_MARKER_DELAY                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356732
#define RSRFSIGGEN_ATTR_ONEWEB_MARKER_OFF_TIME                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356733
#define RSRFSIGGEN_ATTR_ONEWEB_MARKER_ON_TIME                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356734
#define RSRFSIGGEN_ATTR_ONEWEB_MARKER_RISE_OFFSET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356735
#define RSRFSIGGEN_ATTR_ONEWEB_MARKER_FALL_OFFSET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356736
#define RSRFSIGGEN_ATTR_ONEWEB_CLOCK_SOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356737
#define RSRFSIGGEN_ATTR_ONEWEB_CLOCK_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356738
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SCHEDULING                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356739
#define RSRFSIGGEN_ATTR_ONEWEB_DL_BANDWIDTH                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356740
#define RSRFSIGGEN_ATTR_ONEWEB_DL_NORB                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356741
#define RSRFSIGGEN_ATTR_ONEWEB_DL_OCCUPIED_BANDWIDTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356742
#define RSRFSIGGEN_ATTR_ONEWEB_DL_OCCUPIED_SUBCARRIERS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356743
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SAMPLING_RATE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356744
#define RSRFSIGGEN_ATTR_ONEWEB_DL_CELL_ID                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356745
#define RSRFSIGGEN_ATTR_ONEWEB_DL_RA_RNTI                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356746
#define RSRFSIGGEN_ATTR_ONEWEB_DL_REFERENCE_SIGNAL_POWER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356747
#define RSRFSIGGEN_ATTR_ONEWEB_DL_P_SYNC_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356748
#define RSRFSIGGEN_ATTR_ONEWEB_DL_P_SYNC_POWER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356749
#define RSRFSIGGEN_ATTR_ONEWEB_DL_MIMO_CONFIGURATION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356750
#define RSRFSIGGEN_ATTR_ONEWEB_DL_MIMO_SIMULATED_ANTENNA                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356751
#define RSRFSIGGEN_ATTR_ONEWEB_DL_MIMO_MAPPING_COORDINATES                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356752
#define RSRFSIGGEN_ATTR_ONEWEB_DL_MIMO_BASEBAND_MAPS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356753
#define RSRFSIGGEN_ATTR_ONEWEB_DL_MIMO_MAPPING_MAGNITUDE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356754
#define RSRFSIGGEN_ATTR_ONEWEB_DL_MIMO_MAPPING_PHASE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356755
#define RSRFSIGGEN_ATTR_ONEWEB_DL_FRAME_CONFIGURABLE_SUBFRAMES                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356756
#define RSRFSIGGEN_ATTR_ONEWEB_DL_FRAME_RESET_ALL_FRAMES                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356757
#define RSRFSIGGEN_ATTR_ONEWEB_DL_FRAME_USER_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356758
#define RSRFSIGGEN_ATTR_ONEWEB_DL_FRAME_USER_TX_MODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356759
#define RSRFSIGGEN_ATTR_ONEWEB_DL_FRAME_USER_UE_CATEGORY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356760
#define RSRFSIGGEN_ATTR_ONEWEB_DL_FRAME_USER_SCRAMBLING                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356761
#define RSRFSIGGEN_ATTR_ONEWEB_DL_FRAME_USER_CHANNEL_CODING_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356762
#define RSRFSIGGEN_ATTR_ONEWEB_DL_FRAME_USER_UE_ID                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356763
#define RSRFSIGGEN_ATTR_ONEWEB_DL_FRAME_USER_DATA_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356764
#define RSRFSIGGEN_ATTR_ONEWEB_DL_FRAME_USER_DATA_LIST                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356765
#define RSRFSIGGEN_ATTR_ONEWEB_DL_FRAME_USER_PATTERN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356767
#define RSRFSIGGEN_ATTR_ONEWEB_DL_FRAME_USER_PDSCH_POWER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356768
#define RSRFSIGGEN_ATTR_ONEWEB_DL_FRAME_USER_CELL_TX_MODE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356769
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_ALLOCATION_COUNT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356770
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_AND_PCFICH_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356771
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_ALLOCATIONS_CODE_WORDS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356772
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_ALLOCATION_USER_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356773
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_ALLOCATION_USER_MODULATION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356774
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_ALLOCATION_USER_RESOURCE_BLOCK_COUNT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356775
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_ALLOCATION_USER_RB_OFFSET                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356776
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_ALLOCATION_USER_PHYSICAL_BITS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356777
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_ALLOCATION_USER_DATA                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356778
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_ALLOCATION_USER_DATA_LIST                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356779
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_ALLOCATION_USER_PATTERN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356781
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_ALLOCATION_USER_POWER                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356782
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_ALLOCATION_USER_CONTENT_TYPE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356783
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_ALLOCATION_USER_CONFLICT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356784
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_USER_PHYSICAL_BITS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356785
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PCFICH_SCRAMBLING_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356786
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PCFICH_POWER                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356787
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PCFICH_CFI                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356788
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_POWER                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356789
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_FORMAT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356790
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_BITS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356791
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_CCE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356792
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_NUMBER_OF_REGS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356793
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_ADD_ROW                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356794
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DELETE_ROW                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356795
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_INSERT_ROW                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356796
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_RESET_TABLE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356797
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_SELECTED_ITEM                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356798
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_ROW_DOWN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356799
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_ROW_UP                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356800
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_RESOLVE_CONFLICTS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356801
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_USED_ITEMS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356802
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_ITEM_USER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356803
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_ITEM_UE_ID                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356804
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_ITEM_CELL_IDX                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356805
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_ITEM_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356806
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_ITEM_DCI_FORMAT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356807
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_ITEM_SEARCH_SPACE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356808
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_ITEM_FORMAT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356809
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_ITEM_CCE_INDEX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356810
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_ITEM_CONFLICT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356811
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_ITEM_CCE_COUNT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356812
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_ITEM_DUMMY_CCE_COUNT                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356813
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_BIT_DATA                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356814
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_CA_IND_FIELD                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356815
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_CYCLIC_SHFT_DMRS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356816
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_CSI_REQUEST                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356817
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_MCSR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356818
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_NEW_DATA_INDICATOR                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356819
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_RESOURCE_BLOCK_ASSIGN                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356820
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_SRS_REQUEST                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356821
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_TPC_COMMAND                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356822
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_HARQ_PROCESS_NUMBER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356823
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_REDUNDANCY_VERSION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356824
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_FORMAT_1A_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356825
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_PRACH_MASK_INDEX                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356826
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_PRACH_PREAMBLE_INDEX                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356827
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_TB_1_NDI                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356828
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_TB_2_NDI                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356829
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_TB_1_REDUNDANCY_VERSION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356830
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_TB_2_REDUNDANCY_VERSION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356831
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_TPC                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356832
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_FORMAT_3_RESOURCE_INDICATOR                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356833
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_MCS_FIRST_TRANSMISSION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356834
#define RSRFSIGGEN_ATTR_ONEWEB_DL_SUBFRAME_PDCCH_DCI_MCS_RETRANSMISSION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356835
#define RSRFSIGGEN_ATTR_ONEWEB_DL_PBCH_MIB_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356836
#define RSRFSIGGEN_ATTR_ONEWEB_DL_PBCH_MIB_SPARE_BITS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356837
#define RSRFSIGGEN_ATTR_ONEWEB_DL_PBCH_SFN_OFFSET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356838
#define RSRFSIGGEN_ATTR_ONEWEB_DL_PBCH_SCRAMBLING_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356839
#define RSRFSIGGEN_ATTR_ONEWEB_DL_PBCH_CHANNEL_CODING_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356840
#define RSRFSIGGEN_ATTR_ONEWEB_DL_PBCH_SCRAMBLING_UE_ID                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356841
#define RSRFSIGGEN_ATTR_ONEWEB_DL_PBCH_IR_SOFT_BUFFER                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356842
#define RSRFSIGGEN_ATTR_ONEWEB_DL_PBCH_REDUNDANCY_VERSION_INDEX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356843
#define RSRFSIGGEN_ATTR_ONEWEB_DL_PBCH_TRANSPORT_BLOCK_SIZE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356844
#define RSRFSIGGEN_ATTR_ONEWEB_UL_BANDWIDTH                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356845
#define RSRFSIGGEN_ATTR_ONEWEB_UL_FFT_SIZE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356846
#define RSRFSIGGEN_ATTR_ONEWEB_UL_LEFT_GUARD_SUBCARRIERS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356847
#define RSRFSIGGEN_ATTR_ONEWEB_UL_RIGHT_GUARD_SUBCARRIERS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356848
#define RSRFSIGGEN_ATTR_ONEWEB_UL_RESOURCE_BLOCKS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356849
#define RSRFSIGGEN_ATTR_ONEWEB_UL_OCCUPIED_BANDWIDTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356850
#define RSRFSIGGEN_ATTR_ONEWEB_UL_OCCUPIED_SUBCARRIERS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356851
#define RSRFSIGGEN_ATTR_ONEWEB_UL_SAMPLE_RATE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356852
#define RSRFSIGGEN_ATTR_ONEWEB_UL_CYCLIC_PREFIX                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356853
#define RSRFSIGGEN_ATTR_ONEWEB_UL_CELL_ID                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356854
#define RSRFSIGGEN_ATTR_ONEWEB_UL_PHYSICAL_CELL_ID_GROUP                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356855
#define RSRFSIGGEN_ATTR_ONEWEB_UL_PHYSICAL_LAYER_ID                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356856
#define RSRFSIGGEN_ATTR_ONEWEB_UL_SFN_OFFSET                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356857
#define RSRFSIGGEN_ATTR_ONEWEB_UL_CELL_CA_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356858
#define RSRFSIGGEN_ATTR_ONEWEB_UL_RESET_ALL_SUBFRAMES                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356859
#define RSRFSIGGEN_ATTR_ONEWEB_UL_CELL_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356860
#define RSRFSIGGEN_ATTR_ONEWEB_UL_CELL_BANDWIDTH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356861
#define RSRFSIGGEN_ATTR_ONEWEB_UL_CELL_DUPLEXING_MODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356862
#define RSRFSIGGEN_ATTR_ONEWEB_UL_CELL_PHYSICAL_ID                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356863
#define RSRFSIGGEN_ATTR_ONEWEB_UL_CELL_INDEX                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356864
#define RSRFSIGGEN_ATTR_ONEWEB_UL_CELL_DMRS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356865
#define RSRFSIGGEN_ATTR_ONEWEB_UL_CELL_SRS_CONFIGURATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356866
#define RSRFSIGGEN_ATTR_ONEWEB_UL_CELL_CSRS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356867
#define RSRFSIGGEN_ATTR_ONEWEB_UL_CELL_DELTA_F                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356868
#define RSRFSIGGEN_ATTR_ONEWEB_UL_CELL_TIME_DELAY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356869
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_CONTENT_TYPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356870
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_VRB_OFFSET                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356871
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_POWER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356872
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUCCH_FORMAT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356873
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUCCH_RB_COUNT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356874
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUCCH_PHYSICAL_BITS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356875
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUCCH_POWER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356876
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUCCH_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356877
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUCCH_CONFLICT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356878
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUCCH_CQI_BITS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356879
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUCCH_CQI_CODED_BITS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356880
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUCCH_CQI_PATTERN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356881
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUCCH_HARQ_BITS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356882
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUCCH_HARQ_CODED_BITS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356883
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUCCH_HARQ_PATTERN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356884
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUCCH_HARQ_ACK_NACK_PATTERN                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356885
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUCCH_RESOURCE_INDEX                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356886
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUACH_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356887
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUACH_DELTA                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356888
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUACH_NUM_OF_CODEWORDS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357541
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUACH_POWER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356889
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUACH_CONFLICT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356890
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUACH_CYCLIC_SHIFT_FIELD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356891
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUACH_N_DMRS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356892
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUACH_VRB_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356893
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUACH_NUMBER_OF_RESOURCE_BLOCKS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356894
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUSCH_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356895
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUSCH_NUM_OF_CODEWORDS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356896
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUSCH_POWER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356897
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUSCH_CONFLICT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356898
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUSCH_CYCLIC_SHIFT_FIELD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356899
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUSCH_N_DMRS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356900
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUSCH_VRB_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356901
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUSCH_NUMBER_OF_RESOURCE_BLOCKS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356902
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUSCH_CQI_BITS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356903
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUSCH_CQI_CODED_BITS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356904
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUSCH_CQI_PATTERN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356905
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUSCH_HARQ_BITS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356906
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUSCH_HARQ_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356907
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_PUSCH_HARQ_PATTERN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356908
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_CODEWORD_PUACH_REDUNDANCY_VERSION_INDEX                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356909
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_CODEWORD_PUACH_TRANSPORT_BLOCK_SIZE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356910
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_CODEWORD_PUACH_MODULATION_SCHEME                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356911
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_CODEWORD_PUACH_PHYSICAL_BITS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356912
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_CODEWORD_PUACH_ULSCH_BITS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356913
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_CODEWORD_PUSCH_REDUNDANCY_VERSION_INDEX                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356914
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_CODEWORD_PUSCH_TRANSPORT_BLOCK_SIZE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356915
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_CODEWORD_PUSCH_MODULATION_SCHEME                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356916
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_CODEWORD_PUSCH_PHYSICAL_BITS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356917
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_CODEWORD_PUSCH_ULSCH_BITS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356918
#define RSRFSIGGEN_ATTR_ONEWEB_UL_ALLOCATION_CODEWORD_PUSCH_HARQ_BITS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356919
#define RSRFSIGGEN_ATTR_ONEWEB_UL_SLOT_ALLOCATION_RESOURCE_BLOCK_OFFSET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356920
#define RSRFSIGGEN_ATTR_ONEWEB_UL_SLOT_ALLOCATION_PUCCH_RESOURCE_BLOCK_OFFSET                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356921
#define RSRFSIGGEN_ATTR_ONEWEB_UL_SLOT_ALLOCATION_SET_PUSCH_RESOURCE_BLOCKS_OFFSET                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356922
#define RSRFSIGGEN_ATTR_ONEWEB_UL_SLOT_ALLOCATION_SET_PUACH_RESOURCE_BLOCKS_OFFSET                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356923
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_DMRS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356924
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_DELTA_SEQUENCE_SHIFT                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356925
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_GROUP_HOPPING                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356926
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SEQUENCE_HOPPING                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356927
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SRS_TX_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356928
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SRS_CSRS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356929
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_DELTA_SFC                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356930
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SUBFRAME_CONFIG                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356931
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_TSFC                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356932
#define RSRFSIGGEN_ATTR_ONEWEB_UL_PRACH_FREQUENCY_OFFSET                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356933
#define RSRFSIGGEN_ATTR_ONEWEB_UL_PRACH_CONFIGURATION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356934
#define RSRFSIGGEN_ATTR_ONEWEB_UL_PRACH_RESTRICTED_SET                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356935
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PRACH_PREAMBLE_FORMAT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356936
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PRACH_POWER_RAMPING                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356937
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PRACH_TRANSITION_TIME                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356938
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_SUBFRAME_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 356939
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_SUBFRAME_DELTA_TIME                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356940
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_SUBFRAME_NCS_CONFIGURATION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356941
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_SUBFRAME_POWER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356942
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_SUBFRAME_RB_OFFSET                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356943
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_SUBFRAME_ROOT_SEQUENCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356944
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_SUBFRAME_SEQUENCE_INDEX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356945
#define RSRFSIGGEN_ATTR_ONEWEB_UL_PUCCH_DELTA_SHIFT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356946
#define RSRFSIGGEN_ATTR_ONEWEB_UL_PUCCH_N1CS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356947
#define RSRFSIGGEN_ATTR_ONEWEB_UL_PUCCH_N1NORMCP                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356948
#define RSRFSIGGEN_ATTR_ONEWEB_UL_PUCCH_RANGE_N2                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356949
#define RSRFSIGGEN_ATTR_ONEWEB_UL_PUCCH_N2_RB                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356950
#define RSRFSIGGEN_ATTR_ONEWEB_UL_PUCCH_RANGE_N3                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356951
#define RSRFSIGGEN_ATTR_ONEWEB_UL_PUCCH_RB_COUNT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356952
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_ENABLED                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356953
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_ID                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356954
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356955
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_POWER                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356956
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUCCH_NUMBER_OF_CONFIGURABLE_SUBFRAMES                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356957
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUSCH_NUMBER_OF_CONFIGURABLE_SUBFRAMES                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356958
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUACH_NUMBER_OF_CONFIGURABLE_SUBFRAMES                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356959
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUACH_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356960
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUACH_DATA                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356961
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUACH_DATA_LIST                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356962
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUACH_PATTERN                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356964
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUACH_CQI_INDEX_OFFSET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356965
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUACH_HARQ_INDEX_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356966
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUACH_MODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356967
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUACH_O_CQI_MIN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356968
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUACH_SCRAMBLING_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356969
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUSCH_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356970
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUSCH_DATA                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356971
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUSCH_DATA_LIST                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356972
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUSCH_PATTERN                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356974
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUSCH_CQI_INDEX_OFFSET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356975
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUSCH_HARQ_INDEX_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356976
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUSCH_MODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356977
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUSCH_O_CQI_MIN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356978
#define RSRFSIGGEN_ATTR_ONEWEB_UL_UE_PUSCH_SCRAMBLING_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356979
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SRS_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356980
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SRS_CELL_TRANSMIT_TRIGGER_TYPE_0                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356981
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_DRS_POWER_OFFSET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356982
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SRS_BANDWIDTH_HOPPING                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356983
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SRS_POWER_OFFSET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356984
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SRS_CELL_B_SRS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356985
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SRS_CELL_CYCLIC_SHIFT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356986
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SRS_CELL_I_SRS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356987
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SRS_CELL_N_RRC                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356988
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SRS_NUMBER_OF_TRANSMISSIONS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356989
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SRS_CELL_T_OFFSET                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356990
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SRS_CELL_TRANSMISSION_COMBINATION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356991
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SRS_CELL_T_SRS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356992
#define RSRFSIGGEN_ATTR_ONEWEB_UL_REFERENCE_SIGNAL_SRS_SUBFRAMES_FOR_TRANSMISSION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356993
#define RSRFSIGGEN_ATTR_ONEWEB_NOTCH_FILTER_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357721
#define RSRFSIGGEN_ATTR_ONEWEB_NOTCH_FILTER_CLOCK_FREQUENCY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357722
#define RSRFSIGGEN_ATTR_ONEWEB_NOTCH_FILTER_NUMBER_OF_NOTCHES                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357723
#define RSRFSIGGEN_ATTR_ONEWEB_NOTCH_FILTER_APPLY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357724
#define RSRFSIGGEN_ATTR_ONEWEB_NOTCH_FILTER_NOTCH_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357725
#define RSRFSIGGEN_ATTR_ONEWEB_NOTCH_FILTER_NOTCH_BANDWIDTH_RELATIVE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357726
#define RSRFSIGGEN_ATTR_ONEWEB_NOTCH_FILTER_NOTCH_BANDWIDTH_ABSOLUTE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357727
#define RSRFSIGGEN_ATTR_ONEWEB_NOTCH_FILTER_NOTCH_FREQUENCY_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357728
#define RSRFSIGGEN_ATTR_V5G_ENABLED                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356994
#define RSRFSIGGEN_ATTR_V5G_SET_TO_DEFAULT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356995
#define RSRFSIGGEN_ATTR_V5G_PREDEFINED_CONFIGURATION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356996
#define RSRFSIGGEN_ATTR_V5G_PREDEFINED_CONFIGURATION_CATALOG                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356997
#define RSRFSIGGEN_ATTR_V5G_LINK_DIRECTION                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356998
#define RSRFSIGGEN_ATTR_V5G_SEQUENCE_LENGTH                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356999
#define RSRFSIGGEN_ATTR_V5G_SETTINGS_CATALOG                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357000
#define RSRFSIGGEN_ATTR_V5G_RECALL_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357001
#define RSRFSIGGEN_ATTR_V5G_DELETE_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357003
#define RSRFSIGGEN_ATTR_V5G_SAVE_SETTINGS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357005
#define RSRFSIGGEN_ATTR_V5G_GENERATE_WAVEFORM_FILE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357007
#define RSRFSIGGEN_ATTR_V5G_TRIGGER_STATUS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357009
#define RSRFSIGGEN_ATTR_V5G_TRIGGER_ARM                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357010
#define RSRFSIGGEN_ATTR_V5G_TRIGGER_EXECUTE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357011
#define RSRFSIGGEN_ATTR_V5G_TRIGGER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357012
#define RSRFSIGGEN_ATTR_V5G_TRIGGER_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357013
#define RSRFSIGGEN_ATTR_V5G_TRIGGER_SIGNAL_DURATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357014
#define RSRFSIGGEN_ATTR_V5G_TRIGGER_SIGNAL_DURATION_UNIT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357015
#define RSRFSIGGEN_ATTR_V5G_INTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357016
#define RSRFSIGGEN_ATTR_V5G_INTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357017
#define RSRFSIGGEN_ATTR_V5G_INTERNAL_TRIGGER_TIME_DELAY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357018
#define RSRFSIGGEN_ATTR_V5G_INTERNAL_TRIGGER_ACTUAL_TIME_DELAY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357019
#define RSRFSIGGEN_ATTR_V5G_EXTERNAL_TRIGGER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357020
#define RSRFSIGGEN_ATTR_V5G_EXTERNAL_TRIGGER_DELAY_UNIT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357021
#define RSRFSIGGEN_ATTR_V5G_EXTERNAL_TRIGGER_TIME_DELAY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357022
#define RSRFSIGGEN_ATTR_V5G_EXTERNAL_TRIGGER_INHIBIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357023
#define RSRFSIGGEN_ATTR_V5G_EXTERNAL_TRIGGER_ACTUAL_DELAY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357024
#define RSRFSIGGEN_ATTR_V5G_MARKER_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357025
#define RSRFSIGGEN_ATTR_V5G_MARKER_USER_PERIOD                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357026
#define RSRFSIGGEN_ATTR_V5G_MARKER_OFF_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357027
#define RSRFSIGGEN_ATTR_V5G_MARKER_ON_TIME                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357028
#define RSRFSIGGEN_ATTR_V5G_MARKER_RISE_OFFSET                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357029
#define RSRFSIGGEN_ATTR_V5G_MARKER_FALL_OFFSET                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357030
#define RSRFSIGGEN_ATTR_V5G_MARKER_DELAY                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357031
#define RSRFSIGGEN_ATTR_V5G_FIXED_MARKER_DELAY_TO_CURRENT_RANGE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357032
#define RSRFSIGGEN_ATTR_V5G_FIXED_MARKER_DELAY_MAXIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357033
#define RSRFSIGGEN_ATTR_V5G_FIXED_MARKER_DELAY_MINIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357034
#define RSRFSIGGEN_ATTR_V5G_CLOCK_SOURCE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357035
#define RSRFSIGGEN_ATTR_V5G_CLOCK_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357036
#define RSRFSIGGEN_ATTR_V5G_CLOCK_CUSTOM_EXTERNAL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357037
#define RSRFSIGGEN_ATTR_V5G_CLOCK_MULTIPLIER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357038
#define RSRFSIGGEN_ATTR_V5G_CLOCK_SYNCHRONISATION_EXECUTE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357039
#define RSRFSIGGEN_ATTR_V5G_CLOCK_SYNCHRONISATION_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357040
#define RSRFSIGGEN_ATTR_V5G_CLOCK_SYNCHRONIZATION_OUTPUT_TO_EXTERNAL_TRIGGER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357041
#define RSRFSIGGEN_ATTR_V5G_DL_XPDSCH_SCHEDULING                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357042
#define RSRFSIGGEN_ATTR_V5G_DL_CARRIER_AGGREGATION_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357043
#define RSRFSIGGEN_ATTR_V5G_DL_CARRIER_AGGREGATION_PHYSICAL_CELL_ID                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357044
#define RSRFSIGGEN_ATTR_V5G_DL_CARRIER_AGGREGATION_N_ID_CSI                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357045
#define RSRFSIGGEN_ATTR_V5G_DL_CARRIER_AGGREGATION_RELATIVE_POWER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357046
#define RSRFSIGGEN_ATTR_V5G_DL_CARRIER_AGGREGATION_CELL_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357047
#define RSRFSIGGEN_ATTR_V5G_DL_CARRIER_AGGREGATION_DELTA_FREQUENCY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357048
#define RSRFSIGGEN_ATTR_V5G_DL_CARRIER_AGGREGATION_POWER_OFFSET                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357049
#define RSRFSIGGEN_ATTR_V5G_DL_CARRIER_AGGREGATION_TIME_DELAY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357050
#define RSRFSIGGEN_ATTR_V5G_DL_SIGNALS_P_SYNC_POWER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357051
#define RSRFSIGGEN_ATTR_V5G_DL_SIGNALS_S_SYNC_POWER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357052
#define RSRFSIGGEN_ATTR_V5G_DL_SIGNALS_E_SYNC_POWER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357053
#define RSRFSIGGEN_ATTR_V5G_DL_SIGNALS_BRS_NUMBER_OF_ANTENNA_PORTS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357054
#define RSRFSIGGEN_ATTR_V5G_DL_SIGNALS_BRS_TRANSMISSION_PERIOD                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357055
#define RSRFSIGGEN_ATTR_V5G_DL_ANTENNA_PORT_MAPPING_XPBCH_BRS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357056
#define RSRFSIGGEN_ATTR_V5G_DL_ANTENNA_PORT_MAPPING_CSI_RS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357057
#define RSRFSIGGEN_ATTR_V5G_DL_ANTENNA_PORT_MAPPING_SYNCHRONIZATION_SIGNAL                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357058
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_NO_OF_CONFIGURABLE_SUBFRAMES                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357059
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_RESET_ALL_SUBFRAMES                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357060
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_USER_CONFIGURATION_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357061
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_USER_CONFIGURATION_TX_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357062
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_USER_CONFIGURATION_MAPPING_COORDINATES                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357063
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_USER_CONFIGURATION_CELL_TX_MODE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357064
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_USER_CONFIGURATION_APM_REAL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357065
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_USER_CONFIGURATION_APM_IMAGINARY                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357066
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_USER_CONFIGURATION_SCRAMBLING_STATE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357067
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_USER_CONFIGURATION_CHANNEL_CODING_STATE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357068
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_USER_CONFIGURATION_UE_ID                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357069
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_USER_CONFIGURATION_DATA_SOURCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357070
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_USER_CONFIGURATION_DATA_PATTERN                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357071
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_USER_CONFIGURATION_DATA_LIST                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357072
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_USED_ALLOCATIONS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357073
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_MODULATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357074
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_PRECODING_SCHEME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357075
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_PRECODING_NUMBER_OF_LAYERS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357076
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_PRECODING_ANTENNA_PORTS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357077
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_SCRAMBLING_STATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357078
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_SCRAMBLING_UE_ID_N_RNTI                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357079
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_REFERENCE_SIGNAL_N_SCID                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357080
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_REFERENCE_SIGNAL_DMRS_N_ID_SOURCE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357081
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_REFERENCE_SIGNAL_DMRS_N_ID_DMRS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357082
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_REFERENCE_SIGNAL_PCRS_N_ID_SOURCE                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357083
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_REFERENCE_SIGNAL_PCRS_N_ID_PCRS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357084
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_REFERENCE_SIGNAL_AP_CONFIGURATION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357085
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_REFERENCE_SIGNAL_RELATIVE_POWER                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357086
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_ANTENNA_PORT_MAPPING_STATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357087
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_RESOURCE_BLOCKS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357088
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_SYMBOL_COUNT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357089
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_RESOURCE_BLOCKS_OFFSET                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357090
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_SYMBOL_OFFSET                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357091
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_AUTOMATIC_OFFSET_CALCULATION                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357092
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_PHYSICAL_BITS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357093
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_DATA_SOURCE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357094
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_RHO_A                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357095
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_CONTENT_TYPE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357096
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_STATE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357097
#define RSRFSIGGEN_ATTR_V5G_DL_SUBFRAME_ALLOCATION_CONFLICT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357098
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_POWER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357099
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DUMMY_CCE_XREGS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357100
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DUMMY_CCE_DATA_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357101
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DUMMY_CCE_DATA_LIST                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357102
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DUMMY_CCE_DATA_PATTERN                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357103
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_SELECT_ITEM                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357104
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_APPEND                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357105
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_INSERT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357106
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_DELETE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357107
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_DOWN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357108
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_UP                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357109
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_RESET                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357110
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_RESOLVE_CONFLICTS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357111
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_USER                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357112
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_UE_ID                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357113
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_CELL_INDEX                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357114
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_FORMAT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357115
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_BIT_DATA                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357116
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_LAST_XPUSCH_SYMBOL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357117
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_TRANSMISSION_TIMING_OFFSET_I                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357118
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_RESOURCE_BLOCK_ASSIGNMENT                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357119
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_HARQ_PROCESS_NUMBER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357120
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_MODULATION_AND_CODING_SCHEME                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357121
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_NEW_DATA_INDICATOR                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357122
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_CSI_BSI_BRI_REQUEST                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357123
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_TRANSMISSION_TIMING_OF_CSI_RS_BRRS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357124
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_CSI_RS_BRRS_SYMBOL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357125
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_CSI_RS_BRRS_PROCESS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357126
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_UCI_ON_XPUSCH_W_O_XUL_SCH_DATA                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357127
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_BEAM_SWITCH_INDICATION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357128
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_SRS_REQUEST                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357129
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_SRS_SYMBOL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357130
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_RE_MAPPING_INDEX_FOR_DMRS_PCRS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357131
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_N_SCID                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357132
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_PRECODING_MATRIX_INDICATOR                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357133
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_TPC_COMMAND_FOR_XPUCCH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357134
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_UL_DUAL_PCRS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357135
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_XPDSCH_START                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357136
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_XPDSCH_END                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357137
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_REDUNDANCY_VERSION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357138
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_BMI_FOR_HARQ_ACK                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357139
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_TRANSMISSION_TIMING_OF_XPUCCH                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357140
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_FREQUENCY_RESOURCE_INDEX_OF_XPUCCH                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357141
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_AP_AND_NUMBER_OF_LAYERS_INDICATION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357142
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_DL_PCRS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357143
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_XPDCCH_FORMAT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357144
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_NUMBER_CCES                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357145
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_XPDCCH_SYMBOL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357146
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_CCE_INDEX                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357147
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_DUMMY_CCES                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357148
#define RSRFSIGGEN_ATTR_V5G_DL_FRAME_XPDCCH_DCI_CONFLICT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357149
#define RSRFSIGGEN_ATTR_V5G_UL_CARRIER_AGGREGATION_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357150
#define RSRFSIGGEN_ATTR_V5G_UL_CARRIER_AGGREGATION_PHYSICAL_CELL_ID                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357151
#define RSRFSIGGEN_ATTR_V5G_UL_CARRIER_AGGREGATION_CELL_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357152
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_RESET_ALL_SUBFRAMES                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357153
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_NUMBER_OF_XPUCCH_CONFIGURATIONS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357154
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_NUMBER_OF_XPUSCH_CONFIGURATIONS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357155
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357156
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_UE_ID_N_RNTI                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357157
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_POWER                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357158
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357159
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_NUMBER_OF_ANTENNA_PORTS_FOR_XPUCCH                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357160
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_CELLS_DATA_SOURCE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357161
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_CELLS_DATA_PATTERN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357162
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_CELLS_DATA_LIST                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357163
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_CELLS_TRANSMISSION_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357164
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_CELLS_SCRAMBLING_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357165
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_CELLS_CHANNEL_CODING_AND_MULTIPLEXING_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357166
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_CELLS_CHANNEL_CODING_AND_MULTIPLEXING_MODE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357167
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_CELLS_ANTENNA_PORT_MAPPING_POWER_OFFSET                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357168
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_ANTENNA_PORT_MAPPING_40                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357169
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_ANTENNA_PORT_MAPPING_41                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357170
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_ANTENNA_PORT_MAPPING_100                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357171
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_ANTENNA_PORT_MAPPING_200                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357172
#define RSRFSIGGEN_ATTR_V5G_UL_FRAME_UE_ANTENNA_PORT_MAPPING_201                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357173
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_CONTENT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357174
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_MODULATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357175
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_FORMAT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357176
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_N_XPUCCH_2                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357177
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_NUMBER_OF_USED_ANTENNA_PORTS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357178
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_XPUCCH_PRECODING_SCHEME                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357179
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_XPUSCH_PRECODING_SCHEME                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357180
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_RE_MAPPING_INDEX_K_I                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357181
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_N_SCID                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357182
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_DMRS_N_ID_SOURCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357183
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_DMRS_N_ID_DMRS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357184
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_PCRS_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357185
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_PCRS_RELATIVE_POWER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357186
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_PCRS_N_ID_SOURCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357187
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_PCRS_N_ID_PCRS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357188
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_CHANNEL_CODING_CODE_RATE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357189
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_CHANNEL_CODING_TRANSPORT_BLOCK_SIZE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357190
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_XPUSCH_CONFLICT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357191
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_XPUSCH_RESOURCE_BLOCKS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357192
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_XPUCCH_RESOURCE_BLOCKS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357193
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_XPUSCH_RESOURCE_BLOCKS_OFFSET                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357194
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_XPUCCH_RESOURCE_BLOCKS_OFFSET                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357195
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_XPUSCH_PHYSICAL_BITS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357196
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_XPUCCH_PHYSICAL_BITS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357197
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_XPUSCH_RHO_POWER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357198
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_XPUCCH_RHO_POWER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357199
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_XPUSCH_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357200
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_XPUCCH_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357201
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_XPUCCH_CONFLICT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357202
#define RSRFSIGGEN_ATTR_V5G_UL_SUBFRAME_ALLOCATION_CONFLICT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357203
#define RSRFSIGGEN_ATTR_5G_NR_ENABLED                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360719
#define RSRFSIGGEN_ATTR_5G_NR_SET_TO_DEFAULT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360720
#define RSRFSIGGEN_ATTR_5G_NR_LINK_DIRECTION                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360721
#define RSRFSIGGEN_ATTR_5G_NR_U_PLANE_GENERATION_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362343
#define RSRFSIGGEN_ATTR_5G_NR_VERSION                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360722
#define RSRFSIGGEN_ATTR_5G_NR_APPLICATION_VERSION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362344
#define RSRFSIGGEN_ATTR_5G_NR_SIMPLE_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363215
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_APPLY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360723
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_DISCARD                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360724
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_GENERAL_DUPLEXING                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360725
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_GENERAL_NUMBER_OF_CARRIERS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360726
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_GENERAL_COPY_CARRIER_WITH_SELECTED_TEST_MODEL_ENABLED      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362345
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_GENERAL_DEPLOYMENT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360727
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_GENERAL_CHANNEL_BANDWIDTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360728
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_GENERAL_CHANNEL_RASTER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360729
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_GENERAL_CHANNEL_SPACING                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360730
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_GENERAL_SUBCARRIER_SPACING                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360731
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_GENERAL_ECP_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360732
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_GENERAL_CORESET_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360733
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_GENERAL_CORESET_LENGTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360734
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_GENERAL_RESOURCE_BLOCK_CONFIGURATION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360735
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_GENERAL_MODULATION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360736
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_GENERAL_RESOURCE_BLOCKS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360737
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_GENERAL_RESOURCE_BLOCK_OFFSET                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360738
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_GENERAL_TRANSFORM_PRECODING_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362881
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_FRAME_FORMAT_SLOT_PERIOD                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360739
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_FRAME_FORMAT_DL_SLOTS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360740
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_FRAME_FORMAT_SPECIAL_SLOTS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360741
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_FRAME_FORMAT_UL_SLOTS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360742
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_FRAME_FORMAT_SLOT_FORMAT_INDEX                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360743
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_FRAME_FORMAT_DL_SYMBOLS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360744
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_FRAME_FORMAT_GUARD_SYMBOLS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360745
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_FRAME_FORMAT_UL_SYMBOLS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360746
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_FRAME_FORMAT_IAB_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362882
#define RSRFSIGGEN_ATTR_5G_NR_QUICK_SETTINGS_FRAME_FORMAT_SPECIAL_SLOT_FORMAT_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362883
#define RSRFSIGGEN_ATTR_5G_NR_SETTINGS_CATALOG                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360747
#define RSRFSIGGEN_ATTR_5G_NR_RECALL_SETTINGS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360748
#define RSRFSIGGEN_ATTR_5G_NR_DELETE_SETTINGS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360750
#define RSRFSIGGEN_ATTR_5G_NR_SAVE_SETTINGS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360752
#define RSRFSIGGEN_ATTR_5G_NR_GENERATE_WAVEFORM_FILE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360754
#define RSRFSIGGEN_ATTR_5G_NR_DOWNLINK_SETTINGS_TEST_MODEL_CATALOG                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360756
#define RSRFSIGGEN_ATTR_5G_NR_DOWNLINK_SETTINGS_TEST_MODEL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360757
#define RSRFSIGGEN_ATTR_5G_NR_UPLINK_SETTINGS_TEST_MODEL_CATALOG                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360759
#define RSRFSIGGEN_ATTR_5G_NR_UPLINK_SETTINGS_TEST_MODEL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360760
#define RSRFSIGGEN_ATTR_5G_NR_FILTER_LOAD                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360762
#define RSRFSIGGEN_ATTR_5G_NR_TRIGGER_STATUS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360764
#define RSRFSIGGEN_ATTR_5G_NR_TRIGGER_ARM                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360765
#define RSRFSIGGEN_ATTR_5G_NR_TRIGGER_EXECUTE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360766
#define RSRFSIGGEN_ATTR_5G_NR_TRIGGER_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360767
#define RSRFSIGGEN_ATTR_5G_NR_TRIGGER_SOURCE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360768
#define RSRFSIGGEN_ATTR_5G_NR_TRIGGER_SIGNAL_DURATION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360769
#define RSRFSIGGEN_ATTR_5G_NR_TRIGGER_SIGNAL_DURATION_UNIT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360770
#define RSRFSIGGEN_ATTR_5G_NR_TIME_BASED_TRIGGER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363433
#define RSRFSIGGEN_ATTR_5G_NR_INTERNAL_TRIGGER_DELAY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360771
#define RSRFSIGGEN_ATTR_5G_NR_INTERNAL_TRIGGER_INHIBIT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360772
#define RSRFSIGGEN_ATTR_5G_NR_INTERNAL_TRIGGER_TIME_DELAY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360773
#define RSRFSIGGEN_ATTR_5G_NR_INTERNAL_TRIGGER_ACTUAL_TIME_DELAY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360774
#define RSRFSIGGEN_ATTR_5G_NR_EXTERNAL_TRIGGER_SYNC_OUTPUT_TO_EXT_TRIGGER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360775
#define RSRFSIGGEN_ATTR_5G_NR_EXTERNAL_TRIGGER_DELAY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360776
#define RSRFSIGGEN_ATTR_5G_NR_EXTERNAL_TRIGGER_DELAY_UNIT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360777
#define RSRFSIGGEN_ATTR_5G_NR_EXTERNAL_TRIGGER_INHIBIT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360778
#define RSRFSIGGEN_ATTR_5G_NR_EXTERNAL_TRIGGER_TIME_DELAY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360779
#define RSRFSIGGEN_ATTR_5G_NR_EXTERNAL_TRIGGER_ACTUAL_TIME_DELAY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360780
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360781
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_DUPLEXING                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360782
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_SUBCARRIER_SPACING                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360783
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_EXTENDED_CYCLIC_PREFIX_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360784
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_SLOT_PERIOD                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360785
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_NUMBER_OF_DL_SLOTS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360786
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_NUMBER_OF_SPECIAL_SLOTS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360787
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_NUMBER_OF_UL_SLOTS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360788
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_SLOT_FORMAT_INDEX                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360789
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_NUMBER_OF_DL_SYMBOLS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360790
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_NUMBER_OF_GUARDED_SYMBOLS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360791
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_NUMBER_OF_UL_SYMBOLS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360792
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_DELAY                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360793
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_DELAY_MICROSECONDS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362346
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_USER_PERIOD                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360794
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_RISE_OFFSET                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360795
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_FALL_OFFSET                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360796
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_INVERT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362347
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_ON_TIME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360797
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_OFF_TIME                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360798
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_IAB_FORMAT_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362884
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_CONFIGURATION_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362885
#define RSRFSIGGEN_ATTR_5G_NR_MARKER_SPECIAL_SLOT_FORMAT_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362886
#define RSRFSIGGEN_ATTR_5G_NR_CLOCK_SOURCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360799
#define RSRFSIGGEN_ATTR_5G_NR_CLOCK_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360800
#define RSRFSIGGEN_ATTR_5G_NR_NODE_NUMBER_OF_CARRIERS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360801
#define RSRFSIGGEN_ATTR_5G_NR_NODE_RF_PHASE_COMPENSATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360802
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_CELL_INDICATOR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360803
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_CELL_ID                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360804
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_CELL_N1_ID                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360805
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_CELL_N2_ID                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360806
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_CELL_CIF_PRESENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360807
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_CELL_SCHEDULED_BY                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360808
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_CELL_CIF                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360809
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_CELL_DEPLOYMENT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360810
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_CELL_FREQUENCY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360811
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_CELL_CHANNEL_BW                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360812
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_CELL_DMRS_TYPE_A_POSITION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360813
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_CELL_DELTA_FREQ_TO_OUTPUT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360814
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_CELL_MAPPED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360815
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_CELL_SHARED_SPECTRUM_ACCESS_ENABLED                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362348
#define RSRFSIGGEN_ATTR_5G_NR_NODE_NEW_ADD                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362887
#define RSRFSIGGEN_ATTR_5G_NR_NODE_NEW_BASIC_INFORMATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362888
#define RSRFSIGGEN_ATTR_5G_NR_NODE_NEW_COPY_FROM                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362889
#define RSRFSIGGEN_ATTR_5G_NR_NODE_NEW_SOURCE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362890
#define RSRFSIGGEN_ATTR_5G_NR_NODE_NEW_INDEX_NUMBER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362891
#define RSRFSIGGEN_ATTR_5G_NR_NODE_NEW_LOAD                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362892
#define RSRFSIGGEN_ATTR_5G_NR_NODE_NEW_NUMBER_OF_CARRIERS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362893
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_POINT_A_TO_CARRIER_CENTER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360817
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_CONFLICT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360818
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_RESOLVE_CONFLICT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360819
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_15_KHZ_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360820
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_30_KHZ_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360821
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_60_KHZ_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360822
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_120_KHZ_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360823
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_240_KHZ_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362894
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_480_KHZ_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362895
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_960_KHZ_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362896
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_15_KHZ_N_RB                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360824
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_30_KHZ_N_RB                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360825
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_60_KHZ_N_RB                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360826
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_120_KHZ_N_RB                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360827
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_15_KHZ_OFFSET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360828
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_30_KHZ_OFFSET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360829
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_60_KHZ_OFFSET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360830
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_120_KHZ_OFFSET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360831
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_15_KHZ_K0U                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360832
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_30_KHZ_K0U                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360833
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_60_KHZ_K0U                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360834
#define RSRFSIGGEN_ATTR_5G_NR_NODE_TXBW_SCS_120_KHZ_K0U                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360835
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SYSTEM_INFORMATION_SYS_FRAME_NUMBER_OFFSET                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360836
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SYSTEM_INFORMATION_HARQ_ACK_CODEBOOK                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360837
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SYSTEM_INFORMATION_HARQ_ACK_CODEBOOK_R16                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362349
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SYSTEM_INFORMATION_SUL_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360838
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SYSTEM_INFORMATION_INDICATOR_SIZE_DCI0_2                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362350
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SYSTEM_INFORMATION_INDICATOR_SIZE_DCI1_2                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362351
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SYSTEM_INFORMATION_SYSTEM_FRAME_NUMBER_OFFSET                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362352
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SYSTEM_INFORMATION_SUB_FRAME_OFFSET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362353
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SYSTEM_INFORMATION_TIMING_ADVANCE_OFFSET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362354
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SYSTEM_INFORMATION_CUSTOM_TIMING_ADVANCE_OFFSET_TC                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362355
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SYSTEM_INFORMATION_PHASE_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362356
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SYSTEM_INFORMATION_SSB_TIME_OFFSET_R17                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363434
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_NUMBER_OF_PATTERNS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360839
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_OFFSET_RELATIVE_TO                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360840
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_SC_SPACING_CP                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360841
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_RB_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360842
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_SC_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360843
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_DELTA_FREQUENCY_TO_CARRIER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360844
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_CASE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360845
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_POSITIONS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360846
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_BURST_SET_PERIODICITY                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360847
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_HALF_FRAME_INDEX                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360848
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_DUMMY_CONTENT_FOR_MIB_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360849
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_CHANNEL_CODING_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360850
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_CHANNEL_CODING_DATA_SOURCE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360851
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_CHANNEL_CODING_DATA_LIST                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360852
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_CHANNEL_CODING_PATTERN                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360853
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_MIB_SCS_COMMON                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360854
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_MIB_SSPBCH_SUBCARRIER_OFFSET                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360855
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_MIB_CORESET_ZERO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360856
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_MIB_SEARCH_SPACE_ZERO                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360857
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_MIB_CELL_BARRED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360858
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_MIB_INTRA_FREQ_RESELECTION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360859
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_MIB_ASC_OFFSET_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360860
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_MIB_SPARE_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360861
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_MIB_SF_START                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360862
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_MAPPING_TABLE_CARTESIAN_REAL                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360863
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_MAPPING_TABLE_CARTESIAN_IMAGINARY                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360864
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_MAPPING_TABLE_CYLINDRICAL_MAGNITUDE                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360865
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_MAPPING_TABLE_CYLINDRICAL_PHASE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360866
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_PSS_POWER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360867
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_SSS_POWER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360868
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_PBCH_POWER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360869
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360870
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_L                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360871
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_SL_BLOCKS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362897
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_SL_INCOVERAGE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362898
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_SL_SLOTS_BETWEEN_BLOCKS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362899
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_SL_SPARE_BITS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362900
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_SL_TDD_CONFIG                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362901
#define RSRFSIGGEN_ATTR_5G_NR_NODE_SS_PBCH_PATTERN_SL_TIME_OFFSET                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362902
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362357
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_SC_SPACING_CP                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362358
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_NUMBER_OF_PRS_RESOURCE_SETS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362359
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_SET_PERIODICITY_T_PER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362360
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_SET_SLOT_OFFSET_T_OFFSET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362361
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_SET_REPETITION_FACTOR_T_REP                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362362
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_SET_TIME_GAP_T_GAP                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362363
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_SET_NUMBER_OF_RBS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362364
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_SET_START_RB_TO_POINT_A                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362365
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_SET_COMB_SIZE_K_COMB                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362366
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_SET_NUMBER_OF_PRS_RESOURCES                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362367
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_RE_OFFSET_K_OFF                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362368
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_SLOT_OFFSET_K_OFF_RES                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362369
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_NUMBER_OF_SYMBOLS_L_PRS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362370
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_SYMBOL_OFFSET_L_START                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362371
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_SEQUENCE_ID                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362372
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_POWER_PER_DB                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362373
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_ANTENNA_PORT_MAPPING_REAL                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362374
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_ANTENNA_PORT_MAPPING_IMAGINARY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362375
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_ANTENNA_PORT_MAPPING_MAGNITUDE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362376
#define RSRFSIGGEN_ATTR_5G_NR_NODE_PRS_RESOURCE_ANTENNA_PORT_MAPPING_PHASE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362377
#define RSRFSIGGEN_ATTR_5G_NR_NODE_DUMMY_RES_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360872
#define RSRFSIGGEN_ATTR_5G_NR_NODE_DUMMY_RES_POWER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360873
#define RSRFSIGGEN_ATTR_5G_NR_NODE_DUMMY_RES_SC_SPACING_CP                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360874
#define RSRFSIGGEN_ATTR_5G_NR_NODE_DUMMY_RES_MODULATION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360875
#define RSRFSIGGEN_ATTR_5G_NR_NODE_DUMMY_RES_SLOT_FMT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360876
#define RSRFSIGGEN_ATTR_5G_NR_NODE_DUMMY_RES_TRANSFORM_PRECODING_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360877
#define RSRFSIGGEN_ATTR_5G_NR_NODE_DUMMY_RES_DATA_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360878
#define RSRFSIGGEN_ATTR_5G_NR_NODE_DUMMY_RES_DATA_LIST                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360879
#define RSRFSIGGEN_ATTR_5G_NR_NODE_DUMMY_RES_DATA_PATTERN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360880
#define RSRFSIGGEN_ATTR_5G_NR_NODE_DUMMY_RES_OCNG_PRECODING_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362378
#define RSRFSIGGEN_ATTR_5G_NR_NODE_DUMMY_NES_OCNG_NUMBER_OF_ANTENNA_PORTS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362379
#define RSRFSIGGEN_ATTR_5G_NR_NODE_DUMMY_RES_OCNG_ANTENNA_PORT_REAL_VALUE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362380
#define RSRFSIGGEN_ATTR_5G_NR_NODE_DUMMY_RES_OCNG_ANTENNA_PORT_IMAGINARY_VALUE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362381
#define RSRFSIGGEN_ATTR_5G_NR_NODE_DUMMY_RES_OCNG_ANTENNA_PORT_MAGNITUDE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362382
#define RSRFSIGGEN_ATTR_5G_NR_NODE_DUMMY_RES_OCNG_ANTENNA_PORT_PHASE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362383
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_MAPPING_CARRIER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360881
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_MAPPING_SS_PBCH_AP4000                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360882
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_MAPPING_DELTA_F_TO_OUTPUT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360883
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_MAPPING_CELL_MAPPED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360884
#define RSRFSIGGEN_ATTR_5G_NR_NODE_CARRIER_MAPPING_CARRIERS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362903
#define RSRFSIGGEN_ATTR_5G_NR_NODE_LTE_CRS_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360885
#define RSRFSIGGEN_ATTR_5G_NR_NODE_LTE_CRS_OFFSET_TO_POINT_A                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360886
#define RSRFSIGGEN_ATTR_5G_NR_NODE_LTE_CRS_V_SHIFT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360887
#define RSRFSIGGEN_ATTR_5G_NR_NODE_LTE_CRS_BANDWIDTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360888
#define RSRFSIGGEN_ATTR_5G_NR_NODE_LTE_CRS_ANTENNA_PORTS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360889
#define RSRFSIGGEN_ATTR_5G_NR_NODE_LTE_CRS_NUMBER_OF_PATTERNS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362384
#define RSRFSIGGEN_ATTR_5G_NR_NODE_LTE_CRS_PATTERN_OFFSET_TO_POINT_A                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362385
#define RSRFSIGGEN_ATTR_5G_NR_NODE_LTE_CRS_PATTERN_BANDWIDTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362386
#define RSRFSIGGEN_ATTR_5G_NR_NODE_LTE_CRS_PATTERN_V_SHIFT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362387
#define RSRFSIGGEN_ATTR_5G_NR_NODE_LTE_CRS_PATTERN_ANTENNA_PORTS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362388
#define RSRFSIGGEN_ATTR_5G_NR_NUMBER_OF_USERS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360890
#define RSRFSIGGEN_ATTR_5G_NR_RESTART_DATA_AND_CONTROL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360891
#define RSRFSIGGEN_ATTR_5G_NR_RESTART_SLOT_INDEX                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363435
#define RSRFSIGGEN_ATTR_5G_NR_RESTART_SLOT_INTERVAL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363436
#define RSRFSIGGEN_ATTR_5G_NR_SLOT_INTERVAL                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363437
#define RSRFSIGGEN_ATTR_5G_NR_SLOT_OFFSET                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363438
#define RSRFSIGGEN_ATTR_5G_NR_USER_UE_ID_RNTI                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360892
#define RSRFSIGGEN_ATTR_5G_NR_USER_CS_RNTI                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360893
#define RSRFSIGGEN_ATTR_5G_NR_USER_MCS_C_RNTI                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360894
#define RSRFSIGGEN_ATTR_5G_NR_USER_SP_CSI_RNTI                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360895
#define RSRFSIGGEN_ATTR_5G_NR_USER_SFI_RNTI                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360896
#define RSRFSIGGEN_ATTR_5G_NR_USERS_NUMBER_OF_SFIS_IN_DCI_2_0                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360897
#define RSRFSIGGEN_ATTR_5G_NR_USER_RA_RNTI                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360898
#define RSRFSIGGEN_ATTR_5G_NR_USER_TC_RNTI                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360899
#define RSRFSIGGEN_ATTR_5G_NR_USER_MSGB_RNTI                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362389
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_CHANNEL_CODING_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360901
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_SCRAMBLING_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362390
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_DATA_SOURCE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360902
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_DATA_LIST                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360903
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_DATA_PATTERN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360904
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_INITIALIZATION_PATTERN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360905
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_HARQ_ACK_RETRANSMISSION_INDICATOR_DCI1_1                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363439
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_PUCCH_SSCELLDYN_DCI1_1                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363440
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_SCELL_GROUPS_WITHIN_ACTIVE_TIME                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362391
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_HARQ_ACK_ONE_SHOT_FEEBACK_R16_ENABLED                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362392
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_ACK_NACK_FEEDBACK_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362393
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_NFI_TOTAL_DAI_INCLUDED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362394
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_UL_TOTAL_DAI_INCLUDED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362395
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_DOWNLINK_ASSIGNMENT_INDEX_DCI0_2                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362396
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_COT_DURATION_INDICATORS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362904
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_COT_DURATION_INDICATOR_SIZE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362905
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_AVAILABLE_RB_SET_INDICATORS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362906
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_SEARCH_SPACE_SWITCHING_FLAGS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362907
#define RSRFSIGGEN_ATTR_5G_NR_USER_DSCH_AVAILABLE_RB_SET_INDICATOR_SIZE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362908
#define RSRFSIGGEN_ATTR_5G_NR_USER_USCH_CHANNEL_CODING_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360906
#define RSRFSIGGEN_ATTR_5G_NR_USER_USCH_SCRAMBLING_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362397
#define RSRFSIGGEN_ATTR_5G_NR_USER_USCH_DATA_SOURCE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360907
#define RSRFSIGGEN_ATTR_5G_NR_USER_USCH_DATA_LIST                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360908
#define RSRFSIGGEN_ATTR_5G_NR_USER_USCH_DATA_PATTERN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360909
#define RSRFSIGGEN_ATTR_5G_NR_USER_USCH_INITIALIZATION_PATTERN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360910
#define RSRFSIGGEN_ATTR_5G_NR_USER_USCH_BITS_FOR_SIDELINK_ASSIGNMENT_INDEX                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363441
#define RSRFSIGGEN_ATTR_5G_NR_USER_PSSCH_CHANNEL_CODING_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362909
#define RSRFSIGGEN_ATTR_5G_NR_USER_PSSCH_DATA_SOURCE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362910
#define RSRFSIGGEN_ATTR_5G_NR_USER_PSSCH_DATA_LIST                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362911
#define RSRFSIGGEN_ATTR_5G_NR_USER_PSSCH_INIT_PATTERN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362912
#define RSRFSIGGEN_ATTR_5G_NR_USER_PSSCH_PATTERN                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362913
#define RSRFSIGGEN_ATTR_5G_NR_USER_PSSCH_SCRAMBLING_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362914
#define RSRFSIGGEN_ATTR_5G_NR_USER_PDSCH_UNIQUE_DATA_SOURCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363216
#define RSRFSIGGEN_ATTR_5G_NR_USER_ORAN_TEST_CASE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363217
#define RSRFSIGGEN_ATTR_5G_NR_USER_ORAN_USE_DATA_SOURCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363218
#define RSRFSIGGEN_ATTR_5G_NR_USER_PUCCH_PAYLOAD_DATA_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363219
#define RSRFSIGGEN_ATTR_5G_NR_USER_PUCCH_PAYLOAD_DATA_LIST                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363220
#define RSRFSIGGEN_ATTR_5G_NR_USER_PUCCH_PAYLOAD_UNIQUE_DATA_SOURCE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363221
#define RSRFSIGGEN_ATTR_5G_NR_USER_PUCCH_PAYLOAD_INITIALIZATION_PATTERN                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363222
#define RSRFSIGGEN_ATTR_5G_NR_USER_PUCCH_PAYLOAD_PATTERN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363223
#define RSRFSIGGEN_ATTR_5G_NR_USER_PUSCH_UCI_DATA_SOURCE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363224
#define RSRFSIGGEN_ATTR_5G_NR_USER_PUSCH_UCI_DATA_LIST                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363225
#define RSRFSIGGEN_ATTR_5G_NR_USER_PUSCH_UCI_UNIQUE_DATA_SOURCE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363226
#define RSRFSIGGEN_ATTR_5G_NR_USER_PUSCH_UCI_INITIALIZATION_PATTERN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363227
#define RSRFSIGGEN_ATTR_5G_NR_USER_PUSCH_UCI_PATTERN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363228
#define RSRFSIGGEN_ATTR_5G_NR_USER_RNTI_G_CS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363229
#define RSRFSIGGEN_ATTR_5G_NR_USER_RNTI_G                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363230
#define RSRFSIGGEN_ATTR_5G_NR_USER_RNTI_MCCH                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363231
#define RSRFSIGGEN_ATTR_5G_NR_USER_RNTI_PEI                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363232
#define RSRFSIGGEN_ATTR_5G_NR_USER_RNTI_SL                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363233
#define RSRFSIGGEN_ATTR_5G_NR_USER_RNTI_SL_CS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363234
#define RSRFSIGGEN_ATTR_5G_NR_USER_RNTI_V                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363235
#define RSRFSIGGEN_ATTR_5G_NR_DL_NUMBER_OF_BWPS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360911
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_INDICATOR                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360912
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_SC_SPACING_CP                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360913
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RESOURCE_BLOCKS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360914
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RB_OFFSET_IN_TXBW                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360915
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RB_OFFSET_TO_POINT_A                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360916
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DELTA_F_TO_CARRIER_CENTERS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360917
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_SCRAMBLING_ID_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360930
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_SCRAMBLING_ID                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360931
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_MAX_NUMBER_OF_CODEWORDS_PER_DCI                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360924
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_VRB_TO_PRB_INTERLEAVER                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360936
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_MCS_TABLE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360925
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_RESOURCE_ALLOCATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360935
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_RESOURCE_BLOCK_GROUP_SIZE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360932
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PUSCH_RESOURCE_BLOCK_GROUP_SIZE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360933
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_MAX_CODE_BLOCK_GROUPS_PER_TRANSPORT_BLOCK                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360939
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_CODE_BLOCK_GROUP_FLUSH_INDICATOR                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360937
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_PRECODING_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360940
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_PRECODING_PRB_BUNDLING_TYPE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360941
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_PRECODING_STATIC_BUNDLE_SIZE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360942
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_PRECODING_BUNDLE_SIZE_SET_1                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360943
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_PRECODING_BUNDLE_SIZE_SET_2                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360944
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_K0_NUMBER_OF_ENTRIES                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362398
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_CURRENT_TD_ALLOCATION_LIST                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363442
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_NUMBER_OF_TD_ALLOCATION_LISTS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363443
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_K0_VALUE_FOR_MININUM_APPLICABLE_OFFSET                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362399
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_PRIORITY_INDICATOR_DCI1_1_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362400
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_BITS_FOR_REDUNDANCY_VERSION_DCI1_2                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362401
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_BITS_FOR_HARQ_DCI1_2                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362402
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_ANTENNA_PORTS_PRESENT_DCI1_2_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362403
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_DMRS_SEQUENCE_INITIALIZATION_DCI1_2_ENABLED                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362404
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_PRIORITY_INDICATOR_DCI1_2_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362405
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_TYPE_1_ALLOCATION_GRANULARITY_DCI1_2                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362406
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_NUMBER_OF_MAPPED_TCI_CODEPOINTS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362407
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_TCI_CODEPOINT_STATE_ID_1                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362408
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_TCI_CODEPOINT_USE_STATE_ID_2_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362409
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_TCI_CODEPOINT_STATE_ID_2                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362410
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_SAME_SETTINGS_FOR_TYPE_A_AND_B                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360938
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_DMRS_A_CONFIG_TYPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360918
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_DMRS_A_ADDITIONAL_POSITION_INDEX                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360919
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_DMRS_A_MAX_LENGTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360920
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_DMRS_B_CONFIG_TYPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360921
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_DMRS_B_ADDITIONAL_POSITION_INDEX                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360922
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_DMRS_B_MAX_LENGTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360923
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_DMTA_SCRAMBLING_ID_0                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360926
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_DMTB_SCRAMBILNG_ID_0                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360927
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_DMTA_SCRAMBLING_ID_1                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360928
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_DMTB_SCRAMBLING_ID_1                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360929
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_DMTA_USE_R16_DMRS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362411
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_DMTB_USE_R16_DMRS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362412
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PUSCH_PTRS_DMTA_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360950
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PUSCH_PTRS_DMTB_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360951
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PUSCH_PTRS_DMTA_RE_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360962
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PUSCH_PTRS_DMTB_RE_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360963
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_PTRS_DMTA_EPRE_RATIO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360964
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_PTRS_DMTB_EPRE_RATIO                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360965
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PUSCH_PTRS_DMTA_MCS1                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360952
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PUSCH_PTRS_DMTB_MCS1                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360953
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PUSCH_PTRS_DMTA_MCS2                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360954
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PUSCH_PTRS_DMTB_MCS2                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360955
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PUSCH_PTRS_DMTA_MCS3                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360956
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PUSCH_PTRS_DMTB_MCS3                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360957
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PUSCH_PTRS_DMTA_RB0                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360958
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PUSCH_PTRS_DMTB_RB0                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360959
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PUSCH_PTRS_DMTA_RB1                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360960
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PUSCH_PTRS_DMTB_RB1                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360961
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_TIME_DOMAIN_ALLOCATIONS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360934
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_PRECODING_METHOD                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362915
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_XOVERHEAD                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362916
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_TDA_K0                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360945
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_TDA_MAPPING_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360946
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_TDA_START                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360947
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_TDA_LENGTH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360948
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_TDA_SLIV                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360949
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_TDML_MULTI_TIME_DOMAIN_ALLOCATIONS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363444
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_TDML_K0                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363445
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_TDML_NUMBER_OF_OFDM_SYMBOLS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363446
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_TDML_MAPPING_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363447
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_TDML_SLIV                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363448
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDSCH_TDML_SYMBOL_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363449
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RMC_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362413
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RMC                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362414
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RMC_MODULATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362415
#define RSRFSIGGEN_ATTR_5G_NR_BWP_RMC_SUBCARRIER_SPACING                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362416
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RMC_CQI_INDEX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362917
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDCCH_INT_RNTI                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360970
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDCCH_NUMBER_OF_PREEMPTION_INDICATIONS_IN_DCI_2_1                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360971
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_PDCCH_BITS_FOR_ENHANCED_TYPE_3_CODEBOOK_INDICATOR                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363450
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_REPORT_TRIGGER_SIZE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360972
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_LARGE_RESPONSE_WINDOW_ENABLED                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362417
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_TPC_PUSCH_RNTI                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360973
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_TPC_PUCCH_RNTI                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360974
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_TWOPUSCH_PC_ADJUSTMENT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360975
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_TWOPUCCH_PC_ADJUSTMENT                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360976
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_NUMBER_OF_PUSCH_BLOCKS_2_2                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360977
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_NUMBER_OF_PUCCH_BLOCKS_IN_DCI_2_2                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360978
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_TPC_SRS_RNTI                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360979
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_SRS_TPC_PDCCH_GROUP_TYPE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360980
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_NUMBER_OF_BLOCKS_2_3                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360981
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_CI_RNTI                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362418
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_CANCELLATION_INDICATION_LENGTH                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360982
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_NUMBER_OF_CANCELLATION_INDICATIONS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360983
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_AI_RNTI                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362419
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_NUMBER_OF_AVAILABILITY_INDICATIONS                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362420
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_PS_RNTI                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362421
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_NUMBER_OF_DORMANCY_INDICATIONS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362422
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_CONTROL_NUMBER_OF_SCELL_GROUPS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362423
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_ZP_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360984
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_ZP_RESOURCES                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360985
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_ZP_PERIODICITY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360986
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_ZP_OFFSET                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360987
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_ZP_RB_NUMBER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360988
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_ZP_START_RB                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360989
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_ZP_ROW                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360990
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_ZP_PORTS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360991
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_ZP_DENSITY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360992
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_ZP_CDM_TYPE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360993
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_ZP_BITMAP                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360994
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_ZP_I0                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360995
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_ZP_I1                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360996
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360997
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_RESOURCES                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360998
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_PERIODICITY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360999
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_OFFSET                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361000
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_RB_NUMBER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361001
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_START_RB                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361002
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_ROW                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361003
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_PORTS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361004
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_DENSITY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361005
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_CDM_TYPE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361006
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_BITMAP                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361007
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_I0                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361008
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_I1                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361009
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_SCRAMBLING_ID                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361010
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_POWER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361011
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_ROW_REAL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361013
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_ROW_IMAGINARY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361014
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_ROW_MAGNITUDE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361015
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_NZP_ROW_PHASE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361016
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RATE_MATCH_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361017
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RATE_MATCH_RESOURCES                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361018
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RATE_MATCH_NUMBER_OF_GROUPS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361019
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RATE_MATCH_DATA_LIST                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361020
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RATE_MATCH_RB_PATTERN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361022
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RATE_MATCH_SLOT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361023
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RATE_MATCH_SLOT_PATTERN                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361024
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RATE_MATCH_PERIODICITY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361025
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RATE_MATCH_PERIODICITY_PATTERN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361026
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_RATE_MATCH_GRID                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361027
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_FORMAT_4_2                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363236
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_HARQ_FEEDBACKENABLER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363237
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_MAX_LTE_SUBCHANNELS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363238
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_NUMBER_PER_PEI                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363239
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_PRIORITY_INDICATOR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363240
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_PAYLOAD_SIZE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363241
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_NUMBER_OF_SL_PSFCH_TO_PUCCH_SLOTS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363242
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_NUMBER_OF_SUBGROUPS_PER_PO                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363243
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_TRS_AVAILABILITY_INDICATION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363244
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_MONITORING_ADAPTION_INDICATION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363245
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_PDSCH_HARQ_PROCESS_NUMBER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363246
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_PUSCH_HARQ_PROCESS_NUMBER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363247
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_MAX_BITS_FOR_2ND_DOWNLINK_ASSIGNMENT_INDEX                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363451
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_BITS_FOR_3RD_DOWNLINK_ASSIGNMENT_INDEX                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363452
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_HARQ_ACK_RETRANSMISSION_INDICATOR_DCI1_2                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363453
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_BITS_FOR_2ND_PRECODING_INFORMATION                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363454
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_PUCCH_SSCELLDYN_DCI1_2                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363455
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_BITS_FOR_SRS_OFFSET_INDICATOR                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363456
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_BITS_FOR_2ND_SRS_RESOURCE_INDICATION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363457
#define RSRFSIGGEN_ATTR_5G_NR_DL_BWP_DCI_BITSFOR_SRS_RESOURCE_SET_INDICATION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363458
#define RSRFSIGGEN_ATTR_5G_NR_UL_NUMBER_OF_BWPS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361028
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_INDICATOR                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361029
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SC_SPACING_CP                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361030
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_RESOURCE_BLOCKS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361031
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_RB_OFFSET_IN_TXBW                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361032
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_RB_OFFSET_TO_POINT_A                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361033
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_DELTA_F_TO_CARRIER_CENTERS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361034
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUCCH_ADDITIONAL_DMRS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361035
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUCCH_PI_2_BPSK                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361036
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUCCH_SIMUTANEOUS_HARQ_ACK_CSI                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361037
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUCCH_NUMBER_OF_ENTRIES                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361038
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUCCH_UL_ACCESSCONFIGLIST_DCI1_2                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363459
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUCCH_USE_2ND_TPC_COMMAND                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363460
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUCCH_VALUE_OF_INDICATOR_X                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361039
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUCCH_USE_R16_DMRS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362424
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUCCH_BITS_FOR_RESOURCE_INDICATOR                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362425
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUCCH_CPEXT_NUMBER_OF_ENTRIES                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362426
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUCCH_CPEXT_VALUE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362427
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUCCH_USE_INTERLACE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362428
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361040
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_TYPE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361041
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_SC_SPACING                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361042
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_ALLOCATED_RESOURCE_BLOCKS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361043
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_MODULATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361044
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_PAYLOAD_SIZE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361045
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_RB_OFFSET                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361046
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_PTRS_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361047
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_MAPPING_TYPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361048
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_BANDWIDTH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362918
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_DEPLOYMENT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363461
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_WIZARD_MAPPING_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363462
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_WIZARD_MODULATION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363463
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_WIZARD_PAYLOAD_SIZE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363464
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_WIZARD_RB_OFFSET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363465
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_WIZARD_SC_SPACING                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363466
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_FRC_WIZARD_TYPE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363467
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_TRANSFORM_PRECODING                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361055
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_MAXIMUM_RANK                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361056
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_TX_CONFIG                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361057
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_CODEBOOK_SUBSET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361061
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_SCRAMBLING_ID_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361062
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_DATA_SCRAMBLING_ID                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361063
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_MCS_TABLE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361058
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_MCS_TABLE_TRANSFORM_PRECODING                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361059
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_RESOURCE_ALLOCATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361060
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_FREQUENCY_HOPPING                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361064
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_MAX_CODE_BLOCK_GROUPS_PER_TRANSPORT_BLOCK                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361065
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_UL_ACCESSCONFIGLIST_DCI0_2                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363468
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_USE_2ND_TPC_COMMAND                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363469
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_FREQUENCY_HOPPING_NUMBER_OF_OFFSETS                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361066
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_FREQUENCY_HOPPING_OFFSET_VALUE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361067
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_MINIMUM_SCHEDULING_OFFSET_K2                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362429
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PRIORITY_INDICATOR_DCI0_1_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362430
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PRIORITY_INDICATOR_DCI0_2_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362431
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_INVALID_SYMBOL_INDICATOR_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362432
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_BITS_FOR_OLPC_PARAMETER_SET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362433
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_P0_PUSCH_SET_LIST                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362434
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_UL_ACCESS_CONFIG_LIST                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362435
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_BITS_FOR_REDUNDANCY_VERSION_DCI0_2                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362436
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_ANTENNA_PORTS_PRESENT_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362437
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_DMRS_SEQUENCE_INITIALIZATION_DCI0_2_ENABLED                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362438
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_TYPE_1_ALLOCATION_GRANULARITY_DCI0_2                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362439
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_FULL_POWER_TRANSMISSION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362440
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_SAME_SETTINGS_FOR_TYPE_A_AND_B                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361068
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_DMRS_A_CONFIG_TYPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361049
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_DMRS_A_ADDITIONAL_POSITION_INDEX                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361050
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_DMRS_A_MAX_LENGTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361051
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_DMRS_B_CONFIG_TYPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361052
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_DMRS_B_ADDITIONAL_POSITION_INDEX                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361053
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_DMRS_B_MAX_LENGTH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361054
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PDSCH_TIME_DOMAIN_ALLOCATIONS_DCI0_1                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362441
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PDSCH_TIME_DOMAIN_ALLOCATIONS_DCI0_2                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362442
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PDSCH_TIME_DOMAIN_ALLOCATIONS_MULTI_PUSCH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362443
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PDSCH_MULTI_PUSCH_LENGTH                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362444
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_USE_R16_DMRS_A                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362445
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_USE_R16_DMRS_B                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362446
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_BITS_FOR_HARQ_PROCESS_NUMBER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362447
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_USE_INTERLACE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362919
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_XOVERHEAD                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362920
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_NPUSCH_ID                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361101
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_NPUSCH_ID                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361102
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_SCRAMBLING_ID_0                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361103
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_SCRAMBLING_ID_0                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361104
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_SCRAMBLING_ID_1                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361105
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_SCRAMBLING_ID_1                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361106
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361069
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361070
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_RE_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361097
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_RE_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361098
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_POWER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361079
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_POWER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361080
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_PORT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361081
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_PORT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361082
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_MCS1                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361073
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_MCS1                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361074
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_MCS2                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361075
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_MCS2                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361076
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_MCS3                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361077
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_MCS3                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361078
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_RB0                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361083
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_RB0                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361084
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_RB1                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361087
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_RB1                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361088
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_TP_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361071
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_TP_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361072
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_TIME_DENSITY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361099
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_TIME_DENSITY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361100
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_TP_SCRAMBLING_ID                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361107
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_TP_SCRAMBLING_ID                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361108
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_TP_RB0                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361085
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_TP_RB0                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361086
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_TP_RB1                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361089
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_TP_RB1                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361090
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_TP_RB2                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361091
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_TP_RB2                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361092
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_TP_RB3                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361093
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_TP_RB3                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361094
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTA_TP_RB4                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361095
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_PTRS_DMTB_TP_RB4                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361096
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_UCI_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361109
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_UCI_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361110
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_UCI_SCALING_ALPHA                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361111
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_UCI_I_HARQ_OFFSET_0                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361112
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_UCI_I_HARQ_OFFSET_1                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361113
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_UCI_I_HARQ_OFFSET_2                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361114
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_UCI_I_CSI1_OFFSET_0                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361115
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_UCI_I_CSI1_OFFSET_1                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361116
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_UCI_I_CSI2_OFFSET_0                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361117
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_UCI_I_CSI2_OFFSET_1                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361118
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_UCI_CG_UCI_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362921
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_PUSCH_UCI_CG_UCI_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362922
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_ENABLE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361119
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_SETS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361120
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_CONFIGURED_BY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362448
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_REQUEST_DCI0_2                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362449
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_REQUEST_DCI1_2                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362450
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_TRANSMISSION_TYPE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361121
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_TRANSMISSION_USAGE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361122
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_RESOURCES                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361123
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_PERIODICITY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361124
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_OFFSET                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361125
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_POSITION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361126
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_SYMBOLS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361127
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_FREQUENCY_POSITION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361128
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_FREQUENCY_SHIFT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361129
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_B_SRS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361130
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_C_SRS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361131
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_B_HOP                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361132
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_REPETITION_FACTOR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361133
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_TRANSMISSION_COMB                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361134
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_COMB_OFFSET                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361135
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_CYCLIC_SHIFT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361136
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_SEQUENCE_ID                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361137
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_SEQ_HOPPING                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361138
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_ANTENNA_PORTS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361139
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_POWER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361141
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_PTRS_PORT_INDEX                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361142
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_FREQUENCY_SCALING_FACTOR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363470
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_START_RB_INDEX                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363471
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_REAL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361143
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_IMAGINARY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361144
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_MAGNITUDE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361145
#define RSRFSIGGEN_ATTR_5G_NR_UL_BWP_SRS_PHASE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361146
#define RSRFSIGGEN_ATTR_5G_NR_SL_NUMBER_OF_BWPS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362923
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_DELTA_F_TO_CARRIER_CENTERS_                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362924
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_ID                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362925
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RB_OFFSET_TO_POINT_A                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362926
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_BLOCKS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362927
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RB_OFFSET                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362928
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_SC_SPACING                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362929
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362930
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_ADDITIONAL_MCS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362931
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_BETA_OFFSET_1                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362932
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_BETA_OFFSET_2                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362933
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_BETA_OFFSET_3                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362934
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_BETA_OFFSET_4                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362935
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_ID                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362936
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_MAX_NUMBER_PER_RESERVE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362937
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_MULTI_RESERVE_RESOURCE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362938
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_MCS_TABLE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362939
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_PRBS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362940
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_SUBCHANNELS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362941
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_DMRS_PATTERN_2                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362942
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_DMRS_PATTERN_3                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362943
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_DMRS_PATTERN_4                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362944
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_PERIOD_LIST                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362945
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_RESERVED_BITS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362946
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_SCALING_FACTOR                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362947
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_SUBCHANNEL_SIZE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362948
#define RSRFSIGGEN_ATTR_5G_NR_SL_BWP_RESOURCE_POOLS_START_RB                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362949
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361147
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_RESTRICT_TO_SEARCH_SPACE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361148
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_COUNT_FULL_SYSTEM_FRAME_NUMBER_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362451
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362950
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_NUMBER_OF_ALLOCATIONS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361149
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_COPY_TO_SLOT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361150
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_COPY_TO_SUBFRAME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361151
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_COPY_APPLY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361152
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CONFLICT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361153
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CONTENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361154
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PRACH_SC_SPACING_CP                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361155
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SLOT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361156
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PHYSICAL_BITS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362951
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_MAPPING_TYPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361157
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_FORMAT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361159
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SLOT_FORMAT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361160
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_NUMBER_OF_SYMBOLS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361161
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SYMBOL_OFFSET                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361162
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_NUMBER_OF_RB                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361163
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RB_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361164
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_TRANSFORM_PRECODING_ENABLED                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361165
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_POWER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361166
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361167
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_REPETITION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361168
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PERIOD                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361169
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_DURATION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361170
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_INFO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361171
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTING_INFO                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361172
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTING_CONFLICT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362952
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTING_MAPPING_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362953
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTING_POWER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362954
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTING_ALLOCATION_ENABLED                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362955
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTING_CONTENT_TYPE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362956
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTING_RESOURCE_BLOCKS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362957
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SOURCE_SUBFRAME                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362958
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTING_RB_OFFSET                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362959
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTING_SLOT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362960
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTING_SCS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362961
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTING_SYMBOL_NUMBER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362962
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTING_SYMBOL_OFFSET                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362963
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_MCS_TABLE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362452
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_SRS_CSRS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363248
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_DENSITY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363249
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_SRS_FREQUENCY_POSITION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363250
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_SRS_FREQUENCY_SHIFT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363251
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_SRS_OFFSET                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363252
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_SRS_PORTS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363253
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_SRS_REPETITION_FACTOR                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363254
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_SRS_RESOURCE_TYPE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363255
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_SRS_SEQUENCE_CYCLIC_SHIFT                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363256
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_SRS_SEQUENCE_HOPPING                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363257
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_SRS_SEQUENCE_ID                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363258
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_SRS_TRANSMISSION_COMB                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363259
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_CSI_RS_I0                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363260
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_CSI_RS_I1                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363261
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_CSI_RS_ZERO_POWER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363262
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_CSI_RS_ROW                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363263
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_CSI_RS_SCRAMBLING_ID                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363264
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_RIM_RS_DELTA                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363265
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_RIM_RS_GAMMA                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363266
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_RIM_RS_NTRIM                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363267
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_RESULTS_RIM_RS_NSCID                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363268
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SRS_FREQUENCY_SCALING_FACTOR                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363472
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_START_RB_INDEX                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363473
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SRS_CONFIG                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363474
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TYPE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361173
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_NUMBER_OF_CODEWORDS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361174
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_SCHEDULED_BY_CORESET_0                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361175
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_RATE_MATCH_PATTERN_GROUP                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361176
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_RESOURCE_ALLOCATION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361177
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_RESOURCE_BLOCK_GROUP_BITMAP                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361178
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_PRECODING_GRANULARITY                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361179
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_BURST_MODE_REF_ALLOC_IDENTIFIER_ENABLED       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361180
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_FREQUENCY_DENSITY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363269
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TRANSPORT_BLOCK_MODULATION                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361181
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TRANSPORT_BLOCK_PHYSICAL_BITS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361182
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_DMRS_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361183
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_DMRS_SLOT_SYMBOLS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361184
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_DMRS_POWER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361185
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_DMRS_SEQUENCE_GENERATION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361186
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_DMRS_SCRAMBLING_ID                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361187
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_DMRS_GROUP_OR_SEQUENCE_HOPPING                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361188
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_DMRS_ADDITIONAL_POSITION_INDEX                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363475
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_DMRS_CONFIGURATION_TYPE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363476
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_DMRS_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363477
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_DMRS_TYPE_A_POSITION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363478
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_DMRS_MAP_ANTENNA_PORT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361189
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_PTRS_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361193
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_PTRS_PHASE_TRACKING_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361195
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_PTRS_TIME_DENSITY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361196
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_PTRS_FREQUENCY_DENSITY                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361192
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_PTRS_RESOURCE_ELEMENT_OFFSET                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361194
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_PTRS_EPRE_RATIO                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361191
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TXSCHEME_CDM_GROUPS_WITHOUT_DATA              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361197
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TXSCHEME_NUMBER_OF_LAYERS                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361198
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TXSCHEME_ANTENNA_PORTS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361199
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TXSCHEME_VRB_TO_PRB                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361200
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TXSCHEME_CSI_RS_ANTENNA_PORTS                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362964
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TXSCHEME_CODEBOOK_MODE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362965
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TXSCHEME_CODEBOOK_TYPE                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362966
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TXSCHEME_N1                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362967
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TXSCHEME_N2                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362968
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_CODEBOOK_1_1_PARAMETER                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362969
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_CODEBOOK_1_2_PARAMETER                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362970
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_CODEBOOK_1_3_PARAMETER                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362971
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_CODEBOOK_2_PARAMETER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362972
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_MANUALLY_DEFINED_CODERATE_ENABLED             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362453
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_CHANNEL_CODING_I_MSC                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361201
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_CHANNEL_CODING_TARGET_CODE_RATE               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361202
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_CHANNEL_CODING_TRANSPORT_BLOCK_SIZE           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361203
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_CHANNEL_CODING_REDUNDANCY_VERSION_INDEX       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361204
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_CHANNEL_CODING_MODULATION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361205
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PDSCH_CHANNEL_CODING_TBS_SCALING_FACTOR             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362973
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_TYPE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361206
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_MODULATION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361207
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_PHYSICAL_BITS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361208
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_RESOURCE_ALLOCATION                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361209
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_RESOURCE_BLOCK_GROUP_BITMAP                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361210
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_FREQUENCY_HOPPING_ENABLED                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361211
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_INDEX_TO_FREQUENCY_HOPPING_OFFSET             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361212
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_BURST_MODE_REF_ALLOC_IDENTIFIER_ENABLED       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361213
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_HARQ_PROCESS_NUMBER                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361214
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_TIME_OFFSET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362974
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_NUMBER_OF_SLOTS_TBOMS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363479
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_TBOMS_SLOT_OFFSET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363480
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_INTERLACES                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362975
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_CG_UCI_BITS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362976
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_CG_UCI_PATTERN                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362977
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_AGGREGATION_FACTOR                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362978
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_AGGREGATION_OFFSET                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362979
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_FREQUENCY_DENSITY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363270
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_DMRS_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361215
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_DMRS_SLOT_SYMBOLS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361216
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_DMRS_POWER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361217
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_DMRS_SEQUENCE_GENERATION                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361218
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_DMRS_SCRAMBLING_ID                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361219
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_DMRS_SELECT_N_ID                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361220
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_DMRS_GROUP_OR_SEQUENCE_HOPPING                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361221
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_DMRS_ADDITIONAL_POSITION_INDEX                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363481
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_DMRS_CONFIGURATION_TYPE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363482
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_DMRS_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363483
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_DMRS_TYPE_A_POSITION                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363484
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_DMRS_MAP_ANTENNA_PORT                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361222
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_PTRS_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361227
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_PTRS_DMRS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361233
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_PTRS_PHASE_TRACKING_ENABLED                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361229
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_PTRS_TIME_DENSITY                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361230
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_PTRS_RESOURCE_ELEMENT_OFFSET                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361228
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_PTRS_POWER                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361224
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_PTRS_MAX_PORTS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361223
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_PTRS_TP_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361225
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_PTRS_TP_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361234
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_PTRS_TP_TIME_DENSITY                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361235
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_PTRS_GROUPS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361231
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_PTRS_SCRAMBLING_ID                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361226
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_PTRS_SAMPLES_PER_GROUP                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361232
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_TXSCHEME_CDM_GROUPS_WITHOUT_DATA              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361236
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_TXSCHEME_NUMBER_OF_LAYERS                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361237
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_TXSCHEME_ANTENNA_PORTS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361238
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_TXSCHEME_TPMI                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361239
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_TXSCHEME_SRS                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361240
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_MANUALLY_DEFINED_CODERATE_ENABLED             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362454
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_CHANNEL_CODING_I_MSC                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361241
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_CHANNEL_CODING_TARGET_CODE_RATE               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361242
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_CHANNEL_CODING_TRANSPORT_BLOCK_SIZE           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361243
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_CHANNEL_CODING_REDUNDANCY_VERSION_INDEX       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361244
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_CHANNEL_CODING_MODULATION                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361245
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_CHANNEL_CODING_TBS_SCALING_FACTOR             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362980
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_UCI_NUMBER_OF_ACK_BITS                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361246
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_UCI_ACK_PATTERN                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361247
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_UCI_NUMBER_OF_CSI_1_BITS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361248
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_UCI_CSI_1_PATTERN                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361249
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_UCI_NUMBER_OF_CSI_2_BITS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361250
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_UCI_CSI_2_PATTERN                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361251
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUSCH_INTERLACE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362981
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361253
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_BUNDLE_SIZE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361254
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_SHIFT_INDEX                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361255
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_SIZE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361256
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_USE_DMRS_SCRAMBLING_ID_ENABLED              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361257
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DMRS_SCRAMBLING_ID                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361258
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_USE_BITMAP_FOR_RESOURCES_ENABLED            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361259
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_FREQUENCY_DOMAIN_RESOURCES                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361260
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_NUMBER_OF_DCIS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361261
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DATA_SOURCE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361262
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DATA_LIST                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361263
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_PATTERN                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361265
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_STATE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361266
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_ACTIVE_UL_BWP                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361267
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_PRECODER_GRANULA                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361268
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_TCI                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361269
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_TCI_SIZE_IN_DCI1_2                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362455
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_ID                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361270
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DMRS_REFERENCE_POINT                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363271
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_USAGE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361271
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_RNTI                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361272
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_FORMAT                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361273
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SEARCH_SPACE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361274
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_AGGREGATION_LEVEL                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361275
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_CCE_INDEX                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361276
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_BIT_DATA                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361277
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_FREQUENCY_DOMAIN_RESOURCE_ASSIGNMENT    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361278
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_TIME_DOMAIN_RESOURCE_ASSIGNMENT         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361279
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_FREQUENCY_HOPPING_FLAG                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361280
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_MODULATION_AND_CODING_SCHEME_TB1        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361281
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_NEW_DATA_INDICATOR_TB1                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361282
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_REDUNDANCY_VERSION_TB1                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361283
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_MODULATION_AND_CODING_SCHEME_TB2        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361284
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_NEW_DATA_INDICATOR_TB2                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361285
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_REDUNDANCY_VERSION_TB2                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361286
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_HARQ_PROCESS_NUMBER                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361287
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_TPC_COMMAND_FOR_SCHEDULING_PUSCH        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361288
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_VRB_TO_PRB_MAPPING                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361289
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_1ST_DOWNLINK_ASSIGNMENT_INDEX           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361290
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_TPC_COMMAND_FOR_SCHEDULING_PUCCH        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361291
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_PUCCH_RESOURCE_INDICATOR                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361292
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_PDSCH_TO_HARQ_FEEDBACK_TIMING_INDICATOR RS_SPECIFIC_PUBLIC_ATTR_BASE + 361293
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SRS_RESOURCE_INDICATOR                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361294
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SHORT_MESSAGE_INDICATOR                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361295
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_INITIALIZATION_PATTERN                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361296
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_PATTERN_LENGTH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361297
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_BIT_PATTERN                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361298
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_CREATE_PDSCH                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361299
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_CBGFI                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361300
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_PRECODING_INFORMATION                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361301
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_ANTENNA_PORTS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361302
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_BWP_INDICATOR                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361303
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_CANDIDATE                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361304
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_CBGTI                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361305
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_DAI2                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361306
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_DATA_SOURCE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361307
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_DATA_LIST                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361308
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_DMRS_SEQUENCE_INIT                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361311
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_PRB_BUNDLING                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361312
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_PTRS_DMRS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361313
#define RSRFSIGGEN_ATTR_5G_NRSCHEDULING_ALLOCATION_CORESET_DCI_BETA_OFFSET_INDICATOR                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361314
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SYSTEM_INFORMATION_INDICATOR            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361315
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_TB_SCALING                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361316
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_RESERVED_BITS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361317
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_CHANNEL_CODING_ENABLED                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361318
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_UL_SUL_INDICATOR                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361319
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_CARRIER_INDICATOR                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361320
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_RM_INDICATOR                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361321
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SRS_REQUEST                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361322
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_CSI_REQUEST                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361323
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_TCI                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361324
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_ZP_CSI_RS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361325
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_AGGREGATION_LEVELS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361326
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_MAX_CANDIDATE                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361327
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_CHANNEL_ACCESS_CPEXT                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362456
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_DOWNLINK_FEEDBACK_INDICATOR             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362457
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_PDSCH_DMRS_SYMBOLS                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362458
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_INVALID_SYMBOL_PATTERN_INDICATOR        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362459
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_MINIMUM_APP_SCHED_OFF_IND_ENABLED       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362460
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_ONE_SHOT_HARQ_ACK_REQUEST               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362461
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_LSBS_OF_SFN                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362462
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_NEW_FEEDBACK_INDICATOR                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362463
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_NUM_OF_REQUESTED_PDSCH_GROUPS           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362464
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_OPEN_LOOP_PWR_CTRL_PARAM_INDICATION     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362465
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_PDSCH_GROUP_INDEX                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362466
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_PRIORITY_INDICATOR                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362467
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SHORT_MESSAGES                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362468
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_UL_SCH_INDICATOR                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362469
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_POWER                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362982
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_IDENTIFIER                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362983
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SGS_FLAG_1                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362984
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SGS_FLAG_2                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362985
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SGS_FLAG_3                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362986
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SGS_FLAG_4                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362987
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_ARIND                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363272
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_CONFIGURATION_INDEX                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363273
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_FIELD_RESOURCE                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363274
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_FIELD_FIRST_SUBCHANNEL                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363275
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_HARQ_ACK_FEEDBACK_INFORMATION           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363276
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_MCCH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363277
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_MULTIPLEXING_TABLE                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363278
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_MONITORING_ADAPTION_INDICATION          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363279
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_PSFCH_TO_HARQ                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363280
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_FIELD_RESOURCE_POOL_INDEX               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363281
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SL_INDEX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363282
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SPS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363283
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_TIME_GAP                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363284
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_TIMING_OFFSET                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363285
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_TRS_AVAILABILITY_INDICATOR              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363286
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_DAI3                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363486
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_HART_INDICATOR                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363487
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_PUCCH_CELL_INDICATOR                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363488
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SECOND_PRECODING_INFO                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363489
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SAI                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363490
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SRS_OFFSET_INDICATOR                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363491
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SECOND_SRS_RESOURCE_INDICATOR           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363492
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SRS_RESOURCE_SET_INDICATOR              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363493
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SECOND_TPC_PUCCH                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363494
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SECOND_TPC_PUSCH                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363495
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_T3C_BIND                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363496
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_CANCELLATION_INDICATION                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361328
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_CLOSED_LOOP_INDICATOR                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361329
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_COMMAND_NUMBER                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361330
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_PREEMPTION_INDICATION                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361331
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SLOT_FORMAT_INDICATOR                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361332
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SRS_REQUEST_VALUE                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361333
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_AVAILABILITY_INDICATION_BIT_LENGTH      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362470
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_AVAILABILITY_INDICATION_RB              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362988
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_COT_DURATION_INDICATOR                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362989
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_WAKEUP_INDICATION_ENABLED               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362471
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_SCELL_DORMANCY_INDICATION               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362472
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_CORESET_DCI_INSTANCE_PAGING_EARLY_INDICATOR         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363287
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_GROUP_HOPPING                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361334
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_HOPPING_ID                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361335
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_INTRA_SLOT_FREQUENCY_HOPPING                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361336
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_SECONG_HOPPING_PRB                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361337
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_INITIAL_CYCLIC_SHIFT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361338
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_TIME_DOMAIN_OCC_INDEX                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361339
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_OCC_LENGTH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361340
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_OCC_INDEX                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361341
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_F2_OCC_LENGTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362990
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_F3_OCC_LENGTH                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362991
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_INTERLACES                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362992
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_SCI2_PATTERN                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362993
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_CYCLIC_PREFIX_EXTENSION                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362994
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_POSITIVE_SR_COUNT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361342
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_NUMBER_OF_ACK_BITS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361343
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_ACK_PATTERN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361344
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_NUMBER_OF_UCI_BITS                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361345
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_UCI_PATTERN                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361346
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PUCCH_INTERLACE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362995
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PRACH_FORMAT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361347
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PRACH_RESTRICTED_SET                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361348
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PRACH_LOGICAL_ROOT_SEQUENCE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361349
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PRACH_ZERO_CORRELATION_ZONE                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361350
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PRACH_PREAMBLE_INDEX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361351
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PRACH_RB_NUMBER                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361352
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PRACH_TIME_OFFSET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361353
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PRACH_BURST_MODE_REF_ALLOC_IDENTIFIER               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362473
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PRACH_SEQUENCE_LENGTH                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362996
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PRACH_SCS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362997
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PSCCH_RESOURCE_BLOCKS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362998
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PSCCH_DMRS_SCRAMBLE_ID                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362999
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PSCCH_SYMBOLS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363000
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PSSCH_DMRS_ANTENNA_PORT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363001
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PSSCH_MODULATION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363002
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PSSCH_DMRS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363003
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PSSCH_SUBCHANNELS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363004
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PSSCH_RESOURCE_POOL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363005
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PSSCH_CHANNEL_CODING_FRCR                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363006
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PSSCH_CHANNEL_CODING_RV_INDEX                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363007
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PSSCH_CHANNEL_CODING_TBS_SCALING_FACTOR             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363008
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PSSCH_CHANNEL_CODING_TRANSPORT_BLOCK_SIZE           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363009
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_PSSCH_CHANNEL_CODING_TARGET_CODE_RATE               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363010
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_ADDITIONAL_MCS_INDICATOR                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363011
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_ADDITIONAL_MCS_INDICATOR_ENABLED                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363288
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_BETA_OFFSET_INDICATOR                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363012
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_COMMUNICATION_RANGE_REQUIREMENT                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363013
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_CSI_REQUEST                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363014
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_CAST_TYPE_INDICATOR                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363015
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_DESTINATION_ID                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363016
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_DMRS_PATTERNS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363017
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_DMRS_PORTS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363018
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_FREQUENCY_DOMAIN_RESOURCE_ASSIGNMENT            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363019
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_HARQ_FEEDBACK                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363020
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_HARQ_PROCESS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363021
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_MODULATION_AND_CODING_SCHEME                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363022
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_NEW_DATA_INDICATOR                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363023
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_PATTERN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363024
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_PRIORITY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363025
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_REDUNDANCY_VERSION                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363026
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_RESERVED_BITS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363027
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_RESOURCE_RESERVATION_PERIOD                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363028
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_2ND_STAGE_SCI_FORMAT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363029
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_SOURCE_ID                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363030
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_TIME_DOMAIN_RESOURCE_ASSIGNMENT                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363031
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_SCI_ZONE_ID                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363032
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_AP_IMAGINARY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361354
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_AP_REAL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361355
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_AP_MAGNITUDE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361356
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATION_AP_PHASE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361357
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_REPETITION_TYPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363033
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_CONTENT_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363034
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_COMMON_CONTENT_TYPE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363035
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_DURATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363036
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_PERIOD                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363037
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_SOURCE_SUBFRAME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363038
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_RESOURCE_BLOCKS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363039
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_COMMON_RESOURCE_BLOCKS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363040
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_RB_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363041
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_COMMON_RB_OFFSET                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363042
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_SLOT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363043
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_COMMON_SLOT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363044
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_SCS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363045
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_COMMON_SCS                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363046
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_SYMBOL_NUMBER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363047
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_COMMON_SYMBOL_NUMBER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363048
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_SYMBOL_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363049
#define RSRFSIGGEN_ATTR_5G_NR_SCHEDULING_ALLOCATIONS_COMMON_SYMBOL_OFFSET                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363050
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_SEQUENCE_LENGTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361358
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_SUPPRESS_SUBCARRIER_ON_OUTPUT_CENTER                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361359
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_FILTER_MODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361360
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_SAMPLE_RATE_MODE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361361
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_CONFLICT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362474
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_CLIPPING_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361362
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_CLIPPING_LEVEL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361363
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_BASEBAND_SAMPLE_RATE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361365
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_BASEBAND_CONFLICT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361366
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_BASEBAND_SAMPLE_RATE_VARIATION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361367
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_BASEBAND_PLAYBACK_RATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361368
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_CF_REDUCTION_STATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361369
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_CF_REDUCTION_ALGORITHM                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361370
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_CF_REDUCTION_TARGET_CREST_FACTOR                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361371
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_CF_REDUCTION_MAX_ITERATIONS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361372
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_CF_REDUCTION_ORIGINAL_CF                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361373
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_CF_REDUCTION_RESULTING_CF                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361374
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_CF_REDUCTION_CANCELLATION_PULSE_BANDWIDTH                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363497
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_CF_REDUCTION_TRANSITION_BANDWIDTH                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363498
#define RSRFSIGGEN_ATTR_5G_NR_TIME_DOMAIN_WINDOWING_WOLA_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361375
#define RSRFSIGGEN_ATTR_5G_NR_TIME_DOMAIN_WINDOWING_15_KHZ_NCP_TRANSITION_TIME                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361376
#define RSRFSIGGEN_ATTR_5G_NR_TIME_DOMAIN_WINDOWING_30_KHZ_NCP_TRANSITION_TIME                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361377
#define RSRFSIGGEN_ATTR_5G_NR_TIME_DOMAIN_WINDOWING_60_KHZ_NCP_TRANSITION_TIME                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361378
#define RSRFSIGGEN_ATTR_5G_NR_TIME_DOMAIN_WINDOWING_60_KHZ_ECP_TRANSITION_TIME                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361379
#define RSRFSIGGEN_ATTR_5G_NR_TIME_DOMAIN_WINDOWING_120_KHZ_NCP_TRANSITION_TIME                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361380
#define RSRFSIGGEN_ATTR_5G_NR_TIME_DOMAIN_WINDOWING_240_KHZ_NCP_TRANSITION_TIME                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361381
#define RSRFSIGGEN_ATTR_5G_NR_TIME_DOMAIN_WINDOWING_15_KHZ_TRANSITION_SAMPLES                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361382
#define RSRFSIGGEN_ATTR_5G_NR_TIME_DOMAIN_WINDOWING_30_KHZ_TRANSITION_SAMPLES                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361383
#define RSRFSIGGEN_ATTR_5G_NR_TIME_DOMAIN_WINDOWING_60_KHZ_TRANSITION_SAMPLES                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361384
#define RSRFSIGGEN_ATTR_5G_NR_TIME_DOMAIN_WINDOWING_60_KHZ_ECP_TRANSITION_SAMPLES                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361385
#define RSRFSIGGEN_ATTR_5G_NR_TIME_DOMAIN_WINDOWING_120_KHZ_TRANSITION_SAMPLES                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361386
#define RSRFSIGGEN_ATTR_5G_NR_TIME_DOMAIN_WINDOWING_240_KHZ_TRANSITION_SAMPLES                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361387
#define RSRFSIGGEN_ATTR_5G_NR_POWER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361388
#define RSRFSIGGEN_ATTR_5G_NR_POWER_AVERAGE_RELATIVE_TO_LEVEL_PER_BASEBAND                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361389
#define RSRFSIGGEN_ATTR_5G_NR_POWER_ACTIVE_RELATIVE_TO_LEVEL_15KHZ                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361390
#define RSRFSIGGEN_ATTR_5G_NR_POWER_ACTIVE_RELATIVE_TO_LEVEL_30KHZ                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361391
#define RSRFSIGGEN_ATTR_5G_NR_POWER_ACTIVE_RELATIVE_TO_LEVEL_60KHZ                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361392
#define RSRFSIGGEN_ATTR_5G_NR_POWER_ACTIVE_RELATIVE_TO_LEVEL_120KHZ                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361393
#define RSRFSIGGEN_ATTR_5G_NR_POWER_ACTIVE_RELATIVE_TO_LEVEL_240KHZ                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361394
#define RSRFSIGGEN_ATTR_5G_NR_POWER_ACTIVE_RELATIVE_TO_LEVEL_REFERENCE_BW                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361395
#define RSRFSIGGEN_ATTR_5G_NR_POWER_REFERENCE_SYSTEM_BANDWIDTH                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361396
#define RSRFSIGGEN_ATTR_5G_NR_REALTIME_FEEDBACK_MODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361397
#define RSRFSIGGEN_ATTR_5G_NR_REALTIME_FEEDBACK_SERIAL_RATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361402
#define RSRFSIGGEN_ATTR_5G_NR_REALTIME_FEEDBACK_CUSTOM_SERIAL_RATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363051
#define RSRFSIGGEN_ATTR_5G_NR_REALTIME_FEEDBACK_CONNECTOR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361399
#define RSRFSIGGEN_ATTR_5G_NR_REALTIME_FEEDBACK_BASEBAND                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361401
#define RSRFSIGGEN_ATTR_5G_NR_REALTIME_FEEDBACK_HPN_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361398
#define RSRFSIGGEN_ATTR_5G_NR_REALTIME_FEEDBACK_DELAY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361400
#define RSRFSIGGEN_ATTR_5G_NR_REALTIME_FEEDBACK_TA_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362475
#define RSRFSIGGEN_ATTR_5G_NR_REALTIME_FEEDBACK_PROCESSING_DELAY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362476
#define RSRFSIGGEN_ATTR_5G_NR_REATIME_FEEDBACK_LOGGING_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361403
#define RSRFSIGGEN_ATTR_5G_NR_REALTIME_FEEDBACK_LOG_OUTPUT_PATH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361404
#define RSRFSIGGEN_ATTR_5G_NR_LOGFILE_GENERATION_LOGGING_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361405
#define RSRFSIGGEN_ATTR_5G_NR_LOGFILE_GENERATION_OUTPUT_PATH                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361406
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_APPLY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361407
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_TEST_SPECIFICATION                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361408
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_RELEASE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361409
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_BASE_STATION_CLASS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361410
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_TEST_CASE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361411
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_TRIGGER_CONFIGURATION                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361412
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_MARKER_CONFIGURATION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361413
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_RF_PORTS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363052
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_OUTPUT_MODE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363053
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_GENERATED_SIGNAL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363289
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_OTA_BASE_STATION_TYPE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362477
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_OTA_DECLARED_DIRECTION                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362478
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_OTA_MINIMUM_EIS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362479
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_OTA_EIS_50M                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362480
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_OTA_BEW_THETA_REFSENS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362481
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_OTA_BEW_PHI_REFSENS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362482
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_OTA_FREQUENCY_RANGE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362483
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_TX_ANTENNAS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361414
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_RX_ANTENNAS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361415
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_ADDITIONAL_DRMS_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361416
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_CELL_ID                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361417
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_CSI_PART                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361418
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_CSI_1_PATTERN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361419
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_CSI_2_PATTERN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361420
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_CHANNEL_BANDWIDTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361421
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_DMRS_TYPE_A_POSITION                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361422
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_DUPLEXING                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361423
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_FRACTION_OF_MAX_THROUGHPUT                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361424
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_FRC                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361425
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_FREQUENCY_OFFSET                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361426
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_MAPPING_TYPE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361427
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361428
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_NUMBER_OF_OFDM_SYMBOLS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361429
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_PREAMBLE_FORMAT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361430
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_POWER_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361431
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_PROPAGATION_CONDITIONS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361432
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_PTRS_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362484
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_RB_OFFSET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361433
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_RF_FREQUENCY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361434
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_SUBCARRIER_SPACING                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361435
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_SUBCARRIER_SPACING_PRACH                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361436
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_TEST_SETUP                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361437
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_TIMING_OFFSET_BASE_VALUE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361438
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_UCI_BITS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361439
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_UE_ID                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361440
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_TRANSMIT_SRS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363054
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_RESTRICTED_SET                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363055
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_TEST_REQUIREMENT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363056
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_CG_UCI_PATTERN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363057
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_WS_VIRTUAL_DOWNLINK_RF_FREQUENCY                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363058
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_FREQ_ALLOC_OF_THE_INTERFERING_SIGNAL                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361441
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_BAND                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361442
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_OFFSET_FACTOR_N                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361443
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_DUPLEXING                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361444
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_TEST_MODEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361445
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_INTERFERER_TYPE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361446
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS2_INTERFERER_TYPE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361447
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_TEST_REQUIREMENT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361448
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_RF_FREQUENCY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361449
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS2_RF_FREQUENCY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361450
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_CHANNEL_BANDWIDTH                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361451
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_SUBCARRIER_SPACING                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361452
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_CELL_ID                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361453
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_UE_ID                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361454
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_NUMBER_OF_RESOURCE_BLOCKS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361455
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_RB_OFFSET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361456
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_POWER_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361457
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS2_POWER_LEVEL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361458
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_FREQUENCY_SHIFT_M                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361459
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_INTERFERING_RB_CENTER_FREQUENCY                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361460
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_IS_DISTANCE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362485
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_FEEDBACK_REALTIME_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361461
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_FEEDBACK_SERIAL_RATE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361462
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_FEEDBACK_ADDITIONAL_USER_DELAY                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361463
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_FEEDBACK_CONNECTOR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361464
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_FEEDBACK_BASEBAND_SELECTOR                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361465
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_FEEDBACK_CUSTOM_SERIAL_RATE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363059
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_FEEDBACK_BB_SELECTOR_INDEX                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363060
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_FEEDBACK_SUE_CONNECTOR                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363061
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_FEEDBACK_TRANSMIT_SRS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363062
#define RSRFSIGGEN_ATTR_5G_NR_TEST_CASE_WIZARD_AWGN_POWER_LEVEL                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361466
#define RSRFSIGGEN_ATTR_5G_NR_FILTER_TEST_MODEL_STANDARD                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362486
#define RSRFSIGGEN_ATTR_5G_NR_FILTER_TEST_MODEL_CATALOG                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361467
#define RSRFSIGGEN_ATTR_5G_NR_FILTER_TEST_MODEL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 361468
#define RSRFSIGGEN_ATTR_5G_NR_FILTER_TEST_CASE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363063
#define RSRFSIGGEN_ATTR_5G_NR_FILTER_TEST_MODEL_FREQUENCY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361469
#define RSRFSIGGEN_ATTR_5G_NR_FILTER_TEST_MODEL_DUPLEXING                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361470
#define RSRFSIGGEN_ATTR_5G_NR_FILTER_TEST_MODEL_BANDWIDTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361471
#define RSRFSIGGEN_ATTR_5G_NR_FILTER_TEST_MODEL_SCS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361472
#define RSRFSIGGEN_ATTR_LORA_ENABLED                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360194
#define RSRFSIGGEN_ATTR_LORA_SET_TO_DEFAULT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360195
#define RSRFSIGGEN_ATTR_LORA_BANDWIDTH                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360196
#define RSRFSIGGEN_ATTR_LORA_IDLE_INTERVAL                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360197
#define RSRFSIGGEN_ATTR_LORA_SEQUENCE_LENGTH                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360198
#define RSRFSIGGEN_ATTR_LORA_OVERSAMPLING                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360199
#define RSRFSIGGEN_ATTR_LORA_SAMPLE_RATE_VARIATION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360200
#define RSRFSIGGEN_ATTR_LORA_SETTINGS_CATALOG                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360201
#define RSRFSIGGEN_ATTR_LORA_RECALL_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360202
#define RSRFSIGGEN_ATTR_LORA_DELETE_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360204
#define RSRFSIGGEN_ATTR_LORA_SAVE_SETTINGS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360206
#define RSRFSIGGEN_ATTR_LORA_GENERATE_WAVEFORM_FILE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360208
#define RSRFSIGGEN_ATTR_LORA_TRIGGER_STATUS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360210
#define RSRFSIGGEN_ATTR_LORA_TRIGGER_ARM                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360211
#define RSRFSIGGEN_ATTR_LORA_TRIGGER_EXECUTE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360212
#define RSRFSIGGEN_ATTR_LORA_TRIGGER_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360213
#define RSRFSIGGEN_ATTR_LORA_TRIGGER_SOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360214
#define RSRFSIGGEN_ATTR_LORA_TRIGGER_SIGNAL_DURATION                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360215
#define RSRFSIGGEN_ATTR_LORA_TRIGGER_SIGNAL_DURATION_UNIT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360216
#define RSRFSIGGEN_ATTR_LORA_INTERNAL_TRIGGER_DELAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360217
#define RSRFSIGGEN_ATTR_LORA_INTERNAL_TRIGGER_INHIBIT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360218
#define RSRFSIGGEN_ATTR_LORA_EXTERNAL_TRIGGER_DELAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360219
#define RSRFSIGGEN_ATTR_LORA_EXTERNAL_TRIGGER_INHIBIT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360220
#define RSRFSIGGEN_ATTR_LORA_EXTERNAL_TRIGGER_SYNC_OUTPUT_TO_EXT_TRIGGER                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360221
#define RSRFSIGGEN_ATTR_LORA_MARKER_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360222
#define RSRFSIGGEN_ATTR_LORA_MARKER_DELAY                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360223
#define RSRFSIGGEN_ATTR_LORA_MARKER_ON_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360224
#define RSRFSIGGEN_ATTR_LORA_MARKER_OFF_TIME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360225
#define RSRFSIGGEN_ATTR_LORA_MARKER_PATTERN                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360226
#define RSRFSIGGEN_ATTR_LORA_MARKER_PULSE_DIVIDER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360227
#define RSRFSIGGEN_ATTR_LORA_MARKER_PULSE_FREQUENCY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360228
#define RSRFSIGGEN_ATTR_LORA_CLOCK_SOURCE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360229
#define RSRFSIGGEN_ATTR_LORA_CLOCK_MODE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360230
#define RSRFSIGGEN_ATTR_LORA_FRAME_PAYLOAD_REDUCED_CODING_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360231
#define RSRFSIGGEN_ATTR_LORA_FRAME_SYNC_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360232
#define RSRFSIGGEN_ATTR_LORA_FRAME_UNMODULATED_PREAMBLE_LENGTH                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360233
#define RSRFSIGGEN_ATTR_LORA_FRAME_CODING_RATE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360234
#define RSRFSIGGEN_ATTR_LORA_FRAME_SPREADING_FACTOR                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360235
#define RSRFSIGGEN_ATTR_LORA_FRAME_ENCODER_ACTIVE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360236
#define RSRFSIGGEN_ATTR_LORA_FRAME_INTERLEAVER_ACTIVE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360237
#define RSRFSIGGEN_ATTR_LORA_FRAME_DATA_LENGTH                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360238
#define RSRFSIGGEN_ATTR_LORA_FRAME_DATA_PAYLOAD_CRC                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360239
#define RSRFSIGGEN_ATTR_LORA_FRAME_DATA_SOURCE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360240
#define RSRFSIGGEN_ATTR_LORA_FRAME_DATA_PATTERN                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360241
#define RSRFSIGGEN_ATTR_LORA_FRAME_DATA_LIST                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360242
#define RSRFSIGGEN_ATTR_LORA_FRAME_DATA_HEADER_ACTIVE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360244
#define RSRFSIGGEN_ATTR_LORA_FRAME_DATA_BURST_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360245
#define RSRFSIGGEN_ATTR_LORA_FRAME_DATA_COMPRESSED_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360246
#define RSRFSIGGEN_ATTR_LORA_FRAME_DATA_REVERSED_BIT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360247
#define RSRFSIGGEN_ATTR_LORA_IMPAIRMENTS_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360248
#define RSRFSIGGEN_ATTR_LORA_IMPAIRMENTS_SYMBOL_TIMING_ERROR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360249
#define RSRFSIGGEN_ATTR_LORA_IMPAIRMENTS_FREQUENCY_OFFSET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360250
#define RSRFSIGGEN_ATTR_LORA_IMPAIRMENTS_FREQUENCY_DRIFT_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360251
#define RSRFSIGGEN_ATTR_LORA_IMPAIRMENTS_FREQUENCY_DRIFT_TYPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360252
#define RSRFSIGGEN_ATTR_LORA_IMPAIRMENTS_FREQUENCY_DRIFT_DEVIATION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360253
#define RSRFSIGGEN_ATTR_LORA_IMPAIRMENTS_FREQUENCY_DRIFT_RATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360254
#define RSRFSIGGEN_ATTR_HRP_UWB_ENABLED                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362487
#define RSRFSIGGEN_ATTR_HRP_UWB_SET_TO_DEFAULT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362488
#define RSRFSIGGEN_ATTR_HRP_UWB_MODE                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362489
#define RSRFSIGGEN_ATTR_HRP_UWB_CHANNEL_NUMBER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362490
#define RSRFSIGGEN_ATTR_HRP_UWB_IDLE_INTERVAL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362491
#define RSRFSIGGEN_ATTR_HRP_UWB_BANDWIDTH                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362492
#define RSRFSIGGEN_ATTR_HRP_UWB_SETTINGS_CATALOG                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362493
#define RSRFSIGGEN_ATTR_HRP_UWB_LOAD_SETTINGS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362494
#define RSRFSIGGEN_ATTR_HRP_UWB_SAVE_SETTINGS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362496
#define RSRFSIGGEN_ATTR_HRP_UWB_DELETE_SETTINGS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362498
#define RSRFSIGGEN_ATTR_HRP_UWB_GENERATE_WAVEFORM_FILE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362500
#define RSRFSIGGEN_ATTR_HRP_UWB_FILTER_TYPE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362502
#define RSRFSIGGEN_ATTR_HRP_UWB_FILTER_APCO25                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362503
#define RSRFSIGGEN_ATTR_HRP_UWB_FILTER_COSINE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362504
#define RSRFSIGGEN_ATTR_HRP_UWB_FILTER_COSINE_CUTOFF_FREQUENCY_SHIFT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362505
#define RSRFSIGGEN_ATTR_HRP_UWB_FILTER_GAUSS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362506
#define RSRFSIGGEN_ATTR_HRP_UWB_FILTER_PURE_GAUSS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362507
#define RSRFSIGGEN_ATTR_HRP_UWB_FILTER_ROOT_COSINE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362508
#define RSRFSIGGEN_ATTR_HRP_UWB_FILTER_LTE_OPTIMIZATION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362509
#define RSRFSIGGEN_ATTR_HRP_UWB_FILTER_LTE_ROLLOFF_FACTOR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362510
#define RSRFSIGGEN_ATTR_HRP_UWB_FILTER_LTE_CUTOFF_FREQUENCY_FACTOR                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362511
#define RSRFSIGGEN_ATTR_HRP_UWB_FILTER_LTE_CUTOFF_FREQUENCY_SHIFT                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362512
#define RSRFSIGGEN_ATTR_HRP_UWB_FILTER_LOW_PASS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362513
#define RSRFSIGGEN_ATTR_HRP_UWB_FILTER_LOW_PASS_EVM                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362514
#define RSRFSIGGEN_ATTR_HRP_UWB_FILTER_SPLIT_PHASE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362515
#define RSRFSIGGEN_ATTR_HRP_UWB_FILTER_OVERSAMPLING_FACTOR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362517
#define RSRFSIGGEN_ATTR_HRP_UWB_FILTER_SAMPLE_RATE_VARIATION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362518
#define RSRFSIGGEN_ATTR_HRP_UWB_CLIPPING_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362519
#define RSRFSIGGEN_ATTR_HRP_UWB_CLIPPING_LEVEL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362520
#define RSRFSIGGEN_ATTR_HRP_UWB_CLIPPING_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362521
#define RSRFSIGGEN_ATTR_HRP_UWB_SEQUENCE_LENGTH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362522
#define RSRFSIGGEN_ATTR_HRP_UWB_TRIGGER_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362523
#define RSRFSIGGEN_ATTR_HRP_UWB_TRIGGER_SIGNAL_GENERATION_STATUS                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362524
#define RSRFSIGGEN_ATTR_HRP_UWB_TRIGGER_ARM                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362525
#define RSRFSIGGEN_ATTR_HRP_UWB_TRIGGER_EXECUTE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362526
#define RSRFSIGGEN_ATTR_HRP_UWB_TRIGGER_SOURCE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362527
#define RSRFSIGGEN_ATTR_HRP_UWB_TRIGGER_SIGNAL_DURATION_UNIT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362528
#define RSRFSIGGEN_ATTR_HRP_UWB_TRIGGER_SIGNAL_DURATION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362529
#define RSRFSIGGEN_ATTR_HRP_UWB_TIME_BASED_TRIGGER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363501
#define RSRFSIGGEN_ATTR_HRP_UWB_INTERNAL_TRIGGER_INHIBIT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362530
#define RSRFSIGGEN_ATTR_HRP_UWB_INTERNAL_TRIGGER_DELAY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362531
#define RSRFSIGGEN_ATTR_HRP_UWB_INTERNAL_TRIGGER_SPECIFIED_DELAY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362532
#define RSRFSIGGEN_ATTR_HRP_UWB_INTERNAL_TRIGGER_ACTUAL_DELAY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362533
#define RSRFSIGGEN_ATTR_HRP_UWB_EXTERNAL_TRIGGER_INHIBIT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362534
#define RSRFSIGGEN_ATTR_HRP_UWB_EXTERNAL_TRIGGER_DELAY_UNIT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362535
#define RSRFSIGGEN_ATTR_HRP_UWB_EXTERNAL_TRIGGER_DELAY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362536
#define RSRFSIGGEN_ATTR_HRP_UWB_EXTERNAL_TRIGGER_SPECIFIED_DELAY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362537
#define RSRFSIGGEN_ATTR_HRP_UWB_EXTERNAL_TRIGGER_ACTUAL_DELAY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362538
#define RSRFSIGGEN_ATTR_HRP_UWB_EXTERNAL_TRIGGER_SYNC_OUTPUT_TO_EXT_TRIGGER                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362539
#define RSRFSIGGEN_ATTR_HRP_UWB_MARKER_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362540
#define RSRFSIGGEN_ATTR_HRP_UWB_MARKER_RISE_OFFSET                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362541
#define RSRFSIGGEN_ATTR_HRP_UWB_MARKER_FALL_OFFSET                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362542
#define RSRFSIGGEN_ATTR_HRP_UWB_MARKER_DELAY                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362543
#define RSRFSIGGEN_ATTR_HRP_UWB_CLOCK_SOURCE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362544
#define RSRFSIGGEN_ATTR_HRP_UWB_CLOCK_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362545
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_CODE_INDEX                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362546
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_STS_PACKET_CONFIGURATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362547
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_FIXED_2MS_FRAME                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363064
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_SYNC_LENGTH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362548
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_DELTA_LENGTH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362549
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_MAX_DATA_LENGTH                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363065
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_MAX_FCS_LENGTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363066
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_LENGTH                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363067
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_SFD_LENGTH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362550
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_SFD                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362551
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_SFD_INDICES_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363502
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_DATA_SOURCE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362552
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_DATA_LIST_SELECTION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362553
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_DATA_PATTERN                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362554
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_DATA_VITERBI_RATE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362555
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_DATA_CONVOLUTIONAL_CODE_CONSTRAINT_LENGTH                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362556
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_DATA_HOP_BURSTS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362557
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_DATA_MEAN_PRF                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362558
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_DATA_CHIPS_PER_BURST                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362559
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_DATA_MAC_FCS_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362560
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_DATA_RATE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362561
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_PHR_DATA_RATE_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362562
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_PHR_BIT_RATE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362563
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_DATA_LENGTH                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362564
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_HEX_ADDRESS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362565
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362566
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_FRAME_CONTROL_LENGTH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362567
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_FRAME_CONTROL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362568
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_SEQUENCE_NUMBER_LENGTH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362569
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_SEQUENCE_NUMBER                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362570
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_DESTINATION_PAN_ID_LENGTH                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362571
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_DESTINATION_PAN_ID                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362572
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_DESTINATION_ADDRESS_LENGTH                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362573
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_DESTINATION_ADDRESS                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362574
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_DESTINATION_ADDRESS_2                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362575
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_DESTINATION_ADDRESS_3                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362576
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_DESTINATION_ADDRESS_4                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362577
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_SOURCE_PAN_ID_INFORMATION_ENABLED                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362578
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_SOURCE_PAN_ID_LENGTH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362579
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_SOURCE_PAN_ID                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362580
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_SOURCE_ADDRESS_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362581
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_SOURCE_ADDRESS_LENGTH                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362582
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_SOURCE_ADDRESS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362583
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_SOURCE_ADDRESS_2                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362584
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_SOURCE_ADDRESS_3                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362585
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_SOURCE_ADDRESS_4                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362586
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_FRAME_TYPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362587
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_SECURITY_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362588
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_FRAME_PENDING                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362589
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_AR                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362590
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_PAN_ID_COMPRESSION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362591
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_RESERVED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362592
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_SEQUENCE_NUMBER_SUPPORT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362593
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_IE_PRESENT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362594
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_DESTINATION_ADDRESSING_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362595
#define RSRFSIGGEN_ATTR_HRP_UWB_MAC_HEADER_FRAME_VERSION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362596
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_STS_VUPPER96                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362597
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_STS_VCOUNTER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362598
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_STS_KEY                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362599
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_STS_DELTA_LENGTH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362600
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_STS_ACTIVE_SEGMENT_LENGTH                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362601
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_STS_NUMBER_OF_ACTIVE_SEGMENTS                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362602
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_STS_ADDITIONAL_GAP                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 362603
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_STS_DATA_LIST_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363290
#define RSRFSIGGEN_ATTR_HRP_UWB_FRAME_STS_DATA_LIST                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363291
#define RSRFSIGGEN_ATTR_HRP_UWB_IMPAIRMENTS_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362604
#define RSRFSIGGEN_ATTR_HRP_UWB_IMPAIRMENTS_CHIP_CLOCK_ERROR                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362605
#define RSRFSIGGEN_ATTR_HRP_UWB_IMPAIRMENTS_FREQUENCY_OFFSET                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362606
#define RSRFSIGGEN_ATTR_FSIM_ENABLED                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348696
#define RSRFSIGGEN_ATTR_FSIM_SIGNAL_ROUTING                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348697
#define RSRFSIGGEN_ATTR_FSIM_STANDARD                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348698
#define RSRFSIGGEN_ATTR_FSIM_FADING_CONFIGURATION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348699
#define RSRFSIGGEN_ATTR_FSIM_STANDARD_REFERENCE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 348700
#define RSRFSIGGEN_ATTR_FSIM_STANDARD_RATIO                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355108
#define RSRFSIGGEN_ATTR_FSIM_COPY_TO_DESTINATION                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354051
#define RSRFSIGGEN_ATTR_FSIM_SET_TO_DEFAULT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348701
#define RSRFSIGGEN_ATTR_FSIM_RESTART_SYNCHRONIZATION_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357542
#define RSRFSIGGEN_ATTR_FSIM_CLOCK_RATE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354052
#define RSRFSIGGEN_ATTR_FSIM_COPY_DESTINATION                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357543
#define RSRFSIGGEN_ATTR_FSIM_EXECUTE_COPY                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357544
#define RSRFSIGGEN_ATTR_FSIM_CATALOG                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348702
#define RSRFSIGGEN_ATTR_FSIM_DELETE_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348703
#define RSRFSIGGEN_ATTR_FSIM_SAVE_SETTINGS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348704
#define RSRFSIGGEN_ATTR_FSIM_RECALL_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348705
#define RSRFSIGGEN_ATTR_FSIM_CONFIGURATION_FINE_DELAY_30                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348706
#define RSRFSIGGEN_ATTR_FSIM_CONFIGURATION_FINE_DELAY_50                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348707
#define RSRFSIGGEN_ATTR_FSIM_CONFIGURATION_STANDARD_DELAY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348708
#define RSRFSIGGEN_ATTR_FSIM_CONFIGURATION_BIRTH_DEATH_PROPAGATION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348709
#define RSRFSIGGEN_ATTR_FSIM_CONFIGURATION_MOVING_PROPAGATION                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348710
#define RSRFSIGGEN_ATTR_FSIM_SIGNAL_DEDICATED_TO                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348711
#define RSRFSIGGEN_ATTR_FSIM_VIRTUAL_RF_FREQUENCY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348712
#define RSRFSIGGEN_ATTR_FSIM_DEDICATED_CONNECTOR                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354053
#define RSRFSIGGEN_ATTR_FSIM_COMMON_SPEED_FOR_ALL_PATHS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348713
#define RSRFSIGGEN_ATTR_FSIM_SPEED_UNIT                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348714
#define RSRFSIGGEN_ATTR_FSIM_COPY_GROUP_SETTINGS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355109
#define RSRFSIGGEN_ATTR_FSIM_KEEP_CONSTANT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348715
#define RSRFSIGGEN_ATTR_FSIM_RESTART_EVENT                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348716
#define RSRFSIGGEN_ATTR_FSIM_RESTART                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348717
#define RSRFSIGGEN_ATTR_FSIM_IGNORE_RF_CHANGES_LT_5PCT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348718
#define RSRFSIGGEN_ATTR_FSIM_FREQUENCY_HOPPING_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348719
#define RSRFSIGGEN_ATTR_FSIM_BYPASS_IF_FADING_OFF                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 354055
#define RSRFSIGGEN_ATTR_FSIM_SCENARIO_PRESET_SHIP_TO_SHIP                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350059
#define RSRFSIGGEN_ATTR_FSIM_SCENARIO_PRESET_TOWER_TO_AIRCRAFT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350060
#define RSRFSIGGEN_ATTR_FSIM_SCENARIO                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350061
#define RSRFSIGGEN_ATTR_FSIM_SCENARIO_COORDINATE_SYSTEM                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350062
#define RSRFSIGGEN_ATTR_FSIM_SCENARIO_CREATE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350063
#define RSRFSIGGEN_ATTR_FSIM_SCENARIO_LOAD                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350064
#define RSRFSIGGEN_ATTR_FSIM_SCENARIO_SAVE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350066
#define RSRFSIGGEN_ATTR_FSIM_SCENARIO_CATALOG                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350068
#define RSRFSIGGEN_ATTR_FSIM_USER_FADER_PROFILE_SOURCE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350069
#define RSRFSIGGEN_ATTR_FSIM_USER_FADER_PROFILE_ACTIVE_FILE_TPA                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350070
#define RSRFSIGGEN_ATTR_FSIM_USER_FADER_PROFILE_ACTIVE_FILE_PROFILE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350071
#define RSRFSIGGEN_ATTR_FSIM_USER_FADER_PROFILE_FILES_CATALOG_TPA                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350072
#define RSRFSIGGEN_ATTR_FSIM_USER_FADER_PROFILE_FILES_CATALOG_PROFILE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350073
#define RSRFSIGGEN_ATTR_FSIM_USER_VEHICLE_RX                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360560
#define RSRFSIGGEN_ATTR_FSIM_USER_VEHICLE_TX                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360561
#define RSRFSIGGEN_ATTR_FSIM_USER_VEHICLE_CATEGORY_RX                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360562
#define RSRFSIGGEN_ATTR_FSIM_USER_VEHICLE_CATEGORY_TX                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360563
#define RSRFSIGGEN_ATTR_FSIM_USER_VEHICLE_TYPE_AIR_RX                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360564
#define RSRFSIGGEN_ATTR_FSIM_USER_VEHICLE_TYPE_AIR_TX                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360565
#define RSRFSIGGEN_ATTR_FSIM_USER_VEHICLE_TYPE_LAND_RX                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360566
#define RSRFSIGGEN_ATTR_FSIM_USER_VEHICLE_TYPE_LAND_TX                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360567
#define RSRFSIGGEN_ATTR_FSIM_USER_VEHICLE_TYPE_WATER_RX                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360568
#define RSRFSIGGEN_ATTR_FSIM_USER_VEHICLE_TYPE_WATER_TX                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360569
#define RSRFSIGGEN_ATTR_FSIM_USER_VEHICLE_TYPE_RX                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360570
#define RSRFSIGGEN_ATTR_FSIM_USER_VEHICLE_TYPE_TX                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360571
#define RSRFSIGGEN_ATTR_FSIM_USER_VEHICLE_FILE_RX                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360572
#define RSRFSIGGEN_ATTR_FSIM_USER_VEHICLE_FILE_TX                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360573
#define RSRFSIGGEN_ATTR_FSIM_USER_VEHICLE_CATALOG_RX                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350081
#define RSRFSIGGEN_ATTR_FSIM_USER_VEHICLE_CATALOG_TX                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360574
#define RSRFSIGGEN_ATTR_FSIM_USER_TRAJECTORY_RX                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360575
#define RSRFSIGGEN_ATTR_FSIM_USER_TRAJECTORY_TX                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360576
#define RSRFSIGGEN_ATTR_FSIM_USER_TRAJECTORY_ACTIVE_FILE_TRAJECTORY_RX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360577
#define RSRFSIGGEN_ATTR_FSIM_USER_TRAJECTORY_ACTIVE_FILE_TRAJECTORY_TX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360578
#define RSRFSIGGEN_ATTR_FSIM_USER_TRAJECTORY_ACTIVE_FILE_EPHEMERIS_RX                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360579
#define RSRFSIGGEN_ATTR_FSIM_USER_TRAJECTORY_ACTIVE_FILE_EPHEMERIS_TX                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360580
#define RSRFSIGGEN_ATTR_FSIM_USER_TRAJECTORY_FILES_CATALOG_TRAJECTORY_RX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360581
#define RSRFSIGGEN_ATTR_FSIM_USER_TRAJECTORY_FILES_CATALOG_TRAJECTORY_TX                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360582
#define RSRFSIGGEN_ATTR_FSIM_USER_TRAJECTORY_FILES_CATALOG_EPHEMERIS_RX                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360583
#define RSRFSIGGEN_ATTR_FSIM_USER_TRAJECTORY_FILES_CATALOG_EPHEMERIS_TX                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360584
#define RSRFSIGGEN_ATTR_FSIM_USER_TRAJECTORY_SMOOTH_MOVEMENT_ENABLE_RX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360585
#define RSRFSIGGEN_ATTR_FSIM_USER_TRAJECTORY_SMOOTH_MOVEMENT_ENABLE_TX                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360586
#define RSRFSIGGEN_ATTR_FSIM_USER_TRAJECTORY_BEHAVIOR_AT_END_RX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360587
#define RSRFSIGGEN_ATTR_FSIM_USER_TRAJECTORY_BEHAVIOR_AT_END_TX                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360588
#define RSRFSIGGEN_ATTR_FSIM_USER_TRAJECTORY_ACCELERATION_RX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360589
#define RSRFSIGGEN_ATTR_FSIM_USER_TRAJECTORY_ACCELERATION_TX                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360590
#define RSRFSIGGEN_ATTR_FSIM_SHIP_TO_SHIP_TURN_BACK_AFTER                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350094
#define RSRFSIGGEN_ATTR_FSIM_SHIP_TO_SHIP_DISTANCE_X                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350095
#define RSRFSIGGEN_ATTR_FSIM_SHIP_TO_SHIP_DISTANCE_Y                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350096
#define RSRFSIGGEN_ATTR_FSIM_SHIP_TO_SHIP_WATER_TYPE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350097
#define RSRFSIGGEN_ATTR_FSIM_SHIP_TO_SHIP_WATER_SURFACE_TYPE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350098
#define RSRFSIGGEN_ATTR_FSIM_SHIP_TO_SHIP_VEHICLE_TYPE_RX                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360591
#define RSRFSIGGEN_ATTR_FSIM_SHIP_TO_SHIP_VEHICLE_TYPE_TX                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360592
#define RSRFSIGGEN_ATTR_FSIM_SHIP_TO_SHIP_SPEED_RX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360593
#define RSRFSIGGEN_ATTR_FSIM_SHIP_TO_SHIP_SPEED_TX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360594
#define RSRFSIGGEN_ATTR_FSIM_SHIP_TO_SHIP_HEADING_RX                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360595
#define RSRFSIGGEN_ATTR_FSIM_SHIP_TO_SHIP_HEADING_TX                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360596
#define RSRFSIGGEN_ATTR_FSIM_SHIP_TO_SHIP_HEIGHT_OF_ANTENNA_RX                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360597
#define RSRFSIGGEN_ATTR_FSIM_SHIP_TO_SHIP_HEIGHT_OF_ANTENNA_TX                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360598
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_VEHICLE_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350105
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_CONSTANT_ACCELERATION_ENABLE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350106
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_SPEED_START                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350107
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_SPEED_TAKE_OFF                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350108
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_SPEED_TOUCH_DOWN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350109
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_SPEED_DEPARTURE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350110
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_SPEED_CRUISE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350111
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_SPEED_DESCENT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350112
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_ANGLE_CLIMB_OUT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350113
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_ANGLE_DESCENT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350114
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_RATE_CLIMB_OUT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350115
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_RATE_DESCENT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350116
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_CRUISE_ALTITUDE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350117
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_FIELD_LENGTH_TAKE_OFF                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350118
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_FIELD_LENGTH_LANDING                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350119
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_TURN_RADIUS_LEFT                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 350120
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_TURN_RADIUS_RIGHT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350121
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_TERRAIN_TYPE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350122
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_TRIP_DURATION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350123
#define RSRFSIGGEN_ATTR_FSIM_TOWER_TO_AIRCRAFT_TRIP_LENGTH                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350124
#define RSRFSIGGEN_ATTR_FSIM_FDEL_FADING_PROFILE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348720
#define RSRFSIGGEN_ATTR_FSIM_CONFIGURATION_STANDARD_DELAY_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355832
#define RSRFSIGGEN_ATTR_FSIM_CUSTOM_FADING_PROFILE_DOPPLER_SHAPE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354057
#define RSRFSIGGEN_ATTR_FSIM_RESULTING_DOPPLER_SHIFT_ACTUAL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 354058
#define RSRFSIGGEN_ATTR_FSIM_RESULTING_DOPPLER_SHIFT_FREQUENCY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355110
#define RSRFSIGGEN_ATTR_FSIM_FREQUENCY_SHIFT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 354059
#define RSRFSIGGEN_ATTR_FSIM_FREQUENCY_SPREAD                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 354060
#define RSRFSIGGEN_ATTR_FSIM_ENABLE_PATH_DEL                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360599
#define RSRFSIGGEN_ATTR_FSIM_ENABLE_PATH_DEL_30_MHZ                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360600
#define RSRFSIGGEN_ATTR_FSIM_ENABLE_PATH_DEL_50_MHZ                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360601
#define RSRFSIGGEN_ATTR_FSIM_ENABLE_PATH_MDEL_30_MHZ                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360602
#define RSRFSIGGEN_ATTR_FSIM_FADING_PROFILE_DEL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360603
#define RSRFSIGGEN_ATTR_FSIM_FADING_PROFILE_DEL_30_MHZ                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360604
#define RSRFSIGGEN_ATTR_FSIM_FADING_PROFILE_DEL_50_MHZ                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360605
#define RSRFSIGGEN_ATTR_FSIM_FADING_PROFILE_MDEL_30_MHZ                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360606
#define RSRFSIGGEN_ATTR_FSIM_PATH_LOSS_DEL                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360607
#define RSRFSIGGEN_ATTR_FSIM_PATH_LOSS_DEL_30_MHZ                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360608
#define RSRFSIGGEN_ATTR_FSIM_PATH_LOSS_DEL_50_MHZ                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360609
#define RSRFSIGGEN_ATTR_FSIM_PATH_LOSS_MDEL_30_MHZ                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360610
#define RSRFSIGGEN_ATTR_FSIM_BASIC_DELAY_DEL                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360611
#define RSRFSIGGEN_ATTR_FSIM_BASIC_DELAY_DEL_30_MHZ                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360612
#define RSRFSIGGEN_ATTR_FSIM_BASIC_DELAY_DEL_50_MHZ                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360613
#define RSRFSIGGEN_ATTR_FSIM_BASIC_DELAY_MDEL_30_MHZ                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360614
#define RSRFSIGGEN_ATTR_FSIM_ADDITIONAL_DELAY_DEL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360615
#define RSRFSIGGEN_ATTR_FSIM_ADDITIONAL_DELAY_DEL_30_MHZ                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360616
#define RSRFSIGGEN_ATTR_FSIM_ADDITIONAL_DELAY_DEL_50_MHZ                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360617
#define RSRFSIGGEN_ATTR_FSIM_ADDITIONAL_DELAY_MDEL_30_MHZ                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360618
#define RSRFSIGGEN_ATTR_FSIM_RESULTING_DELAY_DEL                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348726
#define RSRFSIGGEN_ATTR_FSIM_RESULTING_DELAY_DEL_30_MHZ                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360619
#define RSRFSIGGEN_ATTR_FSIM_RESULTING_DELAY_DEL_50_MHZ                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360620
#define RSRFSIGGEN_ATTR_FSIM_RESULTING_DELAY_MDEL_30_MHZ                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360621
#define RSRFSIGGEN_ATTR_FSIM_ACTUAL_DELAY_DEL_30_MHZ_DOPPLER_SHIFT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363068
#define RSRFSIGGEN_ATTR_FSIM_POWER_RATIO_DEL                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360622
#define RSRFSIGGEN_ATTR_FSIM_POWER_RATIO_DEL_30_MHZ                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360623
#define RSRFSIGGEN_ATTR_FSIM_POWER_RATIO_DEL_50_MHZ                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360624
#define RSRFSIGGEN_ATTR_FSIM_POWER_RATIO_MDEL_30_MHZ                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360625
#define RSRFSIGGEN_ATTR_FSIM_CONSTANT_PHASE_DEL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360626
#define RSRFSIGGEN_ATTR_FSIM_CONSTANT_PHASE_DEL_30_MHZ                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360627
#define RSRFSIGGEN_ATTR_FSIM_CONSTANT_PHASE_DEL_50_MHZ                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360628
#define RSRFSIGGEN_ATTR_FSIM_CONSTANT_PHASE_MDEL_30_MHZ                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360629
#define RSRFSIGGEN_ATTR_FSIM_SPEED_DEL                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360630
#define RSRFSIGGEN_ATTR_FSIM_SPEED_DEL_30_MHZ                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360631
#define RSRFSIGGEN_ATTR_FSIM_SPEED_DEL_50_MHZ                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360632
#define RSRFSIGGEN_ATTR_FSIM_SPEED_MDEL_30_MHZ                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360633
#define RSRFSIGGEN_ATTR_FSIM_FREQUENCY_RATIO_DEL                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360634
#define RSRFSIGGEN_ATTR_FSIM_FREQUENCY_RATIO_DEL_30_MHZ                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360635
#define RSRFSIGGEN_ATTR_FSIM_FREQUENCY_RATIO_DEL_50_MHZ                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360636
#define RSRFSIGGEN_ATTR_FSIM_FREQUENCY_RATIO_MDEL_30_MHZ                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360637
#define RSRFSIGGEN_ATTR_FSIM_RESULTING_DOPPLER_SHIFT_DEL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360638
#define RSRFSIGGEN_ATTR_FSIM_RESULTING_DOPPLER_SHIFT_DEL_30_MHZ                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360639
#define RSRFSIGGEN_ATTR_FSIM_RESULTING_DOPPLER_SHIFT_DEL_50_MHZ                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360640
#define RSRFSIGGEN_ATTR_FSIM_RESULTING_DOPPLER_SHIFT_MDEL_30_MHZ                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360641
#define RSRFSIGGEN_ATTR_FSIM_CORRELATION_PATH_DEL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360642
#define RSRFSIGGEN_ATTR_FSIM_CORRELATION_PATH_DEL_30_MHZ                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360643
#define RSRFSIGGEN_ATTR_FSIM_CORRELATION_PATH_DEL_50_MHZ                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360644
#define RSRFSIGGEN_ATTR_FSIM_CORRELATION_PATH_MDEL_30_MHZ                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360645
#define RSRFSIGGEN_ATTR_FSIM_CORRELATION_COEFFICIENT_DEL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 360646
#define RSRFSIGGEN_ATTR_FSIM_CORRELATION_COEFFICIENT_DEL_30_MHZ                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360647
#define RSRFSIGGEN_ATTR_FSIM_CORRELATION_COEFFICIENT_DEL_50_MHZ                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360648
#define RSRFSIGGEN_ATTR_FSIM_CORRELATION_COEFFICIENT_MDEL_30_MHZ                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360649
#define RSRFSIGGEN_ATTR_FSIM_CORRELATION_COEFFICIENT_PHASE_DEL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348734
#define RSRFSIGGEN_ATTR_FSIM_CORRELATION_COEFFICIENT_PHASE_DEL_30_MHZ                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360650
#define RSRFSIGGEN_ATTR_FSIM_CORRELATION_COEFFICIENT_PHASE_DEL_50_MHZ                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360651
#define RSRFSIGGEN_ATTR_FSIM_CORRELATION_COEFFICIENT_PHASE_MDEL_30_MHZ                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360652
#define RSRFSIGGEN_ATTR_FSIM_LOGNORMAL_ENABLED_DEL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360653
#define RSRFSIGGEN_ATTR_FSIM_LOGNORMAL_ENABLED_DEL_30_MHZ                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360654
#define RSRFSIGGEN_ATTR_FSIM_LOGNORMAL_ENABLED_DEL_50_MHZ                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360655
#define RSRFSIGGEN_ATTR_FSIM_LOGNORMAL_ENABLED_MDEL_30_MHZ                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360656
#define RSRFSIGGEN_ATTR_FSIM_LOCAL_CONSTANT_DEL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360657
#define RSRFSIGGEN_ATTR_FSIM_LOCAL_CONSTANT_DEL_30_MHZ                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360658
#define RSRFSIGGEN_ATTR_FSIM_LOCAL_CONSTANT_DEL_50_MHZ                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360659
#define RSRFSIGGEN_ATTR_FSIM_LOCAL_CONSTANT_MDEL_30_MHZ                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360660
#define RSRFSIGGEN_ATTR_FSIM_STANDARD_DEVIATION_DEL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348737
#define RSRFSIGGEN_ATTR_FSIM_STANDARD_DEVIATION_DEL_30_MHZ                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360661
#define RSRFSIGGEN_ATTR_FSIM_STANDARD_DEVIATION_DEL_50_MHZ                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360662
#define RSRFSIGGEN_ATTR_FSIM_STANDARD_DEVIATION_MDEL_30_MHZ                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360663
#define RSRFSIGGEN_ATTR_FSIM_BIRTH_DEATH_MIN_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348738
#define RSRFSIGGEN_ATTR_FSIM_BIRTH_DEATH_DELAY_GRID                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348739
#define RSRFSIGGEN_ATTR_FSIM_BIRTH_DEATH_POSITIONS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348740
#define RSRFSIGGEN_ATTR_FSIM_BIRTH_DEATH_POSITIONS_SMW                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355523
#define RSRFSIGGEN_ATTR_FSIM_BIRTH_DEATH_MAXIMUM_DELAY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348741
#define RSRFSIGGEN_ATTR_FSIM_BIRTH_DEATH_START_OFFSET                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348742
#define RSRFSIGGEN_ATTR_FSIM_BIRTH_DEATH_HOPPING_DWELL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348743
#define RSRFSIGGEN_ATTR_FSIM_BIRTH_DEATH_SPEED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348744
#define RSRFSIGGEN_ATTR_FSIM_BIRTH_DEATH_FREQUENCY_RATIO                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348745
#define RSRFSIGGEN_ATTR_FSIM_BIRTH_DEATH_PROFILE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348746
#define RSRFSIGGEN_ATTR_FSIM_BIRTH_DEATH_PATH_LOSS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348747
#define RSRFSIGGEN_ATTR_FSIM_BIRTH_DEATH_RESULTING_DOPPLER_SHIFT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348748
#define RSRFSIGGEN_ATTR_FSIM_BIRTH_DEATH_ACTUAL_DOPPLER_FREQUENCY                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355111
#define RSRFSIGGEN_ATTR_FSIM_REFERENCE_PATH_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348749
#define RSRFSIGGEN_ATTR_FSIM_REFERENCE_PATH_LOSS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348750
#define RSRFSIGGEN_ATTR_FSIM_REFERENCE_PATH_DELAY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348751
#define RSRFSIGGEN_ATTR_FSIM_MOVING_PATH_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348752
#define RSRFSIGGEN_ATTR_FSIM_MOVING_PATH_LOSS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348753
#define RSRFSIGGEN_ATTR_FSIM_MOVING_PATH_DELAY                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348754
#define RSRFSIGGEN_ATTR_FSIM_MOVING_PATH_VARIATION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348755
#define RSRFSIGGEN_ATTR_FSIM_MOVING_PATH_VARIATION_ALL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348756
#define RSRFSIGGEN_ATTR_FSIM_MOVING_PATH_VARIATION_PERIOD                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348757
#define RSRFSIGGEN_ATTR_FSIM_MOVING_PATH_VARIATION_PERIOD_ALL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348758
#define RSRFSIGGEN_ATTR_FSIM_MOVING_PATH_CHANNELS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348759
#define RSRFSIGGEN_ATTR_FSIM_SPEED_SETTING_COUPLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348760
#define RSRFSIGGEN_ATTR_FSIM_LOCAL_CONSTANT_COUPLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348761
#define RSRFSIGGEN_ATTR_FSIM_STANDARD_DEVIATION_COUPLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348762
#define RSRFSIGGEN_ATTR_FSIM_INSERTION_LOSS_MODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348763
#define RSRFSIGGEN_ATTR_FSIM_INSERTION_LOSS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348764
#define RSRFSIGGEN_ATTR_FSIM_CLIPPED_SAMPLES                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348765
#define RSRFSIGGEN_ATTR_FSIM_GLOBAL_SEED                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348766
#define RSRFSIGGEN_ATTR_FSIM_TCI_REFERENCE_PATH_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348767
#define RSRFSIGGEN_ATTR_FSIM_TCI_REFERENCE_PATH_PROFILE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348768
#define RSRFSIGGEN_ATTR_FSIM_TCI_REFERENCE_PATH_LOSS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348769
#define RSRFSIGGEN_ATTR_FSIM_TCI_REFERENCE_PATH_SPEED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348770
#define RSRFSIGGEN_ATTR_FSIM_TCI_REFERENCE_PATH_DELAY_MIN                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348771
#define RSRFSIGGEN_ATTR_FSIM_TCI_REFERENCE_PATH_DELAY_MAX                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348772
#define RSRFSIGGEN_ATTR_FSIM_TCI_REFERENCE_PATH_MOVING_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348773
#define RSRFSIGGEN_ATTR_FSIM_TCI_REFERENCE_PATH_PERIOD                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348774
#define RSRFSIGGEN_ATTR_FSIM_TCI_REFERENCE_DOPLER_FREQUENCY                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348775
#define RSRFSIGGEN_ATTR_FSIM_TCI_DOPLER_FREQUENCY_RATIO                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348776
#define RSRFSIGGEN_ATTR_FSIM_TCI_PATH_SPEED                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348777
#define RSRFSIGGEN_ATTR_FSIM_TCI_PATH_PERIOD                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348778
#define RSRFSIGGEN_ATTR_FSIM_TCI_MOVING_PATH_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348779
#define RSRFSIGGEN_ATTR_FSIM_TCI_MOVING_PATH_PROFILE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348780
#define RSRFSIGGEN_ATTR_FSIM_TCI_MOVING_PATH_LOSS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348781
#define RSRFSIGGEN_ATTR_FSIM_TCI_MOVING_PATH_SPEED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348782
#define RSRFSIGGEN_ATTR_FSIM_TCI_MOVING_PATH_DELAY_MIN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348783
#define RSRFSIGGEN_ATTR_FSIM_TCI_MOVING_PATH_DELAY_MAX                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348784
#define RSRFSIGGEN_ATTR_FSIM_TCI_MOVING_PATH_MOVING_MODE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348785
#define RSRFSIGGEN_ATTR_FSIM_TCI_MOVING_PATH_PERIOD                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348786
#define RSRFSIGGEN_ATTR_FSIM_TCI_MOVING_DOPLER_FREQUENCY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348787
#define RSRFSIGGEN_ATTR_FSIM_MIMO_TAB                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348788
#define RSRFSIGGEN_ATTR_FSIM_MIMO_COPY_TO_NEXT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348789
#define RSRFSIGGEN_ATTR_FSIM_MIMO_COPY_TO_PREVIOUS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348790
#define RSRFSIGGEN_ATTR_FSIM_MIMO_COPY_TO_ALL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 354061
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SAVE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348791
#define RSRFSIGGEN_ATTR_FSIM_MIMO_LOAD                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348792
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SUBSET                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348793
#define RSRFSIGGEN_ATTR_FSIM_MIMO_CAPABILITY                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357545
#define RSRFSIGGEN_ATTR_FSIM_MIMO_MATRIX_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348794
#define RSRFSIGGEN_ATTR_FSIM_MIMO_MATRIX_ACCEPT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357546
#define RSRFSIGGEN_ATTR_FSIM_MIMO_MATRIX_CONFLICT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357547
#define RSRFSIGGEN_ATTR_FSIM_MIMO_MATRIX_PHASE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348795
#define RSRFSIGGEN_ATTR_FSIM_MIMO_MATRIX_RATIO                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348796
#define RSRFSIGGEN_ATTR_FSIM_MIMO_MATRIX_MAGNITUDE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357548
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_PHASE_AB                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360664
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_PHASE_AC                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360665
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_PHASE_AD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360666
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_PHASE_BC                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360667
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_PHASE_BD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360668
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_PHASE_CD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360669
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_RATIO_AB                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360670
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_RATIO_AC                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360671
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_RATIO_AD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360672
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_RATIO_BC                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360673
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_RATIO_BD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360674
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_RATIO_CD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360675
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_REAL_AB                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360676
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_REAL_AC                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360677
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_REAL_AD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360678
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_REAL_BC                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360679
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_REAL_BD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360680
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_REAL_CD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360681
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_IMAGINARY_AB                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360682
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_IMAGINARY_AC                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360683
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_IMAGINARY_AD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360684
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_IMAGINARY_BC                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360685
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_IMAGINARY_BD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360686
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_RX_IMAGINARY_CD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360687
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_PHASE_AB                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360688
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_PHASE_AC                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360689
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_PHASE_AD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360690
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_PHASE_BC                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360691
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_PHASE_BD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360692
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_PHASE_CD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360693
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_RATIO_AB                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360694
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_RATIO_AC                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360695
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_RATIO_AD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360696
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_RATIO_BC                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360697
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_RATIO_BD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360698
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_RATIO_CD                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360699
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_REAL_AB                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360700
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_REAL_AC                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360701
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_REAL_AD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360702
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_REAL_BC                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360703
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_REAL_BD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360704
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_REAL_CD                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360705
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_IMAGINARY_AB                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360706
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_IMAGINARY_AC                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360707
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_IMAGINARY_AD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360708
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_IMAGINARY_BC                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360709
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_IMAGINARY_BD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360710
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TX_IMAGINARY_CD                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360711
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TABLE_RX_PHASE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355112
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TABLE_RX_REAL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355113
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TABLE_RX_IMAGINARY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355114
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TABLE_RX_MAGNITUDE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355115
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TABLE_TX_PHASE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355116
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TABLE_TX_REAL                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355117
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TABLE_TX_IMAGINARY                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355118
#define RSRFSIGGEN_ATTR_FSIM_MIMO_KRONECKER_CORRELATION_TABLE_TX_MAGNITUDE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355119
#define RSRFSIGGEN_ATTR_FSIM_MIMO_RELATIVE_GAIN_VECTOR_MATRIX_PRESET                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 354070
#define RSRFSIGGEN_ATTR_FSIM_MIMO_INVERSE_CHANNEL_MATRIX_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357549
#define RSRFSIGGEN_ATTR_FSIM_MIMO_INVERSE_CHANNEL_MATRIX_IMAGINARY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357550
#define RSRFSIGGEN_ATTR_FSIM_MIMO_INVERSE_CHANNEL_MATRIX_REAL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357551
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCME_DISTRIBUTION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357552
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCME_DISTANCE_RX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357553
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCME_DISTANCE_TX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357554
#define RSRFSIGGEN_ATTR_FSIM_MIMO_RAY_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357555
#define RSRFSIGGEN_ATTR_FSIM_MIMO_RAY_GAIN                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357556
#define RSRFSIGGEN_ATTR_FSIM_MIMO_ARRIVAL_ARRAY_SPREAD                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355120
#define RSRFSIGGEN_ATTR_FSIM_MIMO_DEPARTURE_ARRAY_SPREAD                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355121
#define RSRFSIGGEN_ATTR_FSIM_MIMO_ARRIVAL_ANGLE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355122
#define RSRFSIGGEN_ATTR_FSIM_MIMO_DEPARTURE_ANGLE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355123
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCME_WINNER_MS_SPEED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 354073
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCME_WINNER_MS_DOT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 354074
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCME_WINNER_CLUSTER_GAIN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 354075
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCME_WINNER_CLUSTER_AOD                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 354076
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCME_WINNER_CLUSTER_AOD_SPREAD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354077
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCME_WINNER_CLUSTER_AOA                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 354078
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCME_WINNER_CLUSTER_AOA_SPREAD                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354079
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCME_WINNER_CLUSTER_DISTRIBUTION                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 354080
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCME_WINNER_CLUSTER_STATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 354081
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCME_WINNER_SUB_CLUSTER_STATE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 354082
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCME_WINNER_SUB_CLUSTER_GAIN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 354083
#define RSRFSIGGEN_ATTR_FSIM_MIMO_RX_ANTENNA_ARRAY_PATTERN_CATALOG                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 354084
#define RSRFSIGGEN_ATTR_FSIM_MIMO_ANTENNA_ARRAY_PATTERN_USER_CATALOG                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355124
#define RSRFSIGGEN_ATTR_FSIM_MIMO_CHANNEL_POLARIZATION_STATE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 354085
#define RSRFSIGGEN_ATTR_FSIM_MIMO_CHANNEL_POLARIZATION_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357557
#define RSRFSIGGEN_ATTR_FSIM_MIMO_CHANNEL_POLARIZATION_VERTICAL_POWER_RATIO                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 354086
#define RSRFSIGGEN_ATTR_FSIM_MIMO_CHANNEL_POLARIZATION_HORIZONTAL_POWER_RATIO                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 354087
#define RSRFSIGGEN_ATTR_FSIM_MIMO_RX_ANTENNA_ARRAY_POLARIZATION_SLANT_ANGLE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 354088
#define RSRFSIGGEN_ATTR_FSIM_MIMO_RX_ANTENNA_ARRAY_NUMBER_OF_ROWS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 354089
#define RSRFSIGGEN_ATTR_FSIM_MIMO_RX_ANTENNA_ARRAY_NUMBER_OF_COLUMNS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 354090
#define RSRFSIGGEN_ATTR_FSIM_MIMO_RX_ANTENNA_ARRAY_HORIZONTAL_SPACING                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 354091
#define RSRFSIGGEN_ATTR_FSIM_MIMO_RX_ANTENNA_ARRAY_VERTICAL_SPACING                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 354092
#define RSRFSIGGEN_ATTR_FSIM_MIMO_RX_ANTENNA_ARRAY_CROSS_POLARIZED_SPACING                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 354093
#define RSRFSIGGEN_ATTR_FSIM_MIMO_RX_ANTENNA_ARRAY_PATTERN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 354094
#define RSRFSIGGEN_ATTR_FSIM_MIMO_RX_ANTENNA_CALCULATION_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357558
#define RSRFSIGGEN_ATTR_FSIM_MIMO_RX_ANTENNA_ARRAY_PATTERN_FILE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 354095
#define RSRFSIGGEN_ATTR_FSIM_MIMO_TX_ANTENNA_ARRAY_POLARIZATION_SLANT_ANGLE                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 354096
#define RSRFSIGGEN_ATTR_FSIM_MIMO_TX_ANTENNA_ARRAY_NUMBER_OF_ROWS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 354097
#define RSRFSIGGEN_ATTR_FSIM_MIMO_TX_ANTENNA_ARRAY_NUMBER_OF_COLUMNS                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 354098
#define RSRFSIGGEN_ATTR_FSIM_MIMO_TX_ANTENNA_ARRAY_HORIZONTAL_SPACING                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 354099
#define RSRFSIGGEN_ATTR_FSIM_MIMO_TX_ANTENNA_ARRAY_VERTICAL_SPACING                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 354100
#define RSRFSIGGEN_ATTR_FSIM_MIMO_TX_ANTENNA_ARRAY_CROSS_POLARIZED_SPACING                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 354101
#define RSRFSIGGEN_ATTR_FSIM_MIMO_TX_ANTENNA_ARRAY_PATTERN                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 354102
#define RSRFSIGGEN_ATTR_FSIM_MIMO_TX_ANTENNA_CALCULATION_MODE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357559
#define RSRFSIGGEN_ATTR_FSIM_MIMO_TX_ANTENNA_ARRAY_PATTERN_FILE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 354103
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_MS_SPEED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355833
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_MS_DOT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355834
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_SIGMA                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355835
#define RSRFSIGGEN_ATTR_FSIM_D3_MODE_STATE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360255
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_AZIMUTH_ANGLE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360256
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ELEVATION_ANGLE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360257
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_RELATIVE_GAIN                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355836
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANGLE_OF_DEPARTURE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355837
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ZENITH_ANGLE_OF_DEPARTURE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360258
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_AOD_SPREAD                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355838
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ZENITH_AOD_SPREAD                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360259
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANGLE_OF_ARRIVAL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360260
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ZENITH_ANGLE_OF_ARRIVAL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355839
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_AOA_SPREAD                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355840
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ZENITH_AOA_SPREAD                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360261
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_SUB_CLUSTER_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355841
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_SUB_CLUSTER_RELATIVE_GAIN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355842
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_POLARIZATION_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355843
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_POLARIZATION_HORIZONTAL_CROSS_POLARIZATION_POWER_RATIO            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355844
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_POLARIZATION_VERTICAL_CROSS_POLARIZATION_POWER_RATIO              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355845
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANTENNA_RX_STRUCTURE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360262
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANTENNA_TX_STRUCTURE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360263
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANTENNA_RX_COLUMNS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355846
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANTENNA_RX_ROWS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355847
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANTENNA_TX_COLUMNS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355848
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANTENNA_TX_ROWS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355849
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANTENNA_RX_CALCULATION_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355850
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANTENNA_TX_CALCULATION_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355851
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANTENNA_RX_HORIZONTAL_SPACING                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355852
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANTENNA_TX_HORIZONTAL_SPACING                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355853
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANTENNA_RX_VERTICAL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360264
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANTENNA_TX_VERTICAL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360265
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANTENNA_RX_PATTERN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355854
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANTENNA_TX_PATTERN                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355855
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANTENNA_RX_PATTERN_FILE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355856
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_ANTENNA_TX_PATTERN_FILE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355858
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_LOS_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355860
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_LOS_ANGLE_OF_DEPARTURE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355861
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_LOS_ANGLE_OF_ARRIVAL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355862
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_LOS_K_FACTOR                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355863
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_LOS_RANDOM_PHASE_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355864
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_LOS_RANDOM_PHASE_HH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355865
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_LOS_RANDOM_PHASE_HV                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355866
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_LOS_RANDOM_PHASE_VH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355867
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_LOS_RANDOM_PHASE_VV                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355868
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_LOS_SUBPATH_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355869
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_LOS_SUBPATH_RANDOM_PHASE_HH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355870
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_LOS_SUBPATH_RANDOM_PHASE_HV                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355871
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_LOS_SUBPATH_RANDOM_PHASE_VH                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355872
#define RSRFSIGGEN_ATTR_FSIM_MIMO_SCM_LOS_SUBPATH_RANDOM_PHASE_VV                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355873
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 354104
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_SPEED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354105
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_PERIOD_DWELL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 354106
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_MOVING_PATH_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 354107
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_MOVING_PATH_PROFILE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 354108
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_MOVING_PATH_DOPPLER_SHIFT                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 354109
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_MOVING_PATH_ACTUAL_DOPPLER_SHIFT                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357560
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_MOVING_PATH_LOSS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 354110
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_MOVING_PATH_FREQUENCY_RATIO                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 354111
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_MOVING_PATH_DELAY_MIN                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354112
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_MOVING_PATH_DELAY_MAX                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 354113
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_MOVING_PATH_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 354114
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_REFERENCE_PATH_ENABLED                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 354115
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_REFERENCE_PATH_PROFILE                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 354116
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_REFERENCE_PATH_DOPPLER_SHIFT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 354117
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_REFERENCE_PATH_ACTUAL_DOPPLER_SHIFT                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357561
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_REFERENCE_PATH_LOSS                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 354118
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_REFERENCE_PATH_FREQUENCY_RATIO                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354119
#define RSRFSIGGEN_ATTR_FSIM_TWO_CHANNEL_INTERFER_REFERENCE_PATH_DELAY_MIN                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 354120
#define RSRFSIGGEN_ATTR_FSIM_HST_ENABLED                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348805
#define RSRFSIGGEN_ATTR_FSIM_HST_PATH_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348819
#define RSRFSIGGEN_ATTR_FSIM_HST_PROFILE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348806
#define RSRFSIGGEN_ATTR_FSIM_HST_SPEED                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348807
#define RSRFSIGGEN_ATTR_FSIM_HST_MINIMUM_DISTANCE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348808
#define RSRFSIGGEN_ATTR_FSIM_HST_START_DISTANCE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 348809
#define RSRFSIGGEN_ATTR_FSIM_HST_DOPPLER_SHIFT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348810
#define RSRFSIGGEN_ATTR_FSIM_HST_RICIAN_FACTOR_K                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 354121
#define RSRFSIGGEN_ATTR_FSIM_HST_CONSIDER_DOWNLINK_RF                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 354122
#define RSRFSIGGEN_ATTR_FSIM_HST_VIRTUAL_DOWNLINK_RF                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 354123
#define RSRFSIGGEN_ATTR_FSIM_HST_START_OFFSET                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363069
#define RSRFSIGGEN_ATTR_FSIM_CUSTOMIZED_DYNAMIC_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355874
#define RSRFSIGGEN_ATTR_FSIM_CUSTOMIZED_DYNAMIC_CATALOG                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355875
#define RSRFSIGGEN_ATTR_FSIM_CUSTOMIZED_DYNAMIC_CATALOG_USER                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355876
#define RSRFSIGGEN_ATTR_FSIM_CUSTOMIZED_DYNAMIC_DELETE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355877
#define RSRFSIGGEN_ATTR_FSIM_CUSTOMIZED_DYNAMIC_PATH_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355879
#define RSRFSIGGEN_ATTR_FSIM_CUSTOMIZED_DYNAMIC_PATH_FADING_PROFILE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355880
#define RSRFSIGGEN_ATTR_FSIM_CUSTOMIZED_DYNAMIC_PATH_DATA_LIST                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355881
#define RSRFSIGGEN_ATTR_FSIM_CUSTOMIZED_DYNAMIC_PATH_CONVERT                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363292
#define RSRFSIGGEN_ATTR_IQ_ENABLED                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348811
#define RSRFSIGGEN_ATTR_IQ_SWAP_ENABLED                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348812
#define RSRFSIGGEN_ATTR_IQ_WIDEBAND_ENABLED                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349777
#define RSRFSIGGEN_ATTR_IQ_INTERNAL_BASEBAND_GAIN                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349778
#define RSRFSIGGEN_ATTR_IQ_INTERNAL_BASEBAND_GAIN_LEGACY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351024
#define RSRFSIGGEN_ATTR_IQ_MODULATION_SOURCE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 349779
#define RSRFSIGGEN_ATTR_IQ_OPTIMIZE_EVM                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363070
#define RSRFSIGGEN_ATTR_IQ_ANALOG_WIDEBAND_GAIN                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 349780
#define RSRFSIGGEN_ATTR_IQ_ANALOG_WIDEBAND_CREST_FACTOR                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 349781
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENABLED                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355561
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_OPTIMIZE_IQ_SIGNALS_FOR_RF_OUTPUT_ENABLED                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349782
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_AUXILIARY_INFORMATION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 349783
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 349784
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_LEVEL_VP                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 349785
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_LEVEL_RESULT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349786
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ANALOG_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349787
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_TYPE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 349788
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_LEVEL_PEP                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349789
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_LEVEL                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 349790
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_OFF_LOAD_VOLTAGE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359760
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_ATTENUATION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359761
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_BIAS_COUPLE_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 349791
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_BIAS_I                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 349792
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_BIAS_Q                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 349793
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_OFFSET_I                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 349794
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_OFFSET_Q                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 349795
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_CREST_FACTOR                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349796
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_CFSN                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 349797
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_INSERTION_LOSS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349798
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_POWER_ON_STATE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349799
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_LOAD                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 349800
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_ENABLED                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357562
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DEFAULT_SETTINGS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353658
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_VOLTAGE_ADAPTATION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357563
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_ETRAK_INTERFACE_TYPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357564
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_VOLTAGE_REFERENCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353659
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_VOUT_MAX                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357565
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_VOUT_MIN                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357566
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_BIAS                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357567
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_DC_MODULATOR_EMF                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357568
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_DC_MODULATOR_RIN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357569
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_TERMINATION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353661
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_BIPOLAR_SIGNAL_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353662
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_MAXIMUM_VPP                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353660
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_VCC_OFFSET                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353663
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_DC_MODULATOR_GAIN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357570
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_DC_MODULATOR_VCC_OFFSET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357571
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_TO_RF_DELAY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357572
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_CALCULATE_ENVELOPE_FROM_PREDISTORED_SIGNAL                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353664
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_VCC                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357573
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_PEP                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357574
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_PA_CHARACTERISTICS_VCC_MAX                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357576
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_PA_CHARACTERISTICS_VCC_MIN                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357577
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_PA_CHARACTERISTICS_POWER_OFFSET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357578
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_PA_CHARACTERISTICS_PEPMIN                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357579
#define RSRFSIGGEN_ATTR_IQ_ENVELOPE_PA_CHARACTERISTICS_PEPMAX                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357580
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_SHAPING                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353665
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_SHAPING_SCALE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353666
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_DETROUGHING_FUNCTION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353667
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_DETROUGHING_FUNCTION_FACTOR                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353668
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_DETROUGHING_FUNCTION_EXPONENT                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353669
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_DETROUGHING_FACTOR_COUPLING                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353670
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_DETROUGHING_POST_GAIN                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357581
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_DETROUGHING_PRE_GAIN                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357582
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_TABLES_CATALOG                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357583
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_TABLES_SELECTED_FILE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357586
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_TABLES_INTERPOLATION                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357587
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_TABLES_AUTO_CATALOG                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357588
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_TABLES_AUTO_SELECTED_FILE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357591
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_POLYNOMIAL_CATALOG                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357593
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_POLYNOMIAL_RECALL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357594
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_ENVELOPE_POLYNOMIAL_SAVE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357596
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_CATALOG                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353671
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DELETE_SETTINGS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353672
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_RECALL_SETTINGS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353674
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_SAVE_SETTINGS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353676
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349801
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_SET_LEVEL_VIA                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359762
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_LEVEL_PEP                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 349802
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_LEVEL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 349803
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_POWER_VARIATION_STEP_MODE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359763
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_POWER_VARIATION_STEP                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359764
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_POWER_ON_STATE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 349804
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_CONNECTED_DEVICE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359765
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_CREST_FACTOR                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 349805
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_CFSN                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349806
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_INSERTION_LOSS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 349807
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_SAMPLE_RATE_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355552
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_SAMPLE_RATE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355883
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_HS_CHANNELS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357789
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_OVERFLOW_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359766
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_OVERFLOW_HOLD_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359767
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_OVERFLOW_HOLD_STATE_RESET                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 359768
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353460
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_CONNECTED_DEVICE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353461
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_OVERFLOW_HOLD                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353462
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_OVERFLOW_HOLD_QUERY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353463
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_CLIPPED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353464
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_POWER_ON_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353465
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_POWER_LEVEL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353466
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_POWER_STEP_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353467
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_POWER_STEP                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353468
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_PEAK_LEVEL                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353469
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_VIA                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353470
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_SAMPLE_RATE_SOURCE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353471
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_SAMPLE_RATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353472
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_MAXIMUM_SAMPLE_RATE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357729
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_SAMPLE_RATE_SUM                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362607
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_APPLY_SAMPLE_RATE_TO_ALL                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357730
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_GROUP_DELAY_COMPENSATION                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353678
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_SLOW_IQ_ENABLED                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360266
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_BBMM_INTERFACE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363071
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_HS_BBMM_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357731
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_HS_BBMM_NAME                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357732
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_HS_BBMM_SAMPLE_RATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357733
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_HS_BBMM_POWER_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363072
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_HS_BBMM_PEAK_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363073
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_FADER_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353473
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_FADER_CONNECTED_DEVICE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353474
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_FADER_OVERFLOW_HOLD                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353475
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_FADER_OVERFLOW_HOLD_QUERY                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353476
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_FADER_CLIPPED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353477
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_FADER_POWER_ON_STATE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353478
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_FADER_POWER_LEVEL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353479
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_FADER_POWER_STEP_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353480
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_FADER_POWER_STEP                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353481
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_FADER_PEAK_LEVEL                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353482
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_FADER_VIA                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353483
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_FADER_SAMPLE_RATE_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353484
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_FADER_SAMPLE_RATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353485
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_DIGITAL_FADER_INTERFACE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363074
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348813
#define RSRFSIGGEN_ATTR_IQ_I_OFFSET                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348814
#define RSRFSIGGEN_ATTR_IQ_Q_OFFSET                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348815
#define RSRFSIGGEN_ATTR_IQ_GAIN_IMBALANCE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348816
#define RSRFSIGGEN_ATTR_IQ_QUADRATURE_OFFSET                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348817
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353679
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_AMAM_FIRST                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353680
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_REFERENCE_LEVEL                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353681
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_MAXIMUM_OUTPUT_LEVEL_ERROR                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353682
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_MAXIMUM_NUMBER_OF_ITERATIONS                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353683
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_MEASURE_VALIDITY_STATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353684
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_ACHIEVED_OUTPUT_LEVEL_ERROR                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353685
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_AMAM_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353686
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_AMPM_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353687
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_DPD_PRESET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357598
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_INPUT_PEP                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353688
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_INPUT_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353689
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_INPUT_CREST_FACTOR                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353690
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_OUTPUT_PEP                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353691
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_OUTPUT_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353692
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_OUTPUT_CREST_FACTOR                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353693
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_CORRECTION_COEFFICIENTS_SHAPING                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353694
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_INTERPOLATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353695
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_INVERT_CORRECTION_VALUES                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353696
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_INPUT_POWER_MAXIMUM                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353697
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_INPUT_POWER_MINIMUM                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353698
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_SCALE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357599
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_DPD_AMAM_DELTA_PHASE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357600
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_DPD_AMAM_DELTA_PHASE_PEP                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357601
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_DPD_AMPM_DELTA_PHASE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357603
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_DPD_AMPM_DELTA_PHASE_PEP                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357604
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357606
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_PRESET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357607
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_PHASE_OFFSET                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357608
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_ATTENUATION_COUPLING_ENABLED                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357609
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_INPUT_PEP                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357610
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_INPUT_LEVEL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357611
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_CALCULATION_STATUS                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357612
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_DIG_ATT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357613
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_OUTPUT_PEP                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357614
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_OUTPUT_LEVEL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357615
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_INTERPOLATION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357616
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_INVERT_CORRECTION_VALUES                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357617
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_INPUT_POWER_MAXIMUM                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357618
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_INPUT_POWER_MINIMUM                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357619
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_PRE_GAIN                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357620
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_SCALE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357621
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_SHAPING_POWER_SPLIT_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357622
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_SHAPING_PHASE_DELTA_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357623
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_SHAPING_MODE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 357624
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_SHAPING_POWER_SPLIT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357625
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_SHAPING_TABLES_AMAM_CATALOG                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357626
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_SHAPING_TABLES_AMAM_SELECTED_FILE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357629
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_SHAPING_TABLES_AMPM_CATALOG                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357630
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_SHAPING_TABLES_AMPM_SELECTED_FILE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357633
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_SHAPING_POLYNOMIAL_CATALOG                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357634
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_SHAPING_POLYNOMIAL_RECALL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357636
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_SHAPING_POLYNOMIAL_SAVE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357638
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_SHAPING_NORMALIZED_CATALOG                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357640
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_SHAPING_NORMALIZED_RECALL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357642
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_SHAPING_NORMALIZED_SAVE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357644
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_AMAM_DELTA_PHASE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357646
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_AMAM_DELTA_PHASE_PEP                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357647
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_AMPM_DELTA_PHASE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357649
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_AMPM_DELTA_PHASE_PEP                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357650
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_CATALOG                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357652
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_DELETE_SETTINGS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357653
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_RECALL_SETTINGS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357655
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_DOHERTY_SAVE_SETTINGS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357657
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_AMAM_CATALOG                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353699
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_AMAM_FILE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353700
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_AMPM_CATALOG                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353702
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_AMPM_FILE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353703
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_POLYNOMIAL_CATALOG                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353705
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_POLYNOMIAL_RECALL_SETTINGS                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353706
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_POLYNOMIAL_SAVE_SETTINGS                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353708
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_NORMALIZED_CATALOG                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 357664
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_NORMALIZED_RECALL                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357666
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_NORMALIZED_SAVE                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357668
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_LINEARIZE_RF_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357670
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_LINEARIZE_RF_ADJUST_LINEARIZATION_CURRENT_FREQUENCY    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357671
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_DPD_CATALOG                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357672
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_DPD_DELETE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357673
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_DPD_RECALL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357675
#define RSRFSIGGEN_ATTR_IQ_DIGITAL_PREDISTORTION_DPD_SAVE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357677
#define RSRFSIGGEN_ATTR_IMP_ENABLED                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348820
#define RSRFSIGGEN_ATTR_IQ_OUTPUT_SIGNAL                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348821
#define RSRFSIGGEN_ATTR_IQ_MIMO_FADING_POWER_CORRECTION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348822
#define RSRFSIGGEN_ATTR_IMP_OPTIMIZATION_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348823
#define RSRFSIGGEN_ATTR_IMP_OPTIMIZATION_MODE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348824
#define RSRFSIGGEN_ATTR_IMP_I_OFFSET                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348825
#define RSRFSIGGEN_ATTR_IMP_Q_OFFSET                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348826
#define RSRFSIGGEN_ATTR_IMP_GAIN_IMBALANCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348827
#define RSRFSIGGEN_ATTR_IMP_QUADRATURE_OFFSET                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348828
#define RSRFSIGGEN_ATTR_IMP_DELAY                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348829
#define RSRFSIGGEN_ATTR_IMP_CREST_FACTOR                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348830
#define RSRFSIGGEN_ATTR_IMP_PEAK_LEVEL                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348831
#define RSRFSIGGEN_ATTR_IMP_SIGNAL_LEVEL                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348832
#define RSRFSIGGEN_ATTR_IMP_SKEW                                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359769
#define RSRFSIGGEN_ATTR_IMP_OPTIMIZATION_ACCURACY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348833
#define RSRFSIGGEN_ATTR_IMP_OPTIMIZATION_BANDWIDTH                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348834
#define RSRFSIGGEN_ATTR_IMP_OPTIMIZATION_DISPLAYED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348835
#define RSRFSIGGEN_ATTR_IMP_OPTIMIZATION_CATALOG                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348836
#define RSRFSIGGEN_ATTR_IMP_OPTIMIZATION_FILE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348837
#define RSRFSIGGEN_ATTR_IMP_OPTIMIZATION_FILE_STATUS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348838
#define RSRFSIGGEN_ATTR_IMP_OPTIMIZATION_FREQUENCY_MAXIMUM                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348839
#define RSRFSIGGEN_ATTR_IMP_OPTIMIZATION_FREQUENCY_MINIMUM                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348840
#define RSRFSIGGEN_ATTR_IMP_OPTIMIZATION_FREQUENCY_OFFSET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348841
#define RSRFSIGGEN_ATTR_IMP_OPTIMIZATION_ATTENUATOR_STATUS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348842
#define RSRFSIGGEN_ATTR_IMP_OPTIMIZATION_LEVEL_MAXIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348843
#define RSRFSIGGEN_ATTR_IMP_OPTIMIZATION_LEVEL_MINIMUM                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348844
#define RSRFSIGGEN_ATTR_IMP_OPTIMIZATION_LEVEL_OFFSET                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348845
#define RSRFSIGGEN_ATTR_IMP_OPTIMIZATION_TYPE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348846
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_BBMM_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353710
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_BBMM_DELAY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353711
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_BBMM_IQ_RATIO                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353712
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_BBMM_LEAKAGE_I                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353713
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_BBMM_LEAKAGE_Q                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353714
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_BBMM_QUADRATURE_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353715
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_BBMM_SKEW                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353716
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_BBMM_PHASE_OFFSET                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357734
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_FADER_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353717
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_FADER_DELAY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353718
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_FADER_IQ_RATIO                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353719
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_FADER_LEAKAGE_I                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353720
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_FADER_LEAKAGE_Q                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353721
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_FADER_QUADRATURE_OFFSET                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353722
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_FADER_SKEW                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353723
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_FADER_PHASE_OFFSET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357735
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_IQ_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353724
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_IQ_DELAY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353725
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_IQ_RATIO                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353726
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_IQ_LEAKAGE_I                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353727
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_IQ_LEAKAGE_Q                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353728
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_IQ_QUADRATURE_OFFSET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353729
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_IQ_SKEW                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353730
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_IQ_PHASE_OFFSET                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357736
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_RF_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353731
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_RF_DELAY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353732
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_RF_IQ_RATIO                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353733
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_RF_LEAKAGE_I                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353734
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_RF_LEAKAGE_Q                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353735
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_RF_QUADRATURE_OFFSET                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353736
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_RF_SKEW                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353737
#define RSRFSIGGEN_ATTR_IQ_IMPAIRMENTS_RF_PHASE_OFFSET                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357737
#define RSRFSIGGEN_ATTR_AWGN_ENABLED                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348847
#define RSRFSIGGEN_ATTR_AWGN_MODE                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348848
#define RSRFSIGGEN_ATTR_AWGN_POWERS_FOR_OUTPUT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356643
#define RSRFSIGGEN_ATTR_AWGN_SYSTEM_BANDWIDTH                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348849
#define RSRFSIGGEN_ATTR_AWGN_SYSTEM_BANDWIDTH_RATIO                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348850
#define RSRFSIGGEN_ATTR_AWGN_CENTER_FREQUENCY_OFFSET                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361473
#define RSRFSIGGEN_ATTR_AWGN_SYSTEM_BANDWIDTH_NOISE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356644
#define RSRFSIGGEN_ATTR_AWGN_RESULTING_CW_FREQUENCY_OFFSET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356645
#define RSRFSIGGEN_ATTR_AWGN_TARGET_CW_FREQUENCY_OFFSET                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356646
#define RSRFSIGGEN_ATTR_AWGN_NOISE_POWER                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356647
#define RSRFSIGGEN_ATTR_AWGN_REFERENCE_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356648
#define RSRFSIGGEN_ATTR_AWGN_BIT_RATE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357738
#define RSRFSIGGEN_ATTR_AWGN_COUPLED_MODE_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357739
#define RSRFSIGGEN_ATTR_AWGN_IMPULSIVE_NOISE_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 357740
#define RSRFSIGGEN_ATTR_AWGN_IMPULSIVE_NOISE_CI                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357741
#define RSRFSIGGEN_ATTR_AWGN_IMPULSIVE_NOISE_FRAME_DURATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357742
#define RSRFSIGGEN_ATTR_AWGN_IMPULSIVE_NOISE_PULSES_PER_BURST                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357743
#define RSRFSIGGEN_ATTR_AWGN_IMPULSIVE_NOISE_PULSE_SPACING_MAXIMUM                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357744
#define RSRFSIGGEN_ATTR_AWGN_IMPULSIVE_NOISE_PULSE_SPACING_MINIMUM                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357745
#define RSRFSIGGEN_ATTR_AWGN_IMPULSIVE_NOISE_BURST_DURATION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357746
#define RSRFSIGGEN_ATTR_AWGN_PHASE_NOISE_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357747
#define RSRFSIGGEN_ATTR_AWGN_PHASE_NOISE_LOAD                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357748
#define RSRFSIGGEN_ATTR_AWGN_PHASE_NOISE_SAVE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357750
#define RSRFSIGGEN_ATTR_AWGN_PHASE_PREDEFINED_SETTINGS_FILES_CATALOG                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360267
#define RSRFSIGGEN_ATTR_AWGN_PHASE_NOISE_FREQUENCY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357752
#define RSRFSIGGEN_ATTR_AWGN_PHASE_NOISE_LEVEL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357753
#define RSRFSIGGEN_ATTR_AWGN_NOISE_LEVEL_VIA                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348851
#define RSRFSIGGEN_ATTR_AWGN_CARRIER_TO_NOISE_RATIO                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348852
#define RSRFSIGGEN_ATTR_AWGN_EB_TO_N0                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348853
#define RSRFSIGGEN_ATTR_AWGN_CARRIER_LEVEL                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348854
#define RSRFSIGGEN_ATTR_AWGN_NOISE_LEVEL                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348855
#define RSRFSIGGEN_ATTR_AWGN_CARRIER_AND_NOISE_LEVEL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348856
#define RSRFSIGGEN_ATTR_AWGN_CARRIER_AND_NOISE_PEP                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348857
#define RSRFSIGGEN_ATTR_EXTERNAL_INPUT_COUPLING_MODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355535
#define RSRFSIGGEN_ATTR_EXTERNAL_LF_SIGNAL_BANDWIDTH                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355562
#define RSRFSIGGEN_ATTR_ALL_RF_OUTPUTS_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348858
#define RSRFSIGGEN_ATTR_ALL_MODULATIONS_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 348859
#define RSRFSIGGEN_ATTR_TRIGGER_SOURCE_FOR_ALL_SWEEPS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348860
#define RSRFSIGGEN_ATTR_RESET_ALL_SWEEPS                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348861
#define RSRFSIGGEN_ATTR_OUTPUT_ENABLED                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348862
#define RSRFSIGGEN_ATTR_OUTPUT_IMPEDANCE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355563
#define RSRFSIGGEN_ATTR_RF_FREQUENCY_ON_RECALL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348863
#define RSRFSIGGEN_ATTR_RF_LEVEL_ON_RECALL                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348864
#define RSRFSIGGEN_ATTR_OVERVOLTAGE_PROTECTION_STATE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355564
#define RSRFSIGGEN_ATTR_OVERVOLTAGE_PROTECTION_CLEAR                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348865
#define RSRFSIGGEN_ATTR_OVERVOLTAGE_PROTECTION_TRIPPED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348866
#define RSRFSIGGEN_ATTR_PEP                                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348867
#define RSRFSIGGEN_ATTR_LOCAL_OSCILLATOR_COUPLING_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353738
#define RSRFSIGGEN_ATTR_RF_FREQUENCY                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348868
#define RSRFSIGGEN_ATTR_RF_FREQUENCY_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355539
#define RSRFSIGGEN_ATTR_RF_FREQUENCY_OFFSET                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348869
#define RSRFSIGGEN_ATTR_RF_FREQUENCY_MULTIPLIER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355536
#define RSRFSIGGEN_ATTR_RF_PHASE_CONTINUOUS_ACTIVE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348870
#define RSRFSIGGEN_ATTR_RF_PHASE_CONTINUOUS_MODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348871
#define RSRFSIGGEN_ATTR_RF_PHASE_CONTINUOUS_MAXIMUM_FREQUENCY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348872
#define RSRFSIGGEN_ATTR_RF_PHASE_CONTINUOUS_MINIMUM_FREQUENCY                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348873
#define RSRFSIGGEN_ATTR_RF_VARIATION_STEP_MODE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357754
#define RSRFSIGGEN_ATTR_RF_VARIATION_STEP                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348874
#define RSRFSIGGEN_ATTR_RF_FREQUENCY_CONVERTER_EXTENDED_RANGE_AVAILABLE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 360268
#define RSRFSIGGEN_ATTR_RF_FREQUENCY_CONVERTER_MINIMUM_FREQUENCY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360269
#define RSRFSIGGEN_ATTR_RF_FREQUENCY_CONVERTER_MAXIMUM_FREQUENCY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360270
#define RSRFSIGGEN_ATTR_RF_FREQUENCY_CONVERTER_EXTENDED_RANGE_ENABLED                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360271
#define RSRFSIGGEN_ATTR_RF_DELTA_PHASE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348875
#define RSRFSIGGEN_ATTR_RESET_RF_DELTA_PHASE_DISPLAY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348876
#define RSRFSIGGEN_ATTR_RF_AMPLITUDE                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348877
#define RSRFSIGGEN_ATTR_RF_LEVEL_LOWER_RANGE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357755
#define RSRFSIGGEN_ATTR_RF_LEVEL_UPPER_RANGE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357756
#define RSRFSIGGEN_ATTR_RF_POWER_MODE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355565
#define RSRFSIGGEN_ATTR_RF_LEVEL_LIMIT                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348878
#define RSRFSIGGEN_ATTR_RF_LEVEL_OFFSET                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348879
#define RSRFSIGGEN_ATTR_RF_LEVEL_POWER                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355566
#define RSRFSIGGEN_ATTR_RF_LEVEL_MODE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350892
#define RSRFSIGGEN_ATTR_RF_LEVEL_SETTING_CHARACTERISTICS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350893
#define RSRFSIGGEN_ATTR_RF_LEVEL_EMF_ENABLED                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353739
#define RSRFSIGGEN_ATTR_RF_LEVEL_REFERENCE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363293
#define RSRFSIGGEN_ATTR_RF_ATTENUATOR_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348880
#define RSRFSIGGEN_ATTR_RF_ATTENUATOR_VALUE_MANUAL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357757
#define RSRFSIGGEN_ATTR_RF_ATTENUATOR_LOWER_RANGE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348881
#define RSRFSIGGEN_ATTR_RF_ATTENUATOR_UPPER_RANGE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348882
#define RSRFSIGGEN_ATTR_RF_ATTENUATOR_RF_OFF_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350894
#define RSRFSIGGEN_ATTR_RF_ATTENUATOR_DIGITAL_ATTENUATION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350895
#define RSRFSIGGEN_ATTR_RF_ATTENUATOR_BLANKING                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353486
#define RSRFSIGGEN_ATTR_RF_ATTENUATOR_ACTIVE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363294
#define RSRFSIGGEN_ATTR_RF_ATTENUATOR_INACTIVE_INDICES                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363295
#define RSRFSIGGEN_ATTR_RF_LEVEL_VARIATION_ACTIVE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348883
#define RSRFSIGGEN_ATTR_RF_LEVEL_VARIATION_STEP                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 348884
#define RSRFSIGGEN_ATTR_POWER_ON_ENABLED                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348885
#define RSRFSIGGEN_ATTR_DISPLAY_LEVEL_AS_VOLTAGE_OF_EMF                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353740
#define RSRFSIGGEN_ATTR_MANDATORY_LO_IN_FREQUENCY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353741
#define RSRFSIGGEN_ATTR_LO_OUT_FREQUENCY                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353742
#define RSRFSIGGEN_ATTR_LO_OUT_FREQUENCY_STATE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356649
#define RSRFSIGGEN_ATTR_ALC_ENABLED                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348886
#define RSRFSIGGEN_ATTR_ALC_MODE                                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361474
#define RSRFSIGGEN_ATTR_ALC_SEARCH_ONCE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348887
#define RSRFSIGGEN_ATTR_ALC_DETECTOR_SENSITIVITY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350896
#define RSRFSIGGEN_ATTR_ALC_DRIVER_AMPLIFIER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353743
#define RSRFSIGGEN_ATTR_ALC_SAMPLE_LEVEL                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350897
#define RSRFSIGGEN_ATTR_ALC_OFF_MODE                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359770
#define RSRFSIGGEN_ATTR_USER_CORRECTION_DATA_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348888
#define RSRFSIGGEN_ATTR_USER_CORRECTION_DATA_VALUE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355567
#define RSRFSIGGEN_ATTR_USER_CORRECTION_DATA_CATALOG                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350147
#define RSRFSIGGEN_ATTR_USER_CORRECTION_DATA_DELETE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355568
#define RSRFSIGGEN_ATTR_USER_CORRECTION_DATA_TABLE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348890
#define RSRFSIGGEN_ATTR_USER_CORRECTION_DATA_FREQUENCY_VALUES                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349946
#define RSRFSIGGEN_ATTR_USER_CORRECTION_DATA_NUMBER_OF_FREQUENCY_VALUES                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348892
#define RSRFSIGGEN_ATTR_USER_CORRECTION_DATA_NUMBER_OF_LEVEL_VALUES                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353744
#define RSRFSIGGEN_ATTR_SGAMMA_ENABLED                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353745
#define RSRFSIGGEN_ATTR_SGAMMA_DELETE_CORRECTION_VALUES                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353746
#define RSRFSIGGEN_ATTR_SGAMMA_MAGNITUDE_POINTS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353748
#define RSRFSIGGEN_ATTR_SGAMMA_PHASE_POINTS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353750
#define RSRFSIGGEN_ATTR_FREQUENCY_SWEEP_EXECUTE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 348893
#define RSRFSIGGEN_ATTR_FREQUENCY_SWEEP_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348894
#define RSRFSIGGEN_ATTR_FREQUENCY_SWEEP_TRIGGER_SOURCE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355569
#define RSRFSIGGEN_ATTR_FREQUENCY_SWEEP_START_FREQUENCY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348895
#define RSRFSIGGEN_ATTR_FREQUENCY_SWEEP_STOP_FREQUENCY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348896
#define RSRFSIGGEN_ATTR_FREQUENCY_SWEEP_CENTER_FREQUENCY                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348897
#define RSRFSIGGEN_ATTR_FREQUENCY_SWEEP_SPAN                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348898
#define RSRFSIGGEN_ATTR_FREQUENCY_SWEEP_SPACING                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 348899
#define RSRFSIGGEN_ATTR_FREQUENCY_SWEEP_STEP_LINEAR                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348900
#define RSRFSIGGEN_ATTR_FREQUENCY_SWEEP_STEP_LOG                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348901
#define RSRFSIGGEN_ATTR_FREQUENCY_SWEEP_DWELL_TIME                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348902
#define RSRFSIGGEN_ATTR_FREQUENCY_SWEEP_MANUAL_STEP                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348903
#define RSRFSIGGEN_ATTR_FREQUENCY_SWEEP_POINTS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348904
#define RSRFSIGGEN_ATTR_FREQUENCY_SWEEP_SHAPE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348905
#define RSRFSIGGEN_ATTR_FREQUENCY_SWEEP_STATUS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355570
#define RSRFSIGGEN_ATTR_LEVEL_SWEEP_EXECUTE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348906
#define RSRFSIGGEN_ATTR_LEVEL_SWEEP_MODE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348907
#define RSRFSIGGEN_ATTR_LEVEL_SWEEP_TRIGGER_SOURCE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355571
#define RSRFSIGGEN_ATTR_LEVEL_SWEEP_USER_DIGITAL_ATTENUATOR                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359771
#define RSRFSIGGEN_ATTR_LEVEL_SWEEP_START_LEVEL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 348908
#define RSRFSIGGEN_ATTR_LEVEL_SWEEP_STOP_LEVEL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348909
#define RSRFSIGGEN_ATTR_LEVEL_SWEEP_STEP                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348910
#define RSRFSIGGEN_ATTR_LEVEL_SWEEP_DWELL_TIME                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348911
#define RSRFSIGGEN_ATTR_LEVEL_SWEEP_MANUAL_STEP                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 348912
#define RSRFSIGGEN_ATTR_LEVEL_SWEEP_POINTS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348913
#define RSRFSIGGEN_ATTR_LEVEL_SWEEP_SHAPE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348914
#define RSRFSIGGEN_ATTR_LEVEL_SWEEP_RETRACE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353365
#define RSRFSIGGEN_ATTR_SWEEP_FREQUENCY_RETRACE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356650
#define RSRFSIGGEN_ATTR_LEVEL_SWEEP_SPACING_MODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353751
#define RSRFSIGGEN_ATTR_LEVEL_SWEEP_STATUS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353752
#define RSRFSIGGEN_ATTR_LEVEL_SWEEP_ATTENUATOR_MODE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356651
#define RSRFSIGGEN_ATTR_COMBINED_SWEEP_COUNT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361475
#define RSRFSIGGEN_ATTR_COMBINED_SWEEP_EXECUTE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361476
#define RSRFSIGGEN_ATTR_COMBINED_SWEEP_MODE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361477
#define RSRFSIGGEN_ATTR_COMBINED_SWEEP_TRIGGER_SOURCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361478
#define RSRFSIGGEN_ATTR_COMBINED_SWEEP_START_FREQUENCY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361479
#define RSRFSIGGEN_ATTR_COMBINED_SWEEP_STOP_FREQUENCY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361480
#define RSRFSIGGEN_ATTR_COMBINED_SWEEP_START_LEVEL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361481
#define RSRFSIGGEN_ATTR_COMBINED_SWEEP_STOP_LEVEL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361482
#define RSRFSIGGEN_ATTR_COMBINED_SWEEP_DWELL_TIME                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 361483
#define RSRFSIGGEN_ATTR_COMBINED_SWEEP_SHAPE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361484
#define RSRFSIGGEN_ATTR_COMBINED_SWEEP_RETRACE_ENABLED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361485
#define RSRFSIGGEN_ATTR_AM_ENABLED                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348915
#define RSRFSIGGEN_ATTR_AM_SOURCE                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348916
#define RSRFSIGGEN_ATTR_AM_SOURCE_SMW                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353366
#define RSRFSIGGEN_ATTR_AM_SOURCE_RATIO                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356634
#define RSRFSIGGEN_ATTR_AM_DEPTH                                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348917
#define RSRFSIGGEN_ATTR_AM_DEPTH_TYPE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350125
#define RSRFSIGGEN_ATTR_AM_DEPTH_LINEAR                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350126
#define RSRFSIGGEN_ATTR_AM_DEPTH_EXPONENTIAL                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350127
#define RSRFSIGGEN_ATTR_AM_DEPTH_TOTAL                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 357759
#define RSRFSIGGEN_ATTR_AM_EXTERNAL_COUPLING                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348918
#define RSRFSIGGEN_ATTR_AM_SENSITIVITY                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348919
#define RSRFSIGGEN_ATTR_AM_DEVIATION_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357760
#define RSRFSIGGEN_ATTR_AM_CHANNEL_SOURCE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355885
#define RSRFSIGGEN_ATTR_AM_CHANNEL_DEPTH                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357761
#define RSRFSIGGEN_ATTR_AM_CHANNEL_ENABLED                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356635
#define RSRFSIGGEN_ATTR_BB_AM_ENABLED                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348920
#define RSRFSIGGEN_ATTR_BB_AM_SENSITIVITY                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348921
#define RSRFSIGGEN_ATTR_FM_ENABLED                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348965
#define RSRFSIGGEN_ATTR_FM_SOURCE                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348966
#define RSRFSIGGEN_ATTR_FM_SOURCE_SMW                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353367
#define RSRFSIGGEN_ATTR_FM_SOURCE_RATIO                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 356636
#define RSRFSIGGEN_ATTR_FM_MODE                                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 348967
#define RSRFSIGGEN_ATTR_FM_DEVIATION_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357762
#define RSRFSIGGEN_ATTR_FM_DEVIATION                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348968
#define RSRFSIGGEN_ATTR_FM_DEVIATION_INTERNAL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359772
#define RSRFSIGGEN_ATTR_FM_DEVIATION_EXTERNAL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359773
#define RSRFSIGGEN_ATTR_FM_DEVIATION_TOTAL                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357763
#define RSRFSIGGEN_ATTR_FM_EXTERNAL_COUPLING                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348969
#define RSRFSIGGEN_ATTR_FM_SENSITIVITY                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348970
#define RSRFSIGGEN_ATTR_FM_CHANNEL_SOURCE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355887
#define RSRFSIGGEN_ATTR_FM_CHANNEL_DEVIATION                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357764
#define RSRFSIGGEN_ATTR_FM_CHANNEL_ENABLED                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356637
#define RSRFSIGGEN_ATTR_PULM_ENABLED                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348922
#define RSRFSIGGEN_ATTR_PULM_POLARITY                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348923
#define RSRFSIGGEN_ATTR_PULM_SOURCE                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348924
#define RSRFSIGGEN_ATTR_PULM_PERIOD                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348925
#define RSRFSIGGEN_ATTR_PULM_WIDTH                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348926
#define RSRFSIGGEN_ATTR_PULM_DELAY                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348927
#define RSRFSIGGEN_ATTR_PULM_DOUBLE_ENABLED                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348928
#define RSRFSIGGEN_ATTR_PULM_DOUBLE_WIDTH                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348929
#define RSRFSIGGEN_ATTR_PULM_DOUBLE_DELAY                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348930
#define RSRFSIGGEN_ATTR_PULM_TRANSITION_TYPE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350898
#define RSRFSIGGEN_ATTR_PULM_OUTPUT_VIDEO_POLARITY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350899
#define RSRFSIGGEN_ATTR_PULM_IMPEDANCE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353753
#define RSRFSIGGEN_ATTR_PULM_TRAIN_CATALOG                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350900
#define RSRFSIGGEN_ATTR_PULM_TRAIN_DELETE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350901
#define RSRFSIGGEN_ATTR_PULM_TRAIN_SELECT                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350903
#define RSRFSIGGEN_ATTR_PULM_TRAIN_OFF_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350904
#define RSRFSIGGEN_ATTR_PULM_TRAIN_OFF_TIME_POINTS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350905
#define RSRFSIGGEN_ATTR_PULM_TRAIN_ON_TIME                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350906
#define RSRFSIGGEN_ATTR_PULM_TRAIN_ON_TIME_POINTS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350907
#define RSRFSIGGEN_ATTR_PULM_TRAIN_REPETITION                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350908
#define RSRFSIGGEN_ATTR_PULM_TRAIN_REPETITION_POINTS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350909
#define RSRFSIGGEN_ATTR_PULM_TRAIN_EXECUTE_TRIGGER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356652
#define RSRFSIGGEN_ATTR_PULM_TRAIN_HOPPING_CATALOG                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350910
#define RSRFSIGGEN_ATTR_PULM_TRAIN_HOPPING_DELETE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350911
#define RSRFSIGGEN_ATTR_PULM_TRAIN_HOPPING_SELECT                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350913
#define RSRFSIGGEN_ATTR_PULM_TRAIN_HOPPING_FREQUENCY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350914
#define RSRFSIGGEN_ATTR_PULM_TRAIN_HOPPING_FREQUENCY_POINTS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350915
#define RSRFSIGGEN_ATTR_PULM_TRAIN_HOPPING_OFF_TIME                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350916
#define RSRFSIGGEN_ATTR_PULM_TRAIN_HOPPING_OFF_TIME_POINTS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350917
#define RSRFSIGGEN_ATTR_PULM_TRAIN_HOPPING_ON_TIME                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350918
#define RSRFSIGGEN_ATTR_PULM_TRAIN_HOPPING_ON_TIME_POINTS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350919
#define RSRFSIGGEN_ATTR_PULM_TRAIN_HOPPING_POWER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350920
#define RSRFSIGGEN_ATTR_PULM_TRAIN_HOPPING_POWER_POINTS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350921
#define RSRFSIGGEN_ATTR_PULM_TRAIN_HOPPING_REPETITION                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350922
#define RSRFSIGGEN_ATTR_PULM_TRAIN_HOPPING_REPETITION_POINTS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350923
#define RSRFSIGGEN_ATTR_CORRECTION_LIST_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348931
#define RSRFSIGGEN_ATTR_CORRECTION_LIST_FILE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348932
#define RSRFSIGGEN_ATTR_CORRECTION_EXECUTE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348933
#define RSRFSIGGEN_ATTR_CORRECTION_ASCII_FILE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348934
#define RSRFSIGGEN_ATTR_CORRECTION_ASCII_EXTENSION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348935
#define RSRFSIGGEN_ATTR_CORRECTION_ASCII_COLUMN_SEPARATOR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348936
#define RSRFSIGGEN_ATTR_CORRECTION_ASCII_COLUMN_DECIMAL_SEPARATOR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348937
#define RSRFSIGGEN_ATTR_CORRECTION_IMPORT_EXPORT_CATALOG                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350146
#define RSRFSIGGEN_ATTR_CORRECTION_DATA_WITH_SENSOR                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355531
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_ENABLED                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356439
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_PRESET                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356440
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_LOAD                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356441
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_STORE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356443
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_APPLY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356445
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_BANDWIDTH_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356446
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_BANDWIDTH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356447
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_OPTIMIZATION_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356448
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_HOLD_FILTER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357679
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_OPTIMIZE_FOR_CURRENT_SETTINGS                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357680
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_ABSOLUTE_LEVEL_ENABLED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356449
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_ABSOLUTE_LEVEL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356450
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_FR_LIST_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356451
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_FR_LIST_CATALOG                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356452
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_FR_LIST_CLEAR                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356453
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_FR_LIST_NUMBER_OF_FILES                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356454
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_S_LIST_CLEAR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356456
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_S_LIST_NUMBER_OF_FILES                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356457
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_FR_LIST_SELECT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356458
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_FR_LIST_PHASE_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356460
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_FR_LIST_MAGNITUDE_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 356461
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_S_LIST_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356462
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_S_LIST_SELECT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356463
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_S_LIST_PORTS_FROM                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356465
#define RSRFSIGGEN_ATTR_CORRECTION_FREQUENCY_S_LIST_PORTS_TO                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356466
#define RSRFSIGGEN_ATTR_RF_NOISE_DISTRIBUTION                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350924
#define RSRFSIGGEN_ATTR_RF_NOISE_BANDWIDTH                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 350925
#define RSRFSIGGEN_ATTR_RF_NOISE_BANDWIDTH_STATE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356653
#define RSRFSIGGEN_ATTR_RF_NOISE_DENSITY                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 350926
#define RSRFSIGGEN_ATTR_RF_NOISE_LEVEL                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350927
#define RSRFSIGGEN_ATTR_LF_OUTPUT_SHAPE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351028
#define RSRFSIGGEN_ATTR_LF_OUTPUT_SOURCE_IMPEDANCE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359774
#define RSRFSIGGEN_ATTR_LFGEN_FREQUENCY                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 351041
#define RSRFSIGGEN_ATTR_LF_GENERATOR_PERIOD                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357765
#define RSRFSIGGEN_ATTR_LF_GENERATOR_PULSE_PERIOD                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 351029
#define RSRFSIGGEN_ATTR_LF_GENERATOR_PULSE_WIDTH                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 351030
#define RSRFSIGGEN_ATTR_LF_GENERATOR_PULSE_DUTY_CYCLE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351031
#define RSRFSIGGEN_ATTR_LF_GENERATOR_TRAPEZOID_PERIOD                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351032
#define RSRFSIGGEN_ATTR_LF_GENERATOR_TRAPEZOID_RISE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351033
#define RSRFSIGGEN_ATTR_LF_GENERATOR_TRAPEZOID_FALL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351034
#define RSRFSIGGEN_ATTR_LF_GENERATOR_TRAPEZOID_HIGH                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 351035
#define RSRFSIGGEN_ATTR_LF_GENERATOR_TRIANGLE_PERIOD                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 351036
#define RSRFSIGGEN_ATTR_LF_GENERATOR_TRIANGLE_RISE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 351037
#define RSRFSIGGEN_ATTR_LF_OUTPUT_ENABLED                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351038
#define RSRFSIGGEN_ATTR_LFGEN_VOLTAGE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 351040
#define RSRFSIGGEN_ATTR_LF_OUTPUT_SOURCE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 351042
#define RSRFSIGGEN_ATTR_LF_OUTPUT_SOURCE_PATH                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355572
#define RSRFSIGGEN_ATTR_LF_OUTPUT_VOLTAGE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 351043
#define RSRFSIGGEN_ATTR_LF_OUTPUT_DC_OFFSET                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 351044
#define RSRFSIGGEN_ATTR_LF_OUTPUT_MONITORING                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 351045
#define RSRFSIGGEN_ATTR_FRONTEND_REMOTE_CONNECTION_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362608
#define RSRFSIGGEN_ATTR_FRONTEND_EXTERNAL_INSTRUMENT_IDENTIFICATION                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362609
#define RSRFSIGGEN_ATTR_FRONTEND_EXTERNAL_INSTRUMENT_OPTIONS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362610
#define RSRFSIGGEN_ATTR_FRONTEND_IP_ADDRESS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362611
#define RSRFSIGGEN_ATTR_FRONTED_START_INTERNAL_CALIBRATION_ALL                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362612
#define RSRFSIGGEN_ATTR_FRONTEND_REFERENCE_FREQUENCY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361486
#define RSRFSIGGEN_ATTR_FRONTEND_REFERENCE_FREQUENCY_LIST                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361487
#define RSRFSIGGEN_ATTR_FRONTEND_CONNECTION_MODE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362613
#define RSRFSIGGEN_ATTR_FRONTEND_INTERMEDIATE_FREQUENCY                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362614
#define RSRFSIGGEN_ATTR_FRONTEND_RF_OUTPUT_CONNECTOR                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361488
#define RSRFSIGGEN_ATTR_FRONTEND_FREQUENCY_BAND_COUNT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361489
#define RSRFSIGGEN_ATTR_FRONTEND_INFO                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361490
#define RSRFSIGGEN_ATTR_FRONTEND_LIST                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361491
#define RSRFSIGGEN_ATTR_FRONTEND_S2P_FILE_CATALOG                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363075
#define RSRFSIGGEN_ATTR_FRONTEND_MODE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363076
#define RSRFSIGGEN_ATTR_FRONTEND_SIDEBAND                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363078
#define RSRFSIGGEN_ATTR_FRONTEND_OFFSET                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363296
#define RSRFSIGGEN_ATTR_FRONTEND_LOAD_CORRECTION_LIST                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363297
#define RSRFSIGGEN_ATTR_FRONTEND_CORRECTION_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363298
#define RSRFSIGGEN_ATTR_FRONTEND_EXTERNAL_DEVICE_LIST                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363299
#define RSRFSIGGEN_ATTR_FRONTEND_EXTERNAL_DEVICE_REFRESH                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363300
#define RSRFSIGGEN_ATTR_FRONTED_FREQUENCY_BAND_CONFIG                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 362615
#define RSRFSIGGEN_ATTR_FRONTED_FREQUENCY_BAND_CONFIG_CATALOG                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362616
#define RSRFSIGGEN_ATTR_FRONTEND_SETTINGS_FREQUENCY_BAND_LOWER_LIMIT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361492
#define RSRFSIGGEN_ATTR_FRONTEND_SETTINGS_FREQUENCY_BAND_UPPER_LIMIT                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361493
#define RSRFSIGGEN_ATTR_FRONTEND_EXTERNAL_DEVICE_FREQUENCY_MINIMUM                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363301
#define RSRFSIGGEN_ATTR_FRONTEND_EXTERNAL_DEVICE_FREQUENCY_MAXIMUM                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363302
#define RSRFSIGGEN_ATTR_FRONTEND_EXTERNAL_DEVICE_GAIN                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363303
#define RSRFSIGGEN_ATTR_FRONTEND_EXTERNAL_DEVICE_NAME                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363304
#define RSRFSIGGEN_ATTR_FRONTEND_EXTERNAL_DEVICE_TYPE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363305
#define RSRFSIGGEN_ATTR_FRONTEND_LOCAL_OSCILLATOR_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363503
#define RSRFSIGGEN_ATTR_FRONTEND_LOCAL_OSCILLATOR_IN_FREQUENCY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363504
#define RSRFSIGGEN_ATTR_FRONTEND_LOCAL_OSCILLATOR_OUTPUT_FREQUENCY                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363505
#define RSRFSIGGEN_ATTR_FRONTEND_LOCAL_OSCILLATOR_OUTPUT_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363506
#define RSRFSIGGEN_ATTR_FRONTEND_DEVICE_ID                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 361494
#define RSRFSIGGEN_ATTR_FRONTEND_ATTENUATION                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362617
#define RSRFSIGGEN_ATTR_FRONTEND_ATTENUATION_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362618
#define RSRFSIGGEN_ATTR_FRONTEND_CABLE_CORRECTION_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361496
#define RSRFSIGGEN_ATTR_FRONTEND_CABLE_CORRECTION_FILE_NAME                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 361495
#define RSRFSIGGEN_ATTR_FRONTEND_RECOMMENDED_FREQUENCY_RANGE_LOWER                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362619
#define RSRFSIGGEN_ATTR_FRONTEND_RECOMMENDED_FREQUENCY_RANGE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 362620
#define RSRFSIGGEN_ATTR_ROSC_SOURCE                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 348939
#define RSRFSIGGEN_ATTR_ROSC_RF_SWITCH_OFF_ACTIVE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348940
#define RSRFSIGGEN_ATTR_ROSC_EXTERNAL_REFERENCE_FREQUENCY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348941
#define RSRFSIGGEN_ATTR_ROSC_SYNCHRONIZATION_BANDWIDTH                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348942
#define RSRFSIGGEN_ATTR_ROSC_NOMINAL_SYNCHRONIZATION_BANDWIDTH                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357766
#define RSRFSIGGEN_ATTR_ROSC_MINIMUM_LOCKING_RANGE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357767
#define RSRFSIGGEN_ATTR_ROSC_ADJUSTMENT_ACTIVE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 348943
#define RSRFSIGGEN_ATTR_ROSC_ADJUSTMENT_FREQUENCY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348944
#define RSRFSIGGEN_ATTR_LF_SWEEP_STATE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355573
#define RSRFSIGGEN_ATTR_LF_SWEEP_TRIGGER                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348945
#define RSRFSIGGEN_ATTR_LF_SWEEP_MODE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348946
#define RSRFSIGGEN_ATTR_LF_SWEEP_TRIGGER_SOURCE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355574
#define RSRFSIGGEN_ATTR_LF_SWEEP_START_FREQUENCY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348947
#define RSRFSIGGEN_ATTR_LF_SWEEP_STOP_FREQUENCY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 348948
#define RSRFSIGGEN_ATTR_LF_SWEEP_SPACING                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348949
#define RSRFSIGGEN_ATTR_LF_SWEEP_STEP_LIN                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348951
#define RSRFSIGGEN_ATTR_LF_SWEEP_STEP_LOG                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348952
#define RSRFSIGGEN_ATTR_LF_SWEEP_DWELL_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348953
#define RSRFSIGGEN_ATTR_LF_SWEEP_MANUAL_STEP                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348954
#define RSRFSIGGEN_ATTR_LF_SWEEP_POINTS                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348955
#define RSRFSIGGEN_ATTR_LF_SWEEP_SHAPE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348950
#define RSRFSIGGEN_ATTR_LF_SWEEP_RETRACE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353754
#define RSRFSIGGEN_ATTR_LF_SWEEP_STATUS                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353755
#define RSRFSIGGEN_ATTR_LF_OUTPUT_CHANNEL_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357768
#define RSRFSIGGEN_ATTR_LF_OUTPUT_CHANNEL_SOURCE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 355886
#define RSRFSIGGEN_ATTR_LF_OUTPUT_CHANNEL_OFFSET                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357769
#define RSRFSIGGEN_ATTR_LF_OUTPUT_CHANNEL_VOLTAGE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 357770
#define RSRFSIGGEN_ATTR_PULM_EXTERNAL_INPUT_IMPEDANCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348960
#define RSRFSIGGEN_ATTR_PULM_TRIGGER_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348961
#define RSRFSIGGEN_ATTR_PULM_EXT_TRIGGER_INPUT_SLOPE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348962
#define RSRFSIGGEN_ATTR_PULM_GATE_INPUT_POLARITY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 348963
#define RSRFSIGGEN_ATTR_PGEN_ENABLED                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348964
#define RSRFSIGGEN_ATTR_PGEN_MODE                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350942
#define RSRFSIGGEN_ATTR_PGEN_OUTPUT                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350943
#define RSRFSIGGEN_ATTR_PGEN_OUTPUT_POLARITY                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350944
#define RSRFSIGGEN_ATTR_PM_ENABLED                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348971
#define RSRFSIGGEN_ATTR_PM_SOURCE                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348972
#define RSRFSIGGEN_ATTR_PM_SOURCE_SMW                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353368
#define RSRFSIGGEN_ATTR_PM_MODE                                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 348973
#define RSRFSIGGEN_ATTR_PM_DEVIATION_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357771
#define RSRFSIGGEN_ATTR_PM_DEVIATION                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348974
#define RSRFSIGGEN_ATTR_PM_DEVIATION_TOTAL                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 357772
#define RSRFSIGGEN_ATTR_PM_EXTERNAL_COUPLING                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348975
#define RSRFSIGGEN_ATTR_PM_SENSITIVITY                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 348976
#define RSRFSIGGEN_ATTR_PM_PATH_ENABLED                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355557
#define RSRFSIGGEN_ATTR_PM_PATH_SOURCE_SMW                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 355558
#define RSRFSIGGEN_ATTR_PM_PATH_DEVIATION                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355559
#define RSRFSIGGEN_ATTR_PM_PATH_DEVIATION_INTERNAL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359775
#define RSRFSIGGEN_ATTR_PM_PATH_DEVIATION_EXTERNAL                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 359776
#define RSRFSIGGEN_ATTR_PM_PATH_MODE                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356639
#define RSRFSIGGEN_ATTR_PM_RATIO                                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350945
#define RSRFSIGGEN_ATTR_PM_CHANNEL_SOURCE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355888
#define RSRFSIGGEN_ATTR_PM_CHANNEL_ENABLED                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356638
#define RSRFSIGGEN_ATTR_LIST_CATALOG                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350144
#define RSRFSIGGEN_ATTR_LIST_DELETE_LIST                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348978
#define RSRFSIGGEN_ATTR_LIST_DELETE_ALL                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348979
#define RSRFSIGGEN_ATTR_LIST_LEARN                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 348980
#define RSRFSIGGEN_ATTR_LIST_FREQUENCY_POINTS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348981
#define RSRFSIGGEN_ATTR_LIST_POWER_POINTS                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 348982
#define RSRFSIGGEN_ATTR_LIST_START_INDEX                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348983
#define RSRFSIGGEN_ATTR_LIST_STOP_INDEX                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348984
#define RSRFSIGGEN_ATTR_LIST_FREE_MEMORY                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353756
#define RSRFSIGGEN_ATTR_LIST_RESET_LIST                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348985
#define RSRFSIGGEN_ATTR_LIST_TRIGGER_EXECUTE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 348986
#define RSRFSIGGEN_ATTR_LIST_MODE                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348987
#define RSRFSIGGEN_ATTR_LIST_RUN_MODE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353757
#define RSRFSIGGEN_ATTR_LIST_DWELL_TIME                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 348988
#define RSRFSIGGEN_ATTR_LIST_DWELL_TIME_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353758
#define RSRFSIGGEN_ATTR_LIST_SELECT_LIST                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 348989
#define RSRFSIGGEN_ATTR_LIST_DWELL_TIME_VALUES                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353759
#define RSRFSIGGEN_ATTR_LIST_DWELL_TIME_POINTS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353760
#define RSRFSIGGEN_ATTR_LIST_FREQUENCY_VALUES                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349929
#define RSRFSIGGEN_ATTR_LIST_POWER_VALUES                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 349943
#define RSRFSIGGEN_ATTR_LIST_TRIGGER_SOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 348993
#define RSRFSIGGEN_ATTR_LIST_INDEX                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355541
#define RSRFSIGGEN_ATTR_LIST_CURRENT_STATE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356654
#define RSRFSIGGEN_ATTR_LIST_IMPORT_EXPORT_LIST_MODE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348994
#define RSRFSIGGEN_ATTR_LIST_IMPORT_EXPORT_LIST_FILE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 348995
#define RSRFSIGGEN_ATTR_IMPORT_EXPORT_EXECUTE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 348996
#define RSRFSIGGEN_ATTR_LIST_IMPORT_EXPORT_ASCII_FILE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 348997
#define RSRFSIGGEN_ATTR_LIST_IMPORT_EXPORT_ASCII_EXTENSION                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 348998
#define RSRFSIGGEN_ATTR_LIST_IMPORT_EXPORT_ASCII_COLUMN_SEPARATOR                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 348999
#define RSRFSIGGEN_ATTR_LIST_IMPORT_EXPORT_ASCII_COLUMN_DECIMAL_SEPARATOR                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 349000
#define RSRFSIGGEN_ATTR_LIST_IMPORT_EXPORT_CATALOG                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350145
#define RSRFSIGGEN_ATTR_BBIN_FREQUENCY_OFFSET                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349002
#define RSRFSIGGEN_ATTR_BBIN_PHASE_OFFSET                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 349003
#define RSRFSIGGEN_ATTR_BBIN_PATH_GAIN                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 349004
#define RSRFSIGGEN_ATTR_BBIN_SIGNAL_ROUTING                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349005
#define RSRFSIGGEN_ATTR_BBIN_ENABLED                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 349006
#define RSRFSIGGEN_ATTR_BBIN_MODE                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349007
#define RSRFSIGGEN_ATTR_BBIN_IQ_SWAP                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 349008
#define RSRFSIGGEN_ATTR_BBIN_IQ_SKEW                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 349009
#define RSRFSIGGEN_ATTR_BBIN_CREST_FACTOR                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 349010
#define RSRFSIGGEN_ATTR_BBIN_PEAK_LEVEL                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 349011
#define RSRFSIGGEN_ATTR_BBIN_MEASUREMENT_PERIOD                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 349012
#define RSRFSIGGEN_ATTR_BBIN_AUTO_LEVEL_SET_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 349013
#define RSRFSIGGEN_ATTR_BBIN_AUTO_LEVEL_SET                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349014
#define RSRFSIGGEN_ATTR_BBIN_CURRENT_CREST_FACTOR                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349015
#define RSRFSIGGEN_ATTR_BBIN_CURRENT_PEAK_LEVEL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 349016
#define RSRFSIGGEN_ATTR_BBIN_OVERLOAD_ENABLED                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349017
#define RSRFSIGGEN_ATTR_BBIN_RMS_POWER                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 349018
#define RSRFSIGGEN_ATTR_BBIN_POWER_LEVEL                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 349019
#define RSRFSIGGEN_ATTR_BBIN_SAMPLE_RATE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 349020
#define RSRFSIGGEN_ATTR_BBIN_SAMPLE_RATE_SOURCE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355575
#define RSRFSIGGEN_ATTR_BBIN_CURRENT_SAMPLE_RATE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349021
#define RSRFSIGGEN_ATTR_BBIN_EXTERNALLY_CONNECTED_ID                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353761
#define RSRFSIGGEN_ATTR_BBIN_DIGITAL_SOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353762
#define RSRFSIGGEN_ATTR_BBIN_OVERLOAD_HOLD_RESET                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353763
#define RSRFSIGGEN_ATTR_BBIN_OVERLOAD_SINCE_LAST_RESET                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353764
#define RSRFSIGGEN_ATTR_BBIN_DIGITAL_INTERFACE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356674
#define RSRFSIGGEN_ATTR_BBIN_MAX_SAMPLE_RATE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356675
#define RSRFSIGGEN_ATTR_BBIN_SUM_SAMPLE_RATE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356676
#define RSRFSIGGEN_ATTR_BBIN_SAMPLE_RATE_FIFO_STATUS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359777
#define RSRFSIGGEN_ATTR_BBIN_ACTIVATE_CHANNEL                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356677
#define RSRFSIGGEN_ATTR_BBIN_CHANNEL_NAME                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356679
#define RSRFSIGGEN_ATTR_BBIN_CHANNEL_CREST_FACTOR                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356680
#define RSRFSIGGEN_ATTR_BBIN_CHANNEL_PEAK_LEVEL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356681
#define RSRFSIGGEN_ATTR_BBIN_CHANNEL_SAMPLE_RATE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356682
#define RSRFSIGGEN_ATTR_BBIN_CHANNEL_RMS_LEVEL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 356683
#define RSRFSIGGEN_ATTR_BBIN_IMPAIRMENTS_GAIN_IMBALANCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 349022
#define RSRFSIGGEN_ATTR_BBIN_IMPAIRMENTS_I_OFFSET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349023
#define RSRFSIGGEN_ATTR_BBIN_IMPAIRMENTS_Q_OFFSET                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349024
#define RSRFSIGGEN_ATTR_POWER_UNIT                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349025
#define RSRFSIGGEN_ATTR_POWER_FREQUENCY                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 349026
#define RSRFSIGGEN_ATTR_POWER_RECORDER_STATE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353765
#define RSRFSIGGEN_ATTR_POWER_OFFSET                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 349027
#define RSRFSIGGEN_ATTR_POWER_OFFSET_ENABLED                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 349028
#define RSRFSIGGEN_ATTR_POWER_SOURCE                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 349029
#define RSRFSIGGEN_ATTR_POWER_ZERO                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349030
#define RSRFSIGGEN_ATTR_POWER_CONTINUOUS                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 349031
#define RSRFSIGGEN_ATTR_POWER_USE_SPARAMETERS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349032
#define RSRFSIGGEN_ATTR_POWER_SPARAMETER_LIST                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 356655
#define RSRFSIGGEN_ATTR_POWER_SPARAMETER_SELECT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356656
#define RSRFSIGGEN_ATTR_POWER_DISPLAY_PERMANENT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353766
#define RSRFSIGGEN_ATTR_POWER_DISPLAY_PERMANENT_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 349033
#define RSRFSIGGEN_ATTR_POWER_SPC_STATE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353769
#define RSRFSIGGEN_ATTR_POWER_SPC_SENSOR_SELECT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353770
#define RSRFSIGGEN_ATTR_POWER_SPC_PEAK_POWER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353771
#define RSRFSIGGEN_ATTR_POWER_SPC_DELAY_TIME                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353772
#define RSRFSIGGEN_ATTR_POWER_SPC_TARGET_LEVEL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353773
#define RSRFSIGGEN_ATTR_POWER_SPC_CATCH_RANGE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353774
#define RSRFSIGGEN_ATTR_POWER_SPC_MEASUREMENT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363507
#define RSRFSIGGEN_ATTR_POWER_SPC_MODE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363508
#define RSRFSIGGEN_ATTR_POWER_SPC_SINGLE_EVENT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363509
#define RSRFSIGGEN_ATTR_POWER_SPC_WARNING                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363510
#define RSRFSIGGEN_ATTR_POWER_FILTER_LENGTH                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349034
#define RSRFSIGGEN_ATTR_POWER_FILTER_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 349035
#define RSRFSIGGEN_ATTR_POWER_FILTER_NS_RATIO                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349036
#define RSRFSIGGEN_ATTR_POWER_FILTER_NS_RATIO_TIMEOUT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 349037
#define RSRFSIGGEN_ATTR_POWER_FILTER_LENGTH_AUTO                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349038
#define RSRFSIGGEN_ATTR_POWER_FILTER_SEARCH_ONCE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349039
#define RSRFSIGGEN_ATTR_POWER_SENSOR_DEVICE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349040
#define RSRFSIGGEN_ATTR_POWER_SENSOR_TYPE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 349041
#define RSRFSIGGEN_ATTR_POWER_READ_POWER                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 349042
#define RSRFSIGGEN_ATTR_POWER_SENSOR_VERSION                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 349043
#define RSRFSIGGEN_ATTR_POWER_SENSOR_SERIAL_NUMBER                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349044
#define RSRFSIGGEN_ATTR_POWER_DEFAULT_APERTURE_TIME_ENABLED                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353775
#define RSRFSIGGEN_ATTR_POWER_APERTURE_TIME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353776
#define RSRFSIGGEN_ATTR_POWER_BASEBAND_ADD_MEASUREMENT                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353777
#define RSRFSIGGEN_ATTR_POWER_BASEBAND_CHANGE_MEASUREMENT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353778
#define RSRFSIGGEN_ATTR_POWER_BASEBAND_DELETE_MEASUREMENT                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353779
#define RSRFSIGGEN_ATTR_POWER_BASEBAND_EXECUTE_MEASUREMENT                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353780
#define RSRFSIGGEN_ATTR_POWER_BASEBAND_MEASUREMENT_STATE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353781
#define RSRFSIGGEN_ATTR_POWER_BASEBAND_SOURCE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353782
#define RSRFSIGGEN_ATTR_POWER_BASEBAND_ABORT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353783
#define RSRFSIGGEN_ATTR_POWER_BASEBAND_ACQUISITION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353784
#define RSRFSIGGEN_ATTR_POWER_BASEBAND_DURATION                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353785
#define RSRFSIGGEN_ATTR_POWER_BASEBAND_GATE_SOURCE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353786
#define RSRFSIGGEN_ATTR_POWER_BASEBAND_INDEX                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353787
#define RSRFSIGGEN_ATTR_POWER_BASEBAND_OUTPUT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353788
#define RSRFSIGGEN_ATTR_POWER_BASEBAND_STATUS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353789
#define RSRFSIGGEN_ATTR_POWER_BASEBAND_RUN_MODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353790
#define RSRFSIGGEN_ATTR_POWER_SENSOR_MAPPING_SCAN_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355889
#define RSRFSIGGEN_ATTR_POWER_SENSOR_MAPPING_LIST                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355890
#define RSRFSIGGEN_ATTR_POWER_SENSOR_MAPPING_ADD_LAN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361497
#define RSRFSIGGEN_ATTR_POWER_SENSOR_MAPPING_ADD_USB                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 361499
#define RSRFSIGGEN_ATTR_POWER_SENSOR_MAPPING_CLEAR_LAN                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361501
#define RSRFSIGGEN_ATTR_POWER_SENSOR_MAPPING_CLEAR_USB                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361502
#define RSRFSIGGEN_ATTR_POWER_SENSOR_MAPPING_CLEAR_ALL                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361503
#define RSRFSIGGEN_ATTR_BERT_ENABLED                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 349045
#define RSRFSIGGEN_ATTR_BERT_START_MEASUREMENT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349046
#define RSRFSIGGEN_ATTR_BERT_STOP_MEASUREMENT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349047
#define RSRFSIGGEN_ATTR_BERT_SET_TO_DEFAULT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359778
#define RSRFSIGGEN_ATTR_BERT_RECALL_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359779
#define RSRFSIGGEN_ATTR_BERT_SAVE_SETTINGS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359781
#define RSRFSIGGEN_ATTR_BERT_MODE                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349049
#define RSRFSIGGEN_ATTR_BERT_EXECUTE_SINGLE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349050
#define RSRFSIGGEN_ATTR_BERT_MAX_DATA_BITS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 349051
#define RSRFSIGGEN_ATTR_BERT_MAX_ERRORS                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 349052
#define RSRFSIGGEN_ATTR_BERT_PRBS                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349053
#define RSRFSIGGEN_ATTR_BERT_DATA_POLARITY                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 349054
#define RSRFSIGGEN_ATTR_BERT_DATA_CONNECTOR                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359783
#define RSRFSIGGEN_ATTR_BERT_CLOCK_SLOPE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 349055
#define RSRFSIGGEN_ATTR_BERT_EXTERNAL_RESTART                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349056
#define RSRFSIGGEN_ATTR_BERT_DATA_ENABLE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 349057
#define RSRFSIGGEN_ATTR_BERT_PATTERN_IGNORE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349058
#define RSRFSIGGEN_ATTR_BERT_IMPEDANCE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 349059
#define RSRFSIGGEN_ATTR_BERT_THRESHOLD                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 349060
#define RSRFSIGGEN_ATTR_BERT_DISPLAY_UNIT                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 349061
#define RSRFSIGGEN_ATTR_BERT_TIMEOUT                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 349062
#define RSRFSIGGEN_ATTR_BLER_ENABLED                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 349063
#define RSRFSIGGEN_ATTR_BLER_START_MEASUREMENT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349064
#define RSRFSIGGEN_ATTR_BLER_STOP_MEASUREMENT                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349065
#define RSRFSIGGEN_ATTR_BLER_SET_TO_DEFAULT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359784
#define RSRFSIGGEN_ATTR_BLER_RECALL_SETTINGS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359785
#define RSRFSIGGEN_ATTR_BLER_SAVE_SETTINGS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 359787
#define RSRFSIGGEN_ATTR_BLER_MODE                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349067
#define RSRFSIGGEN_ATTR_BLER_EXECUTE_SINGLE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349068
#define RSRFSIGGEN_ATTR_BLER_MAX_RECEIVED_BLOCKS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349069
#define RSRFSIGGEN_ATTR_BLER_MAX_ERRORS                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 349070
#define RSRFSIGGEN_ATTR_BLER_TYPE                                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349071
#define RSRFSIGGEN_ATTR_BLER_CRC_ORDER                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 359789
#define RSRFSIGGEN_ATTR_BLER_DATA_POLARITY                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 349072
#define RSRFSIGGEN_ATTR_BLER_DATA_CONNECTOR                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359790
#define RSRFSIGGEN_ATTR_BLER_CLOCK_SLOPE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 349073
#define RSRFSIGGEN_ATTR_BLER_DATA_ENABLE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 349074
#define RSRFSIGGEN_ATTR_BLER_DISPLAY_UNIT                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 349075
#define RSRFSIGGEN_ATTR_BLER_TIMEOUT                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 349076
#define RSRFSIGGEN_ATTR_BERT_BLER_TEST_GENERATOR_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359740
#define RSRFSIGGEN_ATTR_BERT_BLER_TEST_GENERATOR_MEASUREMENT_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359741
#define RSRFSIGGEN_ATTR_BERT_BLER_TEST_GENERATOR_ERROR_RATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 359742
#define RSRFSIGGEN_ATTR_BERT_BLER_TEST_GENERATOR_CLOCK_FREQUENCY                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359743
#define RSRFSIGGEN_ATTR_BERT_BLER_TEST_GENERATOR_TRIGGER                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 359744
#define RSRFSIGGEN_ATTR_BERT_BLER_TEST_GENERATOR_DATA_ENABLE_ON_TIME                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359745
#define RSRFSIGGEN_ATTR_BERT_BLER_TEST_GENERATOR_DATA_ENABLE_OFF_TIME                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 359746
#define RSRFSIGGEN_ATTR_BERT_BLER_TEST_GENERATOR_RESTART_DELAY                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359747
#define RSRFSIGGEN_ATTR_BERT_BLER_TEST_GENERATOR_EXTERNAL_IQ_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 359748
#define RSRFSIGGEN_ATTR_BERT_BLER_TEST_GENERATOR_START_SELFTEST                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 359752
#define RSRFSIGGEN_ATTR_BERT_BLER_TEST_GENERATOR_SELFTEST_RESULT                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 359753
#define RSRFSIGGEN_ATTR_THRESHOLD_DATA_INPUT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 349077
#define RSRFSIGGEN_ATTR_THRESHOLD_TRIGGER_CONTROL_INPUT                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 349078
#define RSRFSIGGEN_ATTR_IMPEDANCE_DATA_INPUT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 349079
#define RSRFSIGGEN_ATTR_IMPEDANCE_CLOCK_CONTROL_INPUT                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 349080
#define RSRFSIGGEN_ATTR_LEGACY_IMPEDANCE_TRIGGER_CONTROL_INPUT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349081
#define RSRFSIGGEN_ATTR_BASEBAND_TRIGGER_INPUT_SLOPE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 349082
#define RSRFSIGGEN_ATTR_LEGACY_INSTRUMENT_TRIGGER_INPUT_SLOPE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349083
#define RSRFSIGGEN_ATTR_CONTROL_INPUT_TRIGGER_IMPEDANCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353791
#define RSRFSIGGEN_ATTR_CONTROL_INPUT_TRIGGER_LEVEL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353792
#define RSRFSIGGEN_ATTR_CONTROL_INPUT_TRIGGER_SLOPE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353793
#define RSRFSIGGEN_ATTR_OUTPUT_TRIGGER                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355576
#define RSRFSIGGEN_ATTR_AUTOMATIC_DELAY_COMPENSATION_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359791
#define RSRFSIGGEN_ATTR_AUTOMATIC_DELAY_COMPENSATION_SLAVE_POSITION_IN_CHAIN                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 359792
#define RSRFSIGGEN_ATTR_TRIGGER_INPUT_SLOPE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355594
#define RSRFSIGGEN_ATTR_TRIGGER_ALL_SWEEPS                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 349084
#define RSRFSIGGEN_ATTR_TRIGGER_RF_FREQUENCY_SWEEP                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349085
#define RSRFSIGGEN_ATTR_TRIGGER_RF_LEVEL_SWEEP                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349086
#define RSRFSIGGEN_ATTR_TRIGGER_LIST_MODE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 349087
#define RSRFSIGGEN_ATTR_TRIGGER_LF_FREQUENCY_SWEEP                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355577
#define RSRFSIGGEN_ATTR_EXTERNAL_INPUT_IMPEDANCE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349088
#define RSRFSIGGEN_ATTR_EXTERNAL_INPUT_IMPEDANCE_CHANNEL                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355892
#define RSRFSIGGEN_ATTR_CONTROL_LINES_RF_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349089
#define RSRFSIGGEN_ATTR_CONTROL_INPUT_CLOCK_IMPEDANCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353794
#define RSRFSIGGEN_ATTR_CONTROL_INPUT_CLOCK_LEVEL                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353795
#define RSRFSIGGEN_ATTR_GLOBAL_CONTROL_INPUT_CLOCK_SLOPE                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 357775
#define RSRFSIGGEN_ATTR_CONTROL_INPUT_PULM_LEVEL                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353796
#define RSRFSIGGEN_ATTR_CONTROL_INPUT_THRESHOLD_CLOCK_LEVEL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355529
#define RSRFSIGGEN_ATTR_CONTROL_INPUT_THRESHOLD_TRIGGER_LEVEL                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355530
#define RSRFSIGGEN_ATTR_LOCAL_CONTROL_INPUT_CLOCK_IMPEDANCE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 355578
#define RSRFSIGGEN_ATTR_LOCAL_CONTROL_INPUT_TRIGGER_IMPEDANCE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355579
#define RSRFSIGGEN_ATTR_CONTROL_INPUT_CLOCK_SLOPE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355580
#define RSRFSIGGEN_ATTR_LOCAL_CONTROL_INPUT_TRIGGER_SLOPE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 355581
#define RSRFSIGGEN_ATTR_CONNECTOR_INPUT_DIRECTION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355582
#define RSRFSIGGEN_ATTR_CONNECTOR_OUTPUT_DIRECTION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355583
#define RSRFSIGGEN_ATTR_CONNECTOR_INPUT_SIGNAL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355584
#define RSRFSIGGEN_ATTR_CONNECTOR_OUTPUT_SIGNAL                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355585
#define RSRFSIGGEN_ATTR_LEGACY_CLOCK_INPUT_SLOPE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349090
#define RSRFSIGGEN_ATTR_CLOCK_SOURCE                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 349091
#define RSRFSIGGEN_ATTR_CLOCK_MODE                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349092
#define RSRFSIGGEN_ATTR_CLOCK_INPUT_FREQUENCY                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349093
#define RSRFSIGGEN_ATTR_CLOCK_INPUT_SLOPE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350946
#define RSRFSIGGEN_ATTR_OUTPUT_CONNECTOR_USER_MAPPING                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 349094
#define RSRFSIGGEN_ATTR_OUTPUT_CONNECTOR_USER_SIGNAL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355538
#define RSRFSIGGEN_ATTR_OUTPUT_CONNECTOR_USER_EXECUTE_TRIGGER                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 355893
#define RSRFSIGGEN_ATTR_OUTPUT_CONNECTOR_DIRECTION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 355586
#define RSRFSIGGEN_ATTR_INPUT_CONNECTOR_DIRECTION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353797
#define RSRFSIGGEN_ATTR_INPUT_CONNECTOR_SIGNAL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353798
#define RSRFSIGGEN_ATTR_NO_SIGNAL_MARKER_POLARITY                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349095
#define RSRFSIGGEN_ATTR_CALIBRATION_ALL                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350148
#define RSRFSIGGEN_ATTR_REMOTE_CONTROL_COMMAND_SET                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356467
#define RSRFSIGGEN_ATTR_CALIBRATION_FREQUENCY                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350149
#define RSRFSIGGEN_ATTR_CALIBRATION_IQ_MODULATOR_FULL                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350150
#define RSRFSIGGEN_ATTR_CALIBRATION_IQ_MODULATION_LOCAL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350151
#define RSRFSIGGEN_ATTR_CALIBRATION_ALC_TABLE                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350152
#define RSRFSIGGEN_ATTR_CALIBRATION_LEVEL                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350153
#define RSRFSIGGEN_ATTR_CALIBRATION_FM_OFFSET                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 350154
#define RSRFSIGGEN_ATTR_CALIBRATION_LEVEL_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349103
#define RSRFSIGGEN_ATTR_CALIBRATION_HIGH_ACCURACY_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 349104
#define RSRFSIGGEN_ATTR_CALIBRATION_CONTINUE_ON_ERROR                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353487
#define RSRFSIGGEN_ATTR_CALIBRATION_LOGGING                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353488
#define RSRFSIGGEN_ATTR_CALIBRATION_ADJUST_INTERNAL_LO                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353489
#define RSRFSIGGEN_ATTR_CALIBRATION_LAST_FULL_ADJUSTMENT                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355587
#define RSRFSIGGEN_ATTR_CALIBRATION_LAST_FULL_ADJUSTMENT_TIME                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357776
#define RSRFSIGGEN_ATTR_CALIBRATION_TEMPERATURE_OFFSET_TO_LAST_FULL_ADJUSTMENT                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 355588
#define RSRFSIGGEN_ATTR_CALIBRATION_ADJUST_EXTERNAL_FREQUENCY_CONVERTER                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355894
#define RSRFSIGGEN_ATTR_CALIBRATION_INTERNAL_ADJUSTMENT_STATE                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357778
#define RSRFSIGGEN_ATTR_LAST_FACTORY_CALIBRATION                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356657
#define RSRFSIGGEN_ATTR_CALIBRATION_ANALOG_I_Q_INPUT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 359794
#define RSRFSIGGEN_ATTR_CALIBRATION_EXTERNAL_LEVEL_ADJUSTMENT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 359796
#define RSRFSIGGEN_ATTR_CALIBRATION_DATA_EXPORT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363511
#define RSRFSIGGEN_ATTR_CALIBRATION_DELAY_MINUTES                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363512
#define RSRFSIGGEN_ATTR_CALIBRATION_SHUTDOWN_AFTER_ADJUSTMENT                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 363513
#define RSRFSIGGEN_ATTR_CALIBRATION_ADJUST_ALL_DELAYED                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363514
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_MODULE_NAMES                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 349106
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_TEST_POINTS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349107
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_ENABLED                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362621
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_DELETE_HISTORY                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362622
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_DELETE_ALL_DATA                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 362623
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_DATA_FORMAT                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362624
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_SAVE_HISTORY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362625
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_HISTORY                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 362626
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_ENHANCED_PROTOCOL_SNMP                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363079
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_ENHANCED_PROTOCOL_REST                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363080
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_ENHANCED_PROTOCOL_READ_ONLY_ACCESS_COMMUNITY                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363081
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_ENHANCED_PROTOCOL_READ_WRITE_ACCESS_COMMUNITY                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 363082
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_TAGS_ALL                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363306
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_TAGS_DELETE                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363307
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_TAGS_DELETE_ALL                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363308
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_CONTACT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363515
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_LOCATION                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363516
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_DELETE_USER                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363519
#define RSRFSIGGEN_ATTR_DIAGNOSTIC_HUMS_DELETE_ALL_USERS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363520
#define RSRFSIGGEN_ATTR_HARD_COPY_EXECUTE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 349110
#define RSRFSIGGEN_ATTR_HARD_COPY_DESTINATION                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349111
#define RSRFSIGGEN_ATTR_HARD_COPY_LANGUAGE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 349112
#define RSRFSIGGEN_ATTR_HARD_COPY_FILE_NAME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349113
#define RSRFSIGGEN_ATTR_HARD_COPY_AUTO_FILE_DIRECTORY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 349114
#define RSRFSIGGEN_ATTR_CLEAR_HARD_COPY_FILE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 349115
#define RSRFSIGGEN_ATTR_HARD_COPY_AUTO_FILE_NAME                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349116
#define RSRFSIGGEN_ATTR_HARD_COPY_AUTO_NAMING_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 349117
#define RSRFSIGGEN_ATTR_HARD_COPY_DAY_TO_FILE_NAME                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349118
#define RSRFSIGGEN_ATTR_HARD_COPY_CURRENT_DAY                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349119
#define RSRFSIGGEN_ATTR_HARD_COPY_MONTH_TO_FILE_NAME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 349120
#define RSRFSIGGEN_ATTR_HARD_COPY_CURRENT_MONTH                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 349121
#define RSRFSIGGEN_ATTR_HARD_COPY_YEAR_TO_FILE_NAME                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 349122
#define RSRFSIGGEN_ATTR_HARD_COPY_CURRENT_YEAR                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349123
#define RSRFSIGGEN_ATTR_HARD_COPY_CURRENT_NUMBER                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349124
#define RSRFSIGGEN_ATTR_HARD_COPY_AUTO_PREFIX_ENABLED                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 349125
#define RSRFSIGGEN_ATTR_HARD_COPY_FILE_NAME_PREFIX                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349126
#define RSRFSIGGEN_ATTR_HARD_COPY_GENERATED_AUTO_NAME                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357779
#define RSRFSIGGEN_ATTR_HARD_COPY_IMAGE_FORMAT                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349127
#define RSRFSIGGEN_ATTR_HARD_COPY_IMAGE_RESOLUTION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349128
#define RSRFSIGGEN_ATTR_HARD_COPY_REGION                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 355537
#define RSRFSIGGEN_ATTR_HARD_COPY_PRINTER_LIST                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349129
#define RSRFSIGGEN_ATTR_HARD_COPY_PAGE_UNIT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349131
#define RSRFSIGGEN_ATTR_HARD_COPY_PAGE_ORIENTATION                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349132
#define RSRFSIGGEN_ATTR_HARD_COPY_PAGE_SIZE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349133
#define RSRFSIGGEN_ATTR_HARD_COPY_PRINTER                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 349134
#define RSRFSIGGEN_ATTR_TEST_GENERATOR_ARBITRARY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350947
#define RSRFSIGGEN_ATTR_TEST_GENERATOR_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 350948
#define RSRFSIGGEN_ATTR_TEST_GENERATOR_IQ_SOURCE                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350949
#define RSRFSIGGEN_ATTR_TEST_GENERATOR_GAIN                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350950
#define RSRFSIGGEN_ATTR_TEST_GENERATOR_FREQUENCY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350951
#define RSRFSIGGEN_ATTR_TEST_GENERATOR_FREQUENCY_2                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363083
#define RSRFSIGGEN_ATTR_TEST_BNC_CONNECTION                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350952
#define RSRFSIGGEN_ATTR_TEST_BNC_SOURCE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350953
#define RSRFSIGGEN_ATTR_TEST_BNC_DESTINATION                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 350954
#define RSRFSIGGEN_ATTR_TEST_BNC_LOG                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350955
#define RSRFSIGGEN_ATTR_TEST_BASEBAND_SELFTEST                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353799
#define RSRFSIGGEN_ATTR_TEST_BASEBAND_SELFTEST_LOG                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 361505
#define RSRFSIGGEN_ATTR_TEST_START_SELFTEST                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357780
#define RSRFSIGGEN_ATTR_TEST_SELFTEST_RESULT                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 357781
#define RSRFSIGGEN_ATTR_TEST_PIXEL_COLOR                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363521
#define RSRFSIGGEN_ATTR_TEST_PIXEL_GRADIENT                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363522
#define RSRFSIGGEN_ATTR_TEST_PIXEL_TEXT_POINT_SIZE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363523
#define RSRFSIGGEN_ATTR_TEST_PIXEL_TEXT_MODE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363525
#define RSRFSIGGEN_ATTR_TEST_PIXEL_WINDOW_MODE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363526
#define RSRFSIGGEN_ATTR_TEST_GENERATOR_PATH_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 350956
#define RSRFSIGGEN_ATTR_TEST_GENERATOR_PATH_FREQUENCY                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350957
#define RSRFSIGGEN_ATTR_TEST_GENERATOR_PATH_GAIN                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 350958
#define RSRFSIGGEN_ATTR_TEST_GENERATOR_PATH_SELECT                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350959
#define RSRFSIGGEN_ATTR_TEST_GENERATOR_PATH_IQ_SOURCE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 350960
#define RSRFSIGGEN_ATTR_TEST_BASEBAND_INPUT_BIT_ERROR_RATE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353490
#define RSRFSIGGEN_ATTR_TEST_INTERFACE_SPEED                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353491
#define RSRFSIGGEN_ATTR_TEST_TRANSMISSION                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353492
#define RSRFSIGGEN_ATTR_KEYBOARD_LAYOUT                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 349136
#define RSRFSIGGEN_ATTR_KEYBOARD_LANGUAGE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 349137
#define RSRFSIGGEN_ATTR_DISPLAY_BLANK_MODE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 349138
#define RSRFSIGGEN_ATTR_DISPLAY_PROPORTIONAL_SCALE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349139
#define RSRFSIGGEN_ATTR_DISPLAY_UPDATE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 349140
#define RSRFSIGGEN_ATTR_DISPLAY_ANNOTATION_AMPLITUDE                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353493
#define RSRFSIGGEN_ATTR_DISPLAY_ANNOTATION_FREQUENCY                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353494
#define RSRFSIGGEN_ATTR_DISPLAY_ANNOTATION_ALL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353495
#define RSRFSIGGEN_ATTR_DISPLAY_DIALOG_ID                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353496
#define RSRFSIGGEN_ATTR_DISPLAY_DIALOG_OPEN                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353497
#define RSRFSIGGEN_ATTR_DISLPAY_DIALOG_CLOSE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353498
#define RSRFSIGGEN_ATTR_DISPLAY_DIALOG_CLOSE_ALL                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353800
#define RSRFSIGGEN_ATTR_DISPLAY_POWER_SAVE_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349141
#define RSRFSIGGEN_ATTR_DISPLAY_POWER_SAVE_HOLDOFF                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349142
#define RSRFSIGGEN_ATTR_MMEMORY_CHANGE_DIRECTORY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349145
#define RSRFSIGGEN_ATTR_MMEMORY_DELETE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 349151
#define RSRFSIGGEN_ATTR_MMEMORY_MAKE_DIRECTORY                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349153
#define RSRFSIGGEN_ATTR_MMEMORY_DRIVE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 349155
#define RSRFSIGGEN_ATTR_MMEMORY_REMOVE_DIRECTORY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349156
#define RSRFSIGGEN_ATTR_MMEMORY_USER_PATH                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353803
#define RSRFSIGGEN_ATTR_MMEMORY_USED_AND_AVAILABLE_MEMORY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356658
#define RSRFSIGGEN_ATTR_MMEMORY_REMOVE_DIRECTORY_RECURSIVE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363527
#define RSRFSIGGEN_ATTR_SYSTEM_REBOOT                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355589
#define RSRFSIGGEN_ATTR_SYSTEM_RESTART                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355590
#define RSRFSIGGEN_ATTR_SYSTEM_SHUTDOWN                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355591
#define RSRFSIGGEN_ATTR_SYSTEM_FACTORY_PRESET                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 357782
#define RSRFSIGGEN_ATTR_SYSTEM_BEEPER                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 349158
#define RSRFSIGGEN_ATTR_SYSTEM_ERROR                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350157
#define RSRFSIGGEN_ATTR_SYSTEM_STATIC_ERRORS                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355592
#define RSRFSIGGEN_ATTR_SYSTEM_ERROR_QUEUE_ALL                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349159
#define RSRFSIGGEN_ATTR_SYSTEM_ERROR_QUEUE_CODE_ALL                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 349160
#define RSRFSIGGEN_ATTR_SYSTEM_ERROR_QUEUE_CODE_NEXT                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 349161
#define RSRFSIGGEN_ATTR_SYSTEM_ERROR_QUEUE_COUNT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349162
#define RSRFSIGGEN_ATTR_SYSTEM_ERROR_GLOBAL                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 357783
#define RSRFSIGGEN_ATTR_SYSTEM_OLDEST_ERROR                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362628
#define RSRFSIGGEN_ATTR_SYSTEM_USB_RESOURCE                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349163
#define RSRFSIGGEN_ATTR_SYSTEM_GPIB_RESOURCE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 349164
#define RSRFSIGGEN_ATTR_SYSTEM_GPIB_LINE_TERMINATOR                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362629
#define RSRFSIGGEN_ATTR_SYSTEM_GPIB_ADDRESS                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 362630
#define RSRFSIGGEN_ATTR_SYSTEM_HISLIP_RESOURCE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 362631
#define RSRFSIGGEN_ATTR_SYSTEM_SERIAL_RESOURCE                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349165
#define RSRFSIGGEN_ATTR_SYSTEM_SERIAL_BAUD                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353804
#define RSRFSIGGEN_ATTR_SYSTEM_SERIAL_PARITY                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353805
#define RSRFSIGGEN_ATTR_SYSTEM_SERIAL_STOP_BITS                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353806
#define RSRFSIGGEN_ATTR_SYSTEM_VISA_RESOURCE_STRING                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353807
#define RSRFSIGGEN_ATTR_SYSTEM_IDENTIFICATION_MODE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362632
#define RSRFSIGGEN_ATTR_SYSTEM_IDENTIFICATION_PRESET                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362633
#define RSRFSIGGEN_ATTR_SYSTEM_IDENTIFICATION_RESPONSE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 362634
#define RSRFSIGGEN_ATTR_SYSTEM_OPTION_USER_DEFINED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349166
#define RSRFSIGGEN_ATTR_SYSTEM_OPTION_TRIALS_LIST                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 362635
#define RSRFSIGGEN_ATTR_SYSTEM_OPTION_TRIAL_ENABLE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 362636
#define RSRFSIGGEN_ATTR_SYSTEM_KEYBOARD_LOCK                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 349167
#define RSRFSIGGEN_ATTR_SYSTEM_USER_INTERFACE_LOCK                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 356659
#define RSRFSIGGEN_ATTR_SYSTEM_DISPLAY_LOCK                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356660
#define RSRFSIGGEN_ATTR_SYSTEM_LOCK_OWNER                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362637
#define RSRFSIGGEN_ATTR_SYSTEM_EXCLUSIVE_LOCK                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 362638
#define RSRFSIGGEN_ATTR_SYSTEM_RELEASE_ALL_LOCKS                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 362639
#define RSRFSIGGEN_ATTR_SYSTEM_VERSION                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 349169
#define RSRFSIGGEN_ATTR_SYSTEM_BIOS_VERSION                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 349170
#define RSRFSIGGEN_ATTR_SYSTEM_STARTUP_COMPLETE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 349171
#define RSRFSIGGEN_ATTR_SYSTEM_ALL_DATA_SHEETS                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353808
#define RSRFSIGGEN_ATTR_SYSTEM_DATA_SHEET_FACTORY_VERSION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353809
#define RSRFSIGGEN_ATTR_SYSTEM_DATA_SHEET_VERSION                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353810
#define RSRFSIGGEN_ATTR_SYSTEM_DATA_SHEET_IDS                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353811
#define RSRFSIGGEN_ATTR_SYSTEM_SCPI_INFORMATION                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353813
#define RSRFSIGGEN_ATTR_SYSTEM_TIME_ZONE_CATALOG                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353815
#define RSRFSIGGEN_ATTR_SYSTEM_TIME_ZONE                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353816
#define RSRFSIGGEN_ATTR_SYSTEM_TIME_PROTOCOL                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363528
#define RSRFSIGGEN_ATTR_SYSTEM_DATE                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353819
#define RSRFSIGGEN_ATTR_SYSTEM_UPTIME                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 355593
#define RSRFSIGGEN_ATTR_SYSTEM_ERROR_HISTORY                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356468
#define RSRFSIGGEN_ATTR_SYSTEM_CLEAR_HISTORY                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 355532
#define RSRFSIGGEN_ATTR_SYSTEM_WAIT                                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 355895
#define RSRFSIGGEN_ATTR_SYSTEM_DEVICE_FOOTPRINT                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357785
#define RSRFSIGGEN_ATTR_SYSTEM_OPERATING_SYSTEM                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 357786
#define RSRFSIGGEN_ATTR_SYSTEM_SCPI_RECORDING_DATA                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357787
#define RSRFSIGGEN_ATTR_SYSTEM_SAVE_INSTRUMENT_SETTINGS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359754
#define RSRFSIGGEN_ATTR_SYSTEM_LOAD_INSTRUMENT_SETTINGS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359756
#define RSRFSIGGEN_ATTR_SYSTEM_EXPORT_HELP                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 362640
#define RSRFSIGGEN_ATTR_OCCUPY_LICENSES_CATALOG                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 363084
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_DOMAIN                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349172
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_GATEWAY                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349173
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_RESOURCE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 349174
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_SUBNET_MASK                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349175
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_WORKGROUP                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 349176
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_MAC_ADDRESS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349177
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353820
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_HOSTNAME                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353821
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_RESTART                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 357788
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_IP_ADDRESS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349178
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_IP_ADDRESS_SUBNET_MASK                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 349179
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_IP_ADDRESS_GATEWAY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 349180
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_IP_ADDRESS_MODE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 349181
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_IP_ADDRESS_EXECUTE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 349182
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_COMMON_WORKGROUP                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 349183
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_COMMON_DOMAIN                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 349184
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_COMMON_EXECUTE                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 349185
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_PREFERED_DNS                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 349186
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_ALTERNATE_DNS                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 349187
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_DNS_SERVER                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 355533
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_DNS_MODE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 349188
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_DNS_EXECUTE                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349189
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_QSFP_IP_ADDRESS_MODE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363086
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_QSFP_IP_ADDRESS                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363087
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_QSFP_SUBNET_MASK                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363088
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_QSFP_PORT                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 363089
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_QSFP_PROTOCOL                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363090
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_QSFP_STATUS                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363091
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_QSFP_MAC_ADDRESS                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363092
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_QSFP_HOSTNAME                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363093
#define RSRFSIGGEN_ATTR_SYSTEM_NETWORK_QSFP_APPLICATION                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363094
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 350961
#define RSRFSIGGEN_ATTR_SYSTEM_FADING_CONFIGURATION                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 356661
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_SIGNAL_OUTPUTS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353822
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_APPLY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 350962
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_SET_TO_DEFAULT                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 350963
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_BASEBAND_SOURCE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353501
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_BB_BANDWIDTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362641
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_CA_BANDWIDTH                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 362642
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_HS_CHANNELS_PER_BBMM_1_                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 362643
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_HS_CHANNELS_PER_BBMM_2                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 362644
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_DUPLICATE_STREAMS_ENABLED                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 355896
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_FREQUENCY_OFFSET                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353823
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_PHASE_OFFSET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353824
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_EXTERNAL_CLEAN                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353826
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_EXTERNAL_CONNECT_ALL                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353827
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_EXTERNAL_DISCONNECT_ALL                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353828
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_EXTERNAL_DISPLAY_MODE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353502
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_EXTERNAL_PREDEFINED_CATALOG                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353829
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_EXTERNAL_USER_CATALOG                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353830
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_EXTERNAL_REMOTE_SCAN                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353831
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_EXTERNAL_REMOTE_SCAN_STATE                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 355534
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_EXTERNAL_REMOTE_LIST                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353832
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_EXTERNAL_REMOVE_UNUSED                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353833
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_EXTERNAL_AUTO_CONNECT                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353834
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_PRESET_BEHAVIOR_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 355897
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_MIMO_SUBSET                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356662
#define RSRFSIGGEN_ATTR_EXTERNAL_CODER_DIRECTION                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353503
#define RSRFSIGGEN_ATTR_EXTERNAL_CODER_IQ_CONNECTION_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353504
#define RSRFSIGGEN_ATTR_EXTERNAL_CODER_REMOTE_CONNECTION_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 356663
#define RSRFSIGGEN_ATTR_EXTERNAL_CODER_CONNECTED_INSTRUMENTS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353505
#define RSRFSIGGEN_ATTR_EXTERNAL_CODER_TRIGGER_CONNECTION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356664
#define RSRFSIGGEN_ATTR_EXTERNAL_CODER_DISCONNECT_CONNECTION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356665
#define RSRFSIGGEN_ATTR_EXTERNAL_CODER_SEARCHES_FOR_EXTERNAL_INSTRUMENTS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356666
#define RSRFSIGGEN_ATTR_EXTERNAL_CODER_INFO                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356667
#define RSRFSIGGEN_ATTR_EXTERNAL_CODER_INITIALIZATION_FILE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356668
#define RSRFSIGGEN_ATTR_EXTERNAL_CODER_LOAD_INITIALIZATION_FILE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 356669
#define RSRFSIGGEN_ATTR_EXTERNAL_CODER_LOAD_USER_INITIALIZATION_FILE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356670
#define RSRFSIGGEN_ATTR_EXTERNAL_CODER_SELECTED_CONNECTOR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356671
#define RSRFSIGGEN_ATTR_EXTERNAL_CODER_SEND_SCPI_COMMAND                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356672
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_DIRECTION                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353506
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_IQ_CONNECTION_ENABLED                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353507
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_CONNECTED_INSTRUMENTS                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353508
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_REMOTE_CONNECTION_ENABLED                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353509
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_TRIGGER_CONNECTION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353510
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_SEARCHES_FOR_EXTERNAL_INSTRUMENTS                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353511
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_DISCONNECT_CONNECTION                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353512
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_INITIALIZATION_FILE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353513
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_LOAD_INITIALIZATION_FILE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353514
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_LOAD_USER_INITIALIZATION_FILE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 353515
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_SELECTED_CONNECTOR                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353516
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_SEND_SCPI_COMMAND                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353517
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_INFO                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353836
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_RF_ENABLED                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353518
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_RF_COUPLING_ENABLED                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353519
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_RF_FREQUENCY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353520
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_RF_FREQUENCY_OFFSET                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353521
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_RF_POWER                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353522
#define RSRFSIGGEN_ATTR_EXTERNAL_FADER_RF_POWER_OFFSET                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353523
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_DIRECTION                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353524
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_CONNECTED_INSTRUMENTS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353525
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_REMOTE_CONNECTION_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 353526
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_TRIGGER_CONNECTION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353527
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_DISCONNECT_CONNECTION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353529
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_INITIALIZATION_FILE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353530
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_LOAD_INITIALIZATION_FILE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353531
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_LOAD_USER_INITIALIZATION_FILE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353532
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_SELECTED_CONNECTOR                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 353533
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_SEND_SCPI_COMMAND                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353534
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_INFO                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353837
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_RF_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353535
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_RF_COUPLING_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353536
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_RF_FREQUENCY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353537
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_RF_FREQUENCY_OFFSET                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353538
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_RF_POWER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353539
#define RSRFSIGGEN_ATTR_EXTERNAL_IQ_RF_POWER_OFFSET                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353540
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_DIRECTION                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353541
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_CONNECTION_ENABLED                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 356673
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_CONNECTED_INSTRUMENTS                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353542
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_REMOTE_CONNECTION_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353543
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_TRIGGER_CONNECTION                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353544
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_SEARCHES_FOR_EXTERNAL_INSTRUMENTS                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353545
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_DISCONNECT_CONNECTION                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 353546
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_INITIALIZATION_FILE                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353547
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_LOAD_INITIALIZATION_FILE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353548
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_LOAD_USER_INITIALIZATION_FILE                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 353549
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_INITIALIZATION_FILES_CATALOG                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 357791
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_SELECTED_CONNECTOR                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 353550
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_SEND_SCPI_COMMAND                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 353551
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_INFO                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 353838
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_RF_ENABLED                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 353552
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_RF_COUPLING_ENABLED                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353553
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_RF_FREQUENCY                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353554
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_RF_FREQUENCY_OFFSET                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 353555
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_RF_POWER                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353556
#define RSRFSIGGEN_ATTR_EXTERNAL_BBMM_RF_POWER_OFFSET                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 353557
#define RSRFSIGGEN_ATTR_EXTERNAL_RF_DIRECTION                                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361506
#define RSRFSIGGEN_ATTR_EXTERNAL_RF_CONNECTED_INSTRUMENTS                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361507
#define RSRFSIGGEN_ATTR_EXTERNAL_RF_REMOTE_CONNECTION_ENABLED                                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 361508
#define RSRFSIGGEN_ATTR_EXTERNAL_RF_TRIGGER_CONNECTION                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361509
#define RSRFSIGGEN_ATTR_EXTERNAL_RF_DISCONNECT_CONNECTION                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 361510
#define RSRFSIGGEN_ATTR_EXTERNAL_RF_INITIALIZATION_FILE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361511
#define RSRFSIGGEN_ATTR_EXTERNAL_RF_SELECTED_CONNECTOR                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 361512
#define RSRFSIGGEN_ATTR_EXTERNAL_RF_SEND_SCPI_COMMAND                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 361513
#define RSRFSIGGEN_ATTR_EXTERNAL_RF_INFO                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 361514
#define RSRFSIGGEN_ATTR_EXTERNAL_RF_RF_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 361515
#define RSRFSIGGEN_ATTR_EXTERNAL_RF_RF_COUPLING_ENABLED                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361516
#define RSRFSIGGEN_ATTR_EXTERNAL_RF_RF_FREQUENCY                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 361517
#define RSRFSIGGEN_ATTR_EXTERNAL_RF_RF_FREQUENCY_OFFSET                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 361518
#define RSRFSIGGEN_ATTR_EXTERNAL_RF_RF_POWER                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 361519
#define RSRFSIGGEN_ATTR_EXTERNAL_RF_RF_POWER_OFFSET                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 361520
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_ENABLED                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 363100
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_SETUP_FILE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363101
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_RESET_USER_CORRECTIONS                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363311
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_ALIGN_RF_PORTS                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 363312
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_ALIGN_STATUS                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363313
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_ALIGN_INFO_COMMENT                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 363314
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_ALIGN_INFO_DATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363315
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_ALIGN_INFO_TIME                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 363316
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_ALIGN_INFO_FREQUENCY_MAXIMUM                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363317
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_ALIGN_INFO_FREQUENCY_MINIMUM                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 363318
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_ALIGN_INFO_PEP_MAXIMUM                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363319
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_ALIGN_INFO_PEP_MINIMUM                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 363320
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_PORT_ADDITIONAL_IQ_DELAY                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 363321
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_PORT_IQ_DELAY                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 363322
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_PORT_POWER_LEVEL                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 363323
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_PORT_ADDITIONAL_PHASE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 363324
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_PORT_PHASE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363325
#define RSRFSIGGEN_ATTR_BANDWIDTH_EXTENSION_PORT_SOURCE                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 363326
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_MAPPING_BBMM_MODE                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 353839
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_MAPPING_FADER_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353840
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_MAPPING_IQ_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353841
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_MAPPING_RF_MODE                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 353842
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_MAPPING_BBMM_ENABLED                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 353843
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_MAPPING_FADER_ENABLED                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 353844
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_MAPPING_IQ_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353845
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_MAPPING_RF_ENABLED                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 353846
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_MAPPING_BBMM_CHANNEL_ENABLED                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 357794
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_MAPPING_BBMM_CHANNEL_MODE                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 363529
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_MULTIINSTRUMENT_MODE                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 356469
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_MULTIINSTRUMENT_ENABLED                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 356470
#define RSRFSIGGEN_ATTR_SYSTEM_CONFIGURATION_MULTIINSTRUMENT_SYNCHRONIZATION                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 356471
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_ENABLED                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360272
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_STATUS                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360273
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_SYNCHRONIZE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360274
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_PREDEFINED_FILES_CATALOG                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360275
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_LOAD_PREDEFINED_FILE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360276
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_SETUP_FILES_CATALOG                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360278
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_LOAD_SETUP_FILE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360279
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATION_PARAMETERS                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 360281
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATION_DATE                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360282
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATION_TIME                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360283
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATION_AGE                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360284
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATION_TEMPERATURE_OFFSET                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360285
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATION_FREQUENCY_MODE                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360286
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATION_FREQUENCY_LIST                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 360287
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATION_FREQUENCY_RANGE_LOWER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360289
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATION_FREQUENCY_RANGE_UPPER                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360290
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATION_FREQUENCY_STEP_SIZE                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 360291
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATION_PEP_MODE                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360292
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATION_PEP_LIST                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360293
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATION_PEP_RANGE_LOWER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360295
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATION_PEP_RANGE_UPPER                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360296
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATION_PEP_STEP_SIZE                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360297
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATED_FREQUENCY                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 360298
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CALIBRATED_PEP                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 360299
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_IQ_DELAY                                                     RS_SPECIFIC_PUBLIC_ATTR_BASE + 360300
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_CORRECTION_LEVEL                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 360301
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_DELTA_PHASE                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 360302
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_DIGITAL_ATTENUATION                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 360303
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_BASEBAND_FREQUENCY_OFFSET                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 360304
#define RSRFSIGGEN_ATTR_RF_CALIBRATION_LOCAL_OSCILLATOR_COUPLING                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 360305
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_LOCAL_OSCILLATOR_CONNECTION_METHOD                           RS_SPECIFIC_PUBLIC_ATTR_BASE + 360306
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_LOCAL_OSCILLATOR_SOURCE                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 360307
#define RSRFSIGGEN_ATTR_RF_PORTS_ALIGNMENT_LOCAL_OSCILLATOR_REFERENCE_SOURCE                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 360308
#define RSRFSIGGEN_ATTR_STATUS_PRESET                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 349192
#define RSRFSIGGEN_ATTR_UNIT_ANGLE                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349193
#define RSRFSIGGEN_ATTR_UNIT_POWER                                                                      RS_SPECIFIC_PUBLIC_ATTR_BASE + 349194
#define RSRFSIGGEN_ATTR_UNIT_VELOCITY                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 357795
#define RSRFSIGGEN_ATTR_GRAPHICS_ENABLED                                                                RS_SPECIFIC_PUBLIC_ATTR_BASE + 349195
#define RSRFSIGGEN_ATTR_GRAPHICS_SMART_ENABLED                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 349196
#define RSRFSIGGEN_ATTR_GRAPHICS_MODE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 349197
#define RSRFSIGGEN_ATTR_GRAPHICS_TRIGGER_SOURCE                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 349198
#define RSRFSIGGEN_ATTR_GRAPHICS_SAMPLE_RATE_MODE                                                       RS_SPECIFIC_PUBLIC_ATTR_BASE + 349199
#define RSRFSIGGEN_ATTR_GRAPHICS_SAMPLE_RATE                                                            RS_SPECIFIC_PUBLIC_ATTR_BASE + 349200
#define RSRFSIGGEN_ATTR_GRAPHICS_ADD                                                                    RS_SPECIFIC_PUBLIC_ATTR_BASE + 350964
#define RSRFSIGGEN_ATTR_GRAPHICS_CLOSE                                                                  RS_SPECIFIC_PUBLIC_ATTR_BASE + 350965
#define RSRFSIGGEN_ATTR_GRAPHICS_SOURCE                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350966
#define RSRFSIGGEN_ATTR_GRAPHICS_SELECTED_STREAM                                                        RS_SPECIFIC_PUBLIC_ATTR_BASE + 357796
#define RSRFSIGGEN_ATTR_GRAPHICS_FFT_SCALE                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356472
#define RSRFSIGGEN_ATTR_GRAPHICS_FFT_SIZE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 356473
#define RSRFSIGGEN_ATTR_NTP_SERVER_ENABLED                                                              RS_SPECIFIC_PUBLIC_ATTR_BASE + 356475
#define RSRFSIGGEN_ATTR_NTP_SERVER_HOSTNAME                                                             RS_SPECIFIC_PUBLIC_ATTR_BASE + 356476
#define RSRFSIGGEN_ATTR_PRESET                                                                          RS_SPECIFIC_PUBLIC_ATTR_BASE + 359758
#define RSRFSIGGEN_ATTR_SELF_TEST_QUERY                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 359734
#define RSRFSIGGEN_ATTR_ID_QUERY_RESPONSE                                                               RS_SPECIFIC_PUBLIC_ATTR_BASE + 350158
#define RSRFSIGGEN_ATTR_LOGGING                                                                         RS_SPECIFIC_PUBLIC_ATTR_BASE + 355551
#define RSRFSIGGEN_ATTR_PRESET_DEVICE                                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 349217
#define RSRFSIGGEN_ATTR_PROCESS_ALL_PREVIOUS_COMMANDS                                                   RS_SPECIFIC_PUBLIC_ATTR_BASE + 354133
#define RSRFSIGGEN_ATTR_INIT_SW_TRIGGER                                                                 RS_SPECIFIC_PUBLIC_ATTR_BASE + 350156

// RsRFSigGen_rngExternalCoupling
#define RSRFSIGGEN_VAL_EXTERNAL_COUPLING_AC                                 0
#define RSRFSIGGEN_VAL_EXTERNAL_COUPLING_DC                                 1

// RsRFSigGen_rngPulseModulationPolarity
#define RSRFSIGGEN_VAL_PULM_POLARITY_NORMAL                                 0
#define RSRFSIGGEN_VAL_PULM_POLARITY_INVERSE                                1

// RsRFSigGen_rngFrequencySweepSpacing
#define RSRFSIGGEN_VAL_FREQ_SWEEP_SPACING_LINEAR                            0
#define RSRFSIGGEN_VAL_FREQ_SWEEP_SPACING_LOGARITHMIC                       1

// RsRFSigGen_rngReferenceOscillatorSource
#define RSRFSIGGEN_VAL_ROSC_SOURCE_INTERNAL                                 0
#define RSRFSIGGEN_VAL_ROSC_SOURCE_EXTERNAL                                 1

// RsRFSigGen_rngAMSource
#define RSRFSIGGEN_VAL_AM_SOURCE_INTERNAL                                   0
#define RSRFSIGGEN_VAL_AM_SOURCE_EXTERNAL                                   1
#define RSRFSIGGEN_VAL_AM_SOURCE_INTEXT                                     2

// RsRFSigGen_rngFMSource
#define RSRFSIGGEN_VAL_FM_SOURCE_INTERNAL                                   0
#define RSRFSIGGEN_VAL_FM_SOURCE_EXTERNAL                                   1
#define RSRFSIGGEN_VAL_FM_SOURCE_INTEXT                                     2

// RsRFSigGen_rngPMSource
#define RSRFSIGGEN_VAL_PM_SOURCE_INTERNAL                                   0
#define RSRFSIGGEN_VAL_PM_SOURCE_EXTERNAL                                   1
#define RSRFSIGGEN_VAL_PM_SOURCE_INTEXT                                     2

// RsRFSigGen_rngReferenceOscillatorExternalFrequency
#define RSRFSIGGEN_VAL_SMU_ROSC_EXTERNAL_FREQUENCY_5MHZ                     0
#define RSRFSIGGEN_VAL_SMU_ROSC_EXTERNAL_FREQUENCY_10MHZ                    1
#define RSRFSIGGEN_VAL_SMU_ROSC_EXTERNAL_FREQUENCY_13MHZ                    2

// RsRFSigGen_rngDMDigitalStandard
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_BLUETOOTH                        0
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_COFORWARD                        1
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_COREVERSE                        2
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_DECT                             3
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_ETC                              4
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_GSM                              5
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_GSMEDGE                          6
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_NADC                             7
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_PDC                              8
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_PHS                              9
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_TDSCDMA                          10
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_TETRA                            11
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_TFTS                             12
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_W3GPP                            13
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_WORLDSPACE                       14
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_APCO_PHASE1_C4FM                 15
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_APCO_PHASE1_CQPSK                16
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_APCO_PHASE2_H_CPM                17
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_APCO_PHASE2_H_DQPSK              18
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_APCO_PHASE2_H_D8PSK_WIDE         19
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_APCO_PHASE2_H_D8PSK_NARROW       20
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_APCO_PHASE1_LSM                  21
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_APCO_PHASE1_WCQPSK               22
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_USER                             23
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_CWBP                             24
#define RSRFSIGGEN_VAL_DM_DIGITAL_STANDARD_SOQPSKTG                         25

// RsRFSigGen_rngDABDataSource
#define RSRFSIGGEN_VAL_DAB_DATA_SOURCE_ALL0                                 0
#define RSRFSIGGEN_VAL_DAB_DATA_SOURCE_ALL1                                 1
#define RSRFSIGGEN_VAL_DAB_DATA_SOURCE_PN15                                 2
#define RSRFSIGGEN_VAL_DAB_DATA_SOURCE_PN23                                 3
#define RSRFSIGGEN_VAL_DAB_DATA_SOURCE_ETIFILE                              4

// RsRFSigGen_rngDABMarkerMode
#define RSRFSIGGEN_VAL_DAB_MARKER_TYPE_RESTART                              0
#define RSRFSIGGEN_VAL_DAB_MARKER_TYPE_FRAME                                1
#define RSRFSIGGEN_VAL_DAB_MARKER_TYPE_PULSE                                2
#define RSRFSIGGEN_VAL_DAB_MARKER_TYPE_PATTERN                              3
#define RSRFSIGGEN_VAL_DAB_MARKER_TYPE_RATIO                                4

// RsRFSigGen_rngDABTransportMode
#define RSRFSIGGEN_VAL_DAB_TRANSPORT_MODE_1                                 0
#define RSRFSIGGEN_VAL_DAB_TRANSPORT_MODE_2                                 1
#define RSRFSIGGEN_VAL_DAB_TRANSPORT_MODE_3                                 2
#define RSRFSIGGEN_VAL_DAB_TRANSPORT_MODE_4                                 3

// RsRFSigGen_rngDataSource
#define RSRFSIGGEN_VAL_DATA_SOURCE_ZERO                                     0
#define RSRFSIGGEN_VAL_DATA_SOURCE_ONE                                      1
#define RSRFSIGGEN_VAL_DATA_SOURCE_PATTERN                                  2
#define RSRFSIGGEN_VAL_DATA_SOURCE_PN9                                      3
#define RSRFSIGGEN_VAL_DATA_SOURCE_PN11                                     4
#define RSRFSIGGEN_VAL_DATA_SOURCE_PN15                                     5
#define RSRFSIGGEN_VAL_DATA_SOURCE_PN16                                     6
#define RSRFSIGGEN_VAL_DATA_SOURCE_PN20                                     7
#define RSRFSIGGEN_VAL_DATA_SOURCE_PN21                                     8
#define RSRFSIGGEN_VAL_DATA_SOURCE_PN23                                     9
#define RSRFSIGGEN_VAL_DATA_SOURCE_DLIST                                    10
#define RSRFSIGGEN_VAL_DATA_SOURCE_AMPDU                                    11

// RsRFSigGen_rngClockMode
#define RSRFSIGGEN_VAL_CLOCK_MODE_SAMPLE                                    0
#define RSRFSIGGEN_VAL_CLOCK_MODE_MSAMPLE                                   1

// RsRFSigGen_rngClockSynchronisationMode
#define RSRFSIGGEN_VAL_CLOCK_SYNC_MODE_NONE                                 0
#define RSRFSIGGEN_VAL_CLOCK_SYNC_MODE_MASTER                               1
#define RSRFSIGGEN_VAL_CLOCK_SYNC_MODE_SLAVE                                2

// RsRFSigGen_rngFilterType
#define RSRFSIGGEN_VAL_FILTER_TYPE_RCOS                                     0
#define RSRFSIGGEN_VAL_FILTER_TYPE_COSINE                                   1
#define RSRFSIGGEN_VAL_FILTER_TYPE_GAUSS                                    2
#define RSRFSIGGEN_VAL_FILTER_TYPE_LGAUSS                                   3
#define RSRFSIGGEN_VAL_FILTER_TYPE_CONE                                     4
#define RSRFSIGGEN_VAL_FILTER_TYPE_COF705                                   5
#define RSRFSIGGEN_VAL_FILTER_TYPE_COEQ                                     6
#define RSRFSIGGEN_VAL_FILTER_TYPE_COF                                      7
#define RSRFSIGGEN_VAL_FILTER_TYPE_C2K3X                                    8
#define RSRFSIGGEN_VAL_FILTER_TYPE_APCO25                                   9
#define RSRFSIGGEN_VAL_FILTER_TYPE_RECTANGLE                                10
#define RSRFSIGGEN_VAL_FILTER_TYPE_SPHASE                                   11
#define RSRFSIGGEN_VAL_FILTER_TYPE_PGAUSS                                   12
#define RSRFSIGGEN_VAL_FILTER_TYPE_LPASS                                    13
#define RSRFSIGGEN_VAL_FILTER_TYPE_DIRAC                                    14
#define RSRFSIGGEN_VAL_FILTER_TYPE_ENPS                                     15
#define RSRFSIGGEN_VAL_FILTER_TYPE_EWPS                                     16
#define RSRFSIGGEN_VAL_FILTER_TYPE_LPASSEVM                                 17
#define RSRFSIGGEN_VAL_FILTER_TYPE_LTE                                      18
#define RSRFSIGGEN_VAL_FILTER_TYPE_USER                                     19

// RsRFSigGen_rngClippingMode
#define RSRFSIGGEN_VAL_CLIPPING_MODE_VECTOR                                 0
#define RSRFSIGGEN_VAL_CLIPPING_MODE_SCALAR                                 1

// RsRFSigGen_rngLinkDirection
#define RSRFSIGGEN_VAL_LINK_DOWNLINK                                        0
#define RSRFSIGGEN_VAL_LINK_UPLINK                                          1

// RsRFSigGen_rngTriggerMode
#define RSRFSIGGEN_VAL_TRIGGER_MODE_AUTO                                    0
#define RSRFSIGGEN_VAL_TRIGGER_MODE_RETRIGGER                               1
#define RSRFSIGGEN_VAL_TRIGGER_MODE_AAUTO                                   2
#define RSRFSIGGEN_VAL_TRIGGER_MODE_ARETRIGGER                              3
#define RSRFSIGGEN_VAL_TRIGGER_MODE_SINGLE                                  4

// RsRFSigGen_rngSMUTriggerSour
#define RSRFSIGGEN_VAL_SMU_TRIGGER_SOURCE_INTERNAL                          0
#define RSRFSIGGEN_VAL_SMU_TRIGGER_SOURCE_OBASEBAND                         1
#define RSRFSIGGEN_VAL_SMU_TRIGGER_SOURCE_EXTERNAL                          2
#define RSRFSIGGEN_VAL_SMU_TRIGGER_SOURCE_BEXTERNAL                         3
#define RSRFSIGGEN_VAL_SMU_TRIGGER_SOURCE_INTB                              4
#define RSRFSIGGEN_VAL_SMU_TRIGGER_SOURCE_EGT1                              5
#define RSRFSIGGEN_VAL_SMU_TRIGGER_SOURCE_EGT2                              6
#define RSRFSIGGEN_VAL_SMU_TRIGGER_SOURCE_EGC1                              7
#define RSRFSIGGEN_VAL_SMU_TRIGGER_SOURCE_EGC2                              8
#define RSRFSIGGEN_VAL_SMU_TRIGGER_SOURCE_ELTR                              9
#define RSRFSIGGEN_VAL_SMU_TRIGGER_SOURCE_INTA                              10
#define RSRFSIGGEN_VAL_SMU_TRIGGER_SOURCE_ELCL                              11
#define RSRFSIGGEN_VAL_SMU_TRIGGER_SOURCE_BBSY                              12

// RsRFSigGen_rngSMUClockSource
#define RSRFSIGGEN_VAL_SMU_CLOCK_SOURCE_INTERNAL                            0
#define RSRFSIGGEN_VAL_SMU_CLOCK_SOURCE_EXTERNAL                            1
#define RSRFSIGGEN_VAL_SMU_CLOCK_SOURCE_AINT                                2
#define RSRFSIGGEN_VAL_SMU_CLOCK_SOURCE_ELCL                                3

// RsRFSigGen_rngEUTRADuplexing
#define RSRFSIGGEN_VAL_EUTRA_DUPLEXING_TDD                                  0
#define RSRFSIGGEN_VAL_EUTRA_DUPLEXING_FDD                                  1
#define RSRFSIGGEN_VAL_EUTRA_DUPLEXING_LAA                                  2

// RsRFSigGen_rngEUTRAWizardTestCase
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC67                     0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC72                     1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC73                     2
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC74                     3
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC75A                    4
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC75B                    5
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC76                     6
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC78                     7
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC821                    8
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC822                    9
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC823                    10
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC824                    11
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC831                    12
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC832                    13
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC833                    14
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC841                    15
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC838                    16
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC837                    17
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC839                    18
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC834                    19
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC835                    20
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC836                    21
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC826                    22
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC826A                   23
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC827                    24
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC829                    25
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC8310                   26
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC8311                   27
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC8312                   28
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC8313                   29
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC851                    30
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC852                    31
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_CASE_TS36141_TC853                    32

// RsRFSigGen_rngEUTRAWizardGeneralTriggerConfiguration
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TRIG_AAUT                                  0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TRIG_UNCH                                  1

// RsRFSigGen_rngEUTRAWizardMarkerConfiguration
#define RSRFSIGGEN_VAL_EUTRA_WIZ_MARKER_FRAM                                0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_MARKER_UNCH                                1

// RsRFSigGen_rngEUTRAWizardSignalRouting
#define RSRFSIGGEN_VAL_EUTRA_WIZ_SIGN_ROUT_PORTA                            0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_SIGN_ROUT_PORTB                            1

// RsRFSigGen_rngEUTRAWizardInstrumentSetup
#define RSRFSIGGEN_VAL_EUTRA_WIZ_INST_SETUP_ONE                             0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_INST_SETUP_TWO                             1

// RsRFSigGen_rngEUTRAWizardNumberofRXAntennas
#define RSRFSIGGEN_VAL_EUTRA_WIZ_RX_ANT1                                    0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_RX_ANT2                                    1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_RX_ANT4                                    2

// RsRFSigGen_rngEUTRAWizardAntennaSubset
#define RSRFSIGGEN_VAL_EUTRA_WIZ_ANT_SUBSET_AS12                            0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_ANT_SUBSET_AS34                            1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_ANT_SUBSET_ALL                             2
#define RSRFSIGGEN_VAL_EUTRA_WIZ_ANT_SUBSET_AS56                            3
#define RSRFSIGGEN_VAL_EUTRA_WIZ_ANT_SUBSET_AS78                            4

// RsRFSigGen_rngEUTRAWizardGeneratedSignal
#define RSRFSIGGEN_VAL_EUTRA_WIZ_GEN_SIGNAL_WANTED                          0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_GEN_SIGNAL_INTERF                          1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_GEN_SIGNAL_ALL                             2
#define RSRFSIGGEN_VAL_EUTRA_WIZ_GEN_SIGNAL_WSUE1UE2AWGN                    3
#define RSRFSIGGEN_VAL_EUTRA_WIZ_GEN_SIGNAL_WSUE3UE4                        4
#define RSRFSIGGEN_VAL_EUTRA_WIZ_GEN_SIGNAL_IF                              5

// RsRFSigGen_rngEUTRAWizardGeneralMode
#define RSRFSIGGEN_VAL_EUTRA_WIZ_MODE_DRAT                                  0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_MODE_FDR                                   1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_MODE_ADR                                   2

// RsRFSigGen_rngEUTRAWizardAllocationFrequency
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FREQ_ALL_LOW                               0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FREQ_ALL_HIGH                              1

// RsRFSigGen_rngEUTRAWizardWSFrequencyOffset
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FO_0                                       0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FO_270                                     1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FO_625                                     2
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FO_1340                                    3
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FO_200                                     4

// RsRFSigGen_rngEUTRAWizardWSChannelBandwidth
#define RSRFSIGGEN_VAL_EUTRA_WIZ_BW1_40                                     0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_BW3_00                                     1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_BW5_00                                     2
#define RSRFSIGGEN_VAL_EUTRA_WIZ_BW10_00                                    3
#define RSRFSIGGEN_VAL_EUTRA_WIZ_BW15_00                                    4
#define RSRFSIGGEN_VAL_EUTRA_WIZ_BW20_00                                    5
#define RSRFSIGGEN_VAL_EUTRA_WIZ_BW00_20                                    6

// RsRFSigGen_rngEUTRAWizardSignalAdvanceNTAoffset
#define RSRFSIGGEN_VAL_EUTRA_WIZ_NTAOFFS_NTA0                               0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_NTAOFFS_NTA624                             1

// RsRFSigGen_rngEUTRASubframeCyclicPrefix
#define RSRFSIGGEN_VAL_EUTRA_CYCP_NORMAL                                    0
#define RSRFSIGGEN_VAL_EUTRA_CYCP_EXTENDED                                  1

// RsRFSigGen_rngEUTRAWizardWSPropagationConditions
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_PROPAGATION_EPA5                        0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_PROPAGATION_EVA5                        1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_PROPAGATION_EVA70                       2
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_PROPAGATION_ETU70                       3
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_PROPAGATION_ETU300                      4
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_PROPAGATION_ETU200M                     5
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_PROPAGATION_PDM                         6
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_PROPAGATION_HST1                        7
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_PROPAGATION_HST3                        8
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_PROPAGATION_AWGN                        9
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_PROPAGATION_ETU5                        10
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_PROPAGATION_ETU200                      11
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_PROPAGATION_ETU1                        12
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_PROPAGATION_EPA1                        13

// RsRFSigGen_rngEUTRAWizardWSFRC
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A11                                    0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A12                                    1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A13                                    2
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A14                                    3
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A15                                    4
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A21                                    5
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A22                                    6
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A23                                    7
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A31                                    8
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A32                                    9
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A33                                    10
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A34                                    11
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A35                                    12
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A36                                    13
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A37                                    14
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A41                                    15
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A42                                    16
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A43                                    17
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A44                                    18
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A45                                    19
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A46                                    20
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A47                                    21
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A48                                    22
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A51                                    23
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A52                                    24
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A53                                    25
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A54                                    26
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A55                                    27
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A56                                    28
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A57                                    29
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A71                                    30
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A72                                    31
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A73                                    32
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A74                                    33
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A75                                    34
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A76                                    35
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A81                                    36
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A82                                    37
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A83                                    38
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A84                                    39
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A85                                    40
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A86                                    41
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_UE11                                   42
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_UE12                                   43
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_UE21                                   44
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_UE22                                   45
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_UE3                                    46
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A16                                    47
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A17                                    48
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A121                                   49
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A122                                   50
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A123                                   51
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A124                                   52
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A125                                   53
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A126                                   54
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A131                                   55
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A132                                   56
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A133                                   57
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A134                                   58
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A135                                   59
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A136                                   60
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A171                                   61
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A172                                   62
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A173                                   63
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A174                                   64
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A175                                   65
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A176                                   66
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A181                                   67
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A182                                   68
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A183                                   69
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A184                                   70
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A185                                   71
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A186                                   72
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A191                                   73
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A192                                   74
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A193                                   75
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A194                                   76
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A195                                   77
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A196                                   78
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A211                                   79
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A212                                   80
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A213                                   81
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A214                                   82
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A215                                   83
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A216                                   84
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A221                                   85
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A222                                   86
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A223                                   87
#define RSRFSIGGEN_VAL_EUTRA_WIZ_FRC_A224                                   88

// RsRFSigGen_rngEUTRAWizardWSBurstFormat
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_BURST_BF0                               0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_BURST_BF1                               1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_BURST_BF2                               2
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_BURST_BF3                               3
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_BURST_BF4                               4

// RsRFSigGen_rngEUTRAWizardWSFractionThrougput
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_THROUGHPUT_FMT30                        0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_WS_THROUGHPUT_FMT70                        1

// RsRFSigGen_rngEUTRAWizardISOffsetToChannelEdge
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_OCE2_5                                  0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_OCE7_5                                  1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_OCE12_5                                 2

// RsRFSigGen_rngEUTRAWizardFrequencyShiftm
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_SHIFT_M_FS0                             0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_SHIFT_M_FS1                             1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_SHIFT_M_FS2                             2
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_SHIFT_M_FS3                             3
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_SHIFT_M_FS4                             4
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_SHIFT_M_FS5                             5
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_SHIFT_M_FS7                             6
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_SHIFT_M_FS9                             7
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_SHIFT_M_FS10                            8
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_SHIFT_M_FS13                            9
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_SHIFT_M_FS14                            10
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_SHIFT_M_FS19                            11
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_SHIFT_M_FS24                            12

// RsRFSigGen_rngEUTRAWizardInterfererType
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_TYPE_CW                                 0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_TYPE_EUT                                1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_TYPE_NEUT                               2
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_TYPE_UTRA                               3

// RsRFSigGen_rngEUTRAWizardTestRequirement
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_TEST_REQ_BLPE                           0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_IS_TEST_REQ_COBS                           1

// RsRFSigGen_rngEUTRAWizardRTFMode
#define RSRFSIGGEN_VAL_EUTRA_WIZ_RTF_MODE_BIN                               0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_RTF_MODE_SER                               1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_RTF_MODE_SER3X8                            2

// RsRFSigGen_rngEUTRAWizardRTFConnector
#define RSRFSIGGEN_VAL_EUTRA_WIZ_RTF_CONN_NOFB                              0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_RTF_CONN_USER1                             1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_RTF_CONN_LEV                               2

// RsRFSigGen_rngEUTRAWizardRTFSerialRate
#define RSRFSIGGEN_VAL_EUTRA_WIZ_RTF_SR_115_2K                              0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_RTF_SR_1_6M                                1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_RTF_SR_1_92M                               2

// RsRFSigGen_rngEUTRAWizardRTFACKDefinition
#define RSRFSIGGEN_VAL_EUTRA_WIZ_RTF_ACK_HIGH                               0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_RTF_ACK_LOW                                1

// RsRFSigGen_rngEUTRACyclicPrefix
#define RSRFSIGGEN_VAL_EUTRA_CPC_NORM                                       0
#define RSRFSIGGEN_VAL_EUTRA_CPC_EXT                                        1
#define RSRFSIGGEN_VAL_EUTRA_CPC_USER                                       2

// RsRFSigGen_rngEUTRAPhysicalSettingsChannelBandwidth
#define RSRFSIGGEN_VAL_EUTRA_PHYSICAL_SETTINGS_BANDWIDTH_USER               0
#define RSRFSIGGEN_VAL_EUTRA_PHYSICAL_SETTINGS_BANDWIDTH_BW1_40             1
#define RSRFSIGGEN_VAL_EUTRA_PHYSICAL_SETTINGS_BANDWIDTH_BW3_00             2
#define RSRFSIGGEN_VAL_EUTRA_PHYSICAL_SETTINGS_BANDWIDTH_BW5_00             3
#define RSRFSIGGEN_VAL_EUTRA_PHYSICAL_SETTINGS_BANDWIDTH_BW10_00            4
#define RSRFSIGGEN_VAL_EUTRA_PHYSICAL_SETTINGS_BANDWIDTH_BW15_00            5
#define RSRFSIGGEN_VAL_EUTRA_PHYSICAL_SETTINGS_BANDWIDTH_BW20_00            6
#define RSRFSIGGEN_VAL_EUTRA_PHYSICAL_SETTINGS_BANDWIDTH_BW0_20             7

// RsRFSigGen_rngEUTRADLPhysicalSettingsMappedResourceBlocks
#define RSRFSIGGEN_VAL_EUTRA_DL_PHYS_RBM_V80                                0
#define RSRFSIGGEN_VAL_EUTRA_DL_PHYS_RBM_V81                                1

// RsRFSigGen_rngEUTRADLK55PDSCHScheduling
#define RSRFSIGGEN_VAL_EUTRA_K55_PDSCH_SCHEDULING_MANUAL                    0
#define RSRFSIGGEN_VAL_EUTRA_K55_PDSCH_SCHEDULING_AUTO                      1
#define RSRFSIGGEN_VAL_EUTRA_K55_PDSCH_SCHEDULING_ASEQ                      2

// RsRFSigGen_rngEUTRADLCellPHICHDuration
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_CELL_PHICH_DURATION_NORMAL            0
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_CELL_PHICH_DURATION_EXTEND            1

// RsRFSigGen_rngEUTRADLCellPHICHN_g
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_CELL_PHICH_NG1_6                      0
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_CELL_PHICH_NG1_2                      1
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_CELL_PHICH_NG1                        2
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_CELL_PHICH_NG2                        3
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_CELL_PHICH_NGC                        4

// RsRFSigGen_rngEUTRADLMIMOGlobalConfiguration
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_MIMO_GLOBAL_TX1                       0
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_MIMO_GLOBAL_TX2                       1
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_MIMO_GLOBAL_TX4                       2
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_MIMO_GLOBAL_SIBF                      3

// RsRFSigGen_rngEUTRADLMIMOSimulatedAntenna
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_REF_SYMBOL_ANT1                       0
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_REF_SYMBOL_ANT2                       1
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_REF_SYMBOL_ANT3                       2
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_REF_SYMBOL_ANT4                       3

// RsRFSigGen_rngEUTRAMappingCoordinates
#define RSRFSIGGEN_VAL_EUTRA_COORDINATES_CARTESIAN                          0
#define RSRFSIGGEN_VAL_EUTRA_COORDINATES_CYLINDRICAL                        1

// RsRFSigGen_rngEUTRADLReferenceOrthogonalSequence
#define RSRFSIGGEN_VAL_EUTRA_DL_SIGNAL_ORTHOGONAL_ORS0                      0
#define RSRFSIGGEN_VAL_EUTRA_DL_SIGNAL_ORTHOGONAL_ORS1                      1
#define RSRFSIGGEN_VAL_EUTRA_DL_SIGNAL_ORTHOGONAL_ORS2                      2

// RsRFSigGen_rngEUTRADLPRSModulationScheme
#define RSRFSIGGEN_VAL_EUTRA_DL_MODULATION_SCHEME_QPSK                      0
#define RSRFSIGGEN_VAL_EUTRA_DL_MODULATION_SCHEME_IQF                       1

// RsRFSigGen_rngEUTRADLPSSyncTxAntenna
#define RSRFSIGGEN_VAL_EUTRA_DL_SYNC_TX_ANTENNA_ALL                         0
#define RSRFSIGGEN_VAL_EUTRA_DL_SYNC_TX_ANTENNA_ANTENNA1                    1
#define RSRFSIGGEN_VAL_EUTRA_DL_SYNC_TX_ANTENNA_ANTENNA2                    2
#define RSRFSIGGEN_VAL_EUTRA_DL_SYNC_TX_ANTENNA_ANTENNA3                    3
#define RSRFSIGGEN_VAL_EUTRA_DL_SYNC_TX_ANTENNA_ANTENNA4                    4
#define RSRFSIGGEN_VAL_EUTRA_DL_SYNC_TX_ANTENNA_NONE                        5

// RsRFSigGen_rngEUTRADLMBSFNMode
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_MODE_OFF                              0
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_MODE_MIX                              1

// RsRFSigGen_rngEUTRADLMBSFNUECategory
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_UEC_1                                 0
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_UEC_2                                 1
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_UEC_3                                 2
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_UEC_4                                 3
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_UEC_5                                 4
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_UEC_USER                              5

// RsRFSigGen_rngEUTRADLMBSFNAllocationPeriod
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_APER_AP1                              0
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_APER_AP2                              1
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_APER_AP4                              2
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_APER_AP8                              3
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_APER_AP16                             4
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_APER_AP32                             5

// RsRFSigGen_rngEUTRADLMBSFNAllocationMode
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_AMODE_1FRAME                          0
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_AMODE_4FRAME                          1

// RsRFSigGen_rngEUTRADLMBSFNMCCHRepetitionPeriod
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_MCCH_RP32                             0
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_MCCH_RP64                             1
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_MCCH_RP128                            2
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_MCCH_RP256                            3

// RsRFSigGen_rngEUTRADLMBSFNMCCHModificationPeriod
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_MCCH_MP512                            0
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_MCCH_MP1024                           1

// RsRFSigGen_rngEUTRADLMBSFNMCCHMCS
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_MCCH_MCS2                             0
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_MCCH_MCS7                             1
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_MCCH_MCS13                            2
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_MCCH_MCS19                            3

// RsRFSigGen_rngEUTRADLMBSFNRepetitionCoefficient
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_NRC2                                  0
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_NRC4                                  1

// RsRFSigGen_rngEUTRADLMBSFNPMCHSchedulingPeriod
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_SPERIOD_SPM                           0
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_SPERIOD_SPRF8                         1
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_SPERIOD_SPRF16                        2
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_SPERIOD_SPRF32                        3
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_SPERIOD_SPRF64                        4
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_SPERIOD_SPRF128                       5
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_SPERIOD_SPRF256                       6
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_SPERIOD_SPRF512                       7
#define RSRFSIGGEN_VAL_EUTRA_DL_MBSFN_SPERIOD_SPRF1024                      8

// RsRFSigGen_rngEUTRADLPRSBandwidth
#define RSRFSIGGEN_VAL_EUTRA_DL_PRS_BW1_40                                  0
#define RSRFSIGGEN_VAL_EUTRA_DL_PRS_BW3_00                                  1
#define RSRFSIGGEN_VAL_EUTRA_DL_PRS_BW5_00                                  2
#define RSRFSIGGEN_VAL_EUTRA_DL_PRS_BW10_00                                 3
#define RSRFSIGGEN_VAL_EUTRA_DL_PRS_BW15_00                                 4
#define RSRFSIGGEN_VAL_EUTRA_DL_PRS_BW20_00                                 5

// RsRFSigGen_rngEUTRADLUnscheduledREs
#define RSRFSIGGEN_VAL_EUTRA_UNSCHEDULED_RBS_DUD                            0
#define RSRFSIGGEN_VAL_EUTRA_UNSCHEDULED_RBS_DTX                            1

// RsRFSigGen_rngEUTRADLDummyDataModulation
#define RSRFSIGGEN_VAL_EUTRA_DUMMY_QPSK                                     0
#define RSRFSIGGEN_VAL_EUTRA_DUMMY_QAM16                                    1
#define RSRFSIGGEN_VAL_EUTRA_DUMMY_QAM64                                    2
#define RSRFSIGGEN_VAL_EUTRA_DUMMY_QAM256                                   3
#define RSRFSIGGEN_VAL_EUTRA_DUMMY_QAM1024                                  4

// RsRFSigGen_rngEUTRADLUserChannelCoding
#define RSRFSIGGEN_VAL_EUTRA_USER_CHANNEL_CODING_NONE                       0
#define RSRFSIGGEN_VAL_EUTRA_USER_CHANNEL_CODING_TC                         1

// RsRFSigGen_rngEUTRADLUserUECategory
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_USER                       0
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C1                         1
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C2                         2
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C3                         3
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C4                         4
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C5                         5
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C6                         6
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C7                         7
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C8                         8
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C9                         9
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C10                        10
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C11                        11
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C12                        12
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C13                        13
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C14                        14
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C15                        15
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C16                        16
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C17                        17
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C18                        18
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C19                        19
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_C20                        20
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_M1                         21
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_NB1                        22
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_M2                         23
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_UE_CATEGORY_NB2                        24

// RsRFSigGen_rngEUTRADLUserPA
#define RSRFSIGGEN_VAL_EUTRA_USER_PA_M602                                   0
#define RSRFSIGGEN_VAL_EUTRA_USER_PA_M477                                   1
#define RSRFSIGGEN_VAL_EUTRA_USER_PA_M301                                   2
#define RSRFSIGGEN_VAL_EUTRA_USER_PA_M177                                   3
#define RSRFSIGGEN_VAL_EUTRA_USER_PA_0                                      4
#define RSRFSIGGEN_VAL_EUTRA_USER_PA_P097                                   5
#define RSRFSIGGEN_VAL_EUTRA_USER_PA_P204                                   6
#define RSRFSIGGEN_VAL_EUTRA_USER_PA_P301                                   7

// RsRFSigGen_rngEUTRADLUserViewMode
#define RSRFSIGGEN_VAL_EUTRA_USER_TIME_PLAN_VIEW_PRB                        0
#define RSRFSIGGEN_VAL_EUTRA_USER_TIME_PLAN_VIEW_VRB                        1

// RsRFSigGen_rngEUTRADLUserTransmissionMode
#define RSRFSIGGEN_VAL_EUTRA_USER_TXM_USER                                  0
#define RSRFSIGGEN_VAL_EUTRA_USER_TXM_M1                                    1
#define RSRFSIGGEN_VAL_EUTRA_USER_TXM_M2                                    2
#define RSRFSIGGEN_VAL_EUTRA_USER_TXM_M3                                    3
#define RSRFSIGGEN_VAL_EUTRA_USER_TXM_M4                                    4
#define RSRFSIGGEN_VAL_EUTRA_USER_TXM_M5                                    5
#define RSRFSIGGEN_VAL_EUTRA_USER_TXM_M6                                    6
#define RSRFSIGGEN_VAL_EUTRA_USER_TXM_M7                                    7
#define RSRFSIGGEN_VAL_EUTRA_USER_TXM_M8                                    8
#define RSRFSIGGEN_VAL_EUTRA_USER_TXM_M9                                    9
#define RSRFSIGGEN_VAL_EUTRA_USER_TXM_M10                                   10

// RsRFSigGen_rngEUTRADLUserAPMPortMapping
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_AMP_MAPPING_CODEBOOK                   0
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_AMP_MAPPING_RCODEBOOK                  1
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_AMP_MAPPING_WEIGHT                     2

// RsRFSigGen_rngEUTRADLEnhancedPrecodingScheme
#define RSRFSIGGEN_VAL_EUTRA_DL_ENHANCED_PRECODING_NONE                     0
#define RSRFSIGGEN_VAL_EUTRA_DL_ENHANCED_PRECODING_TX                       1

// RsRFSigGen_rngEUTRADLPowerMode
#define RSRFSIGGEN_VAL_EUTRA_DL_ENHANCED_PHICH_PMODE_CONS                   0
#define RSRFSIGGEN_VAL_EUTRA_DL_ENHANCED_PHICH_PMODE_IND                    1

// RsRFSigGen_rngEUTRADLPDCCHFormat
#define RSRFSIGGEN_VAL_EUTRA_DL_ENHANCED_PDCCH_FORMAT_VARIABLE              0
#define RSRFSIGGEN_VAL_EUTRA_DL_ENHANCED_PDCCH_FORMAT_MINUS1                1
#define RSRFSIGGEN_VAL_EUTRA_DL_ENHANCED_PDCCH_FORMAT_0                     2
#define RSRFSIGGEN_VAL_EUTRA_DL_ENHANCED_PDCCH_FORMAT_1                     3
#define RSRFSIGGEN_VAL_EUTRA_DL_ENHANCED_PDCCH_FORMAT_2                     4
#define RSRFSIGGEN_VAL_EUTRA_DL_ENHANCED_PDCCH_FORMAT_3                     5

// RsRFSigGen_rngEUTRADLPDCCHDummyCCEREGs
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_DUMMY_CCE_REGS_DATA                   0
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_DUMMY_CCE_REGS_DTX                    1

// RsRFSigGen_rngEUTRADLEnhancedPDCCHDCIUser
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_USER1                    0
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_USER2                    1
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_USER3                    2
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_USER4                    3
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_PRNTI                    4
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_SIRNTI                   5
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_RARNTI                   6
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_NONE                     7
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_U1E                      8
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_U2E                      9
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_U3E                      10
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_U4E                      11
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_U1SP                     12
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_U2SP                     13
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_U3SP                     14
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_U4SP                     15
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_USER_CCNRTI                   16

// RsRFSigGen_rngEUTRADLDCIFormat
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_FORMAT_F0                     0
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_FORMAT_F1                     1
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_FORMAT_F1A                    2
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_FORMAT_F1B                    3
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_FORMAT_F1C                    4
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_FORMAT_F1D                    5
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_FORMAT_F2                     6
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_FORMAT_F2A                    7
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_FORMAT_F2B                    8
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_FORMAT_F3                     9
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_FORMAT_F3A                    10
#define RSRFSIGGEN_VAL_EUTRA_DL_PDCCH_ENH_DCI_FORMAT_F2C                    11

// RsRFSigGen_rngEUTRADLDCIMode
#define RSRFSIGGEN_VAL_EUTRA_DL_ENH_PDCCH_DCI_FORM_MODE_PDSCH               0
#define RSRFSIGGEN_VAL_EUTRA_DL_ENH_PDCCH_DCI_FORM_MODE_PRACH               1

// RsRFSigGen_rngEUTRAULPUSCHFrequencyHoppingMode
#define RSRFSIGGEN_VAL_EUTRA_UL_PUSCH_HOPPING_INTRA                         0
#define RSRFSIGGEN_VAL_EUTRA_UL_PUSCH_HOPPING_INTER                         1

// RsRFSigGen_rngEUTRAULPRACHPreambleSet
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_RESTRICTED                            0
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_UNRESTRICTED                          1

// RsRFSigGen_rngEUTRAULRTFBMode
#define RSRFSIGGEN_VAL_EUTRA_UL_RTFB_MODE_OFF                               0
#define RSRFSIGGEN_VAL_EUTRA_UL_RTFB_MODE_BAN                               1
#define RSRFSIGGEN_VAL_EUTRA_UL_RTFB_MODE_SERIAL                            2
#define RSRFSIGGEN_VAL_EUTRA_UL_RTFB_MODE_S3X8                              3

// RsRFSigGen_rngEUTRAULRTFBACKDefinition
#define RSRFSIGGEN_VAL_EUTRA_UL_RTFB_ACK_HIGH                               0
#define RSRFSIGGEN_VAL_EUTRA_UL_RTFB_ACK_LOW                                1

// RsRFSigGen_rngEUTRAULRTFBConnector
#define RSRFSIGGEN_VAL_EUTRA_UL_RTFB_CONN_LOCAL                             2
#define RSRFSIGGEN_VAL_EUTRA_UL_RTFB_CONN_GLOBAL                            3

// RsRFSigGen_rngEUTRAULRTFBDistanceMode
#define RSRFSIGGEN_VAL_EUTRA_UL_RTFB_DMODE_STD                              0
#define RSRFSIGGEN_VAL_EUTRA_UL_RTFB_DMODE_DIR                              1

// RsRFSigGen_rngEUTRAULRTFBSerialRate
#define RSRFSIGGEN_VAL_EUTRA_UL_RTFB_SER_SR115_2K                           0
#define RSRFSIGGEN_VAL_EUTRA_UL_RTFB_SER_SR1_92M                            1
#define RSRFSIGGEN_VAL_EUTRA_UL_RTFB_SER_SR1_6M                             2

// RsRFSigGen_rngEUTRAULRTFBBlockErrorInsertion
#define RSRFSIGGEN_VAL_EUTRA_UL_RTFB_BLOCK_ERR_INSERTION_OFF                0
#define RSRFSIGGEN_VAL_EUTRA_UL_RTFB_BLOCK_ERR_INSERTION_FPR                1
#define RSRFSIGGEN_VAL_EUTRA_UL_RTFB_BLOCK_ERR_INSERTION_APR                2

// RsRFSigGen_rngEUTRAULUEMode
#define RSRFSIGGEN_VAL_EUTRA_UL_UE_MODE_STANDARD                            0
#define RSRFSIGGEN_VAL_EUTRA_UL_UE_MODE_PRACH                               1

// RsRFSigGen_rngEUTRAULUEPUSCHCCODMode
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_CCOD_MODE_COMB                         0
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_CCOD_MODE_ULSC                         1
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_CCOD_MODE_UC                           2

// RsRFSigGen_rngEUTRAULSRSPeriodicity
#define RSRFSIGGEN_VAL_EUTRA_UL_REFERENCE_SRS_PERIODICITY_2MS               0
#define RSRFSIGGEN_VAL_EUTRA_UL_REFERENCE_SRS_PERIODICITY_5MS               1
#define RSRFSIGGEN_VAL_EUTRA_UL_REFERENCE_SRS_PERIODICITY_10MS              2
#define RSRFSIGGEN_VAL_EUTRA_UL_REFERENCE_SRS_PERIODICITY_20MS              3
#define RSRFSIGGEN_VAL_EUTRA_UL_REFERENCE_SRS_PERIODICITY_40MS              4
#define RSRFSIGGEN_VAL_EUTRA_UL_REFERENCE_SRS_PERIODICITY_80MS              5
#define RSRFSIGGEN_VAL_EUTRA_UL_REFERENCE_SRS_PERIODICITY_160MS             6
#define RSRFSIGGEN_VAL_EUTRA_UL_REFERENCE_SRS_PERIODICITY_320MS             7

// RsRFSigGen_rngEUTRAULUESymbolInSubframe
#define RSRFSIGGEN_VAL_EUTRA_UL_REFERENCE_SYMBOL_SUBFRAME_FIRST             0
#define RSRFSIGGEN_VAL_EUTRA_UL_REFERENCE_SYMBOL_SUBFRAME_LAST              1

// RsRFSigGen_rngEUTRAFRCType
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A11                                0
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A12                                1
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A13                                2
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A14                                3
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A15                                4
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A21                                5
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A22                                6
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A23                                7
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A31                                8
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A32                                9
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A33                                10
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A34                                11
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A35                                12
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A36                                13
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A37                                14
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A41                                15
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A42                                16
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A43                                17
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A44                                18
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A45                                19
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A46                                20
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A47                                21
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A48                                22
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A51                                23
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A52                                24
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A53                                25
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A54                                26
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A55                                27
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A56                                28
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A57                                29
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A71                                30
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A72                                31
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A73                                32
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A74                                33
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A75                                34
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A76                                35
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A81                                36
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A82                                37
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A83                                38
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A84                                39
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A85                                40
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A86                                41
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_UE11                               42
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_UE12                               43
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_UE21                               44
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_UE22                               45
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_UE3                                46
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A16                                47
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A17                                48
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A121                               49
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A122                               50
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A123                               51
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A124                               52
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A125                               53
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A126                               54
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A131                               55
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A132                               56
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A133                               57
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A134                               58
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A135                               59
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A136                               60
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A171                               61
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A172                               62
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A173                               63
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A174                               64
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A175                               65
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A176                               66
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A181                               67
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A182                               68
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A183                               69
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A184                               70
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A185                               71
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A186                               72
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A191                               73
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A192                               74
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A193                               75
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A194                               76
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A195                               77
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A196                               78
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A211                               79
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A212                               80
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A213                               81
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A214                               82
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A215                               83
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A216                               84
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A221                               85
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A222                               86
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A223                               87
#define RSRFSIGGEN_VAL_EUTRA_UL_FRC_TYPE_A224                               88

// RsRFSigGen_rngEUTRAULSubframeContentType
#define RSRFSIGGEN_VAL_EUTRA_UL_SUBFRAME_CONTENT_TYPE_PUSCH                 0
#define RSRFSIGGEN_VAL_EUTRA_UL_SUBFRAME_CONTENT_TYPE_PUCCH                 1
#define RSRFSIGGEN_VAL_EUTRA_UL_SUBFRAME_CONTENT_TYPE_EMTC                  2
#define RSRFSIGGEN_VAL_EUTRA_UL_SUBFRAME_CONTENT_TYPE_NIOT                  3

// RsRFSigGen_rngEUTRAModulation
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_MODULATION_QPSK                       0
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_MODULATION_QAM16                      1
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_MODULATION_QAM64                      2
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_MODULATION_QAM256                     3
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_MODULATION_QAM1024                    4

// RsRFSigGen_rngEUTRAULSubframeFormat
#define RSRFSIGGEN_VAL_EUTRA_UL_SUBFRAME_FORMAT_F1                          0
#define RSRFSIGGEN_VAL_EUTRA_UL_SUBFRAME_FORMAT_F1A                         1
#define RSRFSIGGEN_VAL_EUTRA_UL_SUBFRAME_FORMAT_F1B                         2
#define RSRFSIGGEN_VAL_EUTRA_UL_SUBFRAME_FORMAT_F2                          3
#define RSRFSIGGEN_VAL_EUTRA_UL_SUBFRAME_FORMAT_F2A                         4
#define RSRFSIGGEN_VAL_EUTRA_UL_SUBFRAME_FORMAT_F2B                         5
#define RSRFSIGGEN_VAL_EUTRA_UL_SUBFRAME_FORMAT_F3                          6
#define RSRFSIGGEN_VAL_EUTRA_UL_SUBFRAME_FORMAT_F4                          7
#define RSRFSIGGEN_VAL_EUTRA_UL_SUBFRAME_FORMAT_F5                          8

// RsRFSigGen_rngEUTRAULSubframeEnhFrequencyHopping
#define RSRFSIGGEN_VAL_EUTRA_UL_SUBFRAME_ENH_PUSCH_FHOP_NONE                0
#define RSRFSIGGEN_VAL_EUTRA_UL_SUBFRAME_ENH_PUSCH_FHOP_TP1                 1
#define RSRFSIGGEN_VAL_EUTRA_UL_SUBFRAME_ENH_PUSCH_FHOP_TP2                 2

// RsRFSigGen_rngEUTRAULSubframeEnhPUSCHNumberofACKNACKMode
#define RSRFSIGGEN_VAL_EUTRA_UL_ENH_PUSCH_ACKNACK_MODE_MUX                  0
#define RSRFSIGGEN_VAL_EUTRA_UL_ENH_PUSCH_ACKNACK_MODE_BUND                 1

// RsRFSigGen_rngEUTRAFilterMode
#define RSRFSIGGEN_VAL_EUTRA_FILTER_MODE_REALTIME                           0
#define RSRFSIGGEN_VAL_EUTRA_FILTER_MODE_OFFLINE                            1

// RsRFSigGen_rngEUTRAFilterLTEOptimization
#define RSRFSIGGEN_VAL_EUTRA_FILTER_LTE_OPTIMIZATION_STD                    0
#define RSRFSIGGEN_VAL_EUTRA_FILTER_LTE_OPTIMIZATION_EVM                    1
#define RSRFSIGGEN_VAL_EUTRA_FILTER_LTE_OPTIMIZATION_ACP                    2
#define RSRFSIGGEN_VAL_EUTRA_FILTER_LTE_OPTIMIZATION_ACPN                   3
#define RSRFSIGGEN_VAL_EUTRA_FILTER_LTE_OPTIMIZATION_BENU                   4

// RsRFSigGen_rngEUTRAPowerLevelReference
#define RSRFSIGGEN_VAL_EUTRA_POWER_LEVEL_REFERENCE_FRMS                     0
#define RSRFSIGGEN_VAL_EUTRA_POWER_LEVEL_REFERENCE_DRMS                     1
#define RSRFSIGGEN_VAL_EUTRA_POWER_LEVEL_REFERENCE_URMS                     2
#define RSRFSIGGEN_VAL_EUTRA_POWER_LEVEL_REFERENCE_UEB                      3
#define RSRFSIGGEN_VAL_EUTRA_POWER_LEVEL_REFERENCE_NPBCH                    4

// RsRFSigGen_rngEUTRASignalAdvanceNTAoffset
#define RSRFSIGGEN_SIGNAL_ADVANCE_NTA_0                                     0
#define RSRFSIGGEN_SIGNAL_ADVANCE_NTA_624                                   1

// RsRFSigGen_rngEUTRATriggerSignalDurationUnit
#define RSRFSIGGEN_VAL_EUTRA_SIGNAL_DURATION_UNIT_FRAME                     0
#define RSRFSIGGEN_VAL_EUTRA_SIGNAL_DURATION_UNIT_SEQUENCE                  1
#define RSRFSIGGEN_VAL_EUTRA_SIGNAL_DURATION_UNIT_SUBFRAME                  2
#define RSRFSIGGEN_VAL_EUTRA_SIGNAL_DURATION_UNIT_SLOT                      3
#define RSRFSIGGEN_VAL_EUTRA_SIGNAL_DURATION_UNIT_SAMPLE                    4

// RsRFSigGen_rngEUTRAMarkerMode
#define RSRFSIGGEN_VAL_EUTRA_MARKER_TYPE_RESTART                            0
#define RSRFSIGGEN_VAL_EUTRA_MARKER_TYPE_FRAME                              1
#define RSRFSIGGEN_VAL_EUTRA_MARKER_TYPE_PERIOD                             2
#define RSRFSIGGEN_VAL_EUTRA_MARKER_TYPE_SUBFRAM                            3
#define RSRFSIGGEN_VAL_EUTRA_MARKER_TYPE_RATIO                              4
#define RSRFSIGGEN_VAL_EUTRA_MARKER_TYPE_TRIG                               5
#define RSRFSIGGEN_VAL_EUTRA_MARKER_TYPE_INT                                6
#define RSRFSIGGEN_VAL_EUTRA_MARKER_TYPE_FAP                                7

// RsRFSigGen_rngEUTRAClockMode
#define RSRFSIGGEN_VAL_EUTRA_CLOCK_MODE_SAMPLE                              0
#define RSRFSIGGEN_VAL_EUTRA_CLOCK_MODE_MSAMPLE                             1
#define RSRFSIGGEN_VAL_EUTRA_CLOCK_MODE_CUSTOM                              2

// RsRFSigGen_rngEUTRADLSubframeDataSource
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_USER1                     0
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_USER2                     1
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_USER3                     2
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_USER4                     3
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_PN9                       4
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_PN11                      5
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_PN15                      6
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_PN16                      7
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_PN20                      8
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_PN21                      9
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_PN23                      10
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_PATT                      11
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_DLIST                     12
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_ALL0                      13
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_ALL1                      14
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_MIB                       15
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_MCCH                      16
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_DATA_SOURCE_MTCH                      17

// RsRFSigGen_rngEUTRASubframeContentType
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_TYPE_PDSCH                            0
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_TYPE_PBCH                             1
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_TYPE_PDCC                             2
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_TYPE_RSVD                             3

// RsRFSigGen_rngEUTRADLPrecodingScheme
#define RSRFSIGGEN_VAL_EUTRA_DL_SUBFRAME_ENH_PRECOD_SCHEME_NONE             0
#define RSRFSIGGEN_VAL_EUTRA_DL_SUBFRAME_ENH_PRECOD_SCHEME_SPM              1
#define RSRFSIGGEN_VAL_EUTRA_DL_SUBFRAME_ENH_PRECOD_SCHEME_TXD              2
#define RSRFSIGGEN_VAL_EUTRA_DL_SUBFRAME_ENH_PRECOD_SCHEME_BF               3

// RsRFSigGen_rngEUTRADLCyclicDelayDiversity
#define RSRFSIGGEN_VAL_EUTRA_DL_SUBFRAME_ENH_CDD_NOCCD                      0
#define RSRFSIGGEN_VAL_EUTRA_DL_SUBFRAME_ENH_CDD_SMALL                      1
#define RSRFSIGGEN_VAL_EUTRA_DL_SUBFRAME_ENH_CDD_LARGE                      2

// RsRFSigGen_rngEUTRATransmissionMode
#define RSRFSIGGEN_VAL_EUTRA_DL_SUBFRAME_ENH_TRANSM_TM7                     0
#define RSRFSIGGEN_VAL_EUTRA_DL_SUBFRAME_ENH_TRANSM_TM8                     1

// RsRFSigGen_rngEUTRADLSubframeEnhAntennaPorts
#define RSRFSIGGEN_VAL_EUTRA_DL_ENH_ANTENNA_PORTS_AP7                       0
#define RSRFSIGGEN_VAL_EUTRA_DL_ENH_ANTENNA_PORTS_AP5                       1
#define RSRFSIGGEN_VAL_EUTRA_DL_ENH_ANTENNA_PORTS_AP8                       2
#define RSRFSIGGEN_VAL_EUTRA_DL_ENH_ANTENNA_PORTS_AP78                      3
#define RSRFSIGGEN_VAL_EUTRA_DL_ENH_ANTENNA_PORTS_AP79                      4
#define RSRFSIGGEN_VAL_EUTRA_DL_ENH_ANTENNA_PORTS_AP710                     5
#define RSRFSIGGEN_VAL_EUTRA_DL_ENH_ANTENNA_PORTS_AP711                     6
#define RSRFSIGGEN_VAL_EUTRA_DL_ENH_ANTENNA_PORTS_AP712                     7
#define RSRFSIGGEN_VAL_EUTRA_DL_ENH_ANTENNA_PORTS_AP713                     8
#define RSRFSIGGEN_VAL_EUTRA_DL_ENH_ANTENNA_PORTS_AP714                     9

// RsRFSigGen_rngEUTRASubframeAntennaPortsMapping
#define RSRFSIGGEN_VAL_EUTRA_DL_ENH_ANTENNA_MAPPING_CB                      0
#define RSRFSIGGEN_VAL_EUTRA_DL_ENH_ANTENNA_MAPPING_RCB                     1
#define RSRFSIGGEN_VAL_EUTRA_DL_ENH_ANTENNA_MAPPING_FW                      2

// RsRFSigGen_rngEUTRAULSubframeCyclicPrefix
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_CPC_NORMAL                            0
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAME_CPC_EXTENDED                          1

// RsRFSigGen_rngEUTRADLReferenceFirstReferenceSignalPosition
#define RSRFSIGGEN_VAL_EUTRA_DL_FIRST_SYMBOL                                1
#define RSRFSIGGEN_VAL_EUTRA_DL_SECOND_SYMBOL                               2

// RsRFSigGen_rngEUTRADLMBSFNAIMCCHModulation
#define RSVNA_DL_MBSFN_MCCH_MODULATION_QPSK                                 0
#define RSVNA_DL_MBSFN_MCCH_MODULATION_QAM16                                1
#define RSVNA_DL_MBSFN_MCCH_MODULATION_QAM64                                2
#define RSVNA_DL_MBSFN_MCCH_MODULATION_QAM256                               3

// RsRFSigGen_rngEUTRASearchSpaceType
#define RSRFSIGGEN_VAL_EUTRA_DCI_SEARCH_SPACE_OFF                           0
#define RSRFSIGGEN_VAL_EUTRA_DCI_SEARCH_SPACE_AUTO                          2
#define RSRFSIGGEN_VAL_EUTRA_DCI_SEARCH_SPACE_COMMON                        3
#define RSRFSIGGEN_VAL_EUTRA_DCI_SEARCH_SPACE_UE                            4

// RsRFSigGen_rngEUTRAWizardISChannelBandwidth
#define RSRFSIGGEN_VAL_EUTRA_WIZARD_IS_BW_20_0                              0
#define RSRFSIGGEN_VAL_EUTRA_WIZARD_IS_BW_15_0                              1
#define RSRFSIGGEN_VAL_EUTRA_WIZARD_IS_BW_10_0                              2
#define RSRFSIGGEN_VAL_EUTRA_WIZARD_IS_BW_5_0                               3
#define RSRFSIGGEN_VAL_EUTRA_WIZARD_IS_BW_3_0                               4
#define RSRFSIGGEN_VAL_EUTRA_WIZARD_IS_BW_1_4                               5

// RsRFSigGen_rngEUTRAULUE3GPPRelease
#define RSRFSIGGEN_VAL_EUTRA_UL_3GPP_RELEASE_8_9                            0
#define RSRFSIGGEN_VAL_EUTRA_UL_3GPP_RELEASE_10                             1
#define RSRFSIGGEN_VAL_EUTRA_UL_3GPP_LTE_ADV                                2
#define RSRFSIGGEN_VAL_EUTRA_UL_3GPP_LTE_EMTC                               3
#define RSRFSIGGEN_VAL_EUTRA_UL_3GPP_LTE_NIOT                               4

// RsRFSigGen_rngEUTRATestSpecificationRelease
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_RELEASE_8                             0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_RELEASE_9                             1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_RELEASE_10                            2
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_RELEASE_11                            3
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_RELEASE_12                            4
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_RELEASE_13                            5
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_RELEASE_14                            6
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TEST_RELEASE_15                            7

// RsRFSigGen_rngEUTRADLCarrierAggregationCellBandwidth
#define RSRFSIGGEN_VAL_EUTRA_PHYSICAL_SETTINGS_BANDWIDTH_1_40               0
#define RSRFSIGGEN_VAL_EUTRA_PHYSICAL_SETTINGS_BANDWIDTH_3_00               1
#define RSRFSIGGEN_VAL_EUTRA_PHYSICAL_SETTINGS_BANDWIDTH_5_00               2
#define RSRFSIGGEN_VAL_EUTRA_PHYSICAL_SETTINGS_BANDWIDTH_10_00              3
#define RSRFSIGGEN_VAL_EUTRA_PHYSICAL_SETTINGS_BANDWIDTH_15_00              4
#define RSRFSIGGEN_VAL_EUTRA_PHYSICAL_SETTINGS_BANDWIDTH_20_0               5

// RsRFSigGen_rngEUTRACarrierAggregationCellBaseband
#define RSRFSIGGEN_VAL_PATH_A                                               1
#define RSRFSIGGEN_VAL_PATH_B                                               2

// RsRFSigGen_rngTETRATestMode
#define RSRFSIGGEN_VAL_TETRA_TEST_MODE_T1                                   0
#define RSRFSIGGEN_VAL_TETRA_TEST_MODE_T4                                   1
#define RSRFSIGGEN_VAL_TETRA_TEST_MODE_USER                                 2
#define RSRFSIGGEN_VAL_TETRA_TEST_MODE_T2                                   3
#define RSRFSIGGEN_VAL_TETRA_TEST_MODE_T3                                   4

// RsRFSigGen_rngTETRAChannelType
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH0                                  0
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH1                                  1
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH2                                  2
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH3                                  3
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH4                                  4
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH7                                  5
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH8                                  6
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH9                                  7
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH10                                 8
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH11                                 9
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH21                                 10
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH22                                 11
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH23                                 12
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH24                                 13
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH25                                 14
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH26                                 15
#define RSRFSIGGEN_VAL_TETRA_CHAN_TYPE_CH27                                 16

// RsRFSigGen_rngTETRADLBurstType
#define RSRFSIGGEN_VAL_TETRA_DL_BURST_TYPE_CONT                             0
#define RSRFSIGGEN_VAL_TETRA_DL_BURST_TYPE_DISCONT                          1

// RsRFSigGen_rngTETRAModulationType
#define RSRFSIGGEN_VAL_TETRA_MODULATION_TYPE_PHAS                           0
#define RSRFSIGGEN_VAL_TETRA_MODULATION_TYPE_QAM                            1

// RsRFSigGen_rngTETRAPowerRampFunction
#define RSRFSIGGEN_VAL_TETRA_PRAMP_FUNC_LINEAR                              0
#define RSRFSIGGEN_VAL_TETRA_PRAMP_FUNC_COSINE                              1

// RsRFSigGen_rngTETRACarrierBandwidth
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_CBAND_C25                            0
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_CBAND_C50                            1
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_CBAND_C100                           2
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_CBAND_C150                           3

// RsRFSigGen_rngTETRAFrequencyBand
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_FBAND_F100                           0
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_FBAND_F200                           1
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_FBAND_F300                           2
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_FBAND_F400                           3
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_FBAND_F500                           4
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_FBAND_F600                           5
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_FBAND_F700                           6
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_FBAND_F800                           7
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_FBAND_F900                           8

// RsRFSigGen_rngTETRABroadcastFrequencyOffset
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_OFFSET_ZERO                          0
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_OFFSET_P625                          1
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_OFFSET_M625                          2
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_OFFSET_P125                          3

// RsRFSigGen_rngTETRADuplexSpacing
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_DUPLEX_SPAC_DS0                      0
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_DUPLEX_SPAC_DS1                      1
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_DUPLEX_SPAC_DS2                      2
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_DUPLEX_SPAC_DS3                      3
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_DUPLEX_SPAC_DS4                      4
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_DUPLEX_SPAC_DS5                      5
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_DUPLEX_SPAC_DS6                      6
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_DUPLEX_SPAC_DS7                      7

// RsRFSigGen_rngTETRASystemCode
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_SCODE_S0                             0
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_SCODE_S1                             1
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_SCODE_S2                             2
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_SCODE_S3                             3
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_SCODE_S4                             4
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_SCODE_S5                             5
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_SCODE_S6                             6
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_SCODE_S7                             7

// RsRFSigGen_rngTETRASharingMode
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_SHARING_MODE_CONTINUOUS              0
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_SHARING_MODE_CARRIER                 1
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_SHARING_MODE_MCCH                    2
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_SHARING_MODE_TRAFFIC                 3

// RsRFSigGen_rngTETRATSReservedFrames
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_TS_F1                                0
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_TS_F2                                1
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_TS_F3                                2
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_TS_F4                                3
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_TS_F6                                4
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_TS_F9                                5
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_TS_F12                               6
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_TS_F18                               7

// RsRFSigGen_rngTETRACellServiceLevel
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_CELL_SERVICE_CLUN                    0
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_CELL_SERVICE_LCL                     1
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_CELL_SERVICE_MCL                     2
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_CELL_SERVICE_HCL                     3

// RsRFSigGen_rngTETRAMSTXPWRMAXCELL
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_MSTXPWR_M15                          0
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_MSTXPWR_M20                          1
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_MSTXPWR_M25                          2
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_MSTXPWR_M30                          3
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_MSTXPWR_M35                          4
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_MSTXPWR_M40                          5
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_MSTXPWR_M45                          6

// RsRFSigGen_rngTETRAACCESS_PARAMETER
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_ACCESS_PARAM_AP53                    0
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_ACCESS_PARAM_AP51                    1
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_ACCESS_PARAM_AP49                    2
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_ACCESS_PARAM_AP47                    3
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_ACCESS_PARAM_AP45                    4
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_ACCESS_PARAM_AP43                    5
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_ACCESS_PARAM_AP41                    6
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_ACCESS_PARAM_AP39                    7
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_ACCESS_PARAM_AP37                    8
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_ACCESS_PARAM_AP35                    9
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_ACCESS_PARAM_AP33                    10
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_ACCESS_PARAM_AP31                    11
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_ACCESS_PARAM_AP29                    12
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_ACCESS_PARAM_AP27                    13
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_ACCESS_PARAM_AP25                    14
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_ACCESS_PARAM_AP23                    15

// RsRFSigGen_rngTETRATx_On
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_TX_ON_RON                            0
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_TX_ON_TON                            1

// RsRFSigGen_rngTETRATxBurstType
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_TX_BURST_NUB                         0
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_TX_BURST_CUB                         1

// RsRFSigGen_rngTETRAT1T4BurstType
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_T72F                      0
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_T72S                      1
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_SFD                       2
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_BSHD                      3
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_T24D                      4
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_T72U                      5
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_SFU                       6
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_SSTC                      7
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_T24U                      8
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_SSCH                      9
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_RSB                       10
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_RSSB                      11
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_TPTD                      12
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_TPTU                      13
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_T48D                      14
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_T48U                      15
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_TSCD                      16
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_TSCU                      17
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_T108                      18
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_SPHD                      19
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_SPHU                      20
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_SPF                       21
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_SQHU                      22
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_SQU                       23
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_SQD                       24
#define RSRFSIGGEN_VAL_TETRA_BROADCAST_T1T4_BURST_SQRA                      25

// RsRFSigGen_rngTETRASlotLevel
#define RSRFSIGGEN_VAL_TETRA_SLOT_LEVEL_OFF                                 0
#define RSRFSIGGEN_VAL_TETRA_SLOT_LEVEL_ATT                                 1
#define RSRFSIGGEN_VAL_TETRA_SLOT_LEVEL_FULL                                2

// RsRFSigGen_rngTETRASlotAttenuation
#define RSRFSIGGEN_VAL_TETRA_SLOT_ATT_A1                                    0
#define RSRFSIGGEN_VAL_TETRA_SLOT_ATT_A2                                    1
#define RSRFSIGGEN_VAL_TETRA_SLOT_ATT_A3                                    2
#define RSRFSIGGEN_VAL_TETRA_SLOT_ATT_A4                                    3

// RsRFSigGen_rngTETRASlotLogicalChannelType
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_T72                  0
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_T48                  1
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_T24                  2
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_TCHF                 3
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_TCHH                 4
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_STCH                 5
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_SSTCH                6
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_SCHF                 7
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_T108                 8
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_SP8F                 9
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_SSHD                 10
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_BSHD                 11
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_SBNCH                12
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_BBNCH                13
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_S8HD                 14
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_D4H                  15
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_D16H                 16
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_D64H                 17
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_D64M                 18
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_D16U                 19
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_D64U                 20
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_B4H                  21
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_B16H                 22
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_B64H                 23
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_B64M                 24
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_B16U                 25
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_B64U                 26
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_SSHU                 27
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_S8HU                 28
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_S4S8                 29
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_S8S4                 30
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_U4H                  31
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_U16H                 32
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_U64H                 33
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_U64M                 34
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_U16U                 35
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_U64U                 36
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_H4H                  37
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_H16H                 38
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_H64H                 39
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_H64M                 40
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_H16U                 41
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_H64U                 42
#define RSRFSIGGEN_VAL_TETRA_SLOT_LOGICAL_CHANNEL_TYPE_SQRA                 43

// RsRFSigGen_rngTETRATrainingSequenceTSC
#define RSRFSIGGEN_VAL_TETRA_SLOT_TRAINING_SEQ_DEF                          0
#define RSRFSIGGEN_VAL_TETRA_SLOT_TRAINING_SEQ_UDEF                         1

// RsRFSigGen_rngTETRASlotBurstType
#define RSRFSIGGEN_VAL_TETRA_SLOT_BURST_TYPE_NCDB                           0
#define RSRFSIGGEN_VAL_TETRA_SLOT_BURST_TYPE_SCDB                           1
#define RSRFSIGGEN_VAL_TETRA_SLOT_BURST_TYPE_NDDB                           2
#define RSRFSIGGEN_VAL_TETRA_SLOT_BURST_TYPE_SDDB                           3
#define RSRFSIGGEN_VAL_TETRA_SLOT_BURST_TYPE_ND4                            4
#define RSRFSIGGEN_VAL_TETRA_SLOT_BURST_TYPE_ND16                           5
#define RSRFSIGGEN_VAL_TETRA_SLOT_BURST_TYPE_ND64                           6
#define RSRFSIGGEN_VAL_TETRA_SLOT_BURST_TYPE_NUB                            7
#define RSRFSIGGEN_VAL_TETRA_SLOT_BURST_TYPE_CUB                            8
#define RSRFSIGGEN_VAL_TETRA_SLOT_BURST_TYPE_NU4                            9
#define RSRFSIGGEN_VAL_TETRA_SLOT_BURST_TYPE_NU16                           10
#define RSRFSIGGEN_VAL_TETRA_SLOT_BURST_TYPE_NU64                           11
#define RSRFSIGGEN_VAL_TETRA_SLOT_BURST_TYPE_CU4                            12
#define RSRFSIGGEN_VAL_TETRA_SLOT_BURST_TYPE_CU16                           13
#define RSRFSIGGEN_VAL_TETRA_SLOT_BURST_TYPE_CU64                           14
#define RSRFSIGGEN_VAL_TETRA_SLOT_BURST_TYPE_RAB                            15

// RsRFSigGen_rngTETRAAACHMode
#define RSRFSIGGEN_VAL_TETRA_AACH_MODE_AAPDU                                0
#define RSRFSIGGEN_VAL_TETRA_AACH_MODE_RELEMENT                             1

// RsRFSigGen_rngTETRATriggerSignalDurationUnit
#define RSRFSIGGEN_VAL_TETRA_SIGNAL_DURATION_UNIT_SEQ                       0
#define RSRFSIGGEN_VAL_TETRA_SIGNAL_DURATION_UNIT_MFR                       1

// RsRFSigGen_rngTETRAMarkerMode
#define RSRFSIGGEN_VAL_TETRA_MARKER_TYPE_RESTART                            0
#define RSRFSIGGEN_VAL_TETRA_MARKER_TYPE_SSTART                             1
#define RSRFSIGGEN_VAL_TETRA_MARKER_TYPE_FSTART                             2
#define RSRFSIGGEN_VAL_TETRA_MARKER_TYPE_MFSTART                            3
#define RSRFSIGGEN_VAL_TETRA_MARKER_TYPE_HFSTART                            4
#define RSRFSIGGEN_VAL_TETRA_MARKER_TYPE_PULSE                              5
#define RSRFSIGGEN_VAL_TETRA_MARKER_TYPE_PATTERN                            6
#define RSRFSIGGEN_VAL_TETRA_MARKER_TYPE_RATIO                              7

// RsRFSigGen_rngBTTransportMode
#define RSRFSIGGEN_VAL_BT_TRANSPORT_MODE_ACL                                0
#define RSRFSIGGEN_VAL_BT_TRANSPORT_MODE_SCO                                1
#define RSRFSIGGEN_VAL_BT_TRANSPORT_MODE_ESCO                               2

// RsRFSigGen_rngBTPacketType
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_ID                                    0
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_NULL                                  1
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_POLL                                  2
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_FHS                                   3
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_DM1                                   4
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_DH1                                   5
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_DM3                                   6
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_DH3                                   7
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_DM5                                   8
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_DH5                                   9
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_AUX1                                  10
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_2DH1                                  11
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_2DH3                                  12
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_2DH5                                  13
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_3DH1                                  14
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_3DH3                                  15
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_3DH5                                  16
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_HV1                                   17
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_HV2                                   18
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_HV3                                   19
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_DV                                    20
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_EV3                                   21
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_EV4                                   22
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_EV5                                   23
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_2EV3                                  24
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_2EV5                                  25
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_3EV3                                  26
#define RSRFSIGGEN_VAL_BT_PACKET_TYPE_3EV5                                  27

// RsRFSigGen_rngBTTriggerSignalDurationUnit
#define RSRFSIGGEN_VAL_BT_SIGNAL_DURATION_UNIT_FRAME                        0
#define RSRFSIGGEN_VAL_BT_SIGNAL_DURATION_UNIT_SEQUENCE                     1
#define RSRFSIGGEN_VAL_BT_SIGNAL_DURATION_UNIT_EVENT                        2

// RsRFSigGen_rngBTMarkerMode
#define RSRFSIGGEN_VAL_BT_MARKER_TYPE_RESTART                               0
#define RSRFSIGGEN_VAL_BT_MARKER_TYPE_FRAMESTART                            1
#define RSRFSIGGEN_VAL_BT_MARKER_TYPE_FRAMEACTIVE                           2
#define RSRFSIGGEN_VAL_BT_MARKER_TYPE_PULSE                                 3
#define RSRFSIGGEN_VAL_BT_MARKER_TYPE_PATT                                  4
#define RSRFSIGGEN_VAL_BT_MARKER_TYPE_RATIO                                 5
#define RSRFSIGGEN_VAL_BT_MARKER_TYPE_IACTIVE                               6

// RsRFSigGen_rngBTClockMode
#define RSRFSIGGEN_VAL_BT_CLOCK_MODE_SAMPLE                                 0
#define RSRFSIGGEN_VAL_BT_CLOCK_MODE_MSAMPLE                                1

// RsRFSigGen_rngBTRampFunction
#define RSRFSIGGEN_VAL_BT_RAMP_FUNC_LINEAR                                  0
#define RSRFSIGGEN_VAL_BT_RAMP_FUNC_COSINE                                  1

// RsRFSigGen_rngBTPacketDataSource
#define RSRFSIGGEN_VAL_BT_PACKET_DATA_SOURCE_PED                            0
#define RSRFSIGGEN_VAL_BT_PACKET_DATA_SOURCE_ADAT                           1

// RsRFSigGen_rngBTFlowControl
#define RSRFSIGGEN_VAL_BT_PACKET_HEAD_FLOW_CONTROL_STOP                     0
#define RSRFSIGGEN_VAL_BT_PACKET_HEAD_FLOW_CONTROL_GO                       1

// RsRFSigGen_rngBTAcknowledgment
#define RSRFSIGGEN_VAL_BT_PACKET_HEAD_ACK_NAK                               0
#define RSRFSIGGEN_VAL_BT_PACKET_HEAD_ACK_ACK                               1

// RsRFSigGen_rngBTEIRPacketFollows
#define RSRFSIGGEN_VAL_BT_PACKET_PAYLOAD_EIR_NO                             0
#define RSRFSIGGEN_VAL_BT_PACKET_PAYLOAD_EIR_YES                            1

// RsRFSigGen_rngBTScanRepetitionMode
#define RSRFSIGGEN_VAL_BT_PACKET_PAYLOAD_SRM_R0                             0
#define RSRFSIGGEN_VAL_BT_PACKET_PAYLOAD_SRM_R1                             1
#define RSRFSIGGEN_VAL_BT_PACKET_PAYLOAD_SRM_R2                             2

// RsRFSigGen_rngBTDTTTableSettings
#define RSRFSIGGEN_VAL_BT_DTT_TABLE_NOT                                     0
#define RSRFSIGGEN_VAL_BT_DTT_TABLE_SHORT                                   1
#define RSRFSIGGEN_VAL_BT_DTT_TABLE_LONG                                    2

// RsRFSigGen_rngBTDTTPayloadType
#define RSRFSIGGEN_VAL_BT_DTT_TPC_TYPE_PN9                                  0
#define RSRFSIGGEN_VAL_BT_DTT_TPC_TYPE_PAT1                                 1
#define RSRFSIGGEN_VAL_BT_DTT_TPC_TYPE_PAT2                                 2
#define RSRFSIGGEN_VAL_BT_DTT_TPC_TYPE_PN15                                 3
#define RSRFSIGGEN_VAL_BT_DTT_TPC_TYPE_PAT3                                 4
#define RSRFSIGGEN_VAL_BT_DTT_TPC_TYPE_PAT4                                 5
#define RSRFSIGGEN_VAL_BT_DTT_TPC_TYPE_PAT5                                 6
#define RSRFSIGGEN_VAL_BT_DTT_TPC_TYPE_PAT6                                 7

// RsRFSigGen_rngBTLEChannelType
#define RSRFSIGGEN_VAL_BT_LE_CHAN_TYPE_ADVERTISING                          0
#define RSRFSIGGEN_VAL_BT_LE_CHAN_TYPE_DATA                                 1

// RsRFSigGen_rngBTLEPacketType
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_AIND                               0
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_ADIN                               1
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_ANIN                               2
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_ADC                                3
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_SREQ                               4
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_SRSP                               5
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_CREQ                               6
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_DATA                               7
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_CUR                                8
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_CMR                                9
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_TIND                               10
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_EREQ                               11
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_ERSP                               12
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_SER                                13
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_SERS                               14
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_URSP                               15
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_FREQ                               16
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_FRSP                               17
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_TPAC                               18
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_PER                                19
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_PERS                               20
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_VIND                               21
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_RIND                               22
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_PREQ                               23
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_PRSP                               24
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_PUIN                               25
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_LREQ                               26
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_LRSP                               27
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_SFR                                28
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_CPR                                29
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_CPRS                               30
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_REIN                               31
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_PIR                                32
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_PIRS                               33
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_AEIN                               34
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_AAIN                               35
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_ACIN                               36
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_ASIN                               37
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_ASR                                38
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_ASPS                               39
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_ACRS                               40
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_ACR                                41
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_MUCH                               42
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_CONT                               43
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_CTEQ                               44
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_CTEP                               45
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_PSIND                              46
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_CAR                                47
#define RSRFSIGGEN_VAL_BT_LE_PACKET_TYPE_CARS                               48

// RsRFSigGen_rngBTLEConnectionMode
#define RSRFSIGGEN_VAL_BT_LE_CONNECTION_MODE_UENC                           0
#define RSRFSIGGEN_VAL_BT_LE_CONNECTION_MODE_ENC                            1

// RsRFSigGen_rngBTLEMoreProfiles
#define RSRFSIGGEN_VAL_BT_LE_MORE_PROF_NO                                   0
#define RSRFSIGGEN_VAL_BT_LE_MORE_PROF_YES                                  1

// RsRFSigGen_rngBTLESleepClockAccuracy
#define RSRFSIGGEN_VAL_BT_LE_SLEEP_CLK_ACCURACY_FHUN                        0
#define RSRFSIGGEN_VAL_BT_LE_SLEEP_CLK_ACCURACY_THF                         1
#define RSRFSIGGEN_VAL_BT_LE_SLEEP_CLK_ACCURACY_OHF                         2
#define RSRFSIGGEN_VAL_BT_LE_SLEEP_CLK_ACCURACY_OHUN                        3
#define RSRFSIGGEN_VAL_BT_LE_SLEEP_CLK_ACCURACY_SFIV                        4
#define RSRFSIGGEN_VAL_BT_LE_SLEEP_CLK_ACCURACY_FIFT                        5
#define RSRFSIGGEN_VAL_BT_LE_SLEEP_CLK_ACCURACY_THIR                        6
#define RSRFSIGGEN_VAL_BT_LE_SLEEP_CLK_ACCURACY_TWEN                        7

// RsRFSigGen_rngBTLEDevicesAddrType
#define RSRFSIGGEN_VAL_BT_LE_ADDR_TYPE_PUBLIC                               0
#define RSRFSIGGEN_VAL_BT_LE_ADDR_TYPE_PRIVATE                              1

// RsRFSigGen_rngXMRPhysicalLayerMode
#define RSRFSIGGEN_VAL_XMR_PHYS_LAYER_MODE_SAT1A                            0
#define RSRFSIGGEN_VAL_XMR_PHYS_LAYER_MODE_SAT2A                            1
#define RSRFSIGGEN_VAL_XMR_PHYS_LAYER_MODE_TERRA                            2
#define RSRFSIGGEN_VAL_XMR_PHYS_LAYER_MODE_TERRB                            3
#define RSRFSIGGEN_VAL_XMR_PHYS_LAYER_MODE_SAT2B                            4
#define RSRFSIGGEN_VAL_XMR_PHYS_LAYER_MODE_SAT1B                            5

// RsRFSigGen_rngXMRMarkerMode
#define RSRFSIGGEN_VAL_XMR_MARKER_MODE_PATTERN                              0
#define RSRFSIGGEN_VAL_XMR_MARKER_MODE_PULSE                                1
#define RSRFSIGGEN_VAL_XMR_MARKER_MODE_RATIO                                2
#define RSRFSIGGEN_VAL_XMR_MARKER_MODE_USER                                 3

// RsRFSigGen_rngXMRTriggerSignalDurationUnit
#define RSRFSIGGEN_VAL_XMR_TERR_SIGNAL_DURATION_UNIT_TPL                    0
#define RSRFSIGGEN_VAL_XMR_TERR_SIGNAL_DURATION_UNIT_MCM                    1
#define RSRFSIGGEN_VAL_XMR_TERR_SIGNAL_DURATION_UNIT_SAMP                   2

// RsRFSigGen_rngXMRTerrestrialMarkerMode
#define RSRFSIGGEN_VAL_XMR_TERR_MARKER_MODE_TPL                             0
#define RSRFSIGGEN_VAL_XMR_TERR_MARKER_MODE_MCM                             1
#define RSRFSIGGEN_VAL_XMR_TERR_MARKER_MODE_USER                            2
#define RSRFSIGGEN_VAL_XMR_TERR_MARKER_MODE_RATIO                           3

// RsRFSigGen_rngSiriusPhysicalLayer
#define RSRFSIGGEN_VAL_SIRIUS_PLAYER_LEG                                    0
#define RSRFSIGGEN_VAL_SIRIUS_PLAYER_OVER                                   1

// RsRFSigGen_rngSiriusPhysicalLayerTransmission
#define RSRFSIGGEN_VAL_SIRIUS_PLAYER_TRANS_SAT1                             0
#define RSRFSIGGEN_VAL_SIRIUS_PLAYER_TRANS_SAT2                             1
#define RSRFSIGGEN_VAL_SIRIUS_PLAYER_TRANS_TERR                             2

// RsRFSigGen_rngSiriusModulation
#define RSRFSIGGEN_VAL_SIRIUS_SAT_MODULATION_QPSK                           0
#define RSRFSIGGEN_VAL_SIRIUS_SAT_MODULATION_PSK8                           1
#define RSRFSIGGEN_VAL_SIRIUS_SAT_MODULATION_P8INV                          2

// RsRFSigGen_rngSiriusMarkerMode
#define RSRFSIGGEN_VAL_SIRIUS_SAT_MARKER_TYPE_FRAME                         0
#define RSRFSIGGEN_VAL_SIRIUS_SAT_MARKER_TYPE_PULSE                         1
#define RSRFSIGGEN_VAL_SIRIUS_SAT_MARKER_TYPE_PATTERN                       2
#define RSRFSIGGEN_VAL_SIRIUS_SAT_MARKER_TYPE_USER                          3
#define RSRFSIGGEN_VAL_SIRIUS_SAT_MARKER_TYPE_RATIO                         4

// RsRFSigGen_rngGPSRFBand
#define RSRFSIGGEN_VAL_GPS_RF_BAND_L1                                       0
#define RSRFSIGGEN_VAL_GPS_RF_BAND_L2                                       1

// RsRFSigGen_rngGPSFilter
#define RSRFSIGGEN_VAL_GPS_FILTER_GAUSS                                     0
#define RSRFSIGGEN_VAL_GPS_FILTER_RECTANGULAR                               1

// RsRFSigGen_rngGPSAGPSTestScenario
#define RSRFSIGGEN_VAL_GPS_AGPS_USER                                        0
#define RSRFSIGGEN_VAL_GPS_AGPS_GSM_SIGNALLING                              1
#define RSRFSIGGEN_VAL_GPS_AGPS_GSM_PERFORMANCE1                            2
#define RSRFSIGGEN_VAL_GPS_AGPS_GSM_PERFORMANCE2                            3
#define RSRFSIGGEN_VAL_GPS_AGPS_GSM_PERFORMANCE3                            4
#define RSRFSIGGEN_VAL_GPS_AGPS_3GPP_SIGNALLING                             5
#define RSRFSIGGEN_VAL_GPS_AGPS_3GPP_PERFORMANCE1                           6
#define RSRFSIGGEN_VAL_GPS_AGPS_3GPP_PERFORMANCE2                           7
#define RSRFSIGGEN_VAL_GPS_AGPS_3GPP_PERFORMANCE3                           8

// RsRFSigGen_rngGPSSimulationMode
#define RSRFSIGGEN_VAL_GPS_SIMULATION_GENERIC                               0
#define RSRFSIGGEN_VAL_GPS_SIMULATION_LOCALIZATION                          1

// RsRFSigGen_rngGPSLocalizationMode
#define RSRFSIGGEN_VAL_GPS_LOCALIZATION_MODE_AUTO                           0
#define RSRFSIGGEN_VAL_GPS_LOCALIZATION_MODE_AUTO_UPDATE                    1
#define RSRFSIGGEN_VAL_GPS_LOCALIZATION_MODE_FULL                           2

// RsRFSigGen_rngGPSTriggerSignalDurationUnit
#define RSRFSIGGEN_VAL_TRIGGER_SIGNAL_DURATION_UNIT_SUBFRAME                0
#define RSRFSIGGEN_VAL_TRIGGER_SIGNAL_DURATION_UNIT_NBIT                    1
#define RSRFSIGGEN_VAL_TRIGGER_SIGNAL_DURATION_UNIT_CA                      2

// RsRFSigGen_rngGPSMarkerMode
#define RSRFSIGGEN_VAL_GPS_MARKER_TYPE_NAVBIT                               0
#define RSRFSIGGEN_VAL_GPS_MARKER_TYPE_WORD                                 1
#define RSRFSIGGEN_VAL_GPS_MARKER_TYPE_SUBFRAME                             2
#define RSRFSIGGEN_VAL_GPS_MARKER_TYPE_1PPS                                 3
#define RSRFSIGGEN_VAL_GPS_MARKER_TYPE_PULSE                                4
#define RSRFSIGGEN_VAL_GPS_MARKER_TYPE_PATTERN                              5
#define RSRFSIGGEN_VAL_GPS_MARKER_TYPE_RATIO                                6
#define RSRFSIGGEN_VAL_GPS_MARKER_TYPE_PP2S                                 7
#define RSRFSIGGEN_VAL_GPS_MARKER_TYPE_TRIGGER                              8
#define RSRFSIGGEN_VAL_GPS_MARKER_TYPE_DISABLED                             9

// RsRFSigGen_rngGPSClockMode
#define RSRFSIGGEN_VAL_GPS_CLOCK_MODE_SAMP                                  0
#define RSRFSIGGEN_VAL_GPS_CLOCK_MODE_MSAMP                                 1

// RsRFSigGen_rngGPSLocalizationReadOutMode
#define RSRFSIGGEN_VAL_GPS_LOCALIZATION_READ_OUT_MODE_CYCLIC                0
#define RSRFSIGGEN_VAL_GPS_LOCALIZATION_READ_OUT_MODE_ROUNDTRIP             1
#define RSRFSIGGEN_VAL_GPS_LOCALIZATION_READ_OUT_MODE_ONEWAY                2

// RsRFSigGen_rngGPSPositionFormat
#define RSRFSIGGEN_VAL_GPS_LOCALIZATION_POSITION_FORMAT_DMS                 0
#define RSRFSIGGEN_VAL_GPS_LOCALIZATION_POSITION_FORMAT_DECIMAL             1

// RsRFSigGen_rngGPSLatitudeDirection
#define RSRFSIGGEN_VAL_GPS_LOCALIZATION_DIRECTION_NORTH                     0
#define RSRFSIGGEN_VAL_GPS_LOCALIZATION_DIRECTION_SOUTH                     1

// RsRFSigGen_rngGPSLongitudeDirection
#define RSRFSIGGEN_VAL_GPS_LOCALIZATION_DIRECTION_EAST                      0
#define RSRFSIGGEN_VAL_GPS_LOCALIZATION_DIRECTION_WEST                      1

// RsRFSigGen_rngGPSDataSource
#define RSRFSIGGEN_VAL_GPS_DATA_SOURCE_ZERO                                 0
#define RSRFSIGGEN_VAL_GPS_DATA_SOURCE_ONE                                  1
#define RSRFSIGGEN_VAL_GPS_DATA_SOURCE_PATTERN                              2
#define RSRFSIGGEN_VAL_GPS_DATA_SOURCE_PN9                                  3
#define RSRFSIGGEN_VAL_GPS_DATA_SOURCE_PN11                                 4
#define RSRFSIGGEN_VAL_GPS_DATA_SOURCE_PN15                                 5
#define RSRFSIGGEN_VAL_GPS_DATA_SOURCE_PN16                                 6
#define RSRFSIGGEN_VAL_GPS_DATA_SOURCE_PN20                                 7
#define RSRFSIGGEN_VAL_GPS_DATA_SOURCE_PN21                                 8
#define RSRFSIGGEN_VAL_GPS_DATA_SOURCE_PN23                                 9
#define RSRFSIGGEN_VAL_GPS_DATA_SOURCE_DLIST                                10
#define RSRFSIGGEN_VAL_GPS_DATA_SOURCE_REAL                                 11

// RsRFSigGen_rngGPSRangingCode
#define RSRFSIGGEN_VAL_GPS_RANGING_CODE_CA                                  0

// RsRFSigGen_rngGPSNMESCodeOnL2
#define RSRFSIGGEN_VAL_GPS_NMES_CODEONL2_RESERVED                           0
#define RSRFSIGGEN_VAL_GPS_NMES_CODEONL2_PON                                1
#define RSRFSIGGEN_VAL_GPS_NMES_CODEONL2_CAON                               2

// RsRFSigGen_rngGSMMode
#define RSRFSIGGEN_VAL_GSM_MODE_UNFRAMED                                    0
#define RSRFSIGGEN_VAL_GSM_MODE_SINGLE                                      1
#define RSRFSIGGEN_VAL_GSM_MODE_DOUBLE                                      2
#define RSRFSIGGEN_VAL_GSM_MODE_MULT                                        3

// RsRFSigGen_rngGSMSymbolRateMode
#define RSRFSIGGEN_VAL_GSM_SYMBOL_RATE_MODE_NSR                             0
#define RSRFSIGGEN_VAL_GSM_SYMBOL_RATE_MODE_HSR                             1

// RsRFSigGen_rngGSMSimulationMode
#define RSRFSIGGEN_VAL_GSM_UNFRAMED_MOD_SIGNAL_GSM                          0
#define RSRFSIGGEN_VAL_GSM_UNFRAMED_MOD_SIGNAL_AQPSK                        1
#define RSRFSIGGEN_VAL_GSM_UNFRAMED_MOD_SIGNAL_EDGE                         2
#define RSRFSIGGEN_VAL_GSM_UNFRAMED_MOD_SIGNAL_16QAM                        3
#define RSRFSIGGEN_VAL_GSM_UNFRAMED_MOD_SIGNAL_32QAM                        4
#define RSRFSIGGEN_VAL_GSM_UNFRAMED_MOD_SIGNAL_HSRQPSK                      5
#define RSRFSIGGEN_VAL_GSM_UNFRAMED_MOD_SIGNAL_HSR16QAM                     6
#define RSRFSIGGEN_VAL_GSM_UNFRAMED_MOD_SIGNAL_HSR32QAM                     7

// RsRFSigGen_rngGSMModulation
#define RSRFSIGGEN_VAL_GSM_MODULATION_MSK                                   0
#define RSRFSIGGEN_VAL_GSM_MODULATION_FSK2                                  1

// RsRFSigGen_rngGSMFunction
#define RSRFSIGGEN_VAL_GSM_POWER_RAMP_SHAPE_LINEAR                          0
#define RSRFSIGGEN_VAL_GSM_POWER_RAMP_SHAPE_COSINE                          1

// RsRFSigGen_rngGSMMarkerMode
#define RSRFSIGGEN_VAL_GSM_MARKER_TYPE_SDEF                                 0
#define RSRFSIGGEN_VAL_GSM_MARKER_TYPE_FRAME                                1
#define RSRFSIGGEN_VAL_GSM_MARKER_TYPE_SLOT                                 2
#define RSRFSIGGEN_VAL_GSM_MARKER_TYPE_PULSE                                3
#define RSRFSIGGEN_VAL_GSM_MARKER_TYPE_PATTERN                              4
#define RSRFSIGGEN_VAL_GSM_MARKER_TYPE_RATIO                                5
#define RSRFSIGGEN_VAL_GSM_MARKER_TYPE_TRIG                                 6

// RsRFSigGen_rngGSMClockMode
#define RSRFSIGGEN_VAL_GSM_CLOCK_MODE_BIT                                   0
#define RSRFSIGGEN_VAL_GSM_CLOCK_MODE_SYMBOL                                1
#define RSRFSIGGEN_VAL_GSM_CLOCK_MODE_MSYMBOL                               2
#define RSRFSIGGEN_VAL_GSM_CLOCK_MODE_FSYMBOL                               3

// RsRFSigGen_rngGSMBurstType
#define RSRFSIGGEN_VAL_GSM_BURST_GMSK_FULL                                  0
#define RSRFSIGGEN_VAL_GSM_BURST_GMSK_HALF                                  1
#define RSRFSIGGEN_VAL_GSM_BURST_QPSK_FULL_FULL                             2
#define RSRFSIGGEN_VAL_GSM_BURST_QPSK_FULL_HALF                             3
#define RSRFSIGGEN_VAL_GSM_BURST_QPSK_HALF_HALF                             4
#define RSRFSIGGEN_VAL_GSM_BURST_EDGE                                       5
#define RSRFSIGGEN_VAL_GSM_BURST_QAM16                                      6
#define RSRFSIGGEN_VAL_GSM_BURST_QAM32                                      7
#define RSRFSIGGEN_VAL_GSM_BURST_SYNC                                       8
#define RSRFSIGGEN_VAL_GSM_BURST_FREQ_CORRECTIONS                           9
#define RSRFSIGGEN_VAL_GSM_BURST_DUMMY                                      10
#define RSRFSIGGEN_VAL_GSM_BURST_ACCESS                                     11
#define RSRFSIGGEN_VAL_GSM_BURST_ALL_GMSK                                   12
#define RSRFSIGGEN_VAL_GSM_BURST_ALL_QPSK                                   13
#define RSRFSIGGEN_VAL_GSM_BURST_ALL_EDGE                                   14
#define RSRFSIGGEN_VAL_GSM_BURST_ALL_QAM16                                  15
#define RSRFSIGGEN_VAL_GSM_BURST_ALL_QAM32                                  16
#define RSRFSIGGEN_VAL_GSM_BURST_ALL_HQPSK                                  17
#define RSRFSIGGEN_VAL_GSM_BURST_ALL_H16QAM                                 18
#define RSRFSIGGEN_VAL_GSM_BURST_ALL_H32QAM                                 19

// RsRFSigGen_rngGSMSlotLevel
#define RSRFSIGGEN_VAL_GSM_SLOT_LEVEL_OFF                                   0
#define RSRFSIGGEN_VAL_GSM_SLOT_LEVEL_ATT                                   1
#define RSRFSIGGEN_VAL_GSM_SLOT_LEVEL_FULL                                  2

// RsRFSigGen_rngGSMData
#define RSRFSIGGEN_VAL_GSM_DATA_FIELD_OF_SLOT_PN9                           0
#define RSRFSIGGEN_VAL_GSM_DATA_FIELD_OF_SLOT_PN11                          1
#define RSRFSIGGEN_VAL_GSM_DATA_FIELD_OF_SLOT_PN15                          2
#define RSRFSIGGEN_VAL_GSM_DATA_FIELD_OF_SLOT_PN16                          3
#define RSRFSIGGEN_VAL_GSM_DATA_FIELD_OF_SLOT_PN20                          4
#define RSRFSIGGEN_VAL_GSM_DATA_FIELD_OF_SLOT_PN21                          5
#define RSRFSIGGEN_VAL_GSM_DATA_FIELD_OF_SLOT_PN23                          6
#define RSRFSIGGEN_VAL_GSM_DATA_FIELD_OF_SLOT_DLIST                         7
#define RSRFSIGGEN_VAL_GSM_DATA_FIELD_OF_SLOT_ALL0                          8
#define RSRFSIGGEN_VAL_GSM_DATA_FIELD_OF_SLOT_ALL1                          9
#define RSRFSIGGEN_VAL_GSM_DATA_FIELD_OF_SLOT_PATTERN                       10

// RsRFSigGen_rngGSMSlotFilterType
#define RSRFSIGGEN_VAL_GSM_SLOT_FILTER_TYPE_ENPS                            0
#define RSRFSIGGEN_VAL_GSM_SLOT_FILTER_TYPE_EWPS                            1

// RsRFSigGen_rngGSMTrainingSequence
#define RSRFSIGGEN_VAL_GSM_TRAINING_SEQ_T0                                  0
#define RSRFSIGGEN_VAL_GSM_TRAINING_SEQ_T1                                  1
#define RSRFSIGGEN_VAL_GSM_TRAINING_SEQ_T2                                  2
#define RSRFSIGGEN_VAL_GSM_TRAINING_SEQ_T3                                  3
#define RSRFSIGGEN_VAL_GSM_TRAINING_SEQ_T4                                  4
#define RSRFSIGGEN_VAL_GSM_TRAINING_SEQ_T5                                  5
#define RSRFSIGGEN_VAL_GSM_TRAINING_SEQ_T6                                  6
#define RSRFSIGGEN_VAL_GSM_TRAINING_SEQ_T7                                  7
#define RSRFSIGGEN_VAL_GSM_TRAINING_SEQ_USER                                8

// RsRFSigGen_rngGSMExtendedTrainingSequence
#define RSRFSIGGEN_VAL_GSM_EXTERN_TRAINING_SEQ_STANDARD                     0
#define RSRFSIGGEN_VAL_GSM_EXTERN_TRAINING_SEQ_CTS                          1
#define RSRFSIGGEN_VAL_GSM_EXTERN_TRAINING_SEQ_COMPACT                      2
#define RSRFSIGGEN_VAL_GSM_EXTERN_TRAINING_SEQ_USER                         3

// RsRFSigGen_rngGSMTrainingSequenceSync
#define RSRFSIGGEN_VAL_GSM_SYNC_SEQ_ACCESS_BURST_T0                         0
#define RSRFSIGGEN_VAL_GSM_SYNC_SEQ_ACCESS_BURST_T1                         1
#define RSRFSIGGEN_VAL_GSM_SYNC_SEQ_ACCESS_BURST_T2                         2
#define RSRFSIGGEN_VAL_GSM_SYNC_SEQ_ACCESS_BURST_USER                       3

// RsRFSigGen_rngGSMFixed
#define RSRFSIGGEN_VAL_GSM_FIX_FIELD_FREQ_CORR_BURST_STANDARD               0
#define RSRFSIGGEN_VAL_GSM_FIX_FIELD_FREQ_CORR_BURST_COMPACT                1
#define RSRFSIGGEN_VAL_GSM_FIX_FIELD_FREQ_CORR_BURST_USER                   2

// RsRFSigGen_rngGSMModulationType
#define RSRFSIGGEN_VAL_GSM_MODULATION_AQPSK                                 0
#define RSRFSIGGEN_VAL_GSM_MODULATION_8PSK                                  1
#define RSRFSIGGEN_VAL_GSM_MODULATION_16QAM                                 2
#define RSRFSIGGEN_VAL_GSM_MODULATION_32QAM                                 3
#define RSRFSIGGEN_VAL_GSM_MODULATION_HQPSK                                 4

// RsRFSigGen_rngGSMTrainingSequenceSet
#define RSRFSIGGEN_VAL_GSM_TS_SET1                                          1
#define RSRFSIGGEN_VAL_GSM_TS_SET2                                          2

// RsRFSigGen_rngW3GPPMarkerMode
#define RSRFSIGGEN_VAL_W3GPP_MARKER_MODE_SLOT                               0
#define RSRFSIGGEN_VAL_W3GPP_MARKER_MODE_RFRAME                             1
#define RSRFSIGGEN_VAL_W3GPP_MARKER_MODE_CSPERIOD                           2
#define RSRFSIGGEN_VAL_W3GPP_MARKER_MODE_SFNR                               3
#define RSRFSIGGEN_VAL_W3GPP_MARKER_MODE_USER                               4

// RsRFSigGen_rngW3GPPOCNSModeBS
#define RSRFSIGGEN_VAL_W3GPP_OCNS_MODE_STANDARD                             0
#define RSRFSIGGEN_VAL_W3GPP_OCNS_MODE_HSDPA                                1
#define RSRFSIGGEN_VAL_W3GPP_OCNS_MODE_HSDPA2                               2

// RsRFSigGen_rngW3GPPPageIndicatorsFrame
#define RSRFSIGGEN_VAL_W3GPP_PAGE_INDICATOR_D18                             0
#define RSRFSIGGEN_VAL_W3GPP_PAGE_INDICATOR_D36                             1
#define RSRFSIGGEN_VAL_W3GPP_PAGE_INDICATOR_D72                             2
#define RSRFSIGGEN_VAL_W3GPP_PAGE_INDICATOR_D144                            3

// RsRFSigGen_rngW3GPPTransmitDiversity
#define RSRFSIGGEN_VAL_W3GPP_TRANSMIT_DIVERSITY_SANT                        0
#define RSRFSIGGEN_VAL_W3GPP_TRANSMIT_DIVERSITY_ANT1                        1
#define RSRFSIGGEN_VAL_W3GPP_TRANSMIT_DIVERSITY_ANT2                        2

// RsRFSigGen_rngW3GPPCompressedModeMethod
#define RSRFSIGGEN_VAL_W3GPP_COMPRESSED_METHOD_HLSCHEDULING                 0
#define RSRFSIGGEN_VAL_W3GPP_COMPRESSED_METHOD_PUNCTURING                   1
#define RSRFSIGGEN_VAL_W3GPP_COMPRESSED_METHOD_SF2                          2

// RsRFSigGen_rngW3GPPFrameStructure
#define RSRFSIGGEN_VAL_W3GPP_COMPRESSED_FRAME_STRUCT_A                      0
#define RSRFSIGGEN_VAL_W3GPP_COMPRESSED_FRAME_STRUCT_B                      1

// RsRFSigGen_rngW3GPPPowerOffsetMode
#define RSRFSIGGEN_VAL_W3GPP_COMPRESSED_POWER_OFFSET_AUTO                   0
#define RSRFSIGGEN_VAL_W3GPP_COMPRESSED_POWER_OFFSET_USER                   1

// RsRFSigGen_rngW3GPPSymbolRate
#define RSRFSIGGEN_VAL_W3GPP_SYMBOL_RATE_D7K5                               0
#define RSRFSIGGEN_VAL_W3GPP_SYMBOL_RATE_D15K                               1
#define RSRFSIGGEN_VAL_W3GPP_SYMBOL_RATE_D30K                               2
#define RSRFSIGGEN_VAL_W3GPP_SYMBOL_RATE_D60K                               3
#define RSRFSIGGEN_VAL_W3GPP_SYMBOL_RATE_D120K                              4
#define RSRFSIGGEN_VAL_W3GPP_SYMBOL_RATE_D240K                              5
#define RSRFSIGGEN_VAL_W3GPP_SYMBOL_RATE_D480K                              6
#define RSRFSIGGEN_VAL_W3GPP_SYMBOL_RATE_D960K                              7

// RsRFSigGen_rngW3GPPCrestFactor
#define RSRFSIGGEN_VAL_W3GPP_CREST_MIN                                      0
#define RSRFSIGGEN_VAL_W3GPP_CREST_AVG                                      1
#define RSRFSIGGEN_VAL_W3GPP_CREST_WORST                                    2

// RsRFSigGen_rngW3GPPChannelTypeBS
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_PCPICH                            0
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_SCPICH                            1
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_PSCH                              2
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_SSCH                              3
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_PCCPCH                            4
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_SCCPCH                            5
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_PICH                              6
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_APAICH                            7
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_AICH                              8
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_PDSCH                             9
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_DPCCH                             10
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_DPCH                              11
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_HS_SCCH                           12
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_HS_QPSK                           13
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_HS_QAM                            14
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_HS_16QAM                          15
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_HS_64QAM                          16
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_HS_MIMO                           17
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_EAGCH                             18
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_ERGCH                             19
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_EHICH                             20
#define RSRFSIGGEN_VAL_W3GPP_CHANNEL_TYPE_FDPCH                             21

// RsRFSigGen_rngW3GPPPilotLength
#define RSRFSIGGEN_VAL_W3GPP_PILOT_LENGTH_BIT0                              0
#define RSRFSIGGEN_VAL_W3GPP_PILOT_LENGTH_BIT2                              1
#define RSRFSIGGEN_VAL_W3GPP_PILOT_LENGTH_BIT4                              2
#define RSRFSIGGEN_VAL_W3GPP_PILOT_LENGTH_BIT8                              3
#define RSRFSIGGEN_VAL_W3GPP_PILOT_LENGTH_BIT16                             4

// RsRFSigGen_rngW3GPPTPCDataSource
#define RSRFSIGGEN_VAL_W3GPP_DATA_SOURCE_ZERO                               0
#define RSRFSIGGEN_VAL_W3GPP_DATA_SOURCE_ONE                                1
#define RSRFSIGGEN_VAL_W3GPP_DATA_SOURCE_PATTERN                            2
#define RSRFSIGGEN_VAL_W3GPP_DATA_SOURCE_DLIST                              3

// RsRFSigGen_rngW3GPPTPCReadOutMode
#define RSRFSIGGEN_VAL_W3GPP_TPC_READ_CONT                                  0
#define RSRFSIGGEN_VAL_W3GPP_TPC_READ_S0A                                   1
#define RSRFSIGGEN_VAL_W3GPP_TPC_READ_S1A                                   2
#define RSRFSIGGEN_VAL_W3GPP_TPC_READ_S01A                                  3
#define RSRFSIGGEN_VAL_W3GPP_TPC_READ_S10A                                  4

// RsRFSigGen_rngW3GPPTypeOfCell
#define RSRFSIGGEN_VAL_W3GPP_CELL_SERVING                                   0
#define RSRFSIGGEN_VAL_W3GPP_CELL_NONSERVING                                1

// RsRFSigGen_rngW3GPPERGCHEDCHTTI
#define RSRFSIGGEN_VAL_W3GPP_EDCHTTI_2MS                                    0
#define RSRFSIGGEN_VAL_W3GPP_EDCHTTI_10MS                                   1

// RsRFSigGen_rngW3GPPAbsoluteGrantScope
#define RSRFSIGGEN_VAL_W3GPP_EAGCH_GRANT_SCOPE_ALL                          0
#define RSRFSIGGEN_VAL_W3GPP_EAGCH_GRANT_SCOPE_PER                          1

// RsRFSigGen_rngW3GPPEnhPCPICHPattern
#define RSRFSIGGEN_VAL_W3GPP_ENH_PCPICH_PATTERN_ANT1                        0
#define RSRFSIGGEN_VAL_W3GPP_ENH_PCPICH_PATTERN_ANT2                        1

// RsRFSigGen_rngW3GPPEnhHSDPAModulation
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_MODULATION_QPSK                      0
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_MODULATION_16QAM                     1
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_MODULATION_64QAM                     2

// RsRFSigGen_rngW3GPPHSPredefined
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P1QPSK                       0
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P1QAM16                      1
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P2QPSK                       2
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P2QAM16                      3
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P3QPSK                       4
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P3QAM16                      5
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P4QPSK                       6
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P5QPSK                       7
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P6QPSK                       8
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P6QAM16                      9
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P7QPSK                       10
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P8QAM64                      11
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P9QAM16QPSK                  12
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P10QPSK                      13
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P10QAM16                     14
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P11QAM64QAM16                15
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_P12QPSK                      16
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_PRED_USER                         17

// RsRFSigGen_rngW3GPPHSSCCHType
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_SCCH_NORM                         0
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_SCCH_LOP                          1
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_SCCH_MIMO                         2

// RsRFSigGen_rngW3GPPHSDPATBSTable
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_TBS_TAB0                          0
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_TBS_TAB1                          1

// RsRFSigGen_rngW3GPPHSDPAHARQMode
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_HARQ_MODE_CACK                    0
#define RSRFSIGGEN_VAL_W3GPP_ENH_HSDPA_HS_HARQ_MODE_CNACK                   1

// RsRFSigGen_rngW3GPPModeUE
#define RSRFSIGGEN_VAL_W3GPP_MST_MODE_PRAC                                  0
#define RSRFSIGGEN_VAL_W3GPP_MST_MODE_PPRA                                  1
#define RSRFSIGGEN_VAL_W3GPP_MST_MODE_PCPC                                  2
#define RSRFSIGGEN_VAL_W3GPP_MST_MODE_PPCP                                  3
#define RSRFSIGGEN_VAL_W3GPP_MST_MODE_DPCD                                  4

// RsRFSigGen_rngW3GPPScramblingMode
#define RSRFSIGGEN_VAL_W3GPP_SCRAMB_MODE_OFF                                0
#define RSRFSIGGEN_VAL_W3GPP_SCRAMB_MODE_SHORT                              1
#define RSRFSIGGEN_VAL_W3GPP_SCRAMB_MODE_LONG                               2

// RsRFSigGen_rngW3GPPDataSourcePRACH
#define RSRFSIGGEN_VAL_W3GPP_PRACH_DATA_SOURCE_ZERO                         0
#define RSRFSIGGEN_VAL_W3GPP_PRACH_DATA_SOURCE_ONE                          1
#define RSRFSIGGEN_VAL_W3GPP_PRACH_DATA_SOURCE_PATTERN                      2
#define RSRFSIGGEN_VAL_W3GPP_PRACH_DATA_SOURCE_PN9                          3
#define RSRFSIGGEN_VAL_W3GPP_PRACH_DATA_SOURCE_PN15                         4
#define RSRFSIGGEN_VAL_W3GPP_PRACH_DATA_SOURCE_PN16                         5
#define RSRFSIGGEN_VAL_W3GPP_PRACH_DATA_SOURCE_PN20                         6
#define RSRFSIGGEN_VAL_W3GPP_PRACH_DATA_SOURCE_PN21                         7
#define RSRFSIGGEN_VAL_W3GPP_PRACH_DATA_SOURCE_PN23                         8
#define RSRFSIGGEN_VAL_W3GPP_PRACH_DATA_SOURCE_DLIST                        9
#define RSRFSIGGEN_VAL_W3GPP_PRACH_DATA_SOURCE_USB                          10

// RsRFSigGen_rngW3GPPCodingType
#define RSRFSIGGEN_VAL_W3GPP_ENH_CCOD_TYPE_TB168                            0
#define RSRFSIGGEN_VAL_W3GPP_ENH_CCOD_TYPE_TB360                            1
#define RSRFSIGGEN_VAL_W3GPP_ENH_CCOD_TYPE_TU168                            2
#define RSRFSIGGEN_VAL_W3GPP_ENH_CCOD_TYPE_TU360                            3

// RsRFSigGen_rngW3GPPPowerControlPreambleLength
#define RSRFSIGGEN_VAL_W3GPP_SLOT_LENGTH_S0                                 0
#define RSRFSIGGEN_VAL_W3GPP_SLOT_LENGTH_S8                                 1

// RsRFSigGen_rngW3GPPFBIMode
#define RSRFSIGGEN_VAL_W3GPP_PCPC_FBI_MODE_OFF                              0
#define RSRFSIGGEN_VAL_W3GPP_PCPC_FBI_MODE_D1B                              1
#define RSRFSIGGEN_VAL_W3GPP_PCPC_FBI_MODE_D2B                              2

// RsRFSigGen_rngW3GPPTPCMode
#define RSRFSIGGEN_VAL_W3GPP_DPCCH_TPC_MODE_D2B                             0
#define RSRFSIGGEN_VAL_W3GPP_DPCCH_TPC_MODE_D4B                             1

// RsRFSigGen_rngW3GPPHARQACK
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_MIMO_HACK_DTX                          0
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_MIMO_HACK_SACK                         1
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_MIMO_HACK_SNACK                        2
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_MIMO_HACK_AACK                         3
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_MIMO_HACK_ANACK                        4
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_MIMO_HACK_NACK                         5
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_MIMO_HACK_NNACK                        6

// RsRFSigGen_rngW3GPPCQIType
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_MIMO_CQI_TAST                          0
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_MIMO_CQI_TADT                          1
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_MIMO_CQI_TB                            2

// RsRFSigGen_rngW3GPPOverallSymbolRateDPDCHUE
#define RSRFSIGGEN_VAL_W3GPP_DPDCH_SYMBOL_RATE_D7K5                         0
#define RSRFSIGGEN_VAL_W3GPP_DPDCH_SYMBOL_RATE_D15K                         1
#define RSRFSIGGEN_VAL_W3GPP_DPDCH_SYMBOL_RATE_D30K                         2
#define RSRFSIGGEN_VAL_W3GPP_DPDCH_SYMBOL_RATE_D60K                         3
#define RSRFSIGGEN_VAL_W3GPP_DPDCH_SYMBOL_RATE_D120K                        4
#define RSRFSIGGEN_VAL_W3GPP_DPDCH_SYMBOL_RATE_D240K                        5
#define RSRFSIGGEN_VAL_W3GPP_DPDCH_SYMBOL_RATE_D480K                        6
#define RSRFSIGGEN_VAL_W3GPP_DPDCH_SYMBOL_RATE_D960K                        7
#define RSRFSIGGEN_VAL_W3GPP_DPDCH_SYMBOL_RATE_2_D960K                      8
#define RSRFSIGGEN_VAL_W3GPP_DPDCH_SYMBOL_RATE_3_D960K                      9
#define RSRFSIGGEN_VAL_W3GPP_DPDCH_SYMBOL_RATE_4_D960K                      10
#define RSRFSIGGEN_VAL_W3GPP_DPDCH_SYMBOL_RATE_5_D960K                      11
#define RSRFSIGGEN_VAL_W3GPP_DPDCH_SYMBOL_RATE_6_D960K                      12

// RsRFSigGen_rngW3GPPChannelCodingTypeUE1
#define RSRFSIGGEN_VAL_W3GPP_ENH_CCOD_TYPE_M12K2                            0
#define RSRFSIGGEN_VAL_W3GPP_ENH_CCOD_TYPE_M64K                             1
#define RSRFSIGGEN_VAL_W3GPP_ENH_CCOD_TYPE_M144K                            2
#define RSRFSIGGEN_VAL_W3GPP_ENH_CCOD_TYPE_M384K                            3
#define RSRFSIGGEN_VAL_W3GPP_ENH_CCOD_TYPE_AMR                              4
#define RSRFSIGGEN_VAL_W3GPP_ENH_CCOD_TYPE_USER                             5

// RsRFSigGen_rngW3GPPTransportTimeInterval
#define RSRFSIGGEN_VAL_W3GPP_TTI_10MS                                       0
#define RSRFSIGGEN_VAL_W3GPP_TTI_20MS                                       1
#define RSRFSIGGEN_VAL_W3GPP_TTI_40MS                                       2
#define RSRFSIGGEN_VAL_W3GPP_TTI_80MS                                       3

// RsRFSigGen_rngW3GPPSizeOfCRC
#define RSRFSIGGEN_VAL_W3GPP_CRC_NONE                                       0
#define RSRFSIGGEN_VAL_W3GPP_CRC_8                                          1
#define RSRFSIGGEN_VAL_W3GPP_CRC_12                                         2
#define RSRFSIGGEN_VAL_W3GPP_CRC_16                                         3
#define RSRFSIGGEN_VAL_W3GPP_CRC_24                                         4

// RsRFSigGen_rngW3GPPErrorProtection
#define RSRFSIGGEN_VAL_W3GPP_ENH_ERRPROT_NONE                               0
#define RSRFSIGGEN_VAL_W3GPP_ENH_ERRPROT_TURBO3                             1
#define RSRFSIGGEN_VAL_W3GPP_ENH_ERRPROT_CONV2                              2
#define RSRFSIGGEN_VAL_W3GPP_ENH_ERRPROT_CONV3                              3

// RsRFSigGen_rngW3GPPInsertErrorsOn
#define RSRFSIGGEN_VAL_W3GPP_DERR_LAYER_PHYS                                0
#define RSRFSIGGEN_VAL_W3GPP_DERR_LAYER_TRAN                                1

// RsRFSigGen_rngW3GPPFRCOverallSymbolRate
#define RSRFSIGGEN_VAL_W3GPP_HSUPA_EDPCCH_FRC_ORAT_D15K                     0
#define RSRFSIGGEN_VAL_W3GPP_HSUPA_EDPCCH_FRC_ORAT_D30K                     1
#define RSRFSIGGEN_VAL_W3GPP_HSUPA_EDPCCH_FRC_ORAT_D60K                     2
#define RSRFSIGGEN_VAL_W3GPP_HSUPA_EDPCCH_FRC_ORAT_D120K                    3
#define RSRFSIGGEN_VAL_W3GPP_HSUPA_EDPCCH_FRC_ORAT_D240K                    4
#define RSRFSIGGEN_VAL_W3GPP_HSUPA_EDPCCH_FRC_ORAT_D480K                    5
#define RSRFSIGGEN_VAL_W3GPP_HSUPA_EDPCCH_FRC_ORAT_D960K                    6
#define RSRFSIGGEN_VAL_W3GPP_HSUPA_EDPCCH_FRC_ORAT_D1920K                   7
#define RSRFSIGGEN_VAL_W3GPP_HSUPA_EDPCCH_FRC_ORAT_D2X1920K                 8
#define RSRFSIGGEN_VAL_W3GPP_HSUPA_EDPCCH_FRC_ORAT_D2X960K2X1920K           9

// RsRFSigGen_rngW3GPPTBSTable
#define RSRFSIGGEN_VAL_W3GPP_HSUPA_EDPCCH_FRC_TBS_TAB0TTI2                  0
#define RSRFSIGGEN_VAL_W3GPP_HSUPA_EDPCCH_FRC_TBS_TAB1TTI2                  1
#define RSRFSIGGEN_VAL_W3GPP_HSUPA_EDPCCH_FRC_TBS_TAB2TTI2                  2
#define RSRFSIGGEN_VAL_W3GPP_HSUPA_EDPCCH_FRC_TBS_TAB3TTI2                  3
#define RSRFSIGGEN_VAL_W3GPP_HSUPA_EDPCCH_FRC_TBS_TAB0TTI10                 4
#define RSRFSIGGEN_VAL_W3GPP_HSUPA_EDPCCH_FRC_TBS_TAB1TTI10                 5

// RsRFSigGen_rngW3GPPOverallSymbolRate
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D15K                       0
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D30K                       1
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D60K                       2
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D120K                      3
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D240K                      4
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D480K                      5
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D960K                      6
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D1920K                     7
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D2X1920K                   8
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D2X960K2X1920K             9
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D2x960KI                   10
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D2x960KQ                   11
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D2X1920KI                  12
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D2X1920KQ                  13
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D2X960K2X1920KI            14
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D2X960K2X1920KQ            15
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D2880K                     16
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D3840K                     17
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D4800K                     18
#define RSRFSIGGEN_VAL_W3GPP_OVERALL_SYMBOL_RATE_D5760K                     19

// RsRFSigGen_rngW3GPPEDPDCHModulation
#define RSRFSIGGEN_VAL_W3GPP_EDPDCH_MODULATION_BPSK                         0
#define RSRFSIGGEN_VAL_W3GPP_EDPDCH_MODULATION_4PAM                         1

// RsRFSigGen_rngW3GPPHSUPAHARQMode
#define RSRFSIGGEN_VAL_W3GPP_HARQ_SIMULATION_VIRTUAL                        0
#define RSRFSIGGEN_VAL_W3GPP_HARQ_SIMULATION_FEEDBACK                       1

// RsRFSigGen_rngW3GPPHSUPAACKDefinition
#define RSRFSIGGEN_VAL_W3GPP_HARQ_FEEDBACK_ACK_DEFINITIONS_HIGH             0
#define RSRFSIGGEN_VAL_W3GPP_HARQ_FEEDBACK_ACK_DEFINITIONS_LOW              1

// RsRFSigGen_rngC2kMarkerMode
#define RSRFSIGGEN_VAL_C2K_MARKER_MODE_PCGR                                 0
#define RSRFSIGGEN_VAL_C2K_MARKER_MODE_RFR                                  1
#define RSRFSIGGEN_VAL_C2K_MARKER_MODE_SCFR                                 2
#define RSRFSIGGEN_VAL_C2K_MARKER_MODE_SFR                                  3
#define RSRFSIGGEN_VAL_C2K_MARKER_MODE_ESEC                                 4
#define RSRFSIGGEN_VAL_C2K_MARKER_MODE_CSP                                  5
#define RSRFSIGGEN_VAL_C2K_MARKER_MODE_USER                                 6
#define RSRFSIGGEN_VAL_C2K_MARKER_MODE_RAT                                  7

// RsRFSigGen_rngC2kTransmitDiversity
#define RSRFSIGGEN_VAL_C2K_TRANSMIT_DIVERSITY_OFF                           0
#define RSRFSIGGEN_VAL_C2K_TRANSMIT_DIVERSITY_ANT1                          1
#define RSRFSIGGEN_VAL_C2K_TRANSMIT_DIVERSITY_ANT2                          2

// RsRFSigGen_rngC2kDiversityMode
#define RSRFSIGGEN_VAL_C2K_DIVERSITY_OTD                                    0
#define RSRFSIGGEN_VAL_C2K_DIVERSITY_STS                                    1

// RsRFSigGen_rngC2kCrestFactor
#define RSRFSIGGEN_VAL_C2K_CREST_MIN                                        0
#define RSRFSIGGEN_VAL_C2K_CREST_AVG                                        1
#define RSRFSIGGEN_VAL_C2K_CREST_WORST                                      2

// RsRFSigGen_rngC2kPredefinedDataRate
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR1K2                                  0
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR1K3                                  1
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR1K5                                  2
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR1K8                                  3
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR2K4                                  4
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR2K7                                  5
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR3K6                                  6
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR4K8                                  7
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR7K2                                  8
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR9K6                                  9
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR14K4                                 10
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR19K2                                 11
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR28K8                                 12
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR38K4                                 13
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR57K6                                 14
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR76K8                                 15
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR115K2                                16
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR153K6                                17
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR230K4                                18
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR259K2                                19
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR307K2                                20
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR460K8                                21
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR518K4                                22
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR614K4                                23
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_DR1036K8                               24
#define RSRFSIGGEN_VAL_C2K_DATA_RATE_NONE                                   25

// RsRFSigGen_rngC2kDataSource
#define RSRFSIGGEN_VAL_C2K_DATA_SOURCE_ZERO                                 0
#define RSRFSIGGEN_VAL_C2K_DATA_SOURCE_ONE                                  1
#define RSRFSIGGEN_VAL_C2K_DATA_SOURCE_PATTERN                              2
#define RSRFSIGGEN_VAL_C2K_DATA_SOURCE_DLIST                                3

// RsRFSigGen_rngC2kReadOutMode
#define RSRFSIGGEN_VAL_C2K_RMODE_CONT                                       0
#define RSRFSIGGEN_VAL_C2K_RMODE_S0A                                        1
#define RSRFSIGGEN_VAL_C2K_RMODE_S1A                                        2
#define RSRFSIGGEN_VAL_C2K_RMODE_S01A                                       3
#define RSRFSIGGEN_VAL_C2K_RMODE_S10A                                       4

// RsRFSigGen_rngC2kCodingMode
#define RSRFSIGGEN_VAL_C2K_CODING_OFF                                       0
#define RSRFSIGGEN_VAL_C2K_CODING_COMP                                      1
#define RSRFSIGGEN_VAL_C2K_CODING_NOIN                                      2
#define RSRFSIGGEN_VAL_C2K_CODING_OINT                                      3

// RsRFSigGen_rngC2kCoderType
#define RSRFSIGGEN_VAL_C2K_CODER_CON2                                       0
#define RSRFSIGGEN_VAL_C2K_CODER_CON3                                       1
#define RSRFSIGGEN_VAL_C2K_CODER_CON4                                       2
#define RSRFSIGGEN_VAL_C2K_CODER_CON6                                       3
#define RSRFSIGGEN_VAL_C2K_CODER_TUR2                                       4
#define RSRFSIGGEN_VAL_C2K_CODER_TUR3                                       5
#define RSRFSIGGEN_VAL_C2K_CODER_TUR4                                       6
#define RSRFSIGGEN_VAL_C2K_CODER_TUR5                                       7
#define RSRFSIGGEN_VAL_C2K_CODER_OFF                                        8
#define RSRFSIGGEN_VAL_C2K_CODER_DEF                                        9

// RsRFSigGen_rngC2kOperationMode
#define RSRFSIGGEN_VAL_C2K_OPERATION_TRAF                                   0
#define RSRFSIGGEN_VAL_C2K_OPERATION_ACC                                    1
#define RSRFSIGGEN_VAL_C2K_OPERATION_EACC                                   2
#define RSRFSIGGEN_VAL_C2K_OPERATION_CCON                                   3

// RsRFSigGen_rngEVDOPhysicalLayerSubtype
#define RSRFSIGGEN_VAL_EVDO_SUBTYPE_S1                                      0
#define RSRFSIGGEN_VAL_EVDO_SUBTYPE_S2                                      1
#define RSRFSIGGEN_VAL_EVDO_SUBTYPE_S3                                      2

// RsRFSigGen_rngEVDOChannelRate
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR38K4                            0
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR76K8                            1
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR4K8                             2
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR9K6                             3
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR19K2                            4
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR153K6                           5
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR307K2                           6
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR614K4                           7
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR921K6                           8
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR1228K8                          9
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR1536K                           10
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR1843K2                          11
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR2457K6                          12
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR3072K                           13
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR460K8                           14
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR768K                            15
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR1075K2                          16
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR2150K4                          17
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR3686K4                          18
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR4300K8                          19
#define RSRFSIGGEN_VAL_EVDO_CCHANNEL_RATE_DR4915K2                          20

// RsRFSigGen_rngEVDORABLength
#define RSRFSIGGEN_VAL_EVDO_RAB_LENGTH_RL8                                  0
#define RSRFSIGGEN_VAL_EVDO_RAB_LENGTH_RL16                                 1
#define RSRFSIGGEN_VAL_EVDO_RAB_LENGTH_RL32                                 2
#define RSRFSIGGEN_VAL_EVDO_RAB_LENGTH_RL64                                 3

// RsRFSigGen_rngEVDOPacketSize
#define RSRFSIGGEN_VAL_EVDO_TU_PACKET_SIZE_PS128                            0
#define RSRFSIGGEN_VAL_EVDO_TU_PACKET_SIZE_PS256                            1
#define RSRFSIGGEN_VAL_EVDO_TU_PACKET_SIZE_PS512                            2
#define RSRFSIGGEN_VAL_EVDO_TU_PACKET_SIZE_PS1024                           3
#define RSRFSIGGEN_VAL_EVDO_TU_PACKET_SIZE_PS1536                           4
#define RSRFSIGGEN_VAL_EVDO_TU_PACKET_SIZE_PS2048                           5
#define RSRFSIGGEN_VAL_EVDO_TU_PACKET_SIZE_PS3072                           6
#define RSRFSIGGEN_VAL_EVDO_TU_PACKET_SIZE_PS4096                           7
#define RSRFSIGGEN_VAL_EVDO_TU_PACKET_SIZE_PS5120                           8
#define RSRFSIGGEN_VAL_EVDO_TU_PACKET_SIZE_PS6144                           9
#define RSRFSIGGEN_VAL_EVDO_TU_PACKET_SIZE_PS8192                           10
#define RSRFSIGGEN_VAL_EVDO_TU_PACKET_SIZE_PS12288                          11
#define RSRFSIGGEN_VAL_EVDO_TU_PACKET_SIZE_PS768                            12
#define RSRFSIGGEN_VAL_EVDO_TU_PACKET_SIZE_PS7168                           13

// RsRFSigGen_rngEVDORPCMode
#define RSRFSIGGEN_VAL_EVDO_RPC_MODE_HOLD                                   0
#define RSRFSIGGEN_VAL_EVDO_RPC_MODE_UP                                     1
#define RSRFSIGGEN_VAL_EVDO_RPC_MODE_DOWN                                   2
#define RSRFSIGGEN_VAL_EVDO_RPC_MODE_RANGE                                  3
#define RSRFSIGGEN_VAL_EVDO_RPC_MODE_PATTERN                                4

// RsRFSigGen_rngEVDOLockPeriod
#define RSRFSIGGEN_VAL_EVDO_DRC_LOCK_PERIOD_DP0                             0
#define RSRFSIGGEN_VAL_EVDO_DRC_LOCK_PERIOD_DP4                             1
#define RSRFSIGGEN_VAL_EVDO_DRC_LOCK_PERIOD_DP8                             2
#define RSRFSIGGEN_VAL_EVDO_DRC_LOCK_PERIOD_DP16                            3

// RsRFSigGen_rngEVDOLockLength
#define RSRFSIGGEN_VAL_EVDO_DRC_LOCK_LENGTH_DL1                             0
#define RSRFSIGGEN_VAL_EVDO_DRC_LOCK_LENGTH_DL4                             2
#define RSRFSIGGEN_VAL_EVDO_DRC_LOCK_LENGTH_DL8                             3
#define RSRFSIGGEN_VAL_EVDO_DRC_LOCK_LENGTH_DL16                            4
#define RSRFSIGGEN_VAL_EVDO_DRC_LOCK_LENGTH_DL32                            5
#define RSRFSIGGEN_VAL_EVDO_DRC_LOCK_LENGTH_DL64                            7

// RsRFSigGen_rngEVDOHARQMode
#define RSRFSIGGEN_VAL_EVDO_HARQ_MODE_OFF                                   0
#define RSRFSIGGEN_VAL_EVDO_HARQ_MODE_ACK                                   1
#define RSRFSIGGEN_VAL_EVDO_HARQ_MODE_NAK                                   2

// RsRFSigGen_rngEVDOModeAT
#define RSRFSIGGEN_VAL_EVDO_OPERATION_TRAF                                  0
#define RSRFSIGGEN_VAL_EVDO_OPERATION_ACC                                   1

// RsRFSigGen_rngEVDOPayload
#define RSRFSIGGEN_VAL_EVDO_PAYLOAD_PS128                                   0
#define RSRFSIGGEN_VAL_EVDO_PAYLOAD_PS256                                   1
#define RSRFSIGGEN_VAL_EVDO_PAYLOAD_PS768                                   2
#define RSRFSIGGEN_VAL_EVDO_PAYLOAD_PS1024                                  3
#define RSRFSIGGEN_VAL_EVDO_PAYLOAD_PS1536                                  4
#define RSRFSIGGEN_VAL_EVDO_PAYLOAD_PS2048                                  5
#define RSRFSIGGEN_VAL_EVDO_PAYLOAD_PS3072                                  6
#define RSRFSIGGEN_VAL_EVDO_PAYLOAD_PS4096                                  7
#define RSRFSIGGEN_VAL_EVDO_PAYLOAD_PS6144                                  8
#define RSRFSIGGEN_VAL_EVDO_PAYLOAD_PS8192                                  9
#define RSRFSIGGEN_VAL_EVDO_PAYLOAD_PS12288                                 10
#define RSRFSIGGEN_VAL_EVDO_PAYLOAD_PS512                                   11

// RsRFSigGen_rngEVDODRCChannelLength
#define RSRFSIGGEN_VAL_EVDO_DRCCHANNEL_LENGTH_DL1                           0
#define RSRFSIGGEN_VAL_EVDO_DRCCHANNEL_LENGTH_DL2                           1
#define RSRFSIGGEN_VAL_EVDO_DRCCHANNEL_LENGTH_DL4                           2
#define RSRFSIGGEN_VAL_EVDO_DRCCHANNEL_LENGTH_DL8                           3

// RsRFSigGen_rngEVDOChannelMode
#define RSRFSIGGEN_VAL_EVDO_ACKCHANNEL_MODE_BPSK                            0
#define RSRFSIGGEN_VAL_EVDO_ACKCHANNEL_MODE_OOK                             1

// RsRFSigGen_rngEVDODataRate
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR9K6                        0
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR19K2                       1
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR38K4                       2
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR4K8                        3
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR76K8                       4
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR153K6                      5
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR307K2                      6
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR614K4                      7
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR921K6                      8
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR1228K8                     9
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR1536K                      10
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR1843K2                     11
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR2457K6                     12
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR3072K                      13
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR460K8                      14
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR768K                       15
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR1075K2                     16
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR2150K4                     17
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR3686K4                     18
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR4300K8                     19
#define RSRFSIGGEN_VAL_EVDO_DCHANNEL_DATA_RATE_DR4915K2                     20

// RsRFSigGen_rngEVDOTriggerSignalDurationUnit
#define RSRFSIGGEN_VAL_EVDO_SIGNAL_DURATION_UNIT_SLOT                       0
#define RSRFSIGGEN_VAL_EVDO_SIGNAL_DURATION_UNIT_CHIP                       1
#define RSRFSIGGEN_VAL_EVDO_SIGNAL_DURATION_UNIT_SEQUENCE                   2

// RsRFSigGen_rngEVDOMarkerMode
#define RSRFSIGGEN_VAL_EVDO_MARKER_TYPE_SLOT                                0
#define RSRFSIGGEN_VAL_EVDO_MARKER_TYPE_PNSPERIOD                           1
#define RSRFSIGGEN_VAL_EVDO_MARKER_TYPE_ESM                                 2
#define RSRFSIGGEN_VAL_EVDO_MARKER_TYPE_CSPERIOD                            3
#define RSRFSIGGEN_VAL_EVDO_MARKER_TYPE_USER                                4
#define RSRFSIGGEN_VAL_EVDO_MARKER_TYPE_RATIO                               5
#define RSRFSIGGEN_VAL_EVDO_MARKER_TYPE_TRIGGER                             6

// RsRFSigGen_rngWLANStandard
#define RSRFSIGGEN_VAL_WLAN_STANDARD_80211A                                 0
#define RSRFSIGGEN_VAL_WLAN_STANDARD_80211B                                 1
#define RSRFSIGGEN_VAL_WLAN_STANDARD_80211G                                 2

// RsRFSigGen_rngWLANPhysicalLayerMode
#define RSRFSIGGEN_VAL_WLAN_PHYS_LAYER_OFDM                                 0
#define RSRFSIGGEN_VAL_WLAN_PHYS_LAYER_CCK                                  1
#define RSRFSIGGEN_VAL_WLAN_PHYS_LAYER_PBCC                                 2

// RsRFSigGen_rngWLANSimulationMode
#define RSRFSIGGEN_VAL_WLAN_SIMULATION_FRAM                                 0
#define RSRFSIGGEN_VAL_WLAN_SIMULATION_UNFR                                 1

// RsRFSigGen_rngWLANFrameType
#define RSRFSIGGEN_VAL_WLAN_FRAME_DATA                                      0
#define RSRFSIGGEN_VAL_WLAN_FRAME_RTS                                       1
#define RSRFSIGGEN_VAL_WLAN_FRAME_CTS                                       2
#define RSRFSIGGEN_VAL_WLAN_FRAME_ACK                                       3

// RsRFSigGen_rngWLANBitRate
#define RSRFSIGGEN_VAL_WLAN_PSDU_BITRATE_6M                                 0
#define RSRFSIGGEN_VAL_WLAN_PSDU_BITRATE_9M                                 1
#define RSRFSIGGEN_VAL_WLAN_PSDU_BITRATE_12M                                2
#define RSRFSIGGEN_VAL_WLAN_PSDU_BITRATE_18M                                3
#define RSRFSIGGEN_VAL_WLAN_PSDU_BITRATE_24M                                4
#define RSRFSIGGEN_VAL_WLAN_PSDU_BITRATE_36M                                5
#define RSRFSIGGEN_VAL_WLAN_PSDU_BITRATE_48M                                6
#define RSRFSIGGEN_VAL_WLAN_PSDU_BITRATE_54M                                7
#define RSRFSIGGEN_VAL_WLAN_PSDU_BITRATE_1M                                 8
#define RSRFSIGGEN_VAL_WLAN_PSDU_BITRATE_2M                                 9
#define RSRFSIGGEN_VAL_WLAN_PSDU_BITRATE_5M5                                10
#define RSRFSIGGEN_VAL_WLAN_PSDU_BITRATE_11M                                11
#define RSRFSIGGEN_VAL_WLAN_PSDU_BITRATE_22M                                12

// RsRFSigGen_rngWLANScrambling
#define RSRFSIGGEN_VAL_WLAN_SCRAMBLING_OFF                                  0
#define RSRFSIGGEN_VAL_WLAN_SCRAMBLING_RAND                                 1
#define RSRFSIGGEN_VAL_WLAN_SCRAMBLING_USER                                 2
#define RSRFSIGGEN_VAL_WLAN_SCRAMBLING_ON                                   3
#define RSRFSIGGEN_VAL_WLAN_SCRAMBLING_PONLY                                4

// RsRFSigGen_rngWLANPLCPPHFormat
#define RSRFSIGGEN_VAL_WLAN_PLCP_LONG                                       0
#define RSRFSIGGEN_VAL_WLAN_PLCP_SHORT                                      1

// RsRFSigGen_rngWLANNTransmissionBandwidth
#define RSRFSIGGEN_VAL_WLANN_TRANS_BANDWIDTH_BW20                           0
#define RSRFSIGGEN_VAL_WLANN_TRANS_BANDWIDTH_BW40                           1
#define RSRFSIGGEN_VAL_WLANN_TRANS_BANDWIDTH_BW80                           2
#define RSRFSIGGEN_VAL_WLANN_TRANS_BANDWIDTH_BW160                          3
#define RSRFSIGGEN_VAL_WLANN_TRANS_BANDWIDTH_BW320                          4

// RsRFSigGen_rngWLANNAntennas
#define RSRFSIGGEN_VAL_WLANN_ANTENNAS_A1                                    1
#define RSRFSIGGEN_VAL_WLANN_ANTENNAS_A2                                    2
#define RSRFSIGGEN_VAL_WLANN_ANTENNAS_A3                                    3
#define RSRFSIGGEN_VAL_WLANN_ANTENNAS_A4                                    4
#define RSRFSIGGEN_VAL_WLANN_ANTENNAS_A5                                    5
#define RSRFSIGGEN_VAL_WLANN_ANTENNAS_A6                                    6
#define RSRFSIGGEN_VAL_WLANN_ANTENNAS_A7                                    7
#define RSRFSIGGEN_VAL_WLANN_ANTENNAS_A8                                    8

// RsRFSigGen_rngWLANNMappingCoordinates
#define RSRFSIGGEN_VAL_WLANN_MAPPING_COORDINATES_CARTESIAN                  0
#define RSRFSIGGEN_VAL_WLANN_MAPPING_COORDINATES_CYLINDRICAL                1

// RsRFSigGen_rngWLANNAntennasChainMappingOutput
#define RSRFSIGGEN_VAL_WLANN_ANTENNAS_CHAIN_MAPPING_OUTPUT_OFF              0
#define RSRFSIGGEN_VAL_WLANN_ANTENNAS_CHAIN_MAPPING_OUTPUT_BB               1
#define RSRFSIGGEN_VAL_WLANN_ANTENNAS_CHAIN_MAPPING_OUTPUT_FILE             2
#define RSRFSIGGEN_VAL_WLANN_ANTENNAS_CHAIN_MAPPING_OUTPUT_BBB              3

// RsRFSigGen_rngWLANNFrameBlockType
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TYPE_DATA                          0
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TYPE_SOUNDING                      1
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TYPE_BEACON                        2

// RsRFSigGen_rngWLANNPLCPFormat
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_PLCP_FORMAT_LONG                   0
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_PLCP_FORMAT_SHORT                  1

// RsRFSigGen_rngWLANNPhysicalMode
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_PHYS_MODE_LEGACY                   0
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_PHYS_MODE_MIXED                    1
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_PHYS_MODE_GREEN                    2

// RsRFSigGen_rngWLANNTxMode
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_HT20                       0
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_HT40                       1
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_HTD                        2
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_HTL                        3
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_HTUP                       4
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_V20                        5
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_V40                        6
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_V80                        7
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_V160                       8
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_V8080                      9
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_HE20                       10
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_HE40                       11
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_HE80                       12
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_HE160                      13
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_HE8080                     14
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_EHT320                     15
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_S1                         16
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_S2                         17
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_S4                         18
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_S16                        19
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_PBCC                       25
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_EHT20                      27
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_EHT40                      28
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_EHT80                      29
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_EHT160                     30

// RsRFSigGen_rngWLANNTxModeLegacy
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_L20                        0
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_LDUP                       1
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_LUP                        2
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_LLOW                       3
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_CCK                        4
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_PBCK                       5
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_TX_MODE_L10                        6

// RsRFSigGen_rngWLANNCodingScheme
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS0                               0
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS1                               1
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS2                               2
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS3                               3
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS4                               4
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS5                               5
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS6                               6
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS7                               7
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS8                               8
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS9                               9
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS10                              10
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS11                              11
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS12                              12
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS13                              13
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS14                              14
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS15                              15
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS16                              16
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS17                              17
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS18                              18
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS19                              19
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS20                              20
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS21                              21
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS22                              22
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS23                              23
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS24                              24
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS25                              25
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS26                              26
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS27                              27
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS28                              28
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS29                              29
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS30                              30
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS31                              31
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS32                              32
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS33                              33
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS34                              34
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS35                              35
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS36                              36
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS37                              37
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS38                              38
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS39                              39
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS40                              40
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS41                              41
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS42                              42
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS43                              43
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS44                              44
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS45                              45
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS46                              46
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS47                              47
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS48                              48
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS49                              49
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS50                              50
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS51                              51
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS52                              52
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS53                              53
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS54                              54
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS55                              55
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS56                              56
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS57                              57
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS58                              58
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS59                              59
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS60                              60
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS61                              61
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS62                              62
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS63                              63
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS64                              64
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS65                              65
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS66                              66
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS67                              67
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS68                              68
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS69                              69
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS70                              70
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS71                              71
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS72                              72
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS73                              73
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS74                              74
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS75                              75
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_MCS76                              76

// RsRFSigGen_rngWLANNPSDUBitRate
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_PSDU_BIT_RATE_P1MBPS               0
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_PSDU_BIT_RATE_P2MBPS               1
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_PSDU_BIT_RATE_P55MBPS              2
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_PSDU_BIT_RATE_P11MBPS              3
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_PSDU_BIT_RATE_P22MBPS              4

// RsRFSigGen_rngWLANNPPDUModulation
#define RSRFSIGGEN_VAL_WLANN_PPDU_MODULATION_BPSK                           0
#define RSRFSIGGEN_VAL_WLANN_PPDU_MODULATION_QPSK                           1
#define RSRFSIGGEN_VAL_WLANN_PPDU_MODULATION_QAM16                          2
#define RSRFSIGGEN_VAL_WLANN_PPDU_MODULATION_QAM64                          3
#define RSRFSIGGEN_VAL_WLANN_PPDU_MODULATION_QAM256                         4
#define RSRFSIGGEN_VAL_WLANN_PPDU_MODULATION_QAM1024                        5
#define RSRFSIGGEN_VAL_WLANN_PPDU_MODULATION_QAM4096                        6

// RsRFSigGen_rngWLANNDataGuard
#define RSRFSIGGEN_VAL_WLANN_PPDU_DATA_GUARD_SHORT                          0
#define RSRFSIGGEN_VAL_WLANN_PPDU_DATA_GUARD_LONG                           1

// RsRFSigGen_rngWLANNDataScrambler
#define RSRFSIGGEN_VAL_WLANN_PPDU_DATA_SCRAMBLER_OFF                        0
#define RSRFSIGGEN_VAL_WLANN_PPDU_DATA_SCRAMBLER_RAND                       1
#define RSRFSIGGEN_VAL_WLANN_PPDU_DATA_SCRAMBLER_USER                       2
#define RSRFSIGGEN_VAL_WLANN_PPDU_DATA_SCRAMBLER_ON                         3
#define RSRFSIGGEN_VAL_WLANN_PPDU_DATA_SCRAMBLER_PREAMBLE                   4

// RsRFSigGen_rngWLANNPPDUDataChannelCoding
#define RSRFSIGGEN_VAL_WLANN_PPDU_DATA_CODING_OFF                           0
#define RSRFSIGGEN_VAL_WLANN_PPDU_DATA_CODING_BCC                           1
#define RSRFSIGGEN_VAL_WLANN_PPDU_DATA_CODING_LDPC                          2

// RsRFSigGen_rngWLANNDataCodingRate
#define RSRFSIGGEN_VAL_WLANN_PPDU_DATA_CODING_RATE_CR1D2                    0
#define RSRFSIGGEN_VAL_WLANN_PPDU_DATA_CODING_RATE_CR2D3                    1
#define RSRFSIGGEN_VAL_WLANN_PPDU_DATA_CODING_RATE_CR3D4                    2
#define RSRFSIGGEN_VAL_WLANN_PPDU_DATA_CODING_RATE_CR5D6                    3

// RsRFSigGen_rngWLANNDuplicatedBandwidth
#define RSRFSIGGEN_VAL_WLANN_DUPLICATED_BW20                                0
#define RSRFSIGGEN_VAL_WLANN_DUPLICATED_BW40                                1
#define RSRFSIGGEN_VAL_WLANN_DUPLICATED_BW80                                2
#define RSRFSIGGEN_VAL_WLANN_DUPLICATED_BW160                               3
#define RSRFSIGGEN_VAL_WLANN_DUPLICATED_BWOFF                               4

// RsRFSigGen_rngWLANNScramblingSequence
#define RSRFSIGGEN_VAL_WLANN_SCRAMBLING_SEQUENCE_STATIC                     0
#define RSRFSIGGEN_VAL_WLANN_SCRAMBLING_SEQUENCE_DYNAMIC                    1
#define RSRFSIGGEN_VAL_WLANN_SCRAMBLING_SEQUENCE_OFF                        2

// RsRFSigGen_rngWLANNMappingMode
#define RSRFSIGGEN_VAL_WLANN_PPDU_SMAPPING_MODE_OFF                         0
#define RSRFSIGGEN_VAL_WLANN_PPDU_SMAPPING_MODE_DIRECT                      1
#define RSRFSIGGEN_VAL_WLANN_PPDU_SMAPPING_MODE_EXPANSION                   2
#define RSRFSIGGEN_VAL_WLANN_PPDU_SMAPPING_MODE_BEAM                        3
#define RSRFSIGGEN_VAL_WLANN_PPDU_SMAPPING_MODE_INDIRECT                    4

// RsRFSigGen_rngWLANNSignalDurationUnit
#define RSRFSIGGEN_VAL_WLANN_SIGNAL_DURATION_UNIT_SAMPLE                    0
#define RSRFSIGGEN_VAL_WLANN_SIGNAL_DURATION_UNIT_SEQUENCE                  1

// RsRFSigGen_rngWLANNMarkerMode
#define RSRFSIGGEN_VAL_WLANN_MARKER_TYPE_RESTART                            0
#define RSRFSIGGEN_VAL_WLANN_MARKER_TYPE_FRAME                              1
#define RSRFSIGGEN_VAL_WLANN_MARKER_TYPE_FBLOCK                             2
#define RSRFSIGGEN_VAL_WLANN_MARKER_TYPE_FAPART                             3
#define RSRFSIGGEN_VAL_WLANN_MARKER_TYPE_PATTERN                            4
#define RSRFSIGGEN_VAL_WLANN_MARKER_TYPE_PULSE                              5
#define RSRFSIGGEN_VAL_WLANN_MARKER_TYPE_RATIO                              6

// RsRFSigGen_rngWLANNPPDUStreamSegment
#define RSRFSIGGEN_VAL_WLANN_STREAM_SEG0                                    0
#define RSRFSIGGEN_VAL_WLANN_STREAM_SEG1                                    1
#define RSRFSIGGEN_VAL_WLANN_STREAM_BOTH                                    2

// RsRFSigGen_rngWLANNUserIndex
#define RSRFSIGGEN_VAL_WLANN_UID0                                           0
#define RSRFSIGGEN_VAL_WLANN_UID1                                           1
#define RSRFSIGGEN_VAL_WLANN_UID2                                           2
#define RSRFSIGGEN_VAL_WLANN_UID3                                           3

// RsRFSigGen_rngWLANNStreamSpaceTimeBlockCoding
#define RSRFSIGGEN_VAL_WLANN_STREAM_SPACE_TIME_BLOCK_CODING_INACTIVE        0
#define RSRFSIGGEN_VAL_WLANN_STREAM_SPACE_TIME_BLOCK_CODING_ACTIVE          1

// RsRFSigGen_rngWLANNEncoders
#define RSRFSIGGEN_VAL_WLANN_ENCODER_1                                      1
#define RSRFSIGGEN_VAL_WLANN_ENCODER_2                                      2
#define RSRFSIGGEN_VAL_WLANN_ENCODER_3                                      3
#define RSRFSIGGEN_VAL_WLANN_ENCODER_4                                      4
#define RSRFSIGGEN_VAL_WLANN_ENCODER_5                                      5
#define RSRFSIGGEN_VAL_WLANN_ENCODER_6                                      6
#define RSRFSIGGEN_VAL_WLANN_ENCODER_7                                      7
#define RSRFSIGGEN_VAL_WLANN_ENCODER_8                                      8
#define RSRFSIGGEN_VAL_WLANN_ENCODER_9                                      9
#define RSRFSIGGEN_VAL_WLANN_ENCODER_10                                     10
#define RSRFSIGGEN_VAL_WLANN_ENCODER_11                                     11

// RsRFSigGen_rngWLANNTriggerStatus
#define RSRFSIGGEN_VAL_WLANN_TRIGGER_STATUS_STOP                            0
#define RSRFSIGGEN_VAL_WLANN_TRIGGER_STATUS_RUN                             1

// RsRFSigGen_rngWiMAXVersion
#define RSRFSIGGEN_VAL_WIMAX_VERSION_VC1                                    0
#define RSRFSIGGEN_VAL_WIMAX_VERSION_VC2D4                                  1

// RsRFSigGen_rngWiMAXPhysicalLayerMode
#define RSRFSIGGEN_VAL_WIMAX_PHYS_LAYER_OFDM                                0
#define RSRFSIGGEN_VAL_WIMAX_PHYS_LAYER_OFDMA                               1
#define RSRFSIGGEN_VAL_WIMAX_PHYS_LAYER_WIBRO                               2

// RsRFSigGen_rngWiMAXDuplexing
#define RSRFSIGGEN_VAL_WIMAX_DUPLEX_TDD                                     0
#define RSRFSIGGEN_VAL_WIMAX_DUPLEX_FDD                                     1

// RsRFSigGen_rngWiMAXFrameDuration
#define RSRFSIGGEN_VAL_WIMAX_FRAME_DURATION_2M                              0
#define RSRFSIGGEN_VAL_WIMAX_FRAME_DURATION_2M5                             1
#define RSRFSIGGEN_VAL_WIMAX_FRAME_DURATION_4M                              2
#define RSRFSIGGEN_VAL_WIMAX_FRAME_DURATION_5M                              3
#define RSRFSIGGEN_VAL_WIMAX_FRAME_DURATION_8M                              4
#define RSRFSIGGEN_VAL_WIMAX_FRAME_DURATION_10M                             5
#define RSRFSIGGEN_VAL_WIMAX_FRAME_DURATION_12M5                            6
#define RSRFSIGGEN_VAL_WIMAX_FRAME_DURATION_20M                             7
#define RSRFSIGGEN_VAL_WIMAX_FRAME_DURATION_CONT                            8
#define RSRFSIGGEN_VAL_WIMAX_FRAME_DURATION_USER                            9

// RsRFSigGen_rngWiMAXPredefinedFrames
#define RSRFSIGGEN_VAL_WIMAX_FRAME_USER                                     0
#define RSRFSIGGEN_VAL_WIMAX_FRAME_BPSK12SHORT                              1
#define RSRFSIGGEN_VAL_WIMAX_FRAME_BPSK12MID                                2
#define RSRFSIGGEN_VAL_WIMAX_FRAME_BPSK12LONG                               3
#define RSRFSIGGEN_VAL_WIMAX_FRAME_QPSK12SHORT                              4
#define RSRFSIGGEN_VAL_WIMAX_FRAME_QPSK12MID                                5
#define RSRFSIGGEN_VAL_WIMAX_FRAME_QPSK12LONG                               6
#define RSRFSIGGEN_VAL_WIMAX_FRAME_QPSK34SHORT                              7
#define RSRFSIGGEN_VAL_WIMAX_FRAME_QPSK34MID                                8
#define RSRFSIGGEN_VAL_WIMAX_FRAME_QPSK34LONG                               9
#define RSRFSIGGEN_VAL_WIMAX_FRAME_16QAM12SHORT                             10
#define RSRFSIGGEN_VAL_WIMAX_FRAME_16QAM12MID                               11
#define RSRFSIGGEN_VAL_WIMAX_FRAME_16QAM12LONG                              12
#define RSRFSIGGEN_VAL_WIMAX_FRAME_16QAM34SHORT                             13
#define RSRFSIGGEN_VAL_WIMAX_FRAME_16QAM34MID                               14
#define RSRFSIGGEN_VAL_WIMAX_FRAME_16QAM34LONG                              15
#define RSRFSIGGEN_VAL_WIMAX_FRAME_64QAM23SHORT                             16
#define RSRFSIGGEN_VAL_WIMAX_FRAME_64QAM23MID                               17
#define RSRFSIGGEN_VAL_WIMAX_FRAME_64QAM23LONG                              18
#define RSRFSIGGEN_VAL_WIMAX_FRAME_64QAM34SHORT                             19
#define RSRFSIGGEN_VAL_WIMAX_FRAME_64QAM34MID                               20
#define RSRFSIGGEN_VAL_WIMAX_FRAME_64QAM34LONG                              21

// RsRFSigGen_rngWiMAXLevelReference
#define RSRFSIGGEN_VAL_WIMAX_LEVREF_BURS                                    0
#define RSRFSIGGEN_VAL_WIMAX_LEVREF_PRE                                     1

// RsRFSigGen_rngWiMAXOFDMALevelReference
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_LEVREF_PRE                               0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_LEVREF_RMS                               1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_LEVREF_WOPR                              2

// RsRFSigGen_rngWiMAXOFDMFrequencyBand
#define RSRFSIGGEN_VAL_WIMAX_BAND_ETSI                                      0
#define RSRFSIGGEN_VAL_WIMAX_BAND_MMDS                                      1
#define RSRFSIGGEN_VAL_WIMAX_BAND_WCS                                       2
#define RSRFSIGGEN_VAL_WIMAX_BAND_UNII                                      3
#define RSRFSIGGEN_VAL_WIMAX_BAND_USER                                      4
#define RSRFSIGGEN_VAL_WIMAX_BAND_WIBRO                                     5

// RsRFSigGen_rngWiMAXTgtoTbRatio
#define RSRFSIGGEN_VAL_WIMAX_TGRAT_1D4                                      0
#define RSRFSIGGEN_VAL_WIMAX_TGRAT_1D8                                      1
#define RSRFSIGGEN_VAL_WIMAX_TGRAT_1D16                                     2
#define RSRFSIGGEN_VAL_WIMAX_TGRAT_1D32                                     3

// RsRFSigGen_rngWiMAXNumberOfUsedSubchannels
#define RSRFSIGGEN_VAL_WIMAX_SUBCHAN_1                                      0
#define RSRFSIGGEN_VAL_WIMAX_SUBCHAN_2                                      1
#define RSRFSIGGEN_VAL_WIMAX_SUBCHAN_4                                      2
#define RSRFSIGGEN_VAL_WIMAX_SUBCHAN_8                                      3
#define RSRFSIGGEN_VAL_WIMAX_SUBCHAN_16                                     4

// RsRFSigGen_rngWiMAXSubchannelIndex
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_1                                     0
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_2                                     1
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_3                                     2
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_4                                     3
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_5                                     4
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_6                                     5
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_7                                     6
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_8                                     7
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_9                                     8
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_10                                    9
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_11                                    10
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_12                                    11
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_13                                    12
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_14                                    13
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_15                                    14
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_16                                    15
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_17                                    16
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_18                                    17
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_19                                    18
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_20                                    19
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_21                                    20
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_22                                    21
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_23                                    22
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_24                                    23
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_25                                    24
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_26                                    25
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_27                                    26
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_28                                    27
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_29                                    28
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_30                                    29
#define RSRFSIGGEN_VAL_WIMAX_SUBC_IND_31                                    30

// RsRFSigGen_rngWiMAXFramePreamble
#define RSRFSIGGEN_VAL_WIMAX_FRAME_PREAMBLE_OFF                             0
#define RSRFSIGGEN_VAL_WIMAX_FRAME_PREAMBLE_LONG                            1
#define RSRFSIGGEN_VAL_WIMAX_FRAME_PREAMBLE_SHORT                           2

// RsRFSigGen_rngWiMAXFCHMode
#define RSRFSIGGEN_VAL_WIMAX_FCH_MODE_AUTO                                  0
#define RSRFSIGGEN_VAL_WIMAX_FCH_MODE_USER                                  1

// RsRFSigGen_rngWiMAXMidambleRepetition
#define RSRFSIGGEN_VAL_WIMAX_BURST_MIDAMBLE_REP_OFF                         0
#define RSRFSIGGEN_VAL_WIMAX_BURST_MIDAMBLE_REP_5                           1
#define RSRFSIGGEN_VAL_WIMAX_BURST_MIDAMBLE_REP_9                           2
#define RSRFSIGGEN_VAL_WIMAX_BURST_MIDAMBLE_REP_17                          3

// RsRFSigGen_rngWiMAXModulationAndCodingRate
#define RSRFSIGGEN_VAL_WIMAX_BURST_MOD_QPSK12                               0
#define RSRFSIGGEN_VAL_WIMAX_BURST_MOD_QPSK34                               1
#define RSRFSIGGEN_VAL_WIMAX_BURST_MOD_16QAM12                              2
#define RSRFSIGGEN_VAL_WIMAX_BURST_MOD_16QAM34                              3
#define RSRFSIGGEN_VAL_WIMAX_BURST_MOD_64QAM12                              4
#define RSRFSIGGEN_VAL_WIMAX_BURST_MOD_64QAM23                              5
#define RSRFSIGGEN_VAL_WIMAX_BURST_MOD_64QAM34                              6
#define RSRFSIGGEN_VAL_WIMAX_BURST_MOD_64QAM56                              7

// RsRFSigGen_rngWiMAXBurstType
#define RSRFSIGGEN_VAL_WIMAX_BURST_TYPE_DATA                                0
#define RSRFSIGGEN_VAL_WIMAX_BURST_TYPE_FCH                                 1
#define RSRFSIGGEN_VAL_WIMAX_BURST_TYPE_DLMAP                               2
#define RSRFSIGGEN_VAL_WIMAX_BURST_TYPE_ULMAP                               3
#define RSRFSIGGEN_VAL_WIMAX_BURST_TYPE_RANGING                             4

// RsRFSigGen_rngWiMAXAllocationStartTimeBase
#define RSRFSIGGEN_VAL_WIMAX_ULMAP_AMOD_DLSF                                0
#define RSRFSIGGEN_VAL_WIMAX_ULMAP_AMOD_FRAM                                1

// RsRFSigGen_rngWiMAXOFDMAPredefinedFrame
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_USER                         0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL3M21SQPSK12                1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL3M21SQPSK34                2
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL3M21S16QAM12               3
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL3M21S16QAM34               4
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL3M21S64QAM12               5
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL3M21S64QAM23               6
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL3M21S64QAM34               7
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL3M21S64QAM56               8
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL5M29SQPSK12                9
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL5M29SQPSK34                10
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL5M29S16QAM12               11
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL5M29S16QAM34               12
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL5M29S64QAM12               13
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL5M29S64QAM23               14
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL5M29S64QAM34               15
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL5M29S64QAM56               16
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL7M21SQPSK12                17
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL7M21SQPSK34                18
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL7M21S16QAM12               19
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL7M21S16QAM34               20
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL7M21S64QAM12               21
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL7M21S64QAM23               22
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL7M21S64QAM34               23
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL7M21S64QAM56               24
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL8M27SQPSK12                25
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL8M27SQPSK34                26
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL8M27S16QAM12               27
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL8M27S16QAM34               28
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL8M27S64QAM12               29
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL8M27S64QAM23               30
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL8M27S64QAM34               31
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL8M27S64QAM56               32
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL10M29SQPSK12               33
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL10M29SQPSK34               34
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL10M29S16QAM12              35
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL10M29S16QAM34              36
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL10M29S64QAM12              37
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL10M29S64QAM23              38
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL10M29S64QAM34              39
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_DL10M29S64QAM56              40
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL3M12SQPSK12                41
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL3M12SQPSK34                42
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL3M12S16QAM12               43
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL3M12S16QAM34               44
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL5M18SQPSK12                45
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL5M18SQPSK34                46
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL5M18S16QAM12               47
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL5M18S16QAM34               48
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL7M12SQPSK12                49
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL7M12SQPSK34                50
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL7M12S16QAM12               51
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL7M12S16QAM34               52
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL8M15SQPSK12                53
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL8M15SQPSK34                54
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL8M15S16QAM12               55
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL8M15S16QAM34               56
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL10M18SQPSK12               57
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL10M18SQPSK34               58
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL10M18S16QAM12              59
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PRED_FRAMES_UL10M18S16QAM34              60

// RsRFSigGen_rngWiMAXPreambleMode
#define RSRFSIGGEN_VAL_WIMAX_PREAMBLE_AUTO                                  0
#define RSRFSIGGEN_VAL_WIMAX_PREAMBLE_USER                                  1

// RsRFSigGen_rngWiMAXFFTSize
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_FFT_128                                  0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_FFT_512                                  1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_FFT_1024                                 2
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_FFT_2048                                 3

// RsRFSigGen_rngWiMAXZoneType
#define RSRFSIGGEN_VAL_WIMAX_ZONE_TYPE_PUSC                                 0
#define RSRFSIGGEN_VAL_WIMAX_ZONE_TYPE_FUSC                                 1
#define RSRFSIGGEN_VAL_WIMAX_ZONE_TYPE_AMC2X3                               2
#define RSRFSIGGEN_VAL_WIMAX_ZONE_TYPE_SOUNDING                             3

// RsRFSigGen_rngWiMAXPilotPattern
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PILOT_PATTERN_A                          0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_PILOT_PATTERN_B                          1

// RsRFSigGen_rngWiMAXSpaceTimeCodingMode
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SPACE_TIME_MODE_OFF                      0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SPACE_TIME_MODE_MATRIXA                  1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SPACE_TIME_MODE_MATRIXB                  2
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SPACE_TIME_MODE_BURST                    3
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SPACE_TIME_MODE_COLL                     4
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SPACE_TIME_MODE_CSTD                     5
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SPACE_TIME_MODE_4MATRIXA                 6
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SPACE_TIME_MODE_4MATRIXB                 7
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SPACE_TIME_MODE_4MATRIXC                 8

// RsRFSigGen_rngWiMAXSpaceTimeCodingAntenna
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SPACE_TIME_ANT_ANT0                      0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SPACE_TIME_ANT_ANT1                      1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SPACE_TIME_ANT_ANT2                      2
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SPACE_TIME_ANT_ANT3                      3

// RsRFSigGen_rngWiMAXOFDMAChannelCoding
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_CHAN_CODING_OFF                          0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_CHAN_CODING_CC                           1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_CHAN_CODING_CTC                          2

// RsRFSigGen_rngWiMAXOFDMAOffsetMode
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_OFFSET_MODE_USER                         0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_OFFSET_MODE_AUTO                         1

// RsRFSigGen_rngWiMAXOFDMABurstType
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_BURST_TYPE_DATA                          0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_BURST_TYPE_FCH                           1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_BURST_TYPE_DLMAP                         2
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_BURST_TYPE_ULMAP                         3
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_BURST_TYPE_RANGING                       4
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_BURST_TYPE_HARQ                          5
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_BURST_TYPE_FAST                          6
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_BURST_TYPE_DCD                           7
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_BURST_TYPE_UCD                           8
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_BURST_TYPE_SUBM                          9

// RsRFSigGen_rngWiMAXUseAllSubchannels
#define RSRFSIGGEN_VAL_WIMAX_USE_SUBCHANNEL_ALL                             0
#define RSRFSIGGEN_VAL_WIMAX_USE_SUBCHANNEL_USER                            1

// RsRFSigGen_rngWiMAXHARQMode
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_MODE_IR                             0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_MODE_CHASE                          1

// RsRFSigGen_rngWiMAXChaseModulation
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_CHASE_MOD_QPSK_12                   0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_CHASE_MOD_QPSK_34                   1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_CHASE_MOD_QAM16_12                  2
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_CHASE_MOD_QAM16_34                  3
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_CHASE_MOD_QAM64_12                  4
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_CHASE_MOD_QAM64_23                  5
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_CHASE_MOD_QAM64_34                  6
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_CHASE_MOD_QAM64_56                  7

// RsRFSigGen_rngWiMAXPacketSize
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_PSIZE_PS48                          0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_PSIZE_PS96                          1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_PSIZE_PS144                         2
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_PSIZE_PS192                         3
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_PSIZE_PS288                         4
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_PSIZE_PS384                         5
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_PSIZE_PS480                         6
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_PSIZE_PS960                         7
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_PSIZE_PS1K92                        8
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_PSIZE_PS2K88                        9
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_PSIZE_PS3K84                        10
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_PSIZE_PS4K8                         11
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_PSIZE_PS9K6                         12
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_PSIZE_PS14K4                        13
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_PSIZE_PS19K2                        14
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_HARQ_PSIZE_PS24K                         15

// RsRFSigGen_rngWiMAXRepetitionCoding
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_CHANNEL_CODIN_REPETITION_0               0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_CHANNEL_CODIN_REPETITION_2               1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_CHANNEL_CODIN_REPETITION_4               2
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_CHANNEL_CODIN_REPETITION_6               3

// RsRFSigGen_rngWiMAXDLMAPMode
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_DLMAP_MODE_USER                          0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_DLMAP_MODE_AUTO                          1

// RsRFSigGen_rngWiMAXDLMAPRepetitionCoding
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_DLMAP_REPETITION_0                       0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_DLMAP_REPETITION_2                       1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_DLMAP_REPETITION_4                       2
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_DLMAP_REPETITION_6                       3

// RsRFSigGen_rngWiMAXFastFeedbackMode
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_FFB_MODE_NORM                            0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_FFB_MODE_ENH                             1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_FFB_MODE_ENHM                            2
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_FFB_MODE_ACK                             3

// RsRFSigGen_rngWiMAXSoundingType
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_TYPE_A                          0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_TYPE_B                          1

// RsRFSigGen_rngWiMAXRelevanceFlag
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_RELEVANCE_FLAG_SAME             0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_RELEVANCE_FLAG_IND              1

// RsRFSigGen_rngWiMAXRelevance
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_RELEVANCE_THIS                  0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_RELEVANCE_NEXT                  1

// RsRFSigGen_rngWiMAXSeparabilityType
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_SEPARABILITY_TYPE_CYCL          0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_SEPARABILITY_TYPE_DEC           1

// RsRFSigGen_rngWiMAXDecimationValue
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_DECIMATION_DEC2                 0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_DECIMATION_DEC4                 1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_DECIMATION_DEC5                 2
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_DECIMATION_DEC8                 3
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_DECIMATION_DEC16                4
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_DECIMATION_DEC32                5
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_DECIMATION_DEC64                6
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_DECIMATION_DEC128               7

// RsRFSigGen_rngWiMAXCyclicShiftIndex
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_CMAX_MC4                        0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_CMAX_MC8                        1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_CMAX_MC16                       2
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_CMAX_MC32                       3
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_CMAX_MC9                        4
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_CMAX_MC18                       5

// RsRFSigGen_rngWiMAXOFDMASoundingPeriodicity
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_PERIODICITY_PER0                0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_PERIODICITY_PER1                1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_PERIODICITY_PER2                2
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_PERIODICITY_PER4                3
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_PERIODICITY_PER8                4
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_PERIODICITY_PER16               5
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_PERIODICITY_PER32               6
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_PERIODICITY_PER64               7

// RsRFSigGen_rngWiMAXSoundingAllocationMode
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_ALLOCATION_MODE_NORMAL          0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_SOUNDING_ALLOCATION_MODE_AMC             1

// RsRFSigGen_rngWiMAXOFDMABurstProfileMapping
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_PROFILE_MAPPING_AUTO                 0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_PROFILE_MAPPING_MANUAL               1

// RsRFSigGen_rngWiMAXFECModulationType
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_FEC_MODULATION_TYPE_MQPSKCC12        0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_FEC_MODULATION_TYPE_MQPSKCC34        1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_FEC_MODULATION_TYPE_M16QAMCC12       2
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_FEC_MODULATION_TYPE_M16QAMCC34       3
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_FEC_MODULATION_TYPE_M64QAMCC12       4
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_FEC_MODULATION_TYPE_M64QAMCC23       5
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_FEC_MODULATION_TYPE_M64QAMCC34       6
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_FEC_MODULATION_TYPE_MQPSKCTC12       7
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_FEC_MODULATION_TYPE_MQPSKCTC34       8
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_FEC_MODULATION_TYPE_M16QAMCTC12      9
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_FEC_MODULATION_TYPE_M16QAMCTC34      10
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_FEC_MODULATION_TYPE_M64QAMCTC12      11
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_FEC_MODULATION_TYPE_M64QAMCTC23      12
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_FEC_MODULATION_TYPE_M64QAMCTC34      13
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_UCD_FEC_MODULATION_TYPE_M64QAMCTC56      14

// RsRFSigGen_rngWiMAXACKRegionIndex
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_DLUL_ACK_REGION_INDEX_IX0                0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_DLUL_ACK_REGION_INDEX_IX1                1

// RsRFSigGen_rngWiMAXInclude
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_DLUL_INCLUDE_OFF                         0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_DLUL_INCLUDE_INC1                        1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_DLUL_INCLUDE_INC2                        2
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_DLUL_INCLUDE_INC3                        3

// RsRFSigGen_rngWiMAXCSTDNumberOfAntennas
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_CSTD_NUMBER_ANTENNAS_A1                  0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_CSTD_NUMBER_ANTENNAS_A2                  1
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_CSTD_NUMBER_ANTENNAS_A4                  2

// RsRFSigGen_rngWiMAXFilterMode
#define RSRFSIGGEN_VAL_WIMAX_FILTER_MODE_REALTIME                           0
#define RSRFSIGGEN_VAL_WIMAX_FILTER_MODE_OFFLINE                            1

// RsRFSigGen_rngDVBStandard
#define RSRFSIGGEN_VAL_DVB_STANDARD_DVBT                                    0
#define RSRFSIGGEN_VAL_DVB_STANDARD_DVBH                                    1
#define RSRFSIGGEN_VAL_DVB_STANDARD_DVBS                                    2
#define RSRFSIGGEN_VAL_DVB_STANDARD_DVBX                                    3
#define RSRFSIGGEN_VAL_DVB_STANDARD_DVBR                                    4

// RsRFSigGen_rngDVBHierarchyMode
#define RSRFSIGGEN_VAL_DVB_HIERARCHY_MODE_NHIE                              0

// RsRFSigGen_rngDVBSource
#define RSRFSIGGEN_VAL_DVB_HPLP_SOURCE_PAC0                                 0
#define RSRFSIGGEN_VAL_DVB_HPLP_SOURCE_PAC1                                 1
#define RSRFSIGGEN_VAL_DVB_HPLP_SOURCE_PN15                                 2
#define RSRFSIGGEN_VAL_DVB_HPLP_SOURCE_PN23                                 3
#define RSRFSIGGEN_VAL_DVB_HPLP_SOURCE_TSFILE                               4

// RsRFSigGen_rngDVBRate
#define RSRFSIGGEN_VAL_DVB_RATE_CR1D2                                       0
#define RSRFSIGGEN_VAL_DVB_RATE_CR2D3                                       1
#define RSRFSIGGEN_VAL_DVB_RATE_CR3D4                                       2
#define RSRFSIGGEN_VAL_DVB_RATE_CR5D6                                       3
#define RSRFSIGGEN_VAL_DVB_RATE_CR7D8                                       4

// RsRFSigGen_rngDVBInterleaverMode
#define RSRFSIGGEN_VAL_DVB_INNER_INTERLEAVER_MODE_NATIVE                    0
#define RSRFSIGGEN_VAL_DVB_INNER_INTERLEAVER_MODE_INDEPTH                   1

// RsRFSigGen_rngDVBInnerTxMode
#define RSRFSIGGEN_VAL_DVB_INNER_INTERLEAVER_TXMODE_T2K                     0
#define RSRFSIGGEN_VAL_DVB_INNER_INTERLEAVER_TXMODE_T4K                     1
#define RSRFSIGGEN_VAL_DVB_INNER_INTERLEAVER_TXMODE_T8K                     2

// RsRFSigGen_rngDVBRFBandwidth
#define RSRFSIGGEN_VAL_DVB_OFDMRF_BANDWIDTH_5                               0
#define RSRFSIGGEN_VAL_DVB_OFDMRF_BANDWIDTH_6                               1
#define RSRFSIGGEN_VAL_DVB_OFDMRF_BANDWIDTH_7                               2
#define RSRFSIGGEN_VAL_DVB_OFDMRF_BANDWIDTH_8                               3

// RsRFSigGen_rngDVBRFModulation
#define RSRFSIGGEN_VAL_DVB_OFDMRF_MODULATION_QPSK                           0
#define RSRFSIGGEN_VAL_DVB_OFDMRF_MODULATION_QAM16                          1
#define RSRFSIGGEN_VAL_DVB_OFDMRF_MODULATION_QAM64                          2

// RsRFSigGen_rngDVBRFAlpha
#define RSRFSIGGEN_VAL_DVB_OFDMRF_ALPHA_1                                   0
#define RSRFSIGGEN_VAL_DVB_OFDMRF_ALPHA_2                                   1
#define RSRFSIGGEN_VAL_DVB_OFDMRF_ALPHA_4                                   2

// RsRFSigGen_rngDVBRFGuardInterval
#define RSRFSIGGEN_VAL_DVB_OFDMRF_GUARD_INTERVAL_GI1D4                      0
#define RSRFSIGGEN_VAL_DVB_OFDMRF_GUARD_INTERVAL_GI1D8                      1
#define RSRFSIGGEN_VAL_DVB_OFDMRF_GUARD_INTERVAL_GI1D16                     2
#define RSRFSIGGEN_VAL_DVB_OFDMRF_GUARD_INTERVAL_GI1D32                     3

// RsRFSigGen_rngDVBTriggerSignalDurationUnit
#define RSRFSIGGEN_VAL_DVB_SIGNAL_DURATION_UNIT_FRAME                       0
#define RSRFSIGGEN_VAL_DVB_SIGNAL_DURATION_UNIT_SEQUENCE                    1

// RsRFSigGen_rngDVBMarkerMode
#define RSRFSIGGEN_VAL_DVB_MARKER_TYPE_RESTART                              0
#define RSRFSIGGEN_VAL_DVB_MARKER_TYPE_SFRAME                               1
#define RSRFSIGGEN_VAL_DVB_MARKER_TYPE_FRAME                                2
#define RSRFSIGGEN_VAL_DVB_MARKER_TYPE_PULSE                                3
#define RSRFSIGGEN_VAL_DVB_MARKER_TYPE_PATTERN                              4
#define RSRFSIGGEN_VAL_DVB_MARKER_TYPE_RATIO                                5
#define RSRFSIGGEN_VAL_DVB_MARKER_TYPE_SOSF                                 6

// RsRFSigGen_rngDMCoding
#define RSRFSIGGEN_VAL_DM_CODING_OFF                                        0
#define RSRFSIGGEN_VAL_DM_CODING_APCO25                                     1
#define RSRFSIGGEN_VAL_DM_CODING_APCO25FSK                                  2
#define RSRFSIGGEN_VAL_DM_CODING_CDMA2000                                   3
#define RSRFSIGGEN_VAL_DM_CODING_DIFF                                       4
#define RSRFSIGGEN_VAL_DM_CODING_DPHS                                       5
#define RSRFSIGGEN_VAL_DM_CODING_DGRAY                                      6
#define RSRFSIGGEN_VAL_DM_CODING_EDGE                                       7
#define RSRFSIGGEN_VAL_DM_CODING_GRAY                                       8
#define RSRFSIGGEN_VAL_DM_CODING_GSM                                        9
#define RSRFSIGGEN_VAL_DM_CODING_ICO                                        10
#define RSRFSIGGEN_VAL_DM_CODING_NADC                                       11
#define RSRFSIGGEN_VAL_DM_CODING_PDC                                        12
#define RSRFSIGGEN_VAL_DM_CODING_PHS                                        13
#define RSRFSIGGEN_VAL_DM_CODING_TETRA                                      14
#define RSRFSIGGEN_VAL_DM_CODING_PWT                                        15
#define RSRFSIGGEN_VAL_DM_CODING_TFTS                                       16
#define RSRFSIGGEN_VAL_DM_CODING_INMARSAT                                   17
#define RSRFSIGGEN_VAL_DM_CODING_VDL                                        18
#define RSRFSIGGEN_VAL_DM_CODING_WCDMA                                      19
#define RSRFSIGGEN_VAL_DM_CODING_APCO258PSK                                 20

// RsRFSigGen_rngDMDataSource
#define RSRFSIGGEN_VAL_DM_DATA_SOURCE_ZERO                                  0
#define RSRFSIGGEN_VAL_DM_DATA_SOURCE_ONE                                   1
#define RSRFSIGGEN_VAL_DM_DATA_SOURCE_PRBS                                  2
#define RSRFSIGGEN_VAL_DM_DATA_SOURCE_PATTERN                               3
#define RSRFSIGGEN_VAL_DM_DATA_SOURCE_DLIST                                 4
#define RSRFSIGGEN_VAL_DM_DATA_SOURCE_SERIAL                                5
#define RSRFSIGGEN_VAL_DM_DATA_SOURCE_PARALLEL                              6

// RsRFSigGen_rngDMPRBSType
#define RSRFSIGGEN_VAL_DM_PRBS_LENGTH_9                                     0
#define RSRFSIGGEN_VAL_DM_PRBS_LENGTH_11                                    1
#define RSRFSIGGEN_VAL_DM_PRBS_LENGTH_15                                    2
#define RSRFSIGGEN_VAL_DM_PRBS_LENGTH_16                                    3
#define RSRFSIGGEN_VAL_DM_PRBS_LENGTH_20                                    4
#define RSRFSIGGEN_VAL_DM_PRBS_LENGTH_21                                    5
#define RSRFSIGGEN_VAL_DM_PRBS_LENGTH_23                                    6

// RsRFSigGen_rngDMModulationType
#define RSRFSIGGEN_VAL_DM_FORMAT_ASK                                        0
#define RSRFSIGGEN_VAL_DM_FORMAT_BPSK                                       1
#define RSRFSIGGEN_VAL_DM_FORMAT_QPSK                                       2
#define RSRFSIGGEN_VAL_DM_FORMAT_QPSK45                                     3
#define RSRFSIGGEN_VAL_DM_FORMAT_OQPSK                                      4
#define RSRFSIGGEN_VAL_DM_FORMAT_P4QPSK                                     5
#define RSRFSIGGEN_VAL_DM_FORMAT_P2DBPSK                                    6
#define RSRFSIGGEN_VAL_DM_FORMAT_P4DQPSK                                    7
#define RSRFSIGGEN_VAL_DM_FORMAT_P8D8PSK                                    8
#define RSRFSIGGEN_VAL_DM_FORMAT_PSK8                                       9
#define RSRFSIGGEN_VAL_DM_FORMAT_P8EDGE                                     10
#define RSRFSIGGEN_VAL_DM_FORMAT_QAM16                                      11
#define RSRFSIGGEN_VAL_DM_FORMAT_QAM32                                      12
#define RSRFSIGGEN_VAL_DM_FORMAT_QAM64                                      13
#define RSRFSIGGEN_VAL_DM_FORMAT_QAM256                                     14
#define RSRFSIGGEN_VAL_DM_FORMAT_QAM1024                                    15
#define RSRFSIGGEN_VAL_DM_FORMAT_MSK                                        16
#define RSRFSIGGEN_VAL_DM_FORMAT_FSK2                                       17
#define RSRFSIGGEN_VAL_DM_FORMAT_FSK4                                       18
#define RSRFSIGGEN_VAL_DM_FORMAT_USER                                       19
#define RSRFSIGGEN_VAL_DM_FORMAT_FSKVAR                                     20
#define RSRFSIGGEN_VAL_DM_FORMAT_QEDGE                                      21
#define RSRFSIGGEN_VAL_DM_FORMAT_AQPS                                       22
#define RSRFSIGGEN_VAL_DM_FORMAT_QAM128                                     23
#define RSRFSIGGEN_VAL_DM_FORMAT_QAM16ED                                    24
#define RSRFSIGGEN_VAL_DM_FORMAT_QAM32ED                                    25
#define RSRFSIGGEN_VAL_DM_FORMAT_QAM4096                                    26
#define RSRFSIGGEN_VAL_DM_FORMAT_APSK16                                     27
#define RSRFSIGGEN_VAL_DM_FORMAT_APSK32                                     28
#define RSRFSIGGEN_VAL_DM_FORMAT_FSK32                                      29
#define RSRFSIGGEN_VAL_DM_FORMAT_FSK64                                      30
#define RSRFSIGGEN_VAL_DM_FORMAT_FSK8                                       31
#define RSRFSIGGEN_VAL_DM_FORMAT_FSK16                                      32
#define RSRFSIGGEN_VAL_DM_FORMAT_QAM512                                     33
#define RSRFSIGGEN_VAL_DM_FORMAT_QAM2048                                    34

// RsRFSigGen_rngDMVariableFSKType
#define RSRFSIGGEN_VAL_FSK_TYPE_FSK4                                        0
#define RSRFSIGGEN_VAL_FSK_TYPE_FSK8                                        1
#define RSRFSIGGEN_VAL_FSK_TYPE_FSK16                                       2

// RsRFSigGen_rngDMFilterType
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_RCOSINE                               0
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_COSINE                                1
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_GAUSS                                 2
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_LGAUSS                                3
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_CONE                                  4
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_COF705                                5
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_COEQ                                  6
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_COF                                   7
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_C2K3X                                 8
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_APCO25                                9
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_RECTANGLE                             10
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_SPHASE                                11
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_LPASS                                 12
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_USER                                  13
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_PGAUSS                                14
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_DIRAC                                 15
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_ENPS                                  16
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_EWPS                                  17
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_LPASSEVM                              18
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_LTEF                                  19
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_APCO25H                               20
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_APCO25L                               21
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_HRP                                   22
#define RSRFSIGGEN_VAL_DM_FILTER_TYPE_SOQPSK                                23

// RsRFSigGen_rngDMPowerRampSource
#define RSRFSIGGEN_VAL_DM_POWER_RAMP_SOURCE_INTERNAL                        0
#define RSRFSIGGEN_VAL_DM_POWER_RAMP_SOURCE_EXTERNAL                        1

// RsRFSigGen_rngDMPowerRampFunction
#define RSRFSIGGEN_VAL_DM_POWER_RAMP_SHAPE_LINEAR                           0
#define RSRFSIGGEN_VAL_DM_POWER_RAMP_SHAPE_COSINE                           1

// RsRFSigGen_rngDMMarkerMode
#define RSRFSIGGEN_VAL_DM_MARKER_MODE_CLIST                                 0
#define RSRFSIGGEN_VAL_DM_MARKER_MODE_PULSE                                 1
#define RSRFSIGGEN_VAL_DM_MARKER_MODE_PATTERN                               2
#define RSRFSIGGEN_VAL_DM_MARKER_MODE_RATIO                                 3

// RsRFSigGen_rngDMSwitchingSource
#define RSRFSIGGEN_VAL_DM_SWITCHING_SOURCE_INTERNAL                         0
#define RSRFSIGGEN_VAL_DM_SWITCHING_SOURCE_EXTERNAL                         1

// RsRFSigGen_rngARBExtendedTriggerMode
#define RSRFSIGGEN_VAL_ARB_EXTENDED_TRIGGER_MODE_SAME                       0
#define RSRFSIGGEN_VAL_ARB_EXTENDED_TRIGGER_MODE_NEXT                       1
#define RSRFSIGGEN_VAL_ARB_EXTENDED_TRIGGER_MODE_NSEAM                      2
#define RSRFSIGGEN_VAL_ARB_EXTENDED_TRIGGER_MODE_SEQ                        3

// RsRFSigGen_rngARBSignalDurationUnit
#define RSRFSIGGEN_VAL_ARB_TRIGGER_UNIT_SAMPLE                              0
#define RSRFSIGGEN_VAL_ARB_TRIGGER_UNIT_SEQUENCE                            1

// RsRFSigGen_rngARBMarkerMode
#define RSRFSIGGEN_VAL_ARB_MARKER_MODE_UNCH                                 0
#define RSRFSIGGEN_VAL_ARB_MARKER_MODE_RESTART                              1
#define RSRFSIGGEN_VAL_ARB_MARKER_MODE_PULSE                                2
#define RSRFSIGGEN_VAL_ARB_MARKER_MODE_PATTERN                              3
#define RSRFSIGGEN_VAL_ARB_MARKER_MODE_RATIO                                4

// RsRFSigGen_rngARBMultisegmentLevelMode
#define RSRFSIGGEN_VAL_ARB_LEVEL_MODE_UNCH                                  0
#define RSRFSIGGEN_VAL_ARB_LEVEL_MODE_ERMS                                  1

// RsRFSigGen_rngARBSequenceRestart
#define RSRFSIGGEN_VAL_ARB_SRESTART_DISABLED                                0
#define RSRFSIGGEN_VAL_ARB_SRESTART_MRK1                                    1
#define RSRFSIGGEN_VAL_ARB_SRESTART_MRK2                                    2
#define RSRFSIGGEN_VAL_ARB_SRESTART_MRK3                                    3
#define RSRFSIGGEN_VAL_ARB_SRESTART_MRK4                                    4

// RsRFSigGen_rngARBMultisegmentClockMode
#define RSRFSIGGEN_VAL_ARB_CLOCK_MODE_UNCH                                  0
#define RSRFSIGGEN_VAL_ARB_CLOCK_MODE_HIGH                                  1
#define RSRFSIGGEN_VAL_ARB_CLOCK_MODE_USER                                  2

// RsRFSigGen_rngARBMultiCarrierMode
#define RSRFSIGGEN_VAL_ARB_MULTIC_MODE_EQU                                  0
#define RSRFSIGGEN_VAL_ARB_MULTIC_MODE_ARB                                  1

// RsRFSigGen_rngARBMultiCarrierCrestFactorMode
#define RSRFSIGGEN_VAL_ARB_SRC_CFACTOR_MODE_OFF                             0
#define RSRFSIGGEN_VAL_ARB_SRC_CFACTOR_MODE_MIN                             1
#define RSRFSIGGEN_VAL_ARB_SRC_CFACTOR_MODE_MAX                             2

// RsRFSigGen_rngARBSignalPeriodMode
#define RSRFSIGGEN_VAL_ARB_SRC_CALC_MODE_LONG                               0
#define RSRFSIGGEN_VAL_ARB_SRC_CALC_MODE_SHRT                               1
#define RSRFSIGGEN_VAL_ARB_SRC_CALC_MODE_USER                               2
#define RSRFSIGGEN_VAL_ARB_SRC_CALC_MODE_LCM                                3

// RsRFSigGen_rngGSMSlotAttenuation
#define RSRFSIGGEN_VAL_GSM_SLOT_ATTEN_A1                                    0
#define RSRFSIGGEN_VAL_GSM_SLOT_ATTEN_A2                                    1
#define RSRFSIGGEN_VAL_GSM_SLOT_ATTEN_A3                                    2
#define RSRFSIGGEN_VAL_GSM_SLOT_ATTEN_A4                                    3
#define RSRFSIGGEN_VAL_GSM_SLOT_ATTEN_A5                                    4
#define RSRFSIGGEN_VAL_GSM_SLOT_ATTEN_A6                                    5
#define RSRFSIGGEN_VAL_GSM_SLOT_ATTEN_A7                                    6

// RsRFSigGen_rngSatNavSimulationMode
#define RSRFSIGGEN_VAL_SATNAV_SIMULATION_STATIC                             0
#define RSRFSIGGEN_VAL_SATNAV_SIMULATION_AUTO                               1
#define RSRFSIGGEN_VAL_SATNAV_SIMULATION_USER                               2

// RsRFSigGen_rngSatNavMarkerMode
#define RSRFSIGGEN_VAL_SATNAV_MARKER_TYPE_PULSE                             0
#define RSRFSIGGEN_VAL_SATNAV_MARKER_TYPE_PATTERN                           1
#define RSRFSIGGEN_VAL_SATNAV_MARKER_TYPE_RATIO                             2
#define RSRFSIGGEN_VAL_SATNAV_MARKER_TYPE_PPS                               3
#define RSRFSIGGEN_VAL_SATNAV_MARKER_TYPE_PP2S                              4
#define RSRFSIGGEN_VAL_SATNAV_MARKER_TYPE_TRIG                              5
#define RSRFSIGGEN_VAL_SATNAV_MARKER_TYPE_DIS                               6
#define RSRFSIGGEN_VAL_SATNAV_MARKER_TYPE_PPS10                             7

// RsRFSigGen_rngSatNavClockMode
#define RSRFSIGGEN_VAL_SATNAV_CLOCK_MODE_CHIP                               0
#define RSRFSIGGEN_VAL_SATNAV_CLOCK_MODE_MCHIP                              1

// RsRFSigGen_rngSatNavPowerMode
#define RSRFSIGGEN_VAL_SATNAV_POWER_MODE_USER                               0
#define RSRFSIGGEN_VAL_SATNAV_POWER_MODE_AUTO                               1

// RsRFSigGen_rngSatNavIonosphericModel
#define RSRFSIGGEN_VAL_SATNAV_IONOSPHERIC_MODEL_NONE                        0
#define RSRFSIGGEN_VAL_SATNAV_IONOSPHERIC_MODEL_KLOB                        1

// RsRFSigGen_rngSatNavTroposphericModel
#define RSRFSIGGEN_VAL_SATNAV_TROPOSPHERIC_MODEL_NONE                       0
#define RSRFSIGGEN_VAL_SATNAV_TROPOSPHERIC_MODEL_STANAG                     1

// RsRFSigGen_rngSatNavSatStandard
#define RSRFSIGGEN_VAL_SATNAV_STANDARD_GPS                                  0
#define RSRFSIGGEN_VAL_SATNAV_STANDARD_GALILEO                              1
#define RSRFSIGGEN_VAL_SATNAV_STANDARD_GLONASS                              2
#define RSRFSIGGEN_VAL_SATNAV_STANDARD_BEIDOU                               3

// RsRFSigGen_rngSatNavADGAssistanceMode
#define RSRFSIGGEN_VAL_SATNAV_ADG_MODE_GPS                                  0
#define RSRFSIGGEN_VAL_SATNAV_ADG_MODE_GALILEO                              1
#define RSRFSIGGEN_VAL_SATNAV_ADG_MODE_GLONASS                              2

// RsRFSigGen_rngBBINSignalRouting
#define RSRFSIGGEN_VAL_BB_SIGNAL_ROUTING_A                                  0
#define RSRFSIGGEN_VAL_BB_SIGNAL_ROUTING_B                                  1
#define RSRFSIGGEN_VAL_BB_SIGNAL_ROUTING_AB                                 2

// RsRFSigGen_rngBBINMode
#define RSRFSIGGEN_VAL_BBIN_MODE_ANALOG                                     0
#define RSRFSIGGEN_VAL_BBIN_MODE_DIGITAL                                    1

// RsRFSigGen_rngPowerUnit
#define RSRFSIGGEN_VAL_SENSE_POWER_UNIT_DBM                                 0
#define RSRFSIGGEN_VAL_SENSE_POWER_UNIT_DBUV                                1
#define RSRFSIGGEN_VAL_SENSE_POWER_UNIT_WATT                                2

// RsRFSigGen_rngPowerSource
#define RSRFSIGGEN_VAL_SENSE_POWER_SOURCE_A                                 0
#define RSRFSIGGEN_VAL_SENSE_POWER_SOURCE_B                                 1
#define RSRFSIGGEN_VAL_SENSE_POWER_SOURCE_USER                              2
#define RSRFSIGGEN_VAL_SENSE_POWER_SOURCE_RF                                3

// RsRFSigGen_rngPowerFilterMode
#define RSRFSIGGEN_VAL_SENSE_POWER_FILTER_TYPE_AUTO                         0
#define RSRFSIGGEN_VAL_SENSE_POWER_FILTER_TYPE_USER                         1
#define RSRFSIGGEN_VAL_SENSE_POWER_FILTER_TYPE_NSR                          2

// RsRFSigGen_rngBERMode
#define RSRFSIGGEN_VAL_BER_MODE_AUTO                                        0
#define RSRFSIGGEN_VAL_BER_MODE_SINGLE                                      1

// RsRFSigGen_rngBERTPRBS
#define RSRFSIGGEN_VAL_BERT_PRBS_PRBS9                                      0
#define RSRFSIGGEN_VAL_BERT_PRBS_PRBS11                                     1
#define RSRFSIGGEN_VAL_BERT_PRBS_PRBS15                                     2
#define RSRFSIGGEN_VAL_BERT_PRBS_PRBS16                                     3
#define RSRFSIGGEN_VAL_BERT_PRBS_PRBS20                                     4
#define RSRFSIGGEN_VAL_BERT_PRBS_PRBS21                                     5
#define RSRFSIGGEN_VAL_BERT_PRBS_PRBS23                                     6

// RsRFSigGen_rngBERDataPolarity
#define RSRFSIGGEN_VAL_BER_DATA_POLARITY_NORMAL                             0
#define RSRFSIGGEN_VAL_BER_DATA_POLARITY_INVERTED                           1

// RsRFSigGen_rngBERClockSlope
#define RSRFSIGGEN_VAL_BER_CLOCK_SLOPE_RISING                               0
#define RSRFSIGGEN_VAL_BER_CLOCK_SLOPE_FALLING                              1

// RsRFSigGen_rngBERTDataEnable
#define RSRFSIGGEN_VAL_BERT_DATA_ENABLE_OFF                                 0
#define RSRFSIGGEN_VAL_BERT_DATA_ENABLE_LOW                                 1
#define RSRFSIGGEN_VAL_BERT_DATA_ENABLE_HIGH                                2

// RsRFSigGen_rngBERTPatternIgnore
#define RSRFSIGGEN_VAL_BERT_PATTERN_IGNORE_OFF                              0
#define RSRFSIGGEN_VAL_BERT_PATTERN_IGNORE_ONE                              1
#define RSRFSIGGEN_VAL_BERT_PATTERN_IGNORE_ZERO                             2

// RsRFSigGen_rngBERTImpedance
#define RSRFSIGGEN_VAL_BERT_IMP_G50                                         0
#define RSRFSIGGEN_VAL_BERT_IMP_G1K                                         1

// RsRFSigGen_rngBERDisplayUnit
#define RSRFSIGGEN_VAL_BER_DISPLAY_UNIT_ENG                                 0
#define RSRFSIGGEN_VAL_BER_DISPLAY_UNIT_SCI                                 1
#define RSRFSIGGEN_VAL_BER_DISPLAY_UNIT_PCT                                 2
#define RSRFSIGGEN_VAL_BER_DISPLAY_UNIT_PPM                                 3

// RsRFSigGen_rngBLERDataEnable
#define RSRFSIGGEN_VAL_BLER_DATA_ENABLE_LOW                                 0
#define RSRFSIGGEN_VAL_BLER_DATA_ENABLE_HIGH                                1
#define RSRFSIGGEN_VAL_BLER_DATA_ENABLE_OFF                                 2

// RsRFSigGen_rngImpedance
#define RSRFSIGGEN_VAL_IMPEDANCE_G50                                        0
#define RSRFSIGGEN_VAL_IMPEDANCE_G1K                                        1

// RsRFSigGen_rngSlope
#define RSRFSIGGEN_VAL_SLOPE_NEGATIVE                                       0
#define RSRFSIGGEN_VAL_SLOPE_POSITIVE                                       1

// RsRFSigGen_rngGlobalClockMode
#define RSRFSIGGEN_VAL_CLOCK_OUTPUT_MODE_SYMBOL                             0
#define RSRFSIGGEN_VAL_CLOCK_OUTPUT_MODE_BIT                                1

// RsRFSigGen_rngOutputConnectorUserMapping
#define RSRFSIGGEN_VAL_OUTPUT_USER_SOURCE_AMARK4                            0
#define RSRFSIGGEN_VAL_OUTPUT_USER_SOURCE_BMARK4                            1
#define RSRFSIGGEN_VAL_OUTPUT_USER_SOURCE_ACW                               2
#define RSRFSIGGEN_VAL_OUTPUT_USER_SOURCE_BCW                               3
#define RSRFSIGGEN_VAL_OUTPUT_USER_SOURCE_ABLANK                            4
#define RSRFSIGGEN_VAL_OUTPUT_USER_SOURCE_BBLANK                            5
#define RSRFSIGGEN_VAL_OUTPUT_USER_SOURCE_AHOP                              6
#define RSRFSIGGEN_VAL_OUTPUT_USER_SOURCE_BHOP                              7
#define RSRFSIGGEN_VAL_OUTPUT_USER_SOURCE_ATRG                              8
#define RSRFSIGGEN_VAL_OUTPUT_USER_SOURCE_BTRG                              9
#define RSRFSIGGEN_VAL_OUTPUT_USER_SOURCE_BBITCLOCK                         10
#define RSRFSIGGEN_VAL_OUTPUT_USER_SOURCE_BSYMBOLCLOCK                      11
#define RSRFSIGGEN_VAL_OUTPUT_USER_SOURCE_BATTENUATOR                       12
#define RSRFSIGGEN_VAL_OUTPUT_USER_SOURCE_BBURST                            13

// RsRFSigGen_rngNoSignalMarkerPolarity
#define RSRFSIGGEN_VAL_OUTPUT_BLANK_POLARITY_NORMAL                         0
#define RSRFSIGGEN_VAL_OUTPUT_BLANK_POLARITY_INVERSE                        1

// RsRFSigGen_rngIQOutputSignal
#define RSRFSIGGEN_VAL_IQ_OUTPUT_SIGNAL_A                                   0
#define RSRFSIGGEN_VAL_IQ_OUTPUT_SIGNAL_B                                   1

// RsRFSigGen_rngIMPOptimizationMode
#define RSRFSIGGEN_VAL_OPTIM_MODE_FAST                                      0
#define RSRFSIGGEN_VAL_OPTIM_MODE_QHIGH                                     1
#define RSRFSIGGEN_VAL_OPTIM_MODE_UCOR                                      2
#define RSRFSIGGEN_VAL_OPTIM_MODE_QHT                                       3

// RsRFSigGen_rngFSIMSignalRouting
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FAA                              0
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FAAFBB                           1
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FAAFBA                           2
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FABFBB                           3
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FAABFBAB                         4
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FAMAXA                           5
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FBMAXB                           6
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FAMAXAB                          7
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FBMAXAB                          8
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2B                     9
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM24                  10
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM42                  11
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM23                  12
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM32                  13
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM12                  14
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM13                  15
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM14                  16
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM22                  17
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM31                  18
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM33                  19
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM34                  20
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM41                  21
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM43                  22
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM44                  23
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM18                  24
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM81                  25
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM28                  26
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM82                  27
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM21                  28
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM48                  29
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM84                  30
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM212                 31
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM221                 32
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM222                 33
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM213                 34
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM214                 35
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM223                 36
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM231                 37
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM232                 38
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM241                 39
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM312                 40
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM321                 41
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM322                 42
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM412                 43
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM421                 44
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM422                 45
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FAAFBB311                        46
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FAAFBB411                        47
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FAAFBB511                        48
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FAAFBB611                        49
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FAAFBB711                        50
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FAAFBB811                        51
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM224                 52
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM242                 53
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM244                 54
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM233                 55
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM234                 56
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM243                 57
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_ROUTING_FA1A2BFB1A2BM88                  58

// RsRFSigGen_rngFSIMStandard
#define RSRFSIGGEN_VAL_FSIM_STANDARD_CDMA8                                  0
#define RSRFSIGGEN_VAL_FSIM_STANDARD_CDMA30                                 1
#define RSRFSIGGEN_VAL_FSIM_STANDARD_C1DMA30                                2
#define RSRFSIGGEN_VAL_FSIM_STANDARD_CDMA100                                3
#define RSRFSIGGEN_VAL_FSIM_STANDARD_CDMA0                                  4
#define RSRFSIGGEN_VAL_FSIM_STANDARD_CDMA3                                  5
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G6TU3                                  6
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GTU3                                   7
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G6TU50                                 8
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GTU50                                  9
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G6HT100                                10
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GHT100                                 11
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GRA250                                 12
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GET50                                  13
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GET100                                 14
#define RSRFSIGGEN_VAL_FSIM_STANDARD_NADC8                                  15
#define RSRFSIGGEN_VAL_FSIM_STANDARD_NADC50                                 16
#define RSRFSIGGEN_VAL_FSIM_STANDARD_NADC100                                17
#define RSRFSIGGEN_VAL_FSIM_STANDARD_P6TU1                                  18
#define RSRFSIGGEN_VAL_FSIM_STANDARD_PTU1                                   19
#define RSRFSIGGEN_VAL_FSIM_STANDARD_P6TU50                                 20
#define RSRFSIGGEN_VAL_FSIM_STANDARD_PTU50                                  21
#define RSRFSIGGEN_VAL_FSIM_STANDARD_P6HT100                                22
#define RSRFSIGGEN_VAL_FSIM_STANDARD_PHT100                                 23
#define RSRFSIGGEN_VAL_FSIM_STANDARD_PRA130                                 24
#define RSRFSIGGEN_VAL_FSIM_STANDARD_PET50                                  25
#define RSRFSIGGEN_VAL_FSIM_STANDARD_PET100                                 26
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TTU                                    27
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TBU                                    28
#define RSRFSIGGEN_VAL_FSIM_STANDARD_THT                                    29
#define RSRFSIGGEN_VAL_FSIM_STANDARD_T4ET                                   30
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3C1                                   31
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3C2                                   32
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3C3                                   33
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3C4                                   34
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3UEC4                                 35
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3UEC5                                 36
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3UEC6                                 37
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3UEC7SE                               38
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3UEC7BE                               39
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3UEC8CQ                               40
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3UEPA3                                41
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3UEPB3                                42
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3UEVA30                               43
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3UEVA120                              44
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3TU3                                  45
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3TU50                                 46
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3TU120                                47
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3HT120                                48
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3RA120                                49
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3RA250                                50
#define RSRFSIGGEN_VAL_FSIM_STANDARD_BD1                                    51
#define RSRFSIGGEN_VAL_FSIM_STANDARD_MP1                                    52
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GRA130                                 53
#define RSRFSIGGEN_VAL_FSIM_STANDARD_T6TU                                   54
#define RSRFSIGGEN_VAL_FSIM_STANDARD_T6HT                                   55
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDU                                    56
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDR                                    57
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3HST1OS                               58
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3HST2TLC                              59
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3HST3TMA                              60
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HL2A                                   61
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HL2B                                   62
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HL2C                                   63
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HL2D                                   64
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HL2E                                   65
#define RSRFSIGGEN_VAL_FSIM_STANDARD_DABRA04                                66
#define RSRFSIGGEN_VAL_FSIM_STANDARD_DABRA06                                67
#define RSRFSIGGEN_VAL_FSIM_STANDARD_DABTU12                                68
#define RSRFSIGGEN_VAL_FSIM_STANDARD_DABTU06                                69
#define RSRFSIGGEN_VAL_FSIM_STANDARD_DABSFNVHF                              70
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI1A360P90                          71
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI1A360P75                          72
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI1A030P90                          73
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI1A030P75                          74
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI2A360P90                          75
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI2A360P75                          76
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI2A030P90                          77
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI2A030P75                          78
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI3A360P90                          79
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI3A360P75                          80
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI3A030P90                          81
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI3A030P75                          82
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI4A360P90                          83
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI4A360P75                          84
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI4A030P90                          85
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI4A030P75                          86
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI5A360P90                          87
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI5A360P75                          88
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI5A360P50                          89
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI5A030P90                          90
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI5A030P75                          91
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI5A030P50                          92
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI6A360P90                          93
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI6A360P75                          94
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI6A360P50                          95
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI6A030P90                          96
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI6A030P75                          97
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMSUI6A030P50                          98
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMITUOIPA                              99
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMITUOIPB                              100
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMITUVA60                              101
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMITUVA120                             102
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMITUPB3L                              103
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMITUPB3M                              104
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMITUPB3H                              105
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMITUVA60L                             106
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMITUVA60M                             107
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WMITUVA60H                             108
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LTEEPA5                                109
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LTEEVA5                                110
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LTEEVA70                               111
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LTEETU70                               112
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LTEETU300                              113
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMEPA5L                                114
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMEPA5M                                115
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMEPA5H                                116
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMEVA5L                                117
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMEVA5M                                118
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMEVA5H                                119
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU70L                               120
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU70M                               121
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU70H                               122
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU300L                              123
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU300M                              124
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU300H                              125
#define RSRFSIGGEN_VAL_FSIM_STANDARD_EVDO1CH1                               126
#define RSRFSIGGEN_VAL_FSIM_STANDARD_EVDO1CH1BC5                            127
#define RSRFSIGGEN_VAL_FSIM_STANDARD_EVDO1CH2                               128
#define RSRFSIGGEN_VAL_FSIM_STANDARD_EVDO1CH2BC5                            129
#define RSRFSIGGEN_VAL_FSIM_STANDARD_EVDO1CH3                               130
#define RSRFSIGGEN_VAL_FSIM_STANDARD_EVDO1CH3BC5                            131
#define RSRFSIGGEN_VAL_FSIM_STANDARD_EVDO1CH4                               132
#define RSRFSIGGEN_VAL_FSIM_STANDARD_EVDO1CH4BC5                            133
#define RSRFSIGGEN_VAL_FSIM_STANDARD_EVDO1CH5                               134
#define RSRFSIGGEN_VAL_FSIM_STANDARD_EVDO1CH5BC5                            135
#define RSRFSIGGEN_VAL_FSIM_STANDARD_USER                                   136
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GTU1P5                                 137
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G6TU1P5                                138
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GTU3P6                                 139
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G6TU3P6                                140
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GTU6                                   141
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G6TU6                                  142
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G6TU100                                143
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G6TU60                                 144
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GHT120                                 145
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G6HT120                                146
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GHT200                                 147
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G6HT200                                148
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GRA300                                 149
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GRA500                                 150
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GET60                                  151
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GTI5                                   152
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3UEC1                                 153
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3UEC2                                 154
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3UEC3                                 155
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3MBSFN3                               156
#define RSRFSIGGEN_VAL_FSIM_STANDARD_MPLTEETU200                            157
#define RSRFSIGGEN_VAL_FSIM_STANDARD_MPLTEPDOPP                             158
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3HST1OSDU                             159
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3HST2TLCDU                            160
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3HST3TMADU                            161
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3SCMEUMA3                             162
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3SCMEUMA30                            163
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3SCMEUMI3                             164
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3SCMEUMI30                            165
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GEOSCMEUMA3                            166
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GEOSCMEUMA30                           167
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GEOSCMEUMI3                            168
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GEOSCMEUMI30                           169
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LTEEPA1                                170
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LTEETU1                                171
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LTEETU600                              172
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LTEMBSFN5                              173
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMEPA1L                                174
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMEPA1M                                175
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMEPA1H                                176
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMEVA70L                               177
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMEVA70M                               178
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMEVA70H                               179
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU1L                                180
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU1M                                181
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU1H                                182
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU30L                               183
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU30M                               184
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU600L                              185
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU600M                              186
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU600H                              187
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WATTI1                                 188
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WATTI2                                 189
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WATTI3                                 190
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANNSMODA                             191
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANNSMODB                             192
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANNSMODC                             193
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANNSMODD                             194
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANNSMODE                             195
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANNSMODF                             196
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANNMODA                              197
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANNMODB                              198
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANNMODC                              199
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANNMODD                              200
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANNMODE                              201
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANNMODF                              202
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANACSMODA                            203
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANACSMODB                            204
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANACSMODC                            205
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANACSMODD                            206
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANACSMODE                            207
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANACSMODF                            208
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANACMODA                             209
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANACMODB                             210
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANACMODC                             211
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANACMODD                             212
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANACMODE                             213
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANACMODF                             214
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANPRURALLOS                          215
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANPURBANAPPLOS                       216
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANPURBANCRONLOS                      217
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANPHIGHWAYNLOS                       218
#define RSRFSIGGEN_VAL_FSIM_STANDARD_WLANPHIGHWAYLOS                        219
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D5L                              220
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D5M                              221
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D5MA                             222
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D5H                              223
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D10L                             224
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D10M                             225
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D10MA                            226
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D10H                             227
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLB100D400L                           228
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLB100D400M                           229
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLB100D400MA                          230
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLB100D400H                           231
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC300D100L                           232
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC300D100M                           233
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC300D100MA                          234
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC300D100H                           235
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D75L                             236
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D75M                             237
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D75MA                            238
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D75H                             239
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D300L                            240
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D300M                            241
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D300MA                           242
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D300H                            243
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D10S                             244
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLB100D400S                           245
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC300D100S                           246
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D75S                             247
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D300S                            248
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D35S                             249
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC60D300S                            250
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D35L                             251
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D35M                             252
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D35MA                            253
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D35H                             254
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC60D300L                            255
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC60D300M                            256
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC60D300MA                           257
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC60D300H                            258
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HST1NR35015                            259
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HST1NR35030                            260
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HST3NR35015                            261
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HST3NR35030                            262
#define RSRFSIGGEN_VAL_FSIM_STANDARD_MPY15                                  263
#define RSRFSIGGEN_VAL_FSIM_STANDARD_MPY30                                  264
#define RSRFSIGGEN_VAL_FSIM_STANDARD_FR1CDLAUMA                             265
#define RSRFSIGGEN_VAL_FSIM_STANDARD_FR1CDLCUMA                             266
#define RSRFSIGGEN_VAL_FSIM_STANDARD_FR1CDLAUMI                             267
#define RSRFSIGGEN_VAL_FSIM_STANDARD_FR1CDLCUMI                             268
#define RSRFSIGGEN_VAL_FSIM_STANDARD_FR2CDLAINO                             269
#define RSRFSIGGEN_VAL_FSIM_STANDARD_FR2CDLCUMI                             270
#define RSRFSIGGEN_VAL_FSIM_STANDARD_FR1CDLBUMA                             271
#define RSRFSIGGEN_VAL_FSIM_STANDARD_FR1CDLBUMI                             272
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HST1NR50015                            273
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HST1NR50030                            274
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HST3NR50015                            275
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HST3NR50030                            276
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HST1LTE500A                            277
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HST3LTE500A                            278
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HST1LTE500B                            279
#define RSRFSIGGEN_VAL_FSIM_STANDARD_HST3LTE500B                            280
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LTEETU5                                281
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LTEETU200                              282
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU5L                                283
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU5M                                284
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU5H                                285
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU200L                              286
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU200M                              287
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU200H                              288
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC300D600L                           289
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC300D600M                           290
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC300D600H                           291
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC300D1200L                          292
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC300D1200M                          293
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC300D1200H                          294
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC300D400S                           295
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC300D600S                           296
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLC300D1200S                          297
#define RSRFSIGGEN_VAL_FSIM_STANDARD_MPX15                                  298
#define RSRFSIGGEN_VAL_FSIM_STANDARD_MPX30                                  299
#define RSRFSIGGEN_VAL_FSIM_STANDARD_MPZ15                                  300
#define RSRFSIGGEN_VAL_FSIM_STANDARD_MPZ30                                  301
#define RSRFSIGGEN_VAL_FSIM_STANDARD_FR1CDLCUMI2                            302
#define RSRFSIGGEN_VAL_FSIM_STANDARD_FR1CDLCUMA4                            303
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GTU60                                  304
#define RSRFSIGGEN_VAL_FSIM_STANDARD_GTU100                                 305
#define RSRFSIGGEN_VAL_FSIM_STANDARD_G3UEVA3                                306
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LTECQI5                                307
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LTEETU30                               308
#define RSRFSIGGEN_VAL_FSIM_STANDARD_LMETU30H                               309
#define RSRFSIGGEN_VAL_FSIM_STANDARD_TDLA30D5S                              310
#define RSRFSIGGEN_VAL_FSIM_STANDARD_MPY120                                 311
#define RSRFSIGGEN_VAL_FSIM_STANDARD_MPNTNX15                               312
#define RSRFSIGGEN_VAL_FSIM_STANDARD_MPNTNX30                               313
#define RSRFSIGGEN_VAL_FSIM_STANDARD_NTNTDLA100D200L                        314
#define RSRFSIGGEN_VAL_FSIM_STANDARD_NTNTDLA100D200M                        315
#define RSRFSIGGEN_VAL_FSIM_STANDARD_NTNTDLA100D200H                        316
#define RSRFSIGGEN_VAL_FSIM_STANDARD_NTNTDLC5D200L                          317
#define RSRFSIGGEN_VAL_FSIM_STANDARD_NTNTDLC5D200M                          318
#define RSRFSIGGEN_VAL_FSIM_STANDARD_NTNTDLC5D200H                          319

// RsRFSigGen_rngAWGNMode
#define RSRFSIGGEN_VAL_AWGN_MODE_ADD                                        0
#define RSRFSIGGEN_VAL_AWGN_MODE_ONLY                                       1
#define RSRFSIGGEN_VAL_AWGN_MODE_CW                                         2

// RsRFSigGen_rngAWGNNoiseMode
#define RSRFSIGGEN_VAL_AWGN_POWER_MODE_CN                                   0
#define RSRFSIGGEN_VAL_AWGN_POWER_MODE_EN                                   1
#define RSRFSIGGEN_VAL_AWGN_POWER_MODE_SN                                   2

// RsRFSigGen_rngFSIMFadingConfiguration
#define RSRFSIGGEN_VAL_FSIM_CONFIG_STAN                                     0
#define RSRFSIGGEN_VAL_FSIM_CONFIG_BIRT                                     3
#define RSRFSIGGEN_VAL_FSIM_CONFIG_MDEL                                     4
#define RSRFSIGGEN_VAL_FSIM_CONFIG_CDYN                                     5
#define RSRFSIGGEN_VAL_FSIM_CONFIG_TCI                                      6
#define RSRFSIGGEN_VAL_FSIM_CONFIG_HSTR                                     7

// RsRFSigGen_rngStereoAudioSource
#define RSRFSIGGEN_VAL_STEREO_AUDIO_SOURCE_OFF                              0
#define RSRFSIGGEN_VAL_STEREO_AUDIO_SOURCE_SPDIF                            1
#define RSRFSIGGEN_VAL_STEREO_AUDIO_SOURCE_LFG                              2
#define RSRFSIGGEN_VAL_STEREO_AUDIO_SOURCE_FILE                             3

// RsRFSigGen_rngStereoExternalClock
#define RSRFSIGGEN_VAL_STEREO_EXTERNAL_CLOCK_44K1                           0
#define RSRFSIGGEN_VAL_STEREO_EXTERNAL_CLOCK_48K                            1

// RsRFSigGen_rngStereoAudioMode
#define RSRFSIGGEN_VAL_STEREO_AUDIO_MODE_LEFT                               0
#define RSRFSIGGEN_VAL_STEREO_AUDIO_MODE_RIGHT                              1
#define RSRFSIGGEN_VAL_STEREO_AUDIO_MODE_ST_LR                              2
#define RSRFSIGGEN_VAL_STEREO_AUDIO_MODE_ST_LNR                             3
#define RSRFSIGGEN_VAL_STEREO_AUDIO_MODE_ST_TRUE                            4

// RsRFSigGen_rngStereoPreemphasis
#define RSRFSIGGEN_VAL_STEREO_PREEMPHASIS_OFF                               0
#define RSRFSIGGEN_VAL_STEREO_PREEMPHASIS_US50                              1
#define RSRFSIGGEN_VAL_STEREO_PREEMPHASIS_US75                              2

// RsRFSigGen_rngStereoTriggerStatus
#define RSRFSIGGEN_VAL_STEREO_TRIGGER_STOP                                  0
#define RSRFSIGGEN_VAL_STEREO_TRIGGER_RUN                                   1

// RsRFSigGen_rngStereoTriggerMode
#define RSRFSIGGEN_VAL_STEREO_TRIGGER_MODE_AUTO                             0

// RsRFSigGen_rngStereoDSGroupsInputMethod
#define RSRFSIGGEN_VAL_STEREO_DS_GROUPS_INPUT_FORMAT_MESSAGE                0
#define RSRFSIGGEN_VAL_STEREO_DS_GROUPS_INPUT_FORMAT_HEX                    1

// RsRFSigGen_rngStereoDSMode
#define RSRFSIGGEN_VAL_STEREO_DS_MODE_RDS                                   0
#define RSRFSIGGEN_VAL_STEREO_DS_MODE_RBDS                                  1

// RsRFSigGen_rngStereoGroupInputMethod
#define RSRFSIGGEN_VAL_STEREO_GROUP_INPUT_METHOD_STANDARD                   0
#define RSRFSIGGEN_VAL_STEREO_GROUP_INPUT_METHOD_USER                       1

// RsRFSigGen_rngStereoGroupTypeVersion
#define RSRFSIGGEN_VAL_STEREO_GROUP_TYPE_VERSION_A                          0
#define RSRFSIGGEN_VAL_STEREO_GROUP_TYPE_VERSION_B                          1

// RsRFSigGen_rngStereoGroupMusicVoiceSwitch
#define RSRFSIGGEN_VAL_STEREO_GROUP_SWITCH_MUSIC                            0
#define RSRFSIGGEN_VAL_STEREO_GROUP_SWITCH_VOICE                            1

// RsRFSigGen_rngStereoGroupDateType
#define RSRFSIGGEN_VAL_STEREO_GROUP_DATE_TYPE_SYTEM                         0
#define RSRFSIGGEN_VAL_STEREO_GROUP_DATE_TYPE_USER                          1

// RsRFSigGen_rngStereoGroupTimeType
#define RSRFSIGGEN_VAL_STEREO_GROUP_TIME_TYPE_SYSTEM                        0
#define RSRFSIGGEN_VAL_STEREO_GROUP_TIME_TYPE_USER                          1

// RsRFSigGen_rngStereoDSDataSet
#define RSRFSIGGEN_VAL_STEREO_DATA_SET_USER_GROUP                           0
#define RSRFSIGGEN_VAL_STEREO_DATA_SET_GROUP_LIST                           1

// RsRFSigGen_rngFSIMSignalDedicatedTo
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_DEDICATED_TO_RF                          0
#define RSRFSIGGEN_VAL_FSIM_SIGNAL_DEDICATED_TO_BB                          1

// RsRFSigGen_rngFSIMSpeedUnit
#define RSRFSIGGEN_VAL_FSIM_SPEED_UNIT_MPS                                  0
#define RSRFSIGGEN_VAL_FSIM_SPEED_UNIT_KMH                                  1
#define RSRFSIGGEN_VAL_FSIM_SPEED_UNIT_MPH                                  2
#define RSRFSIGGEN_VAL_FSIM_SPEED_UNIT_NMPH                                 3

// RsRFSigGen_rngFSIMKeepConstant
#define RSRFSIGGEN_VAL_FSIM_KEEP_CONSTANT_SPEED                             0
#define RSRFSIGGEN_VAL_FSIM_KEEP_CONSTANT_DSH                               1

// RsRFSigGen_rngFSIMRestartEvent
#define RSRFSIGGEN_VAL_FSIM_RESTART_EVENT_AUTO                              0
#define RSRFSIGGEN_VAL_FSIM_RESTART_EVENT_MANUAL                            1
#define RSRFSIGGEN_VAL_FSIM_RESTART_EVENT_EXT1                              3
#define RSRFSIGGEN_VAL_FSIM_RESTART_EVENT_EXT2                              4

// RsRFSigGen_rngFSIMHoppingMode
#define RSRFSIGGEN_VAL_FSIM_FREQ_HOPPING_MODE_OFF                           0
#define RSRFSIGGEN_VAL_FSIM_FREQ_HOPPING_MODE_IBAND                         1
#define RSRFSIGGEN_VAL_FSIM_FREQ_HOPPING_MODE_OOBAND                        2

// RsRFSigGen_rngFSIMProfile
#define RSRFSIGGEN_VAL_FADING_PROFILE_SPAT                                  0
#define RSRFSIGGEN_VAL_FADING_PROFILE_PDOP                                  1
#define RSRFSIGGEN_VAL_FADING_PROFILE_RAYL                                  2

// RsRFSigGen_rngFSIMTCIMovingMode
#define RSRFSIGGEN_VAL_FADING_TCI_MOVING_MODE_SLID                          0
#define RSRFSIGGEN_VAL_FADING_TCI_MOVING_MODE_HOPP                          1

// RsRFSigGen_rngFSIMMovingChannels
#define RSRFSIGGEN_VAL_FSIM_MOVING_CHANNELS_ONE                             0
#define RSRFSIGGEN_VAL_FSIM_MOVING_CHANNELS_ALL                             1

// RsRFSigGen_rngFSIMInsertionLossMode
#define RSRFSIGGEN_VAL_FSIM_INSERTION_LOSS_NORMAL                           0
#define RSRFSIGGEN_VAL_FSIM_INSERTION_LOSS_LACP                             1
#define RSRFSIGGEN_VAL_FSIM_INSERTION_LOSS_USER                             2

// RsRFSigGen_rngFSIMMIMOTab
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP1                                   0
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP2                                   1
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP3                                   2
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP4                                   3
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP5                                   4
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP6                                   5
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP7                                   6
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP8                                   7
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP9                                   8
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP10                                  9
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP11                                  10
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP12                                  11
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP13                                  12
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP14                                  13
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP15                                  14
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP16                                  15
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP17                                  16
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP18                                  17
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP19                                  18
#define RSRFSIGGEN_VAL_FSIM_MIMO_TAB_TAP20                                  19

// RsRFSigGen_rngFSIMMIMOSubset
#define RSRFSIGGEN_VAL_FSIM_MIMO_SUBSET_SET1                                0
#define RSRFSIGGEN_VAL_FSIM_MIMO_SUBSET_SET2                                1
#define RSRFSIGGEN_VAL_FSIM_MIMO_SUBSET_ALL                                 2

// RsRFSigGen_rngFSIMMIMOMatrixMode
#define RSRFSIGGEN_VAL_FSIM_MIMO_MATRIX_MODE_IND                            0
#define RSRFSIGGEN_VAL_FSIM_MIMO_MATRIX_MODE_KRON                           1

// RsRFSigGen_rngFSIMFadingProfile
#define RSRFSIGGEN_VAL_FSIM_FADING_PROFILE_PDOP                             0
#define RSRFSIGGEN_VAL_FSIM_FADING_PROFILE_SPAT                             1
#define RSRFSIGGEN_VAL_FSIM_FADING_PROFILE_RAYLEIGH                         2
#define RSRFSIGGEN_VAL_FSIM_FADING_PROFILE_RICE                             3
#define RSRFSIGGEN_VAL_FSIM_FADING_PROFILE_CPHASE                           4
#define RSRFSIGGEN_VAL_FSIM_FADING_PROFILE_OGAU                             5
#define RSRFSIGGEN_VAL_FSIM_FADING_PROFILE_TGAU                             6
#define RSRFSIGGEN_VAL_FSIM_FADING_PROFILE_DGAU                             7
#define RSRFSIGGEN_VAL_FSIM_FADING_PROFILE_GDOP                             8
#define RSRFSIGGEN_VAL_FSIM_FADING_PROFILE_GFD8                             9
#define RSRFSIGGEN_VAL_FSIM_FADING_PROFILE_GFD1                             10
#define RSRFSIGGEN_VAL_FSIM_FADING_PROFILE_WDOP                             11
#define RSRFSIGGEN_VAL_FSIM_FADING_PROFILE_WRIC                             12

// RsRFSigGen_rngKeyboardLayout
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_US                                   0
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_DE                                   1
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_ENGUK                                2
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_CHIN                                 3
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_DAN                                  4
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_DUTC                                 5
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_FINN                                 6
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_FREN                                 7
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_FREB                                 8
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_FREC                                 9
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_ITAL                                 10
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_JAP                                  11
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_KOR                                  12
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_NORW                                 13
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_PORT                                 14
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_RUSS                                 15
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_SPAN                                 16
#define RSRFSIGGEN_VAL_SYSTEM_KEYBOARD_SWED                                 17

// RsRFSigGen_rngDisplayBlankMode
#define RSRFSIGGEN_VAL_DISPLAY_BLANK_MODE_ON                                0
#define RSRFSIGGEN_VAL_DISPLAY_BLANK_MODE_OFF                               1
#define RSRFSIGGEN_VAL_DISPLAY_BLANK_MODE_AUTO                              2

// RsRFSigGen_rngDisplayProportionalScale
#define RSRFSIGGEN_VAL_DISPLAY_PROPORTIONAL_SCALE_S0V5                      0
#define RSRFSIGGEN_VAL_DISPLAY_PROPORTIONAL_SCALE_S1V0                      1

// RsRFSigGen_rngGraphicsMode
#define RSRFSIGGEN_VAL_GRAPHICS_MODE_IQ                                     0
#define RSRFSIGGEN_VAL_GRAPHICS_MODE_VECT                                   1
#define RSRFSIGGEN_VAL_GRAPHICS_MODE_CCDF                                   2
#define RSRFSIGGEN_VAL_GRAPHICS_MODE_PSP                                    3
#define RSRFSIGGEN_VAL_GRAPHICS_MODE_CONST                                  4
#define RSRFSIGGEN_VAL_GRAPHICS_MODE_EYEI                                   5
#define RSRFSIGGEN_VAL_GRAPHICS_MODE_EYEQ                                   6

// RsRFSigGen_rngGraphicsTriggerSource
#define RSRFSIGGEN_VAL_GRAPHICS_TRIGGER_SOURCE_SOFTWARE                     0
#define RSRFSIGGEN_VAL_GRAPHICS_TRIGGER_SOURCE_MARKER                       1

// RsRFSigGen_rngGraphicsSampleRateMode
#define RSRFSIGGEN_VAL_GRAPHICS_SAMPLE_RATE_AUTO                            0
#define RSRFSIGGEN_VAL_GRAPHICS_SAMPLE_RATE_FULL                            1
#define RSRFSIGGEN_VAL_GRAPHICS_SAMPLE_RATE_USER                            2

// RsRFSigGen_rngUnitAngle
#define RSRFSIGGEN_VAL_UNIT_ANGLE_DEG                                       0
#define RSRFSIGGEN_VAL_UNIT_ANGLE_RAD                                       1

// RsRFSigGen_rngUnitPower
#define RSRFSIGGEN_VAL_UNIT_POWER_V                                         0
#define RSRFSIGGEN_VAL_UNIT_POWER_DBM                                       1
#define RSRFSIGGEN_VAL_UNIT_POWER_DBUV                                      2

// RsRFSigGen_rngSystemIPAddressMode
#define RSRFSIGGEN_VAL_SYSTEM_COMMUNICATE_IP_MODE_STATIC                    0
#define RSRFSIGGEN_VAL_SYSTEM_COMMUNICATE_IP_MODE_P2P                       1
#define RSRFSIGGEN_VAL_SYSTEM_COMMUNICATE_IP_MODE_AUTO                      2

// RsRFSigGen_rngNetworkDNSMode
#define RSRFSIGGEN_VAL_SYSTEM_COMMUNICATE_DNS_MODE_STATIC                   0
#define RSRFSIGGEN_VAL_SYSTEM_COMMUNICATE_DNS_MODE_AUTO                     1

// RsRFSigGen_rngHardCopyDestination
#define RSRFSIGGEN_VAL_HCOPY_DEVICE_FILE                                    0
#define RSRFSIGGEN_VAL_HCOPY_DEVICE_PRNT                                    1

// RsRFSigGen_rngHardCopyLanguage
#define RSRFSIGGEN_VAL_HCOPY_LANG_BMP                                       0
#define RSRFSIGGEN_VAL_HCOPY_LANG_JPG                                       1
#define RSRFSIGGEN_VAL_HCOPY_LANG_XPM                                       2
#define RSRFSIGGEN_VAL_HCOPY_LANG_PNG                                       3

// RsRFSigGen_rngHardCopyImageResolution
#define RSRFSIGGEN_VAL_HCOPY_IMAGE_320                                      0
#define RSRFSIGGEN_VAL_HCOPY_IMAGE_640                                      1
#define RSRFSIGGEN_VAL_HCOPY_IMAGE_800                                      2
#define RSRFSIGGEN_VAL_HCOPY_IMAGE_1024                                     3

// RsRFSigGen_rngHardCopyPageUnit
#define RSRFSIGGEN_VAL_HCOPY_UNIT_CM                                        0
#define RSRFSIGGEN_VAL_HCOPY_UNIT_IN                                        1

// RsRFSigGen_rngHardCopyPageOrientation
#define RSRFSIGGEN_VAL_HCOPY_PAGE_PORT                                      0
#define RSRFSIGGEN_VAL_HCOPY_PAGE_LAND                                      1

// RsRFSigGen_rngHardCopyPageSize
#define RSRFSIGGEN_VAL_HCOPY_PAGE_LETT                                      0
#define RSRFSIGGEN_VAL_HCOPY_PAGE_LEGL                                      1
#define RSRFSIGGEN_VAL_HCOPY_PAGE_EXEC                                      2
#define RSRFSIGGEN_VAL_HCOPY_PAGE_A4                                        3
#define RSRFSIGGEN_VAL_HCOPY_PAGE_A5                                        4

// RsRFSigGen_rngTriggerSourceForAllSweeps
#define RSRFSIGGEN_VAL_TRIG_SOURCE_SWEEP_AUTO                               0
#define RSRFSIGGEN_VAL_TRIG_SOURCE_SWEEP_IMMEDIATE                          1
#define RSRFSIGGEN_VAL_TRIG_SOURCE_SWEEP_SINGLE                             2
#define RSRFSIGGEN_VAL_TRIG_SOURCE_SWEEP_EXTERNAL                           3
#define RSRFSIGGEN_VAL_TRIG_SOURCE_SWEEP_BUS                                4
#define RSRFSIGGEN_VAL_TRIG_SOURCE_SWEEP_EAUT                               5

// RsRFSigGen_rngRFFrequencyonRecall
#define RSRFSIGGEN_VAL_FREQUENCY_RCL_INCLUDE                                0
#define RSRFSIGGEN_VAL_FREQUENCY_RCL_EXCLUDE                                1

// RsRFSigGen_rngRFPhaseContinuousMode
#define RSRFSIGGEN_VAL_FREQUENCY_PHASE_CONTINUOUS_MODE_NARROW               0
#define RSRFSIGGEN_VAL_FREQUENCY_PHASE_CONTINUOUS_MODE_WIDE                 1

// RsRFSigGen_rngROSCExternalReferenceFrequency
#define RSRFSIGGEN_VAL_EXTERN_REF_FREQ_5MHZ                                 0
#define RSRFSIGGEN_VAL_EXTERN_REF_FREQ_10MHZ                                1
#define RSRFSIGGEN_VAL_EXTERN_REF_FREQ_13MHZ                                2

// RsRFSigGen_rngROSCSynchronizationBandwidth
#define RSRFSIGGEN_VAL_ROSC_SBAN_STANDARD                                   0
#define RSRFSIGGEN_VAL_ROSC_SBAN_NARROW                                     1

// RsRFSigGen_rngRFAttenuatorMode
#define RSRFSIGGEN_VAL_OUTPUT_AMODE_AUTO                                    0
#define RSRFSIGGEN_VAL_OUTPUT_AMODE_FIXED                                   1
#define RSRFSIGGEN_VAL_OUTPUT_AMODE_MANUAL                                  2

// RsRFSigGen_rngPowerOnState
#define RSRFSIGGEN_VAL_OUTPUT_STATE_PON_OFF                                 0
#define RSRFSIGGEN_VAL_OUTPUT_STATE_PON_UNCH                                1

// RsRFSigGen_rngALCEnabled
#define RSRFSIGGEN_VAL_POWER_ALC_STATE_OFF                                  0
#define RSRFSIGGEN_VAL_POWER_ALC_STATE_ON                                   1
#define RSRFSIGGEN_VAL_POWER_ALC_STATE_AUTO                                 2
#define RSRFSIGGEN_VAL_POWER_ALC_STATE_OFF_TABLE                            3
#define RSRFSIGGEN_VAL_POWER_ALC_STATE_ON_TABLE                             4
#define RSRFSIGGEN_VAL_POWER_ALC_STATE_ON_SAMPLE                            5

// RsRFSigGen_rngSweepMode
#define RSRFSIGGEN_VAL_SWEEP_MODE_AUTO                                      0
#define RSRFSIGGEN_VAL_SWEEP_MODE_MANUAL                                    1
#define RSRFSIGGEN_VAL_SWEEP_MODE_STEP                                      2

// RsRFSigGen_rngFrequencySweepShape
#define RSRFSIGGEN_VAL_SWEEP_SHAPE_SAW                                      0
#define RSRFSIGGEN_VAL_SWEEP_SHAPE_TRI                                      1

// RsRFSigGen_rngAMExternalCoupling
#define RSRFSIGGEN_VAL_AM_EXTERNAL_COUPLING_AC                              0
#define RSRFSIGGEN_VAL_AM_EXTERNAL_COUPLING_DC                              1

// RsRFSigGen_rngPULMPolarity
#define RSRFSIGGEN_VAL_PULM_POLARITY_INVERTED                               1

// RsRFSigGen_rngPULMSource
#define RSRFSIGGEN_VAL_PULM_SOURCE_INTERNAL                                 0
#define RSRFSIGGEN_VAL_PULM_SOURCE_EXTERNAL                                 1
#define RSRFSIGGEN_VAL_PULM_SOURCE_CODER                                    2

// RsRFSigGen_rngPULMExternalInputImpedance
#define RSRFSIGGEN_VAL_INPUT_IMPEDANCE_G50                                  0
#define RSRFSIGGEN_VAL_INPUT_IMPEDANCE_G10K                                 1

// RsRFSigGen_rngPULMTriggerMode
#define RSRFSIGGEN_VAL_PULM_TRIGGER_MODE_AUTO                               0
#define RSRFSIGGEN_VAL_PULM_TRIGGER_MODE_EXTERNAL                           1
#define RSRFSIGGEN_VAL_PULM_TRIGGER_MODE_EGATE                              2

// RsRFSigGen_rngFMMode
#define RSRFSIGGEN_VAL_FM_MODE_NORMAL                                       0
#define RSRFSIGGEN_VAL_FM_MODE_HDEV                                         1
#define RSRFSIGGEN_VAL_FM_MODE_LNOIS                                        2

// RsRFSigGen_rngPMMode
#define RSRFSIGGEN_VAL_PM_MODE_HBAN                                         0
#define RSRFSIGGEN_VAL_PM_MODE_LNOIS                                        1
#define RSRFSIGGEN_VAL_PM_MODE_HDEV                                         2

// RsRFSigGen_rngCorrectionListMode
#define RSRFSIGGEN_VAL_DEXC_MODE_IMPORT                                     0
#define RSRFSIGGEN_VAL_DEXC_MODE_EXPORT                                     1

// RsRFSigGen_rngCorrectionASCIIExtension
#define RSRFSIGGEN_VAL_DEXC_ASCII_SOURCE_FILE_EXT_TXT                       0
#define RSRFSIGGEN_VAL_DEXC_ASCII_SOURCE_FILE_EXT_CSV                       1

// RsRFSigGen_rngCorrectionASCIISeparator
#define RSRFSIGGEN_VAL_DEXC_ASCII_SOURCE_FILE_COLUMN_SEP_TAB                0
#define RSRFSIGGEN_VAL_DEXC_ASCII_SOURCE_FILE_COLUMN_SEP_SEM                1
#define RSRFSIGGEN_VAL_DEXC_ASCII_SOURCE_FILE_COLUMN_SEP_COMMA              2
#define RSRFSIGGEN_VAL_DEXC_ASCII_SOURCE_FILE_COLUMN_SEP_SPACE              3

// RsRFSigGen_rngCorrectionASCIIDecimalSeparator
#define RSRFSIGGEN_VAL_DEXC_ASCII_SOURCE_FILE_COLUMN_DEC_SEP_DOT            0
#define RSRFSIGGEN_VAL_DEXC_ASCII_SOURCE_FILE_COLUMN_DEC_SEP_COMMA          1

// RsRFSigGen_rngListTriggerSource
#define RSRFSIGGEN_VAL_LIST_TRIGGER_SOURCE_AUTO                             0
#define RSRFSIGGEN_VAL_LIST_TRIGGER_SOURCE_SINGLE                           1
#define RSRFSIGGEN_VAL_LIST_TRIGGER_SOURCE_EXTERNAL                         2
#define RSRFSIGGEN_VAL_LIST_TRIGGER_SOURCE_IMMEDIATE                        3
#define RSRFSIGGEN_VAL_LIST_TRIGGER_SOURCE_BUS                              4

// RsRFSigGen_rngBBSignalSource
#define RSRFSIGGEN_VAL_BB_SIGNAL_SOURCE_BB                                  0
#define RSRFSIGGEN_VAL_BB_SIGNAL_SOURCE_BBAWGN                              1

// RsRFSigGen_rngTDSCDMARampFunction
#define RSRFSIGGEN_VAL_TDSCDMA_RAMP_FUNC_LINEAR                             0
#define RSRFSIGGEN_VAL_TDSCDMA_RAMP_FUNC_COSINE                             1

// RsRFSigGen_rngTDSCDMATriggerSignalDurationUnit
#define RSRFSIGGEN_VAL_TDSCDMA_SIGNAL_DURATION_UNIT_FRAME                   0
#define RSRFSIGGEN_VAL_TDSCDMA_SIGNAL_DURATION_UNIT_CHIPS                   1
#define RSRFSIGGEN_VAL_TDSCDMA_SIGNAL_DURATION_UNIT_SEQUENCE                2

// RsRFSigGen_rngTDSCDMAMarkerMode
#define RSRFSIGGEN_VAL_TDSCDMA_MARKER_MODE_RFR                              0
#define RSRFSIGGEN_VAL_TDSCDMA_MARKER_MODE_CSP                              1
#define RSRFSIGGEN_VAL_TDSCDMA_MARKER_MODE_SFNR                             2
#define RSRFSIGGEN_VAL_TDSCDMA_MARKER_MODE_FAP                              3
#define RSRFSIGGEN_VAL_TDSCDMA_MARKER_MODE_USER                             4
#define RSRFSIGGEN_VAL_TDSCDMA_MARKER_MODE_RAT                              5
#define RSRFSIGGEN_VAL_TDSCDMA_MARKER_MODE_TRIGGER                          6

// RsRFSigGen_rngTDSCDMASpreadingFactorDedicatedChannels
#define RSRFSIGGEN_VAL_TDSCDMA_DEDICATED_CHANNELS_1                         0
#define RSRFSIGGEN_VAL_TDSCDMA_DEDICATED_CHANNELS_2                         1
#define RSRFSIGGEN_VAL_TDSCDMA_DEDICATED_CHANNELS_4                         2
#define RSRFSIGGEN_VAL_TDSCDMA_DEDICATED_CHANNELS_8                         3
#define RSRFSIGGEN_VAL_TDSCDMA_DEDICATED_CHANNELS_16                        4

// RsRFSigGen_rngTDSCDMACrestFactor
#define RSRFSIGGEN_VAL_TDSCDMA_CREST_FACTOR_MINIMUM                         0
#define RSRFSIGGEN_VAL_TDSCDMA_CREST_FACTOR_AVERAGE                         1
#define RSRFSIGGEN_VAL_TDSCDMA_CREST_FACTOR_WORST                           2

// RsRFSigGen_rngTDSCDMAPhaseRotation
#define RSRFSIGGEN_VAL_TDSCDMA_PHASE_ROTATION_AUTO                          0
#define RSRFSIGGEN_VAL_TDSCDMA_PHASE_ROTATION_S2                            1
#define RSRFSIGGEN_VAL_TDSCDMA_PHASE_ROTATION_S1                            2

// RsRFSigGen_rngTDSCDMANumberofUsers
#define RSRFSIGGEN_VAL_TDSCDMA_USERS_2                                      2
#define RSRFSIGGEN_VAL_TDSCDMA_USERS_4                                      4
#define RSRFSIGGEN_VAL_TDSCDMA_USERS_6                                      6
#define RSRFSIGGEN_VAL_TDSCDMA_USERS_8                                      8
#define RSRFSIGGEN_VAL_TDSCDMA_USERS_10                                     10
#define RSRFSIGGEN_VAL_TDSCDMA_USERS_12                                     12
#define RSRFSIGGEN_VAL_TDSCDMA_USERS_14                                     14
#define RSRFSIGGEN_VAL_TDSCDMA_USERS_16                                     16

// RsRFSigGen_rngTDSCDMADCHCodingTypeDownlink
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_DOWN_RMC12K2                 0
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_DOWN_RMC64K                  1
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_DOWN_RMC144K                 2
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_DOWN_RMC384K                 3
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_DOWN_RMC2048K                4
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_DOWN_HSDPA                   5
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_DOWN_PLCCH                   6
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_DOWN_USER                    7

// RsRFSigGen_rngTDSCDMADataSource
#define RSRFSIGGEN_VAL_TDSCDMA_DATA_SOURCE_ZERO                             0
#define RSRFSIGGEN_VAL_TDSCDMA_DATA_SOURCE_ONE                              1
#define RSRFSIGGEN_VAL_TDSCDMA_DATA_SOURCE_PATTERN                          2
#define RSRFSIGGEN_VAL_TDSCDMA_DATA_SOURCE_PN9                              3
#define RSRFSIGGEN_VAL_TDSCDMA_DATA_SOURCE_PN11                             4
#define RSRFSIGGEN_VAL_TDSCDMA_DATA_SOURCE_PN15                             5
#define RSRFSIGGEN_VAL_TDSCDMA_DATA_SOURCE_PN16                             6
#define RSRFSIGGEN_VAL_TDSCDMA_DATA_SOURCE_PN20                             7
#define RSRFSIGGEN_VAL_TDSCDMA_DATA_SOURCE_PN21                             8
#define RSRFSIGGEN_VAL_TDSCDMA_DATA_SOURCE_PN23                             9
#define RSRFSIGGEN_VAL_TDSCDMA_DATA_SOURCE_DLIST                            10

// RsRFSigGen_rngTDSCDMADCHTransportTimeInterval
#define RSRFSIGGEN_VAL_TDSCDMA_TRANSPORT_INTERVAL_5MS                       0
#define RSRFSIGGEN_VAL_TDSCDMA_TRANSPORT_INTERVAL_10MS                      1
#define RSRFSIGGEN_VAL_TDSCDMA_TRANSPORT_INTERVAL_20MS                      2
#define RSRFSIGGEN_VAL_TDSCDMA_TRANSPORT_INTERVAL_40MS                      3

// RsRFSigGen_rngTDSCDMADCHTransportSizeofCRC
#define RSRFSIGGEN_VAL_TDSCDMA_TRANSPORT_CRC_SIZE_NONE                      0
#define RSRFSIGGEN_VAL_TDSCDMA_TRANSPORT_CRC_SIZE_8                         1
#define RSRFSIGGEN_VAL_TDSCDMA_TRANSPORT_CRC_SIZE_12                        2
#define RSRFSIGGEN_VAL_TDSCDMA_TRANSPORT_CRC_SIZE_16                        3
#define RSRFSIGGEN_VAL_TDSCDMA_TRANSPORT_CRC_SIZE_24                        4

// RsRFSigGen_rngTDSCDMATransportErrorProtection
#define RSRFSIGGEN_VAL_TDSCDMA_TRANSPORT_ERROR_NONE                         0
#define RSRFSIGGEN_VAL_TDSCDMA_TRANSPORT_ERROR_TURBO3                       1
#define RSRFSIGGEN_VAL_TDSCDMA_TRANSPORT_ERROR_CON2                         2
#define RSRFSIGGEN_VAL_TDSCDMA_TRANSPORT_ERROR_CON3                         3

// RsRFSigGen_rngTDSCDMADCHSpreadingCodeSelection
#define RSRFSIGGEN_VAL_TDSCDMA_SCSM_AUTO                                    0
#define RSRFSIGGEN_VAL_TDSCDMA_SCSM_USER                                    1

// RsRFSigGen_rngTDSCDMADCHInsertErrorsOn
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_INSERT_ERRORS_TRAN                       0
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_INSERT_ERRORS_PHYS                       1

// RsRFSigGen_rngTDSCDMARMCConfiguration
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_RMC_CONFIGURATION_05MQPSK                0
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_RMC_CONFIGURATION_11MQPSK                1
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_RMC_CONFIGURATION_11M16QAM               2
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_RMC_CONFIGURATION_16MQPSK                3
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_RMC_CONFIGURATION_16M16QAM               4
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_RMC_CONFIGURATION_22MQPSK                5
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_RMC_CONFIGURATION_22M16QAM               6
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_RMC_CONFIGURATION_28MQPSK                7
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_RMC_CONFIGURATION_28M16QAM               8
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_RMC_CONFIGURATION_64QAM16UE              9
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_RMC_CONFIGURATION_64QAM19UE              10
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_RMC_CONFIGURATION_64QAM22UE              11
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_RMC_CONFIGURATION_USER                   12

// RsRFSigGen_rngTDSCDMADEDCHFRC
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_EDCH_FRC_1                               0
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_EDCH_FRC_2                               1
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_EDCH_FRC_3                               2
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_EDCH_FRC_4                               3
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_EDCH_FRC_USER                            4

// RsRFSigGen_rngTDSCDMAModulation
#define RSRFSIGGEN_VAL_TDSCDMA_HSDPA_HSUPA_MODULATION_QPSK                  0
#define RSRFSIGGEN_VAL_TDSCDMA_HSDPA_HSUPA_MODULATION_QAM16                 1
#define RSRFSIGGEN_VAL_TDSCDMA_HSDPA_HSUPA_MODULATION_QAM64                 2

// RsRFSigGen_rngTDSCDMAHsdpaTransportBlockSizeTable
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_TRANSPORT_BLOCK_SIZE_TABLE_CAT13         0
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_TRANSPORT_BLOCK_SIZE_TABLE_CAT46         1
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_TRANSPORT_BLOCK_SIZE_TABLE_CAT79         2
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_TRANSPORT_BLOCK_SIZE_TABLE_CAT1012       3
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_TRANSPORT_BLOCK_SIZE_TABLE_CAT1315       4
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_TRANSPORT_BLOCK_SIZE_TABLE_CAT1618       5
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_TRANSPORT_BLOCK_SIZE_TABLE_CAT1921       6
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_TRANSPORT_BLOCK_SIZE_TABLE_CAT2224       7

// RsRFSigGen_rngTDSCDMAHsupaTransportBlockSizeTable
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_TRANSPORT_BLOCK_SIZE_TABLE_CAT12         0
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_TRANSPORT_BLOCK_SIZE_TABLE_CAT36         1

// RsRFSigGen_rngTDSCDMASpreadingFactor
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_SFAC_1                                   0
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_SFAC_2                                   1
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_SFAC_4                                   2
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_SFAC_8                                   3
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_SFAC_16                                  4

// RsRFSigGen_rngTDSCDMAHARQMode
#define RSRFSIGGEN_VAL_TDSCDMA_HSDPA_HSUPA_HARQ_MODE_CACK                   0
#define RSRFSIGGEN_VAL_TDSCDMA_HSDPA_HSUPA_HARQ_MODE_CNACK                  1

// RsRFSigGen_rngTDSCDMASlotChannelType
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_PCCPCH1                    0
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_PCCPCH2                    1
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_SCCPCH1                    2
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_SCCPCH2                    3
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_FPACH                      4
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_PDSCH                      5
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_DPCH_QPSK                  6
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_DPCH_8PSK                  7
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_HS_SCCH1                   8
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_HS_SCCH2                   9
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_HS_PDSQPSK                 10
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_HS_PDS16QAM                11
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_PUSCH                      12
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_UP_DPCH_QPSK               13
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_UP_DPCH_8PSK               14
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_HS_SICH                    15
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_HS_PDS64QAM                16
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_E_PUCH_QPSK                17
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_E_PUCH_16QAM               18
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_E_RUCCH                    19
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_PLCCH                      20
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_E_AGCH                     21
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_CHANNEL_TYPE_E_HICH                     22

// RsRFSigGen_rngTDSCDMATPCSource
#define RSRFSIGGEN_VAL_TDSCDMA_TPC_SOURCE_ZERO                              0
#define RSRFSIGGEN_VAL_TDSCDMA_TPC_SOURCE_ONE                               1
#define RSRFSIGGEN_VAL_TDSCDMA_TPC_SOURCE_PATTERN                           2
#define RSRFSIGGEN_VAL_TDSCDMA_TPC_SOURCE_DLIST                             3

// RsRFSigGen_rngTDSCDMAReadOutMode
#define RSRFSIGGEN_VAL_TDSCDMA_READ_OUT_MODE_CONTINUOUS                     0
#define RSRFSIGGEN_VAL_TDSCDMA_READ_OUT_MODE_S0A                            1
#define RSRFSIGGEN_VAL_TDSCDMA_READ_OUT_MODE_S1A                            2
#define RSRFSIGGEN_VAL_TDSCDMA_READ_OUT_MODE_S01A                           3
#define RSRFSIGGEN_VAL_TDSCDMA_READ_OUT_MODE_S10A                           4

// RsRFSigGen_rngTDSCDMASlotMode
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_MODE_DEDICATED                          0
#define RSRFSIGGEN_VAL_TDSCDMA_SLOT_MODE_PRACH                              1

// RsRFSigGen_rngTDSCDMAClockSynchronisationMode
#define RSRFSIGGEN_VAL_TDSCDMA_CLOCK_SYNC_MODE_NONE                         0
#define RSRFSIGGEN_VAL_TDSCDMA_CLOCK_SYNC_MODE_MASTER                       1
#define RSRFSIGGEN_VAL_TDSCDMA_CLOCK_SYNC_MODE_SLAVE                        2

// RsRFSigGen_rngTDSCDMADCHCodingTypeUplink
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_UP_RMC12K2                   0
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_UP_RMC64K                    1
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_UP_RMC144K                   2
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_UP_RMC384K                   3
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_HRMC526K                     4
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_HRMC730K                     5
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_UP_HSUPA                     6
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_UP_HS_SICH                   7
#define RSRFSIGGEN_VAL_TDSCDMA_DCH_CODING_TYPE_UP_USER                      8

// RsRFSigGen_rngTDSCDMATransportTimeInterval
#define RSRFSIGEGN_VAL_TDSCDMA_TTI_5MS                                      0
#define RSRFSIGEGN_VAL_TDSCDMA_TTI_10MS                                     1
#define RSRFSIGEGN_VAL_TDSCDMA_TTI_20MS                                     2
#define RSRFSIGEGN_VAL_TDSCDMA_TTI_40MS                                     3
#define RSRFSIGEGN_VAL_TDSCDMA_TTI_80MS                                     4

// RsRFSigGen_rngTDSCDMASizeOfCRC
#define RSRFSIGGEN_VAL_TDSCDMA_CRC_SIZE_NONE                                0
#define RSRFSIGGEN_VAL_TDSCDMA_CRC_SIZE_8                                   1
#define RSRFSIGGEN_VAL_TDSCDMA_CRC_SIZE_12                                  2
#define RSRFSIGGEN_VAL_TDSCDMA_CRC_SIZE_16                                  3
#define RSRFSIGGEN_VAL_TDSCDMA_CRC_SIZE_24                                  4

// RsRFSigGen_rngMCCWCrestFactorMode
#define RSRFSIGGEN_VAL_MCCW_CREST_FACTOR_MODE_OFF                           0
#define RSRFSIGGEN_VAL_MCCW_CREST_FACTOR_MODE_CHIRP                         1
#define RSRFSIGGEN_VAL_MCCW_CREST_FACTOR_MODE_SLOW                          2

// RsRFSigGen_rngMCCWMarkerMode
#define RSRFSIGGEN_VAL_MCCW_MARKER_TYPE_RESTART                             0
#define RSRFSIGGEN_VAL_MCCW_MARKER_TYPE_PULSE                               1
#define RSRFSIGGEN_VAL_MCCW_MARKER_TYPE_PATTERN                             2
#define RSRFSIGGEN_VAL_MCCW_MARKER_TYPE_RATIO                               3
#define RSRFSIGGEN_VAL_MCCW_MARKER_TYPE_TRIGGER                             4

// RsRFSigGen_rngMCCWClockMode
#define RSRFSIGGEN_VAL_MCCW_CLOCK_MODE_SAMPLE                               0
#define RSRFSIGGEN_VAL_MCCW_CLOCK_MODE_MSAMPLE                              1

// RsRFSigGen_rngBTMode
#define RSRFSIGGEN_VAL_BT_MODE_BASIC                                        0
#define RSRFSIGGEN_VAL_BT_MODE_BLEN                                         1

// RsRFSigGen_rngWLANClockMode
#define RSRFSIGGEN_VAL_WLAN_CLOCK_MODE_CHIP                                 0
#define RSRFSIGGEN_VAL_WLAN_CLOCK_MODE_MCHIP                                1

// RsRFSigGen_rngWLANMarkerMode
#define RSRFSIGGEN_VAL_WLAN_MARKER_MODE_RESTART                             0
#define RSRFSIGGEN_VAL_WLAN_MARKER_MODE_FRAME                               1
#define RSRFSIGGEN_VAL_WLAN_MARKER_MODE_FACT                                2
#define RSRFSIGGEN_VAL_WLAN_MARKER_MODE_PATT                                3
#define RSRFSIGGEN_VAL_WLAN_MARKER_MODE_PULSE                               4
#define RSRFSIGGEN_VAL_WLAN_MARKER_MODE_RATIO                               5

// RsRFSigGen_rngXMRClockMode
#define RSRFSIGGEN_VAL_XMR_CLOCK_MODE_SYMBOL                                0
#define RSRFSIGGEN_VAL_XMR_CLOCK_MODE_MSYMBOL                               1

// RsRFSigGen_rngSiriusClockMode
#define RSRFSIGGEN_VAL_SIRIUS_CLOCK_MODE_SYMBOL                             0
#define RSRFSIGGEN_VAL_SIRIUS_CLOCK_MODE_MSYMBOL                            1

// RsRFSigGen_rngSiriusTerrestrialMarkerMode
#define RSRFSIGGEN_VAL_SIRIUS_TERR_MARKER_MODE_SYMBOL                       0
#define RSRFSIGGEN_VAL_SIRIUS_TERR_MARKER_MODE_FRAME                        1
#define RSRFSIGGEN_VAL_SIRIUS_TERR_MARKER_MODE_SFR                          2
#define RSRFSIGGEN_VAL_SIRIUS_TERR_MARKER_MODE_USER                         3
#define RSRFSIGGEN_VAL_SIRIUS_TERR_MARKER_MODE_RATIO                        4

// RsRFSigGen_rngEVDOClockMode
#define RSRFSIGGEN_VAL_EVDO_CLOCK_MODE_CHIP                                 0
#define RSRFSIGGEN_VAL_EVDO_CLOCK_MODE_MCHIP                                1

// RsRFSigGen_rngDMClockMode
#define RSRFSIGGEN_VAL_DM_CLOCK_MODE_SYMBOL                                 0
#define RSRFSIGGEN_VAL_DM_CLOCK_MODE_MSYMBOL                                1
#define RSRFSIGGEN_VAL_DM_CLOCK_MODE_BIT                                    2

// RsRFSigGen_rngWiMAXLinkDirection
#define RSRFSIGGEN_VAL_WIMAX_LINK_DIRECTION_DOWN                            0
#define RSRFSIGGEN_VAL_WIMAX_LINK_DIRECTION_UP                              1

// RsRFSigGen_rngW3GPPClockMode
#define RSRFSIGGEN_VAL_W3GPP_CLOCK_MODE_CHIP                                0
#define RSRFSIGGEN_VAL_W3GPP_CLOCK_MODE_MCHIP                               1

// RsRFSigGen_rngTriggerStatus
#define RSRFSIGGEN_VAL_TRIGGER_STATUS_STOP                                  0
#define RSRFSIGGEN_VAL_TRIGGER_STATUS_RUN                                   1

// RsRFSigGen_rngSMUIQInternalBasebandGain
#define RSRFSIGGEN_VAL_SMU_IQ_MODULATION_BGAIN_LDIST                        0
#define RSRFSIGGEN_VAL_SMU_IQ_MODULATION_BGAIN_STD                          1
#define RSRFSIGGEN_VAL_SMU_IQ_MODULATION_BGAIN_3GPP                         2
#define RSRFSIGGEN_VAL_SMU_IQ_MODULATION_BGAIN_LNOISE                       3
#define RSRFSIGGEN_VAL_SMU_IQ_MODULATION_BGAIN_AUTO                         4

// RsRFSigGen_rngIQModulationSource
#define RSRFSIGGEN_VAL_IQ_MODULATION_SOURCE_ANALOG                          0
#define RSRFSIGGEN_VAL_IQ_MODULATION_SOURCE_BASEBAND                        1

// RsRFSigGen_rngIQAuxiliaryInformation
#define RSRFSIGGEN_VAL_IQ_OUTPUT_AINF_DISABLED                              0
#define RSRFSIGGEN_VAL_IQ_OUTPUT_AINF_CFS                                   1
#define RSRFSIGGEN_VAL_IQ_OUTPUT_AINF_CFSN                                  2
#define RSRFSIGGEN_VAL_IQ_OUTPUT_AINF_ILOSS                                 3

// RsRFSigGen_rngIQOutputMode
#define RSRFSIGGEN_VAL_IQ_OUTPUT_MODE_FIX                                   0
#define RSRFSIGGEN_VAL_IQ_OUTPUT_MODE_VAR                                   1

// RsRFSigGen_rngIQOutputType
#define RSRFSIGGEN_VAL_IQ_OUTPUT_TYPE_SING                                  0
#define RSRFSIGGEN_VAL_IQ_OUTPUT_TYPE_DIFF                                  1

// RsRFSigGen_rngIQOutputLoad
#define RSRFSIGGEN_VAL_IQ_OUTPUT_LOAD_EMF                                   0
#define RSRFSIGGEN_VAL_IQ_OUTPUT_LOAD_50                                    1
#define RSRFSIGGEN_VAL_IQ_OUTPUT_LOAD_100                                   2

// RsRFSigGen_rngW3GPPEnhHSDPAMode
#define RSRFSIGGEN_VAL_W3GPP_HSDPA_MODE_CONTINUOUS                          0
#define RSRFSIGGEN_VAL_W3GPP_HSDPA_MODE_PSF0                                1
#define RSRFSIGGEN_VAL_W3GPP_HSDPA_MODE_PSF1                                2
#define RSRFSIGGEN_VAL_W3GPP_HSDPA_MODE_PSF2                                3
#define RSRFSIGGEN_VAL_W3GPP_HSDPA_MODE_PSF3                                4
#define RSRFSIGGEN_VAL_W3GPP_HSDPA_MODE_PSF4                                5
#define RSRFSIGGEN_VAL_W3GPP_HSDPA_MODE_HSET                                6
#define RSRFSIGGEN_VAL_W3GPP_HSDPA_MODE_PSF                                 7

// RsRFSigGen_rngBTLEDataSource
#define RSRFSIGGEN_VAL_BT_DATA_SOURCE_ZERO                                  0
#define RSRFSIGGEN_VAL_BT_DATA_SOURCE_ONE                                   1
#define RSRFSIGGEN_VAL_BT_DATA_SOURCE_DLIST                                 10
#define RSRFSIGGEN_VAL_BT_DATA_SOURCE_PATTERN                               2
#define RSRFSIGGEN_VAL_BT_DATA_SOURCE_PN09                                  3
#define RSRFSIGGEN_VAL_BT_DATA_SOURCE_PN11                                  4
#define RSRFSIGGEN_VAL_BT_DATA_SOURCE_PN15                                  5
#define RSRFSIGGEN_VAL_BT_DATA_SOURCE_PN16                                  6
#define RSRFSIGGEN_VAL_BT_DATA_SOURCE_PN20                                  7
#define RSRFSIGGEN_VAL_BT_DATA_SOURCE_PN21                                  8
#define RSRFSIGGEN_VAL_BT_DATA_SOURCE_PN23                                  9

// RsRFSigGen_rngBTLERole
#define RSRFSIGGEN_VAL_BT_LE_ROLE_CENTRAL                                   0
#define RSRFSIGGEN_VAL_BT_LE_ROLE_PERIPHERAL                                1
#define RSRFSIGGEN_VAL_BT_LE_ROLE_ADVERTISER                                4
#define RSRFSIGGEN_VAL_BT_LE_ROLE_SCANNER                                   5
#define RSRFSIGGEN_VAL_BT_LE_ROLE_INITIATOR                                 6

// RsRFSigGen_rngW3GPPBS1ChannelCodingType
#define RSRFSIGGEN_VAL_W3GPP_CODING_M12K2                                   0
#define RSRFSIGGEN_VAL_W3GPP_CODING_M64K                                    1
#define RSRFSIGGEN_VAL_W3GPP_CODING_M144K                                   2
#define RSRFSIGGEN_VAL_W3GPP_CODING_M384K                                   3
#define RSRFSIGGEN_VAL_W3GPP_CODING_AMR                                     4
#define RSRFSIGGEN_VAL_W3GPP_CODING_USER                                    5
#define RSRFSIGGEN_VAL_W3GPP_CODING_BTFD1                                   6
#define RSRFSIGGEN_VAL_W3GPP_CODING_BTFD2                                   7
#define RSRFSIGGEN_VAL_W3GPP_CODING_BTFD3                                   8

// RsRFSigGen_rngDynamicPowerControlMode
#define RSRFSIGGEN_VAL_DYNAMIC_MODE_EXT                                     0
#define RSRFSIGGEN_VAL_DYNAMIC_MODE_TPC                                     1
#define RSRFSIGGEN_VAL_DYNAMIC_MODE_MAN                                     2

// RsRFSigGen_rngControlDirection
#define RSRFSIGGEN_VAL_DIRECTION_UP                                         0
#define RSRFSIGGEN_VAL_DIRECTION_DOWN                                       1

// RsRFSigGen_rngW3GPPDynamicPowerControlManual
#define RSRFSIGGEN_VAL_W3GPP_DPC_MAN0                                       0
#define RSRFSIGGEN_VAL_W3GPP_DPC_MAN1                                       1

// RsRFSigGen_rngW3GPPDynamicPowerControlAssignmentMode
#define RSRFSIGGEN_VAL_W3GPP_ULDTX_NORMAL                                   0
#define RSRFSIGGEN_VAL_W3GPP_ULDTX_FDPCH                                    1

// RsRFSigGen_rngW3GPPFeedbackConnector
#define RSRFSIGGEN_VAL_W3GPP_CONNECTOR_LEVATT                               0
#define RSRFSIGGEN_VAL_W3GPP_CONNECTOR_USER1                                1

// RsRFSigGen_rngEVDOTerminalPredefinedSettings
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_USER                                0
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS1DR9K6                           1
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS1DR19K2                          2
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS1DR38K4                          3
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS1DR76K8                          4
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS1DR153K6                         5
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS2PS128LL                         6
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS2PS256HC                         7
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS2PS256LL                         8
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS2PS512LL                         9
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS2PS768LL                         10
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS2PS1024LL                        11
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS2PS1536LL                        12
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS2PS2048LL                        13
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS2PS3072LL                        14
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS2PS4096LL                        15
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS2PS6144LL                        16
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS2PS8192LL                        17
#define RSRFSIGGEN_VAL_EVDO_UL_SETTINGS_ULS2PS12288LL                       18

// RsRFSigGen_rngFSIMScenario
#define RSRFSIGGEN_VAL_FSIM_SCENARIO_USER                                   0
#define RSRFSIGGEN_VAL_FSIM_SCENARIO_SHIP                                   1
#define RSRFSIGGEN_VAL_FSIM_SCENARIO_AIRCRAFT                               2

// RsRFSigGen_rngFSIMScenarioCoordinateSystem
#define RSRFSIGGEN_VAL_FSIM_SCENARIO_COORDINATE_ENU                         0
#define RSRFSIGGEN_VAL_FSIM_SCENARIO_COORDINATE_GEO                         1
#define RSRFSIGGEN_VAL_FSIM_SCENARIO_COORDINATE_GEO_DEC                     2

// RsRFSigGen_rngFSIMUserFaderProfileSource
#define RSRFSIGGEN_VAL_FSIM_PROFILE_SOURCE_MAUAL                            0
#define RSRFSIGGEN_VAL_FSIM_PROFILE_SOURCE_TPA_FILE                         1
#define RSRFSIGGEN_VAL_FSIM_PROFILE_SOURCE_FADER_PROFILE                    2

// RsRFSigGen_rngFSIMTrajectory
#define RSRFSIGGEN_VAL_FSIM_TRAJECTORY_NONE                                 0
#define RSRFSIGGEN_VAL_FSIM_TRAJECTORY_DESCRIPTION_FILE                     1
#define RSRFSIGGEN_VAL_FSIM_TRAJECTORY_EPHEMERIS_FILE                       2

// RsRFSigGen_rngFSIMVehicle
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_NONE                                    0
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_PREDEFINED                              1
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_USER                                    2

// RsRFSigGen_rngFSIMVehicleCategory
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_CATEGORY_AIR                            0
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_CATEGORY_LAND                           1
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_CATEGORY_WATER                          2

// RsRFSigGen_rngFSIMTypeAir
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_JET                                     0
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_UAV                                     1
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_TRANSPORT_AIRCRAFT                      2
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_AIRLINER                                3
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_SPOTRING_AIRPLANE                       4
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_HELICOPTER                              5

// RsRFSigGen_rngFSIMTypeLand
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_CAR                                     0
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_TRAIN                                   1
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_BICYCLE                                 2
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_PEDESTRIAN                              3

// RsRFSigGen_rngFSIMTypeWater
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_FRIGATE                                 0
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_PATROL_BOAT                             1
#define RSRFSIGGEN_VAL_FSIM_VEHICLE_AIRCRAFT_CARRIER                        2

// RsRFSigGen_rngFSIMBehaviorAtEnd
#define RSRFSIGGEN_VAL_FSIM_TRAJECTORY_AT_END_STOP                          0
#define RSRFSIGGEN_VAL_FSIM_TRAJECTORY_AT_END_LOOP                          1
#define RSRFSIGGEN_VAL_FSIM_TRAJECTORY_AT_END_RETURN                        2
#define RSRFSIGGEN_VAL_FSIM_TRAJECTORY_AT_END_RESTART                       3

// RsRFSigGen_rngFSIMShipToShipWaterType
#define RSRFSIGGEN_VAL_FSIM_WATER_SALT                                      0
#define RSRFSIGGEN_VAL_FSIM_WATER_FRESH                                     1

// RsRFSigGen_rngFSIMShipToShipWaterSurfaceType
#define RSRFSIGGEN_VAL_FSIM_WATER_SURFACE_ROUGH                             0
#define RSRFSIGGEN_VAL_FSIM_WATER_SURFACE_SMOOTH                            1
#define RSRFSIGGEN_VAL_FSIM_WATER_SURFACE_STORMY                            2

// RsRFSigGen_rngFSIMTerrainType
#define RSRFSIGGEN_VAL_FSIM_TERRAIN_NONE                                    0
#define RSRFSIGGEN_VAL_FSIM_TERRAIN_ROCK                                    1
#define RSRFSIGGEN_VAL_FSIM_TERRAIN_GRASS                                   2
#define RSRFSIGGEN_VAL_FSIM_TERRAIN_FOREST                                  3
#define RSRFSIGGEN_VAL_FSIM_TERRAIN_WATER                                   4

// RsRFSigGen_rngAMDepthType
#define RSRFSIGGEN_VAL_AM_DEPTH_LINEAR                                      0
#define RSRFSIGGEN_VAL_AM_DEPTH_EXPONENTIAL                                 1

// RsRFSigGen_rngEVDOBandClass
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B0                                0
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B1                                1
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B2                                2
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B3                                3
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B4                                4
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B5                                5
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B6                                6
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B7                                7
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B8                                8
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B9                                9
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B10                               10
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B11                               11
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B12                               12
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B13                               13
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B14                               14
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B15                               15
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B16                               16
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B17                               17
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B18                               18
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B19                               19
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B20                               20
#define RSRFSIGGEN_VAL_EVDO_MC_BAND_CLASS_B21                               21

// RsRFSigGen_rngW3GPPBS1TCHTransportTimeInterval
#define RSRFSIGGEN_VAL_W3GPP_TCH_TTI_10MS                                   0
#define RSRFSIGGEN_VAL_W3GPP_TCH_TTI_20MS                                   1
#define RSRFSIGGEN_VAL_W3GPP_TCH_TTI_40MS                                   2

// RsRFSigGen_rngW3GPPSRateSCCPCH
#define RSRFSIGGEN_VAL_W3GPP_SYMBOL_RATE_SCCPCH_D15K                        0
#define RSRFSIGGEN_VAL_W3GPP_SYMBOL_RATE_SCCPCH_D30K                        1
#define RSRFSIGGEN_VAL_W3GPP_SYMBOL_RATE_SCCPCH_D60K                        2
#define RSRFSIGGEN_VAL_W3GPP_SYMBOL_RATE_SCCPCH_D120K                       3
#define RSRFSIGGEN_VAL_W3GPP_SYMBOL_RATE_SCCPCH_D240K                       4
#define RSRFSIGGEN_VAL_W3GPP_SYMBOL_RATE_SCCPCH_D480K                       5
#define RSRFSIGGEN_VAL_W3GPP_SYMBOL_RATE_SCCPCH_D960K                       6

// RsRFSigGen_rngC2kClockMode
#define RSRFSIGGEN_VAL_C2K_CLOCK_MODE_CHIP                                  0
#define RSRFSIGGEN_VAL_C2K_CLOCK_MODE_MCHIP                                 1

// RsRFSigGen_rngRFLevelVariationActive
#define RSRFSIGGEN_VAL_RF_VARIATION_ACTIVE_DECIMAL                          0
#define RSRFSIGGEN_VAL_RF_VARIATION_ACTIVE_USER                             1

// RsRFSigGen_rngExternalInputImpedance
#define RSRFSIGGEN_VAL_EXT_INPUT_IMP_G50                                    0
#define RSRFSIGGEN_VAL_EXT_INPUT_IMP_HIGH                                   1

// RsRFSigGen_rngTriggerSour
#define RSRFSIGGEN_VAL_TRIGGER_SOURCE_INTERNAL                              0
#define RSRFSIGGEN_VAL_TRIGGER_SOURCE_INTERNALB                             1
#define RSRFSIGGEN_VAL_TRIGGER_SOURCE_EGT1                                  2
#define RSRFSIGGEN_VAL_TRIGGER_SOURCE_EGT2                                  3
#define RSRFSIGGEN_VAL_TRIGGER_SOURCE_EGC1                                  4
#define RSRFSIGGEN_VAL_TRIGGER_SOURCE_EGC2                                  5
#define RSRFSIGGEN_VAL_TRIGGER_SOURCE_ELT                                   6
#define RSRFSIGGEN_VAL_TRIGGER_SOURCE_ELC                                   7
#define RSRFSIGGEN_VAL_TRIGGER_SOURCE_OBAS                                  8
#define RSRFSIGGEN_VAL_TRIGGER_SOURCE_BEXT                                  9
#define RSRFSIGGEN_VAL_TRIGGER_SOURCE_EXT                                   10
#define RSRFSIGGEN_VAL_TRIGGER_SOURCE_INTERNALA                             11
#define RSRFSIGGEN_VAL_TRIGGER_SOURCE_BBSYNCSIG                             12

// RsRFSigGen_rngClockSource
#define RSRFSIGGEN_VAL_CLOCK_SOURCE_INTERNAL                                0
#define RSRFSIGGEN_VAL_CLOCK_SOURCE_EGC1                                    1
#define RSRFSIGGEN_VAL_CLOCK_SOURCE_EGC2                                    2
#define RSRFSIGGEN_VAL_CLOCK_SOURCE_ELC                                     3

// RsRFSigGen_rngIQInternalBasebandGain
#define RSRFSIGGEN_VAL_IQ_MODULATION_BGAIN_DBM4                             0
#define RSRFSIGGEN_VAL_IQ_MODULATION_BGAIN_DBM2                             1
#define RSRFSIGGEN_VAL_IQ_MODULATION_BGAIN_DB0                              2
#define RSRFSIGGEN_VAL_IQ_MODULATION_BGAIN_DB2                              3
#define RSRFSIGGEN_VAL_IQ_MODULATION_BGAIN_DB4                              4
#define RSRFSIGGEN_VAL_IQ_MODULATION_BGAIN_DB6                              5
#define RSRFSIGGEN_VAL_IQ_MODULATION_BGAIN_DB8                              6
#define RSRFSIGGEN_VAL_IQ_MODULATION_BGAIN_DBM3                             7
#define RSRFSIGGEN_VAL_IQ_MODULATION_BGAIN_DB3                              8
#define RSRFSIGGEN_VAL_IQ_MODULATION_BGAIN_AUTO                             9

// RsRFSigGen_rngPULMTransitionType
#define RSRFSIGGEN_VAL_PULM_TRANSITION_TYPE_SMOOTHED                        0
#define RSRFSIGGEN_VAL_PULM_TRANSITION_TYPE_FAST                            1

// RsRFSigGen_rngPGENMode
#define RSRFSIGGEN_VAL_PULSE_MODE_SINGLE                                    0
#define RSRFSIGGEN_VAL_PULSE_MODE_DOUBLE                                    1
#define RSRFSIGGEN_VAL_PULSE_MODE_TRAIN                                     2

// RsRFSigGen_rngGraphicsSource
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_BBA                                  0
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_BBB                                  1
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_BBC                                  2
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_BBD                                  3
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_BBE                                  4
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_BBF                                  5
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_BBG                                  6
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_BBH                                  7
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_STRA                                 8
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_STRB                                 9
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_STRC                                 10
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_STRD                                 11
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_STRE                                 12
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_STRF                                 13
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_STRG                                 14
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_STRH                                 15
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_RFA                                  16
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_RFB                                  17
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_RFC                                  18
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_RFD                                  19
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_IQO1                                 20
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_IQO2                                 21
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_DO1                                  22
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_DO2                                  23
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_BBIA                                 24
#define RSRFSIGGEN_VAL_GRAPHICS_SOURCE_BBIB                                 25

// RsRFSigGen_rngALCDetectorSensitivity
#define RSRFSIGGEN_VAL_ALC_DETECTOR_AUTO                                    0
#define RSRFSIGGEN_VAL_ALC_DETECTOR_LOW                                     1
#define RSRFSIGGEN_VAL_ALC_DETECTOR_MEDIUM                                  2
#define RSRFSIGGEN_VAL_ALC_DETECTOR_HIGH                                    3
#define RSRFSIGGEN_VAL_ALC_DETECTOR_FIXED                                   4

// RsRFSigGen_rngALCSampleLevel
#define RSRFSIGGEN_VAL_ALC_SAMPLE_LEVEL_FULL                                0
#define RSRFSIGGEN_VAL_ALC_SAMPLE_LEVEL_ATT                                 1
#define RSRFSIGGEN_VAL_ALC_SAMPLE_LEVEL_MINIMUM                             2

// RsRFSigGen_rngRFAttRFOFFMode
#define RSRFSIGGEN_VAL_RF_OFF_MODE_UNCH                                     0
#define RSRFSIGGEN_VAL_RF_OFF_MODE_FULL                                     1

// RsRFSigGen_rngLFGenShapeMode
#define RSRFSIGGEN_VAL_LFG_SHAPE_SINE                                       0
#define RSRFSIGGEN_VAL_LFG_SHAPE_PULSE                                      1
#define RSRFSIGGEN_VAL_LFG_SHAPE_TRIANGLE                                   2
#define RSRFSIGGEN_VAL_LFG_SHAPE_TRAP                                       3

// RsRFSigGen_rngPGENOutputPolarity
#define RSRFSIGGEN_VAL_PGEN_OUTPUT_POLARITY_NORMAL                          0
#define RSRFSIGGEN_VAL_PGEN_OUTPUT_POLARITY_INVERSE                         1

// RsRFSigGen_rngRFLevelMode
#define RSRFSIGGEN_VAL_RF_LEVEL_MODE_NORMAL                                 0
#define RSRFSIGGEN_VAL_RF_LEVEL_MODE_LOWNOISE                               1
#define RSRFSIGGEN_VAL_RF_LEVEL_MODE_LOWDIST                                2

// RsRFSigGen_rngRFLevelSettingCharacteristics
#define RSRFSIGGEN_VAL_RF_LEVEL_SETTING_AUTO                                0
#define RSRFSIGGEN_VAL_RF_LEVEL_SETTING_UNINT                               1
#define RSRFSIGGEN_VAL_RF_LEVEL_SETTING_STRICTLY                            2
#define RSRFSIGGEN_VAL_RF_LEVEL_SETTING_VSWR                                3
#define RSRFSIGGEN_VAL_RF_LEVEL_SETTING_PHASE                               4

// RsRFSigGen_rngLFOutputSource
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_LF1                                     0
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_LF2                                     1
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_NOISE                                   2
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_EXT1                                    3
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_EXT2                                    4
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_AM                                      5
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_FMPM                                    6
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_LF1B                                    7
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_LF2B                                    8
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_AMB                                     9
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_NOISB                                   10
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_FMPMB                                   11
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_LF1A                                    12
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_LF2A                                    13
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_NOISA                                   14
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_FMPMA                                   15
#define RSRFSIGGEN_VAL_LFOUT_SOURCE_AMA                                     16

// RsRFSigGen_rngRFNoiseDistribution
#define RSRFSIGGEN_VAL_RF_NOISE_DISTRIBUTION_GAUSS                          0
#define RSRFSIGGEN_VAL_RF_NOISE_DISTRIBUTION_EQUAL                          1

// RsRFSigGen_rngSystemConfigurationMode
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_MODE_STANDARD                          0
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_MODE_ADVANCED                          1
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_MODE_REGENERATOR                       2
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_MODE_GNSS                              3
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_MODE_ESEQ                              4
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_MODE_BWEX                              5

// RsRFSigGen_rngTestIQSource
#define RSRFSIGGEN_VAL_TEST_IQ_SOURCE_SINE                                  0
#define RSRFSIGGEN_VAL_TEST_IQ_SOURCE_CONST                                 1
#define RSRFSIGGEN_VAL_TEST_IQ_SOURCE_ARB                                   2
#define RSRFSIGGEN_VAL_TEST_IQ_SOURCE_TWO_TONE                              3

// RsRFSigGen_rngTestBNCSource
#define RSRFSIGGEN_VAL_TEST_BNC_USER123                                     0
#define RSRFSIGGEN_VAL_TEST_BNC_USER456                                     1
#define RSRFSIGGEN_VAL_TEST_BNC_AUTO                                        2
#define RSRFSIGGEN_VAL_TEST_BNC_USER2                                       3
#define RSRFSIGGEN_VAL_TEST_BNC_USER3                                       4
#define RSRFSIGGEN_VAL_TEST_BNC_USER5                                       5
#define RSRFSIGGEN_VAL_TEST_BNC_USER6                                       6
#define RSRFSIGGEN_VAL_TEST_BNC_TRGA                                        7
#define RSRFSIGGEN_VAL_TEST_BNC_TRGB                                        8
#define RSRFSIGGEN_VAL_TEST_BNC_C1TMC1                                      9
#define RSRFSIGGEN_VAL_TEST_BNC_C1TM2                                       10
#define RSRFSIGGEN_VAL_TEST_BNC_C1TM3                                       11
#define RSRFSIGGEN_VAL_TEST_BNC_C2TMC4                                      12
#define RSRFSIGGEN_VAL_TEST_BNC_C2TM5                                       13
#define RSRFSIGGEN_VAL_TEST_BNC_C2TM6                                       14
#define RSRFSIGGEN_VAL_TEST_BNC_F1TMC1                                      15
#define RSRFSIGGEN_VAL_TEST_BNC_F1TM2                                       16
#define RSRFSIGGEN_VAL_TEST_BNC_F1TM3                                       17
#define RSRFSIGGEN_VAL_TEST_BNC_F2TMC4                                      18
#define RSRFSIGGEN_VAL_TEST_BNC_F2TM5                                       19
#define RSRFSIGGEN_VAL_TEST_BNC_F2TM6                                       20
#define RSRFSIGGEN_VAL_TEST_BNC_F3TMC1                                      21
#define RSRFSIGGEN_VAL_TEST_BNC_F3TM2                                       22
#define RSRFSIGGEN_VAL_TEST_BNC_F3TM3                                       23
#define RSRFSIGGEN_VAL_TEST_BNC_F4TMC4                                      24
#define RSRFSIGGEN_VAL_TEST_BNC_F4TM5                                       25
#define RSRFSIGGEN_VAL_TEST_BNC_F4TM6                                       26

// RsRFSigGen_rngIQSMWAnalogWidebandGain
#define RSRFSIGGEN_VAL_SMW_IQ_GAIN_DBM3                                     0
#define RSRFSIGGEN_VAL_SMW_IQ_GAIN_DBM4                                     1
#define RSRFSIGGEN_VAL_SMW_IQ_GAIN_DBM2                                     2
#define RSRFSIGGEN_VAL_SMW_IQ_GAIN_DB0                                      3
#define RSRFSIGGEN_VAL_SMW_IQ_GAIN_DB2                                      4
#define RSRFSIGGEN_VAL_SMW_IQ_GAIN_DB3                                      5
#define RSRFSIGGEN_VAL_SMW_IQ_GAIN_DB4                                      6
#define RSRFSIGGEN_VAL_SMW_IQ_GAIN_DB6                                      7
#define RSRFSIGGEN_VAL_SMW_IQ_GAIN_DB8                                      8
#define RSRFSIGGEN_VAL_SMW_IQ_GAIN_AUTO                                     9

// RsRFSigGen_rngSatNavADGMode
#define RSRFSIGGEN_VAL_ADG_MODE_GPS                                         0
#define RSRFSIGGEN_VAL_ADG_MODE_GAL                                         1
#define RSRFSIGGEN_VAL_ADG_MODE_GLON                                        2

// RsRFSigGen_rngADGTimeBasis
#define RSRFSIGGEN_VAL_SATNAV_ADG_TBAS_UTC                                  0
#define RSRFSIGGEN_VAL_SATNAV_ADG_TBAS_GPS                                  1
#define RSRFSIGGEN_VAL_SATNAV_ADG_TBAS_GST                                  2
#define RSRFSIGGEN_VAL_SATNAV_ADG_TBAS_GLO                                  3
#define RSRFSIGGEN_VAL_SATNAV_ADG_TBAS_BDT                                  4
#define RSRFSIGGEN_VAL_SATNAV_ADG_TBAS_NAVIC                                5

// RsRFSigGen_rngSatNavVehicleType
#define RSRFSIGGEN_VAL_SATNAV_VEHICLE_TYPE_HIL                              0
#define RSRFSIGGEN_VAL_SATNAV_VEHICLE_TYPE_SPAC                             1
#define RSRFSIGGEN_VAL_SATNAV_VEHICLE_TYPE_AIRC                             2
#define RSRFSIGGEN_VAL_SATNAV_VEHICLE_TYPE_SHIP                             3
#define RSRFSIGGEN_VAL_SATNAV_VEHICLE_TYPE_LVEH                             4
#define RSRFSIGGEN_VAL_SATNAV_VEHICLE_TYPE_PED                              5

// RsRFSigGen_rngSatNavObscurationType
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_TYPE_USER                         0
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_TYPE_CITY                         1
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_TYPE_SUB1                         2
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_TYPE_URB1                         3
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_TYPE_LTUN                         4
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_TYPE_MTUN                         5
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_TYPE_BR1                          6
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_TYPE_BR2                          7
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_TYPE_P1M                          8
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_TYPE_P10M                         9
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_TYPE_P1H                          10
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_TYPE_HIGH                         11
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_TYPE_CUTT                         12

// RsRFSigGen_rngSatNavObscurationEnvironment
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_ENVIRONMENT_LOS                   0
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_ENVIRONMENT_VOBS                  1
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_ENVIRONMENT_RPL                   2
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_ENVIRONMENT_FULL                  3
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_ENVIRONMENT_GSR                   4

// RsRFSigGen_rngSatNavObscurationPhysicalModel
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_MODEL_OBSC                        0
#define RSRFSIGGEN_VAL_SATNAV_OBSCURATION_MODEL_OMP                         1

// RsRFSigGen_rngSatNavSATModulation
#define RSRFSIGGEN_VAL_SATNAV_SAT_MODULATION_BPSK                           0
#define RSRFSIGGEN_VAL_SATNAV_SAT_MODULATION_CBOC                           1

// RsRFSigGen_rngSatNavSATSignal
#define RSRFSIGGEN_VAL_SATNAV_SAT_SIGNAL_CAC                                0
#define RSRFSIGGEN_VAL_SATNAV_SAT_SIGNAL_PCOD                               1
#define RSRFSIGGEN_VAL_SATNAV_SAT_SIGNAL_CAPQ                               2
#define RSRFSIGGEN_VAL_SATNAV_SAT_SIGNAL_CAPI                               3
#define RSRFSIGGEN_VAL_SATNAV_SAT_SIGNAL_E1D                                4
#define RSRFSIGGEN_VAL_SATNAV_SAT_SIGNAL_RCA                                5

// RsRFSigGen_rngSatNavGPSTestScenario
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_GSMSIG                          0
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_GSMPER1                         1
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_GSMPER2                         2
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_GSMPER3                         3
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_W3GSIG                          4
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_W3GPER1                         5
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_W3GPER2                         6
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_W3GPER3                         7
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_W3G2M                           8
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_W3G2S                           9
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_LTESIGST1                       10
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_LTEPER1ST1                      11
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_LTEPER2ST1                      12
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_LTEPER5ST1                      13
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_W3GSIGST4                       14
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_W3GPER1ST4                      15
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_W3GPER2ST4                      16
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_W3GPER5ST4                      17
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_LTESIGST4                       18
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_LTEPER1ST5                      19
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_LTEPER2ST5                      20
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_LTEPER5ST5                      21
#define RSRFSIGGEN_VAL_SATNAV_TEST_SCENARIO_USER                            22

// RsRFSigGen_rngNFCTechnology
#define RSRFSIGGEN_VAL_NFC_TECHNOLOGY_NFCA                                  0
#define RSRFSIGGEN_VAL_NFC_TECHNOLOGY_NFCB                                  1
#define RSRFSIGGEN_VAL_NFC_TECHNOLOGY_NFCF                                  2
#define RSRFSIGGEN_VAL_NFC_TECHNOLOGY_EMVA                                  3
#define RSRFSIGGEN_VAL_NFC_TECHNOLOGY_EMVB                                  4

// RsRFSigGen_rngNFCDivisor
#define RSRFSIGGEN_VAL_NFC_DIVISOR_DIV2                                     0
#define RSRFSIGGEN_VAL_NFC_DIVISOR_DIV4                                     1

// RsRFSigGen_rngNFCTransmissionMode
#define RSRFSIGGEN_VAL_NFC_TRANSMISSION_MODE_POLL                           0
#define RSRFSIGGEN_VAL_NFC_TRANSMISSION_MODE_LISTEN                         1

// RsRFSigGen_rngNFCPredefinedSequence
#define RSRFSIGGEN_VAL_NFC_PREDEFINED_SEQ_FPS                               0
#define RSRFSIGGEN_VAL_NFC_PREDEFINED_SEQ_BPA                               1
#define RSRFSIGGEN_VAL_NFC_PREDEFINED_SEQ_BPS                               2
#define RSRFSIGGEN_VAL_NFC_PREDEFINED_SEQ_APA                               3
#define RSRFSIGGEN_VAL_NFC_PREDEFINED_SEQ_APS                               4

// RsRFSigGen_rngNFCSequenceCommandType
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_ALAQ                            0
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_SNAQ                            1
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_SDAQ                            2
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_SLAQ                            3
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_SPAQ                            4
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_RDAQ                            5
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_RLAQ                            6
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_T1RQ                            7
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_WREQ                            8
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_WNEQ                            9
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_RSGQ                            10
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_RD8Q                            11
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_WE8Q                            12
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_WN8Q                            13
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_T2RQ                            14
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_T2WQ                            15
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_SSLQ                            16
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_RATQ                            17
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_T4AD                            18
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_ATRQ                            19
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_PSLQ                            20
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_DEPQ                            21
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_DSLQ                            22
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_RLSQ                            23
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_ALBQ                            24
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_SNBQ                            25
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_SMAR                            26
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_SPBQ                            27
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_ATBQ                            28
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_T4BD                            29
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_SNFQ                            30
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_CHKQ                            31
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_UPDQ                            32
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_SNAS                            33
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_SDAS                            34
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_SLAS                            35
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_RDAS                            36
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_RLAS                            37
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_T1RS                            38
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_WRES                            39
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_WNES                            40
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_RSGS                            41
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_RD8S                            42
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_WE8S                            43
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_WN8S                            44
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_T2RS                            45
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_ACK                             46
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_NACK                            47
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_ATSS                            48
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_ATRS                            49
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_PSLS                            50
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_DEPS                            51
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_DSLS                            52
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_RLSS                            53
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_SNBS                            54
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_SPBS                            55
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_ATBS                            56
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_SNFS                            57
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_CHKS                            58
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_UPDS                            59
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_GENE                            60
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_IDLE                            61
#define RSRFSIGGEN_VAL_NFC_SEQ_COMMAND_TYPE_BLNK                            62

// RsRFSigGen_rngNFCFrameNFCSize
#define RSRFSIGGEN_VAL_NFC_SIZE_SINGLE                                      0
#define RSRFSIGGEN_VAL_NFC_SIZE_DOUBLE                                      1
#define RSRFSIGGEN_VAL_NFC_SIZE_TRIPLE                                      2

// RsRFSigGen_rngNFCFrameSELCMD
#define RSRFSIGGEN_VAL_NFC_FRAME_SEL_CL1                                    0
#define RSRFSIGGEN_VAL_NFC_FRAME_SEL_CL2                                    1
#define RSRFSIGGEN_VAL_NFC_FRAME_SEL_CL3                                    2

// RsRFSigGen_rngNFCPacketSelection
#define RSRFSIGGEN_VAL_NFC_SELECTION_PACKET1                                0
#define RSRFSIGGEN_VAL_NFC_SELECTION_PACKET2                                1

// RsRFSigGen_rngNFCBlockType
#define RSRFSIGGEN_VAL_NFC_BLOCK_TYPE_I                                     0
#define RSRFSIGGEN_VAL_NFC_BLOCK_TYPE_R                                     1
#define RSRFSIGGEN_VAL_NFC_BLOCK_TYPE_S                                     2

// RsRFSigGen_rngNFCLengthReduction
#define RSRFSIGGEN_VAL_NFC_LENGTH_REDUCTION_64                              0
#define RSRFSIGGEN_VAL_NFC_LENGTH_REDUCTION_128                             1
#define RSRFSIGGEN_VAL_NFC_LENGTH_REDUCTION_192                             2
#define RSRFSIGGEN_VAL_NFC_LENGTH_REDUCTION_254                             3

// RsRFSigGen_rngSatNavGlobalSignalGPS
#define RSRFSIGGEN_VAL_SATNAV_GLOBAL_SIGNAL_GPS_CAC                         0
#define RSRFSIGGEN_VAL_SATNAV_GLOBAL_SIGNAL_GPS_PCOD                        1
#define RSRFSIGGEN_VAL_SATNAV_GLOBAL_SIGNAL_GPS_CAPQ                        2
#define RSRFSIGGEN_VAL_SATNAV_GLOBAL_SIGNAL_GPS_CAPI                        3

// RsRFSigGen_rngSatNavGlobalSignalGALILEO
#define RSRFSIGGEN_VAL_SATNAV_GLOBAL_SIGNAL_GAL_E1D                         0

// RsRFSigGen_rngSatNavGlobalSignalGLONASS
#define RSRFSIGGEN_VAL_SATNAV_GLOBAL_SIGNAL_GLON_RCA                        0

// RsRFSigGen_rngSatNavGlobalSignalBeiDou
#define RSRFSIGGEN_VAL_SATNAV_GLOBAL_SIGNAL_BEIDOU_B1CA                     0

// RsRFSigGen_rngSatNavSatOrbit
#define RSRFSIGGEN_VAL_SATNAV_ORBIT_MEO                                     0
#define RSRFSIGGEN_VAL_SATNAV_ORBIT_IGSO                                    1
#define RSRFSIGGEN_VAL_SATNAV_ORBIT_GEO                                     2

// RsRFSigGen_rngTriggerSignalDurationUnit
#define RSRFSIGGEN_VAL_TRIGGER_SIGNAL_DURATION_UNIT_SEQUENCE                0
#define RSRFSIGGEN_VAL_TRIGGER_SIGNAL_DURATION_UNIT_SAMPLE                  1

// RsRFSigGen_rngNFCMarkerMode
#define RSRFSIGGEN_VAL_NFC_MARKER_MODE_PULSE                                0
#define RSRFSIGGEN_VAL_NFC_MARKER_MODE_RESTART                              1
#define RSRFSIGGEN_VAL_NFC_MARKER_MODE_PATTERN                              2
#define RSRFSIGGEN_VAL_NFC_MARKER_MODE_RATIO                                3
#define RSRFSIGGEN_VAL_NFC_MARKER_MODE_TRIGGER                              4

// RsRFSigGen_rngNFCApplicationCoding
#define RSRFSIGGEN_VAL_NFC_CODING_PROP                                      0
#define RSRFSIGGEN_VAL_NFC_CODING_CRCB                                      1

// RsRFSigGen_rngNFCANSelection
#define RSRFSIGGEN_VAL_NFC_ANSELECTION_ACK                                  0
#define RSRFSIGGEN_VAL_NFC_ANSELECTION_NACK                                 1

// RsRFSigGen_rngNFCFrameType
#define RSRFSIGGEN_VAL_NFC_FRAME_TYPE_SHORT                                 0
#define RSRFSIGGEN_VAL_NFC_FRAME_TYPE_STANDARD                              1
#define RSRFSIGGEN_VAL_NFC_FRAME_TYPE_BOSD                                  2

// RsRFSigGen_rngNFCBitFrameAnticollision
#define RSRFSIGGEN_VAL_NFC_ANTICOLLISION_SDD0                               0
#define RSRFSIGGEN_VAL_NFC_ANTICOLLISION_SDD1                               1
#define RSRFSIGGEN_VAL_NFC_ANTICOLLISION_SDD2                               2
#define RSRFSIGGEN_VAL_NFC_ANTICOLLISION_SDD4                               3
#define RSRFSIGGEN_VAL_NFC_ANTICOLLISION_SDD8                               4
#define RSRFSIGGEN_VAL_NFC_ANTICOLLISION_SDD16                              5

// RsRFSigGen_rngNFCDLPoll
#define RSRFSIGGEN_VAL_NFC_POLL_DIV1                                        0
#define RSRFSIGGEN_VAL_NFC_POLL_DIV2                                        1
#define RSRFSIGGEN_VAL_NFC_POLL_DIV4                                        2
#define RSRFSIGGEN_VAL_NFC_POLL_DIV8                                        3

// RsRFSigGen_rngNFCFrameD
#define RSRFSIGGEN_VAL_NFC_D_D1                                             0
#define RSRFSIGGEN_VAL_NFC_D_D2                                             1
#define RSRFSIGGEN_VAL_NFC_D_D4                                             2
#define RSRFSIGGEN_VAL_NFC_D_D8                                             3
#define RSRFSIGGEN_VAL_NFC_D_D16                                            4
#define RSRFSIGGEN_VAL_NFC_D_D32                                            5
#define RSRFSIGGEN_VAL_NFC_D_D64                                            6

// RsRFSigGen_rngNFCDWSelection
#define RSRFSIGGEN_VAL_NFC_DW_DSEL                                          0
#define RSRFSIGGEN_VAL_NFC_DW_WTX                                           1

// RsRFSigGen_rngNFCMaximumFrameSize
#define RSRFSIGGEN_VAL_NFC_MAX_FRAME_SIZE_F16                               0
#define RSRFSIGGEN_VAL_NFC_MAX_FRAME_SIZE_F24                               1
#define RSRFSIGGEN_VAL_NFC_MAX_FRAME_SIZE_F32                               2
#define RSRFSIGGEN_VAL_NFC_MAX_FRAME_SIZE_F40                               3
#define RSRFSIGGEN_VAL_NFC_MAX_FRAME_SIZE_F48                               4
#define RSRFSIGGEN_VAL_NFC_MAX_FRAME_SIZE_F64                               5
#define RSRFSIGGEN_VAL_NFC_MAX_FRAME_SIZE_F96                               6
#define RSRFSIGGEN_VAL_NFC_MAX_FRAME_SIZE_F128                              7
#define RSRFSIGGEN_VAL_NFC_MAX_FRAME_SIZE_F256                              8

// RsRFSigGen_rngNFCMTR0
#define RSRFSIGGEN_VAL_NFC_MTR0_TR00                                        0
#define RSRFSIGGEN_VAL_NFC_MTR0_TR01                                        1
#define RSRFSIGGEN_VAL_NFC_MTR0_TR02                                        2

// RsRFSigGen_rngNFCMTR1
#define RSRFSIGGEN_VAL_NFC_MTR0_TR10                                        0
#define RSRFSIGGEN_VAL_NFC_MTR0_TR11                                        1
#define RSRFSIGGEN_VAL_NFC_MTR0_TR12                                        2

// RsRFSigGen_rngNFCMTR2
#define RSRFSIGGEN_VAL_NFC_MTR0_TR20                                        0
#define RSRFSIGGEN_VAL_NFC_MTR0_TR21                                        1
#define RSRFSIGGEN_VAL_NFC_MTR0_TR22                                        2

// RsRFSigGen_rngNFCNFCID2Format
#define RSRFSIGGEN_VAL_NFC_CID2_FORMAT_NDEP                                 0
#define RSRFSIGGEN_VAL_NFC_CID2_FORMAT_TT3                                  1

// RsRFSigGen_rngNFCNACK
#define RSRFSIGGEN_VAL_NFC_NACK_NCK0                                        0
#define RSRFSIGGEN_VAL_NFC_NACK_NCK1                                        1
#define RSRFSIGGEN_VAL_NFC_NACK_NCK4                                        2
#define RSRFSIGGEN_VAL_NFC_NACK_NCK5                                        3

// RsRFSigGen_rngNFCNumberOfSlots
#define RSRFSIGGEN_VAL_NFC_NUMBER_OF_SLOTS_S1                               0
#define RSRFSIGGEN_VAL_NFC_NUMBER_OF_SLOTS_S2                               1
#define RSRFSIGGEN_VAL_NFC_NUMBER_OF_SLOTS_S4                               2
#define RSRFSIGGEN_VAL_NFC_NUMBER_OF_SLOTS_S8                               3
#define RSRFSIGGEN_VAL_NFC_NUMBER_OF_SLOTS_S16                              4

// RsRFSigGen_rngNFCSizeNFCID1
#define RSRFSIGGEN_VAL_NFC_SIZE_NFCID1_SINGLE                               0
#define RSRFSIGGEN_VAL_NFC_SIZE_NFCID1_DOUBLE                               1
#define RSRFSIGGEN_VAL_NFC_SIZE_NFCID1_TRIPLE                               2

// RsRFSigGen_rngNFCTypePDU
#define RSRFSIGGEN_VAL_NFC_PDU_INFO                                         0
#define RSRFSIGGEN_VAL_NFC_PDU_ANACK                                        1
#define RSRFSIGGEN_VAL_NFC_PDU_SUPER                                        2

// RsRFSigGen_rngNFCRequestCode
#define RSRFSIGGEN_VAL_NFC_RC_CODE_NSCI                                     0
#define RSRFSIGGEN_VAL_NFC_RC_CODE_SCIR                                     1
#define RSRFSIGGEN_VAL_NFC_RC_CODE_APFS                                     2

// RsRFSigGen_rngNFCSelectCL
#define RSRFSIGGEN_VAL_NFC_SELECT_CL1                                       0
#define RSRFSIGGEN_VAL_NFC_SELECT_CL2                                       1
#define RSRFSIGGEN_VAL_NFC_SELECT_CL3                                       2

// RsRFSigGen_rngNFCSlotNumber
#define RSRFSIGGEN_NFC_SLOT_NUMBER_SN2                                      0
#define RSRFSIGGEN_NFC_SLOT_NUMBER_SN3                                      1
#define RSRFSIGGEN_NFC_SLOT_NUMBER_SN4                                      2
#define RSRFSIGGEN_NFC_SLOT_NUMBER_SN5                                      3
#define RSRFSIGGEN_NFC_SLOT_NUMBER_SN6                                      4
#define RSRFSIGGEN_NFC_SLOT_NUMBER_SN7                                      5
#define RSRFSIGGEN_NFC_SLOT_NUMBER_SN8                                      6
#define RSRFSIGGEN_NFC_SLOT_NUMBER_SN9                                      7
#define RSRFSIGGEN_NFC_SLOT_NUMBER_SN10                                     8
#define RSRFSIGGEN_NFC_SLOT_NUMBER_SN11                                     9
#define RSRFSIGGEN_NFC_SLOT_NUMBER_SN12                                     10
#define RSRFSIGGEN_NFC_SLOT_NUMBER_SN13                                     11
#define RSRFSIGGEN_NFC_SLOT_NUMBER_SN14                                     12
#define RSRFSIGGEN_NFC_SLOT_NUMBER_SN15                                     13
#define RSRFSIGGEN_NFC_SLOT_NUMBER_SN16                                     14

// RsRFSigGen_rngNFCTSN
#define RSRFSIGGEN_VAL_NFC_TSN_TSN1                                         0
#define RSRFSIGGEN_VAL_NFC_TSN_TSN2                                         1
#define RSRFSIGGEN_VAL_NFC_TSN_TSN4                                         2
#define RSRFSIGGEN_VAL_NFC_TSN_TSN8                                         3
#define RSRFSIGGEN_VAL_NFC_TSN_TSN16                                        4

// RsRFSigGen_rngNFCProtocolConfigured
#define RSRFSIGGEN_VAL_NFC_PROTOCOL_T2                                      0
#define RSRFSIGGEN_VAL_NFC_PROTOCOL_T4A                                     1
#define RSRFSIGGEN_VAL_NFC_PROTOCOL_NDEP                                    2
#define RSRFSIGGEN_VAL_NFC_PROTOCOL_DT4A                                    3
#define RSRFSIGGEN_VAL_NFC_PROTOCOL_OFF                                     4
#define RSRFSIGGEN_VAL_NFC_PROTOCOL_ON                                      5

// RsRFSigGen_rngNFCAttentionTimeout
#define RSRFSIGGEN_VAL_NFC_ATTENTION_TIMEOUT_ATTENTION                      0
#define RSRFSIGGEN_VAL_NFC_ATTENTION_TIMEOUT_TIMEOUT                        1

// RsRFSigGen_rngNFCCodeListConfiguration
#define RSRFSIGGEN_VAL_NFC_CODE_LIST_AARW                                   0
#define RSRFSIGGEN_VAL_NFC_CODE_LIST_AARO                                   1

// RsRFSigGen_rngNFCBlockLength
#define RSRFSIGGEN_VAL_NFC_BLOCK_LENGTH_LEN2                                0
#define RSRFSIGGEN_VAL_NFC_BLOCK_LENGTH_LEN3                                1

// RsRFSigGen_rngWiMAXOFDMABurstSpaceTimeCodingMode
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_STC_TWO_ANTENNAS_MATRIX_A                0
#define RSRFSIGGEN_VAL_WIMAX_OFDMA_STC_TWO_ANTENNAS_MATRIX_B                1

// RsRFSigGen_rngWiMAXExternalClockMode
#define RSRFSIGGEN_VAL_WIMAX_EXTERNAL_CLOCK_MODE_SAMPLE                     0
#define RSRFSIGGEN_VAL_WIMAX_EXTERNAL_CLOCK_MODE_MULTI_SAMPLE               1

// RsRFSigGen_rngWiMAXClockSource
#define RSRFSIGGEN_VAL_WIMAX_CLOCK_SOURCE_INTERNAL                          0
#define RSRFSIGGEN_VAL_WIMAX_CLOCK_SOURCE_EXTERNAL                          1
#define RSRFSIGGEN_VAL_WIMAX_CLOCK_SOURCE_A_INTERNAL_TO_B                   2

// RsRFSigGen_rngWiMAXClockSynchronizationMode
#define RSRFSIGGEN_VAL_WIMAX_CLOCK_SYNCHRONIZATION_MODE_NONE                0
#define RSRFSIGGEN_VAL_WIMAX_CLOCK_SYNCHRONIZATION_MODE_MASTER              1
#define RSRFSIGGEN_VAL_WIMAX_CLOCK_SYNCHRONIZATION_MODE_SLAVE               2

// RsRFSigGen_rngWiMAXOFDMBurstMode
#define RSRFSIGGEN_VAL_WIMAX_BURST_MODE_NORMAL                              0
#define RSRFSIGGEN_VAL_WIMAX_BURST_MODE_DL_MAP                              1
#define RSRFSIGGEN_VAL_WIMAX_BURST_MODE_UL_MAP                              2

// RsRFSigGen_rngWiMAXOFDMFFTSize
#define RSRFSIGGEN_VAL_WIMAX_OFDM_FFT_256                                   0

// RsRFSigGen_rngTDSCDMADwPTSMode
#define RSRFSIGGEN_VAL_TDSCDMA_CELL_MODE_AUTO                               0
#define RSRFSIGGEN_VAL_TDSCDMA_CELL_MODE_ON                                 1
#define RSRFSIGGEN_VAL_TDSCDMA_CELL_MODE_OFF                                2

// RsRFSigGen_rngGBASVDBSSID
#define RSRFSIGGEN_VAL_GBAS_VDB_SSID_A                                      0
#define RSRFSIGGEN_VAL_GBAS_VDB_SSID_B                                      1
#define RSRFSIGGEN_VAL_GBAS_VDB_SSID_C                                      2
#define RSRFSIGGEN_VAL_GBAS_VDB_SSID_D                                      3
#define RSRFSIGGEN_VAL_GBAS_VDB_SSID_E                                      4
#define RSRFSIGGEN_VAL_GBAS_VDB_SSID_F                                      5
#define RSRFSIGGEN_VAL_GBAS_VDB_SSID_G                                      6
#define RSRFSIGGEN_VAL_GBAS_VDB_SSID_H                                      7

// RsRFSigGen_rngGBASVDBData
#define RSRFSIGGEN_VAL_GBAS_VDB_DATA_ZERO                                   0
#define RSRFSIGGEN_VAL_GBAS_VDB_DATA_ONE                                    1
#define RSRFSIGGEN_VAL_GBAS_VDB_DATA_PATTERN                                2
#define RSRFSIGGEN_VAL_GBAS_VDB_DATA_PN9                                    3
#define RSRFSIGGEN_VAL_GBAS_VDB_DATA_PN11                                   4
#define RSRFSIGGEN_VAL_GBAS_VDB_DATA_PN15                                   5
#define RSRFSIGGEN_VAL_GBAS_VDB_DATA_PN16                                   6
#define RSRFSIGGEN_VAL_GBAS_VDB_DATA_PN20                                   7
#define RSRFSIGGEN_VAL_GBAS_VDB_DATA_PN21                                   8
#define RSRFSIGGEN_VAL_GBAS_VDB_DATA_PN23                                   9
#define RSRFSIGGEN_VAL_GBAS_VDB_DATA_DLIST                                  10
#define RSRFSIGGEN_VAL_GBAS_VDB_DATA_REAL                                   11

// RsRFSigGen_rngGBASVDBGSReferenceReceivers
#define RSRFSIGGEN_GBAS_GS_REFERENCE_RECEIVERS_2                            2
#define RSRFSIGGEN_GBAS_GS_REFERENCE_RECEIVERS_3                            3
#define RSRFSIGGEN_GBAS_GS_REFERENCE_RECEIVERS_4                            4

// RsRFSigGen_rngGBASGSAccuracyDesignator
#define RSRFSIGGEN_GBAS_GS_ACCURACY_DESIGNATOR_A                            0
#define RSRFSIGGEN_GBAS_GS_ACCURACY_DESIGNATOR_B                            1
#define RSRFSIGGEN_GBAS_GS_ACCURACY_DESIGNATOR_C                            2

// RsRFSigGen_rngGBASGSContinuityDesignator
#define RSRFSIGGEN_GBAS_GS_CONTINUITY_DESIGNATOR_FC                         0
#define RSRFSIGGEN_GBAS_GS_CONTINUITY_DESIGNATOR_FD                         1

// RsRFSigGen_rngFeetMeter
#define RSRFSIGGEN_VAL_FEET                                                 0
#define RSRFSIGGEN_VAL_METER                                                1

// RsRFSigGen_rngGBASRunwayLetter
#define RSRFSIGGEN_VAL_RUNWAY_NO_LETTER                                     0
#define RSRFSIGGEN_VAL_RUNWAY_LETTER_R                                      1
#define RSRFSIGGEN_VAL_RUNWAY_LETTER_L                                      2
#define RSRFSIGGEN_VAL_RUNWAY_LETTER_C                                      3

// RsRFSigGen_rngGBASApproachDesignator
#define RSRFSIGGEN_VAL_GBAS_APPROACH_DESIGNATOR_GAB                         0
#define RSRFSIGGEN_VAL_GBAS_APPROACH_DESIGNATOR_GC                          1
#define RSRFSIGGEN_VAL_GBAS_APPROACH_DESIGNATOR_GCD                         2

// RsRFSigGen_rngGBASTriggerSource
#define RSRFSIGGEN_VAL_GBAS_TRIGGER_INT                                     0
#define RSRFSIGGEN_VAL_GBAS_TRIGGER_EXT                                     1

// RsRFSigGen_rngGBASSignalDurationUnit
#define RSRFSIGGEN_VAL_GBAS_SIGNAL_DURATION_UNIT_SEQUENCE                   0
#define RSRFSIGGEN_VAL_GBAS_SIGNAL_DURATION_UNIT_SAMPLE                     1

// RsRFSigGen_rngGBASMarkerMode
#define RSRFSIGGEN_VAL_GBAS_MARKER_MODE_PPS                                 0
#define RSRFSIGGEN_VAL_GBAS_MARKER_MODE_RESTART                             1
#define RSRFSIGGEN_VAL_GBAS_MARKER_MODE_PULSE                               2
#define RSRFSIGGEN_VAL_GBAS_MARKER_MODE_PATTERN                             3
#define RSRFSIGGEN_VAL_GBAS_MARKER_MODE_RATIO                               4
#define RSRFSIGGEN_VAL_GBAS_MARKER_MODE_TRIGGER                             5

// RsRFSigGen_rngGBASClockMode
#define RSRFSIGGEN_VAL_GBAS_CLOCK_MODE_SAMPLE                               0
#define RSRFSIGGEN_VAL_GBAS_CLOCK_MODE_MSAMPLE                              1

// RsRFSigGen_rngNFCTriggerSource
#define RSRFSIGGEN_VAL_NFC_TRIGGER_SOURCE_INTERNAL                          0
#define RSRFSIGGEN_VAL_NFC_TRIGGER_SOURCE_EXTERNAL                          1

// RsRFSigGen_rngNFCClockSource
#define RSRFSIGGEN_VAL_NFC_CLOCK_SOURCE_INTERNAL                            0
#define RSRFSIGGEN_VAL_NFC_CLOCK_SOURCE_EXTERNAL                            1

// RsRFSigGen_rngWLANNFrameBlockStandard
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_STANDARD_USER                      0
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_STANDARD_WAG                       1
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_STANDARD_WBG                       2
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_STANDARD_WCG                       3
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_STANDARD_WPJ                       4
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_STANDARD_WN                        5
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_STANDARD_WAC                       6
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_STANDARD_WAX                       7
#define RSRFSIGGEN_VAL_WLANN_FRAME_BLOCK_STANDARD_WBE                       8

// RsRFSigGen_rngWLANNMPDUEOF
#define RSRFSIGGEN_VAL_WLANN_MPDU_EOF_DEFAULT                               0
#define RSRFSIGGEN_VAL_WLANN_MPDU_EOF_E0                                    1
#define RSRFSIGGEN_VAL_WLANN_MPDU_EOF_E1                                    2

// RsRFSigGen_rngW3GPPCopyFromSource
#define RSRFSIGGEN_VAL_W3GPP_BASE_STATION_1                                 1
#define RSRFSIGGEN_VAL_W3GPP_BASE_STATION_2                                 2
#define RSRFSIGGEN_VAL_W3GPP_BASE_STATION_3                                 3
#define RSRFSIGGEN_VAL_W3GPP_BASE_STATION_4                                 4

// RsRFSigGen_rngW3GPPTS25141TestMode
#define RSRFSIGGEN_VAL_TS25141_TEST_MODE_STANDARD                           0
#define RSRFSIGGEN_VAL_TS25141_TEST_MODE_USER                               1

// RsRFSigGen_rngW3GPPBSTestCase
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC642                              0
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC66                               1
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC72                               2
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC73                               3
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC74                               4
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC75                               5
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC76                               6
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC78                               7
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC821                              8
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC831                              9
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC832                              10
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC833                              11
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC834                              12
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC84                               13
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC85                               14
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC86                               15
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC881                              16
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC882                              17
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC883                              18
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC884                              19
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC891                              20
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC892                              21
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC893                              22
#define RSRFSIGGEN_VAL_TS25141_TEST_CASE_TC894                              23

// RsRFSigGen_rngW3GPPTS25141BlockErrorRate
#define RSRFSIGGEN_VAL_TS25141_BLOCK_ERROR_RATE_B0                          0
#define RSRFSIGGEN_VAL_TS25141_BLOCK_ERROR_RATE_B01                         1
#define RSRFSIGGEN_VAL_TS25141_BLOCK_ERROR_RATE_B001                        2
#define RSRFSIGGEN_VAL_TS25141_BLOCK_ERROR_RATE_B0001                       3

// RsRFSigGen_rngW3GPPTS25141RequiredProbabilityofDetection
#define RSRFSIGGEN_VAL_TS25141_REQUIRED_PROBABILITY_DETECTION_PD099         0
#define RSRFSIGGEN_VAL_TS25141_REQUIRED_PROBABILITY_DETECTION_PD0999        1

// RsRFSigGen_rngW3GPPTS25141BSPowerClass
#define RSRFSIGGEN_VAL_TS25141_BS_POWER_CLASS_WIDE                          0
#define RSRFSIGGEN_VAL_TS25141_BS_POWER_CLASS_MEDIUM                        1
#define RSRFSIGGEN_VAL_TS25141_BS_POWER_CLASS_LOCAL                         2

// RsRFSigGen_rngW3GPPTS25141TriggerConfiguration
#define RSRFSIGGEN_VAL_TS25141_TRIGGER_CONFIGURATION_AUTO                   0
#define RSRFSIGGEN_VAL_TS25141_TRIGGER_CONFIGURATION_PRESET                 1
#define RSRFSIGGEN_VAL_TS25141_TRIGGER_CONFIGURATION_SINGLE                 2

// RsRFSigGen_rngW3GPPTS25141MarkerConfiguration
#define RSRFSIGGEN_VAL_TS25141_MARKER_CONFIGURATION_AUTO                    0
#define RSRFSIGGEN_VAL_TS25141_MARKER_CONFIGURATION_PRESET                  1

// RsRFSigGen_rngW3GPPTS25141BlockingScenario
#define RSRFSIGGEN_VAL_TS25141_BLOCKING_SCENARIO_WIDE                       0
#define RSRFSIGGEN_VAL_TS25141_BLOCKING_SCENARIO_COLOCATED                  1
#define RSRFSIGGEN_VAL_TS25141_BLOCKING_SCENARIO_NARROW                     2

// RsRFSigGen_rngW3GPPTS25141TPCRepeatPattern
#define RSRFSIGGEN_VAL_TS25141_TPC_PATTERN_SINGLE                           0
#define RSRFSIGGEN_VAL_TS25141_TPC_PATTERN_AGGREGATED                       1
#define RSRFSIGGEN_VAL_TS25141_TPC_PATTERN_ONE                              2
#define RSRFSIGGEN_VAL_TS25141_TPC_PATTERN_ZERO                             3
#define RSRFSIGGEN_VAL_TS25141_TPC_PATTERN_PATTERN                          4
#define RSRFSIGGEN_VAL_TS25141_TPC_PATTERN_DATA_LIST                        5

// RsRFSigGen_rngW3GPPTS25141TPCStartPattern
#define RSRFSIGGEN_VAL_TS25141_TPC_START_MAXIMUM_POWER                      0
#define RSRFSIGGEN_VAL_TS25141_TPC_START_DATA_LIST                          1

// RsRFSigGen_rngW3GPPTS25141ChannelCodingScheme
#define RSRFSIGGEN_VAL_TS25141_CHANNEL_CODING_M12K2                         0
#define RSRFSIGGEN_VAL_TS25141_CHANNEL_CODING_M64K                          1
#define RSRFSIGGEN_VAL_TS25141_CHANNEL_CODING_M144K                         2
#define RSRFSIGGEN_VAL_TS25141_CHANNEL_CODING_M384K                         3
#define RSRFSIGGEN_VAL_TS25141_CHANNEL_CODING_AMR                           4

// RsRFSigGen_rngW3GPPTS25141OverallSymbolRate
#define RSRFSIGGEN_VAL_TS25141_OVERALL_SYMBOL_RATE_D15K                     0
#define RSRFSIGGEN_VAL_TS25141_OVERALL_SYMBOL_RATE_D30K                     1
#define RSRFSIGGEN_VAL_TS25141_OVERALL_SYMBOL_RATE_D60K                     2
#define RSRFSIGGEN_VAL_TS25141_OVERALL_SYMBOL_RATE_D120K                    3
#define RSRFSIGGEN_VAL_TS25141_OVERALL_SYMBOL_RATE_D240K                    4
#define RSRFSIGGEN_VAL_TS25141_OVERALL_SYMBOL_RATE_D480K                    5
#define RSRFSIGGEN_VAL_TS25141_OVERALL_SYMBOL_RATE_D960K                    6
#define RSRFSIGGEN_VAL_TS25141_OVERALL_SYMBOL_RATE_D1920K                   7
#define RSRFSIGGEN_VAL_TS25141_OVERALL_SYMBOL_RATE_D2880K                   8
#define RSRFSIGGEN_VAL_TS25141_OVERALL_SYMBOL_RATE_D3840K                   9
#define RSRFSIGGEN_VAL_TS25141_OVERALL_SYMBOL_RATE_D4800K                   10
#define RSRFSIGGEN_VAL_TS25141_OVERALL_SYMBOL_RATE_D5760K                   11

// RsRFSigGen_rngW3GPPTS25141WantedSignalOperatingBand
#define RSRFSIGGEN_VAL_TS25141_OPERATING_BAND_I                             1
#define RSRFSIGGEN_VAL_TS25141_OPERATING_BAND_II                            2
#define RSRFSIGGEN_VAL_TS25141_OPERATING_BAND_III                           3
#define RSRFSIGGEN_VAL_TS25141_OPERATING_BAND_IV                            4
#define RSRFSIGGEN_VAL_TS25141_OPERATING_BAND_V                             5
#define RSRFSIGGEN_VAL_TS25141_OPERATING_BAND_VI                            6

// RsRFSigGen_rngW3GPPTS25141TransportBlockSize
#define RSRFSIGGEN_VAL_TS25141_TRANSPORT_BLOCK_168                          0
#define RSRFSIGGEN_VAL_TS25141_TRANSPORT_BLOCK_360                          1

// RsRFSigGen_rngW3GPPTS25141BasebandASignalRouting
#define RSRFSIGGEN_VAL_TS25141_BASEBAND_A                                   0
#define RSRFSIGGEN_VAL_TS25141_BASEBAND_B                                   1

// RsRFSigGen_rngW3GPPTS25141ScramblingCodeMode
#define RSRFSIGGEN_VAL_TS25141_SCRAMBLING_CODE_MODE_OFF                     0
#define RSRFSIGGEN_VAL_TS25141_SCRAMBLING_CODE_MODE_ON                      1
#define RSRFSIGGEN_VAL_TS25141_SCRAMBLING_CODE_MODE_LONG                    2
#define RSRFSIGGEN_VAL_TS25141_SCRAMBLING_CODE_MODE_SHORT                   3

// RsRFSigGen_rngW3GPPTS25141InterfererBandwidthType
#define RSRFSIGGEN_VAL_TS25141_BS_BANDWIDTH_WIDE                            0
#define RSRFSIGGEN_VAL_TS25141_BS_BANDWIDTH_NARROW                          1

// RsRFSigGen_rngW3GPPTS25141Interferer2Modulation
#define RSRFSIGGEN_VAL_TS25141_INTERFERER2_MODULATION_WCDMA                 0
#define RSRFSIGGEN_VAL_TS25141_INTERFERER2_MODULATION_CW                    1
#define RSRFSIGGEN_VAL_TS25141_INTERFERER2_MODULATION_GMSK                  2
#define RSRFSIGGEN_VAL_TS25141_INTERFERER2_MODULATION_QPSK                  3

// RsRFSigGen_rngW3GPPTS25141InterferenceModel
#define RSRFSIGGEN_VAL_TS25141_INTERFERENCE_MODEL_TM164                     0
#define RSRFSIGGEN_VAL_TS25141_INTERFERENCE_MODEL_TM116                     1
#define RSRFSIGGEN_VAL_TS25141_INTERFERENCE_MODEL_TM132                     2
#define RSRFSIGGEN_VAL_TS25141_INTERFERENCE_MODEL_TM2                       3
#define RSRFSIGGEN_VAL_TS25141_INTERFERENCE_MODEL_TM316                     4
#define RSRFSIGGEN_VAL_TS25141_INTERFERENCE_MODEL_TM332                     5
#define RSRFSIGGEN_VAL_TS25141_INTERFERENCE_MODEL_TM4                       6
#define RSRFSIGGEN_VAL_TS25141_INTERFERENCE_MODEL_TM538                     7
#define RSRFSIGGEN_VAL_TS25141_INTERFERENCE_MODEL_TM528                     8
#define RSRFSIGGEN_VAL_TS25141_INTERFERENCE_MODEL_TM58                      9

// RsRFSigGen_rngW3GPPEnhHSDPAHSConstellationVersionParameterbState
#define RSRFSIGGEN_VAL_HSDPA_CVPB_0                                         0
#define RSRFSIGGEN_VAL_HSDPA_CVPB_1                                         1
#define RSRFSIGGEN_VAL_HSDPA_CVPB_2                                         2
#define RSRFSIGGEN_VAL_HSDPA_CVPB_3                                         3

// RsRFSigGen_rngW3GPPEnhHSDPAHSHSPDSCHAlternativeModulation
#define RSRFSIGGEN_VAL_W3GPP_MODULATION_QPSK                                0
#define RSRFSIGGEN_VAL_W3GPP_MODULATION_QAM16                               1
#define RSRFSIGGEN_VAL_W3GPP_MODULATION_QAM64                               2

// RsRFSigGen_rngW3GPPUEAICHTransmissionTimingPRACH
#define RSRFSIGGEN_VAL_W3GPP_PRACH_AICH_TRANSMISSION_TIMING_0               0
#define RSRFSIGGEN_VAL_W3GPP_PRACH_AICH_TRANSMISSION_TIMING_1               1

// RsRFSigGen_rngW3GPPUEHSDPCCHMIMOHARQACK
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_DTX                           0
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_PRE                           1
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_POST                          2
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_A                             3
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_N                             4
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_M_A                           5
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_M_N                           6
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_M_AA                          7
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_M_AN                          8
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_M_NA                          9
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_M_NN                          10
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S_A_D                         11
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S_N_D                         12
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S_D_A                         13
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S_D_N                         14
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S_A_A                         15
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S_A_N                         16
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S_N_A                         17
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S_N_N                         18
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_A_D                        19
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_N_D                        20
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_AA_D                       21
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_AN_D                       22
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_NA_D                       23
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_NN_D                       24
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_D_A                        25
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_D_N                        26
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_D_AA                       27
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_D_AN                       28
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_D_NA                       29
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_D_NN                       30
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_A_A                        31
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_A_N                        32
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_N_A                        33
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_N_N                        34
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_A_AA                       35
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_A_AN                       36
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_A_NA                       37
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_A_NN                       38
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_N_AA                       39
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_N_AN                       40
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_N_NA                       41
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_N_NN                       42
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_AA_A                       43
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_AA_N                       44
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_AN_A                       45
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_AN_N                       46
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_NA_A                       47
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_NA_N                       48
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_NN_A                       49
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_NN_N                       50
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_AA_AA                      51
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_AA_AN                      52
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_AA_NA                      53
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_AA_NN                      54
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_AN_AA                      55
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_AN_AN                      56
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_AN_NA                      57
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_AN_NN                      58
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_NA_AA                      59
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_NA_AN                      60
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_NA_NA                      61
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_NA_NN                      62
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_NN_AA                      63
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_NN_AN                      64
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_NN_NA                      65
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_MS_NN_NN                      66
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_A_D_D                      67
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_N_D_D                      68
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_D_A_D                      69
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_D_N_D                      70
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_D_D_A                      71
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_D_D_N                      72
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_A_A_D                      73
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_A_N_D                      74
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_N_A_D                      75
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_N_N_D                      76
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_A_D_A                      77
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_A_D_N                      78
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_N_D_A                      79
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_N_D_N                      80
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_D_A_A                      81
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_D_A_N                      82
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_D_N_A                      83
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_D_N_N                      84
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_A_A_A                      85
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_A_A_N                      86
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_A_N_A                      87
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_A_N_N                      88
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_N_A_A                      89
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_N_A_N                      90
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_N_N_A                      91
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_S2_N_N_N                      92
#define RSRFSIGGEN_VAL_W3GPP_HSDPCCH_HARQ_ACK_D_DTX                         93

// RsRFSigGen_rngW3GPPUEHSDPCCHMIMOPCICQIType
#define RSRFSIGGEN_VAL_W3GPP_PCI_CQI_TYPE_DTX                               0
#define RSRFSIGGEN_VAL_W3GPP_PCI_CQI_TYPE_CQI                               1
#define RSRFSIGGEN_VAL_W3GPP_PCI_CQI_TYPE_CCQI                              2
#define RSRFSIGGEN_VAL_W3GPP_PCI_CQI_TYPE_TAST                              3
#define RSRFSIGGEN_VAL_W3GPP_PCI_CQI_TYPE_TADT                              4
#define RSRFSIGGEN_VAL_W3GPP_PCI_CQI_TYPE_TBI                               5

// RsRFSigGen_rngW3GPPHSDPABitErrorInsertion
#define RSRFSIGGEN_VAL_HSDPA_BIT_ERROR_LAYER_TRANSPORT                      0
#define RSRFSIGGEN_VAL_HSDPA_BIT_ERROR_LAYER_PHYSICAL                       1

// RsRFSigGen_rngW3GPPUEDTXMode
#define RSRFSIGGEN_VAL_W3GPP_UE_DTX_MODE_UPLINK_DISCONTINUOUS_TRANSMISSION  0
#define RSRFSIGGEN_VAL_W3GPP_UE_DTX_MODE_USER_SCHEDULING                    1

// RsRFSigGen_rngW3GPPUEDTXSchedulingEDCHTTI
#define RSRFSIGGEN_VAL_W3GPP_EDCH_TTI_DURATION_2                            0
#define RSRFSIGGEN_VAL_W3GPP_EDCH_TTI_DURATION_10                           1

// RsRFSigGen_rngW3GPPUEDTXInactivityThresholdforCycle2
#define RSRFSIGGEN_VAL_W3GPP_DTX_INACTIVITY_THRESHOLD_1                     0
#define RSRFSIGGEN_VAL_W3GPP_DTX_INACTIVITY_THRESHOLD_4                     1
#define RSRFSIGGEN_VAL_W3GPP_DTX_INACTIVITY_THRESHOLD_8                     2
#define RSRFSIGGEN_VAL_W3GPP_DTX_INACTIVITY_THRESHOLD_16                    3
#define RSRFSIGGEN_VAL_W3GPP_DTX_INACTIVITY_THRESHOLD_32                    4
#define RSRFSIGGEN_VAL_W3GPP_DTX_INACTIVITY_THRESHOLD_64                    5
#define RSRFSIGGEN_VAL_W3GPP_DTX_INACTIVITY_THRESHOLD_128                   6
#define RSRFSIGGEN_VAL_W3GPP_DTX_INACTIVITY_THRESHOLD_256                   7

// RsRFSigGen_rngW3GPPUEDTXLongPreambleLength
#define RSRFSIGGEN_VAL_W3GPP_DTX_LONG_PREAMBLE_LENGTH_2                     0
#define RSRFSIGGEN_VAL_W3GPP_DTX_LONG_PREAMBLE_LENGTH_4                     1
#define RSRFSIGGEN_VAL_W3GPP_DTX_LONG_PREAMBLE_LENGTH_15                    2

// RsRFSigGen_rngW3GPPUEDTXBurstLength1
#define RSRFSIGGEN_VAL_W3GPP_BURST_LENGTH_1                                 0
#define RSRFSIGGEN_VAL_W3GPP_BURST_LENGTH_2                                 1
#define RSRFSIGGEN_VAL_W3GPP_BURST_LENGTH_5                                 2

// RsRFSigGen_rngW3GPPUEDTXCycle1
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE_1                                    0
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE_4                                    1
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE_5                                    2
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE_8                                    3
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE_10                                   4
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE_16                                   5
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE_20                                   6

// RsRFSigGen_rngW3GPPUEDTXCycle2
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE2_4                                   0
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE2_5                                   1
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE2_8                                   2
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE2_10                                  3
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE2_16                                  4
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE2_20                                  5
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE2_32                                  6
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE2_40                                  7
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE2_64                                  8
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE2_80                                  9
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE2_128                                 10
#define RSRFSIGGEN_VAL_W3GPP_DTX_CYCLE2_160                                 11

// RsRFSigGen_rngGSMTriggerSignalDurationUnit
#define RSRFSIGGEN_VAL_TRIGGER_SEQUENCE_UNIT_FRAME                          0
#define RSRFSIGGEN_VAL_TRIGGER_SEQUENCE_UNIT_SYMBOL                         1

// RsRFSigGen_rngBTLEDevicesAddrTypeTxRx
#define RSRFSIGGEN_VAL_BT_LE_ADDR_TYPE_RANDOM                               1

// RsRFSigGen_rngEUTRADLCSIAntennaPortsNumber
#define RSRFSIGGEN_VAL_EUTRA_DL_CSI_AP1                                     0
#define RSRFSIGGEN_VAL_EUTRA_DL_CSI_AP2                                     1
#define RSRFSIGGEN_VAL_EUTRA_DL_CSI_AP4                                     2
#define RSRFSIGGEN_VAL_EUTRA_DL_CSI_AP8                                     3

// RsRFSigGen_rngEUTRADLUserAPMCell
#define RSRFSIGGEN_VAL_EUTRA_APM_CELL_PC0                                   0
#define RSRFSIGGEN_VAL_EUTRA_APM_CELL_SC1                                   1
#define RSRFSIGGEN_VAL_EUTRA_APM_CELL_SC2                                   2
#define RSRFSIGGEN_VAL_EUTRA_APM_CELL_SC3                                   3
#define RSRFSIGGEN_VAL_EUTRA_ANTENNA_MAPPING_SC4                            4

// RsRFSigGen_rngEUTRADLUserSPSInterval
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_SPS_S10                                0
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_SPS_S20                                1
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_SPS_S32                                2
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_SPS_S40                                3
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_SPS_S64                                4
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_SPS_S80                                5
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_SPS_S128                               6
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_SPS_S160                               7
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_SPS_S320                               8
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_SPS_S640                               9

// RsRFSigGen_rngEUTRAWizardWSANBits
#define RSRFSIGGEN_VAL_EUTRA_WS_ANB4                                        0
#define RSRFSIGGEN_VAL_EUTRA_WS_ANB16                                       1
#define RSRFSIGGEN_VAL_EUTRA_WS_ANB24                                       2
#define RSRFSIGGEN_VAL_EUTRA_WS_ANB64                                       3

// RsRFSigGen_rngEUTRADLSubframePBCHSFNRestartPeriod
#define RSRFSIGGEN_VAL_EUTRA_DL_SFN_PER3                                    0
#define RSRFSIGGEN_VAL_EUTRA_DL_SFN_PERS                                    1

// RsRFSigGen_rngC2kBSDomainOrder
#define RSRFSIGGEN_VAL_C2K_DOMAIN_MODE_HAD                                  0
#define RSRFSIGGEN_VAL_C2K_DOMAIN_MODE_BREV                                 1

// RsRFSigGen_rngC2kTriggerSignalDurationUnit
#define RSRFSIGGEN_VAL_C2K_SIGNAL_DURATION_UNIT_FRAME                       0
#define RSRFSIGGEN_VAL_C2K_SIGNAL_DURATION_UNIT_CHIP                        1
#define RSRFSIGGEN_VAL_C2K_SIGNAL_DURATION_UNIT_SEQUENCE                    2

// RsRFSigGen_rngEUTRATriggerDelayUnit
#define RSRFSIGGEN_VAL_EUTRA_TRIGGER_DELAY_UNIT_SAMPLE                      0
#define RSRFSIGGEN_VAL_EUTRA_TRIGGER_DELAY_UNIT_TIME                        1

// RsRFSigGen_rngEUTRAWizardGeneralNumberofTXAntennas
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TX_ANT1                                    0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_TX_ANT2                                    1

// RsRFSigGen_rngEUTRAWizardGeneralBaseStationClass
#define RSRFSIGGEN_VAL_EUTRA_WIZ_BSC_WIDE                                   0
#define RSRFSIGGEN_VAL_EUTRA_WIZ_BSC_LOCAL                                  1
#define RSRFSIGGEN_VAL_EUTRA_WIZ_BSC_HOME                                   2
#define RSRFSIGGEN_VAL_EUTRA_WIZ_BSC_MEDIUM                                 3

// RsRFSigGen_rngAMSourceSMW
#define RSRFSIGGEN_VAL_AM_SOURCE_LF1                                        0
#define RSRFSIGGEN_VAL_AM_SOURCE_LF2                                        1
#define RSRFSIGGEN_VAL_AM_SOURCE_NOISE                                      2
#define RSRFSIGGEN_VAL_AM_SOURCE_EXT1                                       3
#define RSRFSIGGEN_VAL_AM_SOURCE_EXT2                                       4

// RsRFSigGen_rngFMSourceSMW
#define RSRFSIGGEN_VAL_FM_SOURCE_LF1                                        0
#define RSRFSIGGEN_VAL_FM_SOURCE_LF2                                        1
#define RSRFSIGGEN_VAL_FM_SOURCE_NOISE                                      2
#define RSRFSIGGEN_VAL_FM_SOURCE_EXT1                                       3
#define RSRFSIGGEN_VAL_FM_SOURCE_EXT2                                       4

// RsRFSigGen_rngPMSourceSMW
#define RSRFSIGGEN_VAL_PM_SOURCE_LF1                                        0
#define RSRFSIGGEN_VAL_PM_SOURCE_LF2                                        1
#define RSRFSIGGEN_VAL_PM_SOURCE_NOISE                                      2
#define RSRFSIGGEN_VAL_PM_SOURCE_EXT1                                       3
#define RSRFSIGGEN_VAL_PM_SOURCE_EXT2                                       4
#define RSRFSIGGEN_VAL_PM_SOURCE_INT                                        7
#define RSRFSIGGEN_VAL_PM_SOURCE_EXT                                        8
#define RSRFSIGGEN_VAL_PM_SOURCE_INTB                                       9

// RsRFSigGen_rngBTSlotTimingMode
#define RSRFSIGGEN_VAL_BT_SLOT_TIMING_TX                                    0
#define RSRFSIGGEN_VAL_BT_SLOT_TIMING_LOOP                                  1

// RsRFSigGen_rngBTLEClockAccuracy
#define RSRFSIGGEN_VAL_BT_CLOCK_ACC_SCA0                                    0
#define RSRFSIGGEN_VAL_BT_CLOCK_ACC_SCA1                                    1
#define RSRFSIGGEN_VAL_BT_CLOCK_ACC_SCA2                                    2
#define RSRFSIGGEN_VAL_BT_CLOCK_ACC_SCA3                                    3
#define RSRFSIGGEN_VAL_BT_CLOCK_ACC_SCA4                                    4
#define RSRFSIGGEN_VAL_BT_CLOCK_ACC_SCA5                                    5
#define RSRFSIGGEN_VAL_BT_CLOCK_ACC_SCA6                                    6
#define RSRFSIGGEN_VAL_BT_CLOCK_ACC_SCA7                                    7

// RsRFSigGen_rngPSweepSignalDurationUnit
#define RSRFSIGGEN_VAL_POWER_SWEEP_SIGNAL_DURATION_UNIT_FRAME               0
#define RSRFSIGGEN_VAL_POWER_SWEEP_SIGNAL_DURATION_UNIT_SEQ                 1

// RsRFSigGen_rngPSweepMarkerMode
#define RSRFSIGGEN_VAL_POWER_SWEEP_MARKER_MODE_UNCH                         0
#define RSRFSIGGEN_VAL_POWER_SWEEP_MARKER_MODE_RFBL                         1
#define RSRFSIGGEN_VAL_POWER_SWEEP_MARKER_MODE_PRES                         2
#define RSRFSIGGEN_VAL_POWER_SWEEP_MARKER_MODE_START                        3

// RsRFSigGen_rngPSweepClockMode
#define RSRFSIGGEN_VAL_POWER_SWEEP_CLOCK_MODE_SAMPLE                        0
#define RSRFSIGGEN_VAL_POWER_SWEEP_CLOCK_MODE_MSAMPLE                       1

// RsRFSigGen_rngPSweepShape
#define RSRFSIGGEN_VAL_POWER_SWEEP_SHAPE_LINEAR                             0
#define RSRFSIGGEN_VAL_POWER_SWEEP_SHAPE_STAIR                              1
#define RSRFSIGGEN_VAL_POWER_SWEEP_SHAPE_TRIANGLE                           2

// RsRFSigGen_rngPSweepSlope
#define RSRFSIGGEN_VAL_POWER_SWEEP_SLOPE_ASC                                0
#define RSRFSIGGEN_VAL_POWER_SWEEP_SLOPE_DESC                               1

// RsRFSigGen_rngEUTRAWizardSubtest
#define RSRFSIGGEN_VAL_EUTRA_SUBTEST_STC1                                   0
#define RSRFSIGGEN_VAL_EUTRA_SUBTEST_STC2                                   1
#define RSRFSIGGEN_VAL_EUTRA_SUBTEST_STC3                                   2
#define RSRFSIGGEN_VAL_EUTRA_SUBTEST_STC4                                   3

// RsRFSigGen_rngEUTRATestModelCodes
#define RSRFSIGGEN_VAL_EUTRA_TEST_MODEL_CODES_COD4                          0
#define RSRFSIGGEN_VAL_EUTRA_TEST_MODEL_CODES_COD8                          1
#define RSRFSIGGEN_VAL_EUTRA_TEST_MODEL_CODES_COD16                         2
#define RSRFSIGGEN_VAL_EUTRA_TEST_MODEL_CODES_COD32                         3
#define RSRFSIGGEN_VAL_EUTRA_TEST_MODEL_CODES_COD64                         4

// RsRFSigGen_rngEUTRAWizardOption
#define RSRFSIGGEN_VAL_EUTRA_WIZARD_OPTION_OPT1                             0
#define RSRFSIGGEN_VAL_EUTRA_WIZARD_OPTION_OPT2                             1

// RsRFSigGen_rngSystConfBBSource
#define RSRFSIGGEN_VAL_SYSTEM_BB_SOURCE_SEP                                 0
#define RSRFSIGGEN_VAL_SYSTEM_BB_SOURCE_COUP                                1
#define RSRFSIGGEN_VAL_SYSTEM_BB_SOURCE_CPEN                                2

// RsRFSigGen_rngExternalDirection
#define RSRFSIGGEN_VAL_EXTERNAL_DIR_NONE                                    0
#define RSRFSIGGEN_VAL_EXTERNAL_DIR_IN                                      1
#define RSRFSIGGEN_VAL_EXTERNAL_DIR_OUT                                     2

// RsRFSigGen_rngExternalDisplayMode
#define RSRFSIGGEN_VAL_EXTERNAL_DISPLAY_ALL                                 0
#define RSRFSIGGEN_VAL_EXTERNAL_DISPLAY_MAPP                                1
#define RSRFSIGGEN_VAL_EXTERNAL_DISPLAY_INP                                 2
#define RSRFSIGGEN_VAL_EXTERNAL_DISPLAY_OUTP                                3

// RsRFSigGen_rngIQOutputDigitalPowerOnState
#define RSRFSIGGEN_VAL_IQ_OUTPUT_POWER_ON_STATE_OFF                         0
#define RSRFSIGGEN_VAL_IQ_OUTPUT_POWER_ON_STATE_UNCH                        1

// RsRFSigGen_rngIQOutputDigitalPowerStepMode
#define RSRFSIGGEN_VAL_IQ_OUTPUT_DIGITAL_POWER_STEP_MODE_DEC                0
#define RSRFSIGGEN_VAL_IQ_OUTPUT_DIGITAL_POWER_STEP_MODE_USER               1

// RsRFSigGen_rngIQOutputDigitalVIA
#define RSRFSIGGEN_VAL_IQ_OUTPUT_DIGITAL_VIA_PEP                            0
#define RSRFSIGGEN_VAL_IQ_OUTPUT_DIGITAL_VIA_LEVEL                          1

// RsRFSigGen_rngIQOutputDigitalSampleRateSource
#define RSRFSIGGEN_VAL_IQ_OUTPUT_DIGITAL_SAMPLE_RATE_USER                   0
#define RSRFSIGGEN_VAL_IQ_OUTPUT_DIGITAL_SAMPLE_RATE_DOUT                   1

// RsRFSigGen_rngRefOscOutputFreqMode
#define RSRFSIGGEN_VAL_REFERENCE_OSCILLATOR_FREQ_MODE_DER10M                0
#define RSRFSIGGEN_VAL_REFERENCE_OSCILLATOR_FREQ_MODE_SAME                  1

// RsRFSigGen_rngARBPowerReference
#define RSRFSIGGEN_VAL_ARB_POWER_REFERENCE_RMS                              0
#define RSRFSIGGEN_VAL_ARB_POWER_REFERENCE_PEAK                             1

// RsRFSigGen_rngBBGeneratorSource
#define RSRFSIGGEN_VAL_BB_GENERATOR_CODER                                   0
#define RSRFSIGGEN_VAL_BB_GENERATOR_BBIN                                    1

// RsRFSigGen_rngPULMImpedance
#define RSRFSIGGEN_VAL_PULM_IMPEDANCE_G50                                   0
#define RSRFSIGGEN_VAL_PULM_IMPEDANCE_G1K                                   1

// RsRFSigGen_rngSystemConfigurationMappingMode
#define RSRFSIGGEN_VAL_SYST_CONF_MAPPING_MODE_SINGLE                        0
#define RSRFSIGGEN_VAL_SYST_CONF_MAPPING_MODE_ADD                           1
#define RSRFSIGGEN_VAL_SYST_CONF_MAPPING_MODE_MULTIPLEX                     2

// RsRFSigGen_rngPowerBasebandAcquisition
#define RSRFSIGGEN_VAL_POWER_BB_ACQ_NOM                                     0
#define RSRFSIGGEN_VAL_POWER_BB_ACQ_CONT                                    1
#define RSRFSIGGEN_VAL_POWER_BB_ACQ_GAT                                     2
#define RSRFSIGGEN_VAL_POWER_BB_ACQ_MGAT                                    3

// RsRFSigGen_rngPowerBasebandGateSource
#define RSRFSIGGEN_VAL_POWER_BB_GATE_SOURCE_NONE                            0
#define RSRFSIGGEN_VAL_POWER_BB_GATE_SOURCE_MARK1                           1
#define RSRFSIGGEN_VAL_POWER_BB_GATE_SOURCE_MARK2                           2
#define RSRFSIGGEN_VAL_POWER_BB_GATE_SOURCE_MARK3                           3
#define RSRFSIGGEN_VAL_POWER_BB_GATE_SOURCE_MGAT                            4

// RsRFSigGen_rngPowerBasebandOutput
#define RSRFSIGGEN_VAL_POWER_BASEBAND_OUTPUT_RFA                            0
#define RSRFSIGGEN_VAL_POWER_BASEBAND_OUTPUT_RFB                            1
#define RSRFSIGGEN_VAL_POWER_BASEBAND_OUTPUT_IQOUT1                         2
#define RSRFSIGGEN_VAL_POWER_BASEBAND_OUTPUT_IQOUT2                         3
#define RSRFSIGGEN_VAL_POWER_BASEBAND_OUTPUT_BBMM1                          4
#define RSRFSIGGEN_VAL_POWER_BASEBAND_OUTPUT_BBMM2                          5

// RsRFSigGen_rngPowerBasebandRunMode
#define RSRFSIGGEN_VAL_POWER_BASEBAND_RMODE_SINGLE                          0
#define RSRFSIGGEN_VAL_POWER_BASEBAND_RMODE_AUTO                            1

// RsRFSigGen_rngPowerBasebandSource
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_BBA                                  0
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_BBB                                  1
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_BBC                                  2
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_BBD                                  3
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_BBINA                                4
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_BBINB                                5
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_FADINPA                              6
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_FADINPB                              7
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_FADINPC                              8
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_FADINPD                              9
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_FADOUTA                              10
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_FADOUTB                              11
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_FADOUTC                              12
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_FADOUTD                              13
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_AWGNA                                14
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_AWGNB                                15
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_AWGNC                                16
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_AWGND                                17
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_STREAMA                              18
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_STREAMB                              19
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_STREAMC                              20
#define RSRFSIGGEN_VAL_POWER_BB_SOURCE_STREAMD                              21

// RsRFSigGen_rngControlImpedance
#define RSRFSIGGEN_VAL_INPUT_IMP_G1K                                        0
#define RSRFSIGGEN_VAL_INPUT_IMP_G50                                        1

// RsRFSigGen_rngInputConnectorDirection
#define RSRFSIGGEN_VAL_INPUT_DIRECTION_INPUT                                0
#define RSRFSIGGEN_VAL_INPUT_DIRECTION_OUTPUT                               1
#define RSRFSIGGEN_VAL_INPUT_DIRECTION_UNUSED                               2

// RsRFSigGen_rngSystemSerialParity
#define RSRFSIGGEN_VAL_SERIAL_PARITY_NONE                                   0
#define RSRFSIGGEN_VAL_SERIAL_PARITY_ODD                                    1
#define RSRFSIGGEN_VAL_SERIAL_PARITY_EVEN                                   2

// RsRFSigGen_rngInputConnectorSignal
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_TRIG1                                   0
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_TRIG2                                   1
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_CLOCK1                                  2
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_CLOCK2                                  3
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_NSEGM1                                  4
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_NSEGM2                                  5
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_IPULSA                                  6
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_IPULSB                                  7
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_NONE                                    8
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_FEED                                    9
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_ERRTA                                   10
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_ERRTB                                   11
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_BERDATIN                                12
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_BERCLKIN                                13
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_BERDATENIN                              14
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_BERRESTIN                               15
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_SYNCIN                                  16

// RsRFSigGen_rngBBINDigitalSource
#define RSRFSIGGEN_VAL_DIGITAL_SOURCE_CODER1                                0
#define RSRFSIGGEN_VAL_DIGITAL_SOURCE_FADER1                                1
#define RSRFSIGGEN_VAL_DIGITAL_SOURCE_FADER2                                2
#define RSRFSIGGEN_VAL_DIGITAL_SOURCE_CODER2                                3

// RsRFSigGen_rngARBMultisegmentMarkerMode
#define RSRFSIGGEN_VAL_ARB_MARKER_MODE_IGNORE                               0
#define RSRFSIGGEN_VAL_ARB_MARKER_MODE_TAKE                                 1

// RsRFSigGen_rngIQDigitalPredistortionReferenceLevel
#define RSRFSIGGEN_VAL_IQ_LEVEL_BEFORE_DIGITAL_PREDISTORTION                0
#define RSRFSIGGEN_VAL_IQ_LEVEL_AFTER_DIGITAL_PREDISTORTION                 1
#define RSRFSIGGEN_VAL_IQ_LEVEL_STATIC_DIGITAL_PREDISTORTION                2

// RsRFSigGen_rngIQDigitalPredistortionCorrectionCoefficientsShaping
#define RSRFSIGGEN_VAL_IQ_COEFFICIENTS_CORRECTION_FROM_TABLE                0
#define RSRFSIGGEN_VAL_IQ_COEFFICIENTS_CORRECTION_POLYNOMIAL                1
#define RSRFSIGGEN_VAL_IQ_COEFFICIENTS_CORRECTION_NORMALIZED                2

// RsRFSigGen_rngIQDigitalPredistortionInterpolation
#define RSRFSIGGEN_VAL_IQ_DPD_INTERPOLATION_OFF                             0
#define RSRFSIGGEN_VAL_IQ_DPD_INTERPOLATION_POWER                           1
#define RSRFSIGGEN_VAL_IQ_DPD_INTERPOLATION_LINEAR                          2

// RsRFSigGen_rngEUTRADLUserCellDCISequenceMCSMode
#define RSRFSIGGEN_VAL_EUTRA_MCS_MODE_MANUAL                                0
#define RSRFSIGGEN_VAL_EUTRA_MCS_MODE_FIXED                                 1
#define RSRFSIGGEN_VAL_EUTRA_MCS_MODE_TCR                                   2

// RsRFSigGen_rngEUTRADLUserCellDCISequenceTargetModulation
#define RSRFSIGGEN_VAL_EUTRA_TARGET_MODULATION_QPSK                         0
#define RSRFSIGGEN_VAL_EUTRA_TARGET_MODULATION_QAM16                        1
#define RSRFSIGGEN_VAL_EUTRA_TARGET_MODULATION_QAM64                        2
#define RSRFSIGGEN_VAL_EUTRA_TARGET_MODULATION_QAM256                       3

// RsRFSigGen_rngEUTRAULUEPUCCHNumberOfAntennaPortsFormat3
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_PUCCH_ANTENNA_PORT1                    1
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_PUCCH_ANTENNA_PORT2                    2

// RsRFSigGen_rngEUTRAULUEPUSCHNumberOfAntennaPorts
#define RSRFSIGGEN_VAL_EUTRA_UL_PUSCH_ANTENNA_PORT_1                        0
#define RSRFSIGGEN_VAL_EUTRA_UL_PUSCH_ANTENNA_PORT_2                        1
#define RSRFSIGGEN_VAL_EUTRA_UL_PUSCH_ANTENNA_PORT_4                        2

// RsRFSigGen_rngEUTRAULEnhancedPUSCHCQIMapedTo
#define RSRFSIGGEN_VAL_EUTRA_UL_PUSCH_CQI_CODE_WORD_1                       1
#define RSRFSIGGEN_VAL_EUTRA_UL_PUSCH_CQI_CODE_WORD_2                       2

// RsRFSigGen_rngEUTRAULEnhancedPUSCHPrecodingScheme
#define RSRFSIGGEN_VAL_EUTRA_PRECODING_SCHEME_NONE                          0
#define RSRFSIGGEN_VAL_EUTRA_PRECODING_SCHEME_SPATIAL_MULTIPLEXING          1

// RsRFSigGen_rngIQOutputEnvelopeVoltageReference
#define RSRFSIGGEN_VAL_IQ_OUTPUT_VOLTAGE_REFERENCE_VCC                      0
#define RSRFSIGGEN_VAL_IQ_OUTPUT_VOLTAGE_REFERENCE_VOUT                     1

// RsRFSigGen_rngIQOutputEnvelopeTermination
#define RSRFSIGGEN_VAL_IQ_OUTPUT_ENVELOPE_TERMINATION_GROUND                0
#define RSRFSIGGEN_VAL_IQ_OUTPUT_ENVELOPE_TERMINATION_WIRE                  1

// RsRFSigGen_rngIQOutputEnvelopeShaping
#define RSRFSIGGEN_VAL_IQ_OUTPUT_SHAPING_MODE_OFF                           0
#define RSRFSIGGEN_VAL_IQ_OUTPUT_SHAPING_MODE_LINEAR                        1
#define RSRFSIGGEN_VAL_IQ_OUTPUT_SHAPING_MODE_TABLE                         2
#define RSRFSIGGEN_VAL_IQ_OUTPUT_SHAPING_MODE_POLYNOMIAL                    3
#define RSRFSIGGEN_VAL_IQ_OUTPUT_SHAPING_MODE_DETROUGHING                   4
#define RSRFSIGGEN_VAL_IQ_OUTPUT_SHAPING_MODE_POWER                         5

// RsRFSigGen_rngIQOutputEnvelopeShapingScale
#define RSRFSIGGEN_VAL_IQ_OUTPUT_SHAPING_SCALE_POWER                        0
#define RSRFSIGGEN_VAL_IQ_OUTPUT_SHAPING_SCALE_VOLTAGE                      1

// RsRFSigGen_rngIQOutputEnvelopeDetroughingFunction
#define RSRFSIGGEN_VAL_IQ_OUTPUT_DETROUGHING_FUNCTION_1                     1
#define RSRFSIGGEN_VAL_IQ_OUTPUT_DETROUGHING_FUNCTION_2                     2
#define RSRFSIGGEN_VAL_IQ_OUTPUT_DETROUGHING_FUNCTION_3                     3

// RsRFSigGen_rngPowerDisplayPermanent
#define RSRFSIGGEN_VAL_SENSE_POWER_DISPLAY_AVERAGE                          0
#define RSRFSIGGEN_VAL_SENSE_POWER_DISPLAY_PEAK                             1

// RsRFSigGen_rngPowerSPCSensorSelect
#define RSRFSIGGEN_VAL_POWER_CONTROL_SENS1                                  1
#define RSRFSIGGEN_VAL_POWER_CONTROL_SENS2                                  2
#define RSRFSIGGEN_VAL_POWER_CONTROL_SENS3                                  3
#define RSRFSIGGEN_VAL_POWER_CONTROL_SENS4                                  4

// RsRFSigGen_rngLocalOscillatorCouplingMode
#define RSRFSIGGEN_VAL_LOCAL_OSCILLATOR_INTERNAL                            0
#define RSRFSIGGEN_VAL_LOCAL_OSCILLATOR_EXTERNAL                            1
#define RSRFSIGGEN_VAL_LOCAL_OSCILLATOR_INTERNAL_COUPLED                    2
#define RSRFSIGGEN_VAL_LOCAL_OSCILLATOR_EXTERNAL_COUPLED                    3
#define RSRFSIGGEN_VAL_LOCAL_OSCILLATOR_EXTERNAL_BOFF                       4
#define RSRFSIGGEN_VAL_LOCAL_OSCILLATOR_EXTERNAL_AOFF                       5

// RsRFSigGen_rngALCDriverAmplifier
#define RSRFSIGGEN_VAL_ALC_AMPLIFIER_AUTO                                   0
#define RSRFSIGGEN_VAL_ALC_AMPLIFIER_ON                                     1
#define RSRFSIGGEN_VAL_ALC_AMPLIFIER_ON_MAXIMUM_LEVEL                       2
#define RSRFSIGGEN_VAL_ALC_AMPLIFIER_OFF                                    3
#define RSRFSIGGEN_VAL_ALC_AMPLIFIER_FIX                                    4

// RsRFSigGen_rngDMBitClockSlope
#define RSRFSIGGEN_VAL_BIT_CLOCK_SLOPE_NEGATIVE                             0
#define RSRFSIGGEN_VAL_BIT_CLOCK_SLOPE_POSITIVE                             1

// RsRFSigGen_rngDMBitOrder
#define RSRFSIGGEN_VAL_DM_BIT_ORDER_LSB                                     0
#define RSRFSIGGEN_VAL_DM_BIT_ORDER_MSB                                     1

// RsRFSigGen_rngDMExternalTriggerDelayUnit
#define RSRFSIGGEN_VAL_EXTERNAL_TRIGGER_DELAY_UNIT_SAMPLE                   0
#define RSRFSIGGEN_VAL_EXTERNAL_TRIGGER_DELAY_UNIT_TIME                     1

// RsRFSigGen_rngARBMultisegmentSegmentLevelMode
#define RSRFSIGGEN_VAL_MULTI_SEGMENTS_ARB_LEVEL_MODE_UNCHANGED              0
#define RSRFSIGGEN_VAL_MULTI_SEGMENTS_ARB_LEVEL_MODE_HIGHEST                1

// RsRFSigGen_rngEUTRAULUEPUSCHTransmissionMode
#define RSRFSIGGEN_VAL_EUTRA_TRANSMISSION_MODE_M1                           1
#define RSRFSIGGEN_VAL_EUTRA_TRANSMISSION_MODE_M2                           2

// RsRFSigGen_rngEUTRAULUEReferenceSRSNumberOfAntennaPort
#define RSRFSIGGEN_VAL_EUTRA_UL_SRS_ANTENNA_PORT_1                          0
#define RSRFSIGGEN_VAL_EUTRA_UL_SRS_ANTENNA_PORT_2                          1
#define RSRFSIGGEN_VAL_EUTRA_UL_SRS_ANTENNA_PORT_4                          2

// RsRFSigGen_rngSystemConfigurationSignalOutputs
#define RSRFSIGGEN_VAL_SIGNAL_DIGITAL_MULTIPLEXED                           0
#define RSRFSIGGEN_VAL_SIGNAL_DIGITAL                                       1
#define RSRFSIGGEN_VAL_SIGNAL_ANALOG_AND_DIGITAL                            2
#define RSRFSIGGEN_VAL_SIGNAL_ANALOG_AND_ANAL                               3
#define RSRFSIGGEN_VAL_SIGNAL_ANALOG_AND_HSD                                4
#define RSRFSIGGEN_VAL_SIGNAL_ANALOG_AND_HSAL                               5

// RsRFSigGen_rngListRunMode
#define RSRFSIGGEN_VAL_LIST_RUN_LEARNED                                     0
#define RSRFSIGGEN_VAL_LIST_RUN_LIVE                                        1

// RsRFSigGen_rngListDwellTimeMode
#define RSRFSIGGEN_VAL_DWELL_MODE_GLOBAL                                    0
#define RSRFSIGGEN_VAL_DWELL_MODE_LIST                                      1

// RsRFSigGen_rngILSComponent
#define RSRFSIGGEN_ILS_COMPONENT_GS                                         0
#define RSRFSIGGEN_ILS_COMPONENT_LOC                                        1
#define RSRFSIGGEN_ILS_COMPONENT_MBE                                        2

// RsRFSigGen_rngCarrierFrequencyMode
#define RSRFSIGGEN_VAL_CARRIER_FREQUENCY_MODE_USER                          0
#define RSRFSIGGEN_VAL_CARRIER_FREQUENCY_MODE_ICAO                          1

// RsRFSigGen_rngILSICAOChannel
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH18X                                   0
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH18Y                                   1
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH20X                                   2
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH20Y                                   3
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH22X                                   4
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH22Y                                   5
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH24X                                   6
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH24Y                                   7
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH26X                                   8
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH26Y                                   9
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH28X                                   10
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH28Y                                   11
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH30X                                   12
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH30Y                                   13
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH32X                                   14
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH32Y                                   15
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH34X                                   16
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH34Y                                   17
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH36X                                   18
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH36Y                                   19
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH38X                                   20
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH38Y                                   21
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH40X                                   22
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH40Y                                   23
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH42X                                   24
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH42Y                                   25
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH44X                                   26
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH44Y                                   27
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH46X                                   28
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH46Y                                   29
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH48X                                   30
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH48Y                                   31
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH50X                                   32
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH50Y                                   33
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH52X                                   34
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH52Y                                   35
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH54X                                   36
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH54Y                                   37
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH56X                                   38
#define RSRFSIGGEN_ILS_ICAO_CHANNEL_CH56Y                                   39

// RsRFSigGen_rngILSDDMPolarity
#define RSRFSIGGEN_VAL_ILS_DDM_POLARITY_P90_150                             0
#define RSRFSIGGEN_VAL_ILS_DDM_POLARITY_P150_90                             1

// RsRFSigGen_rngILSSignalMode
#define RSRFSIGGEN_VAL_ILS_SIGNAL_MODE_NORMAL                               0
#define RSRFSIGGEN_VAL_ILS_SIGNAL_MODE_90HZ                                 1
#define RSRFSIGGEN_VAL_ILS_SIGNAL_MODE_150HZ                                2

// RsRFSigGen_rngILSFly
#define RSRFSIGGEN_VAL_FLY_UP                                               0
#define RSRFSIGGEN_VAL_FLY_DOWN                                             1

// RsRFSigGen_rngILSDDMStep
#define RSRFSIGGEN_VAL_ILS_DDM_STEP_DEC                                     0
#define RSRFSIGGEN_VAL_ILS_DDM_STEP_PRED                                    1

// RsRFSigGen_rngILSDDMCoupling
#define RSRFSIGGEN_VAL_ILS_DDM_COUPLING_FIXED                               0
#define RSRFSIGGEN_VAL_ILS_DDM_COUPLING_SDM                                 1

// RsRFSigGen_rngILSLocalizerFly
#define RSRFSIGGEN_VAL_FLY_LEFT                                             0
#define RSRFSIGGEN_VAL_FLY_RIGHT                                            1

// RsRFSigGen_rngCOMIDTimeSchema
#define RSRFSIGGEN_VAL_COM_ID_SCHEMA_STD                                    0
#define RSRFSIGGEN_VAL_COM_ID_SCHEMA_USER                                   1

// RsRFSigGen_rngILSBeaconCarrierFrequencyMode
#define RSRFSIGGEN_VAL_ILS_FREQUENCY_MODE_USER                              0
#define RSRFSIGGEN_VAL_ILS_FREQUENCY_MODE_PRED                              1

// RsRFSigGen_rngTriggerSource
#define RSRFSIGGEN_VAL_TRIGGER_INT                                          0
#define RSRFSIGGEN_VAL_TRIGGER_EXT                                          1

// RsRFSigGen_rngAvionicsClockMode
#define RSRFSIGGEN_VAL_CLOCK_MODE_CHIP                                      0
#define RSRFSIGGEN_VAL_CLOCK_MODE_MCHIP                                     1

// RsRFSigGen_rngVORICAOChannel
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH17X                                   0
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH17Y                                   1
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH19X                                   2
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH19Y                                   3
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH21X                                   4
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH21Y                                   5
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH23X                                   6
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH23Y                                   7
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH25X                                   8
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH25Y                                   9
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH27X                                   10
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH27Y                                   11
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH29X                                   12
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH29Y                                   13
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH31X                                   14
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH31Y                                   15
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH33X                                   16
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH33Y                                   17
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH35X                                   18
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH35Y                                   19
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH37X                                   20
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH37Y                                   21
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH39X                                   22
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH39Y                                   23
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH41X                                   24
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH41Y                                   25
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH43X                                   26
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH43Y                                   27
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH45X                                   28
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH45Y                                   29
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH47X                                   30
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH47Y                                   31
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH49X                                   32
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH49Y                                   33
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH51X                                   34
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH51Y                                   35
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH53X                                   36
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH53Y                                   37
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH55X                                   38
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH55Y                                   39
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH57X                                   40
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH57Y                                   41
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH58X                                   42
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH58Y                                   43
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH59X                                   44
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH59Y                                   45
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH70X                                   46
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH70Y                                   47
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH71X                                   48
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH71Y                                   49
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH72X                                   50
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH72Y                                   51
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH73X                                   52
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH73Y                                   53
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH74X                                   54
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH74Y                                   55
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH75X                                   56
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH75Y                                   57
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH76X                                   58
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH76Y                                   59
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH77X                                   60
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH77Y                                   61
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH78X                                   62
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH78Y                                   63
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH79X                                   64
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH79Y                                   65
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH80X                                   66
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH80Y                                   67
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH81X                                   68
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH81Y                                   69
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH82X                                   70
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH82Y                                   71
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH83X                                   72
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH83Y                                   73
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH84X                                   74
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH84Y                                   75
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH85X                                   76
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH85Y                                   77
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH86X                                   78
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH86Y                                   79
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH87X                                   80
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH87Y                                   81
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH88X                                   82
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH88Y                                   83
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH89X                                   84
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH89Y                                   85
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH90X                                   86
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH90Y                                   87
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH91X                                   88
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH91Y                                   89
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH92X                                   90
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH92Y                                   91
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH93X                                   92
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH93Y                                   93
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH94X                                   94
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH94Y                                   95
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH95X                                   96
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH95Y                                   97
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH96X                                   98
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH96Y                                   99
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH97X                                   100
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH97Y                                   101
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH98X                                   102
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH98Y                                   103
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH99X                                   104
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH99Y                                   105
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH100X                                  106
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH100Y                                  107
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH101X                                  108
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH101Y                                  109
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH102X                                  110
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH102Y                                  111
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH103X                                  112
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH103Y                                  113
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH104X                                  114
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH104Y                                  115
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH105X                                  116
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH105Y                                  117
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH106X                                  118
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH106Y                                  119
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH107X                                  120
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH107Y                                  121
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH108X                                  122
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH108Y                                  123
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH109X                                  124
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH109Y                                  125
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH110X                                  126
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH110Y                                  127
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH111X                                  128
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH111Y                                  129
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH112X                                  130
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH112Y                                  131
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH113X                                  132
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH113Y                                  133
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH114X                                  134
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH114Y                                  135
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH115X                                  136
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH115Y                                  137
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH116X                                  138
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH116Y                                  139
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH117X                                  140
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH117Y                                  141
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH118X                                  142
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH118Y                                  143
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH119X                                  144
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH119Y                                  145
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH120X                                  146
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH120Y                                  147
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH121X                                  148
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH121Y                                  149
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH122X                                  150
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH122Y                                  151
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH123X                                  152
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH123Y                                  153
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH124X                                  154
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH124Y                                  155
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH125X                                  156
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH125Y                                  157
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH126X                                  158
#define RSRFSIGGEN_VOR_ICAO_CHANNEL_CH126Y                                  159

// RsRFSigGen_rngVORSignalMode
#define RSRFSIGGEN_VAL_VOR_MODE_NORM                                        0
#define RSRFSIGGEN_VAL_VOR_MODE_VAR                                         1
#define RSRFSIGGEN_VAL_VOR_MODE_SUBC                                        2
#define RSRFSIGGEN_VAL_VOR_MODE_FMS                                         3

// RsRFSigGen_rngVORPositionBearingAngleDirection
#define RSRFSIGGEN_VAL_VOR_BEARING_ANGLE_DIRECTION_FROM                     0
#define RSRFSIGGEN_VAL_VOR_BEARING_ANGLE_DIRECTION_TO                       1

// RsRFSigGen_rngDMEChannelMode
#define RSRFSIGGEN_VAL_DME_CHANNEL_MODE_X                                   0
#define RSRFSIGGEN_VAL_DME_CHANNEL_MODE_Y                                   1
#define RSRFSIGGEN_VAL_DME_CHANNEL_MODE_ICAO                                2

// RsRFSigGen_rngDMEICAOChannel
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH1X                                    0
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH1Y                                    1
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH2X                                    2
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH2Y                                    3
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH3X                                    4
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH3Y                                    5
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH4X                                    6
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH4Y                                    7
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH5X                                    8
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH5Y                                    9
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH6X                                    10
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH6Y                                    11
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH7X                                    12
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH7Y                                    13
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH8X                                    14
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH8Y                                    15
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH9X                                    16
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH9Y                                    17
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH10X                                   18
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH10Y                                   19
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH11X                                   20
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH11Y                                   21
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH12X                                   22
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH12Y                                   23
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH13X                                   24
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH13Y                                   25
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH14X                                   26
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH14Y                                   27
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH15X                                   28
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH15Y                                   29
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH16X                                   30
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH16Y                                   31
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH17X                                   32
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH17Y                                   33
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH18X                                   34
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH18Y                                   35
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH19X                                   36
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH19Y                                   37
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH20X                                   38
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH20Y                                   39
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH21X                                   40
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH21Y                                   41
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH22X                                   42
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH22Y                                   43
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH23X                                   44
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH23Y                                   45
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH24X                                   46
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH24Y                                   47
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH25X                                   48
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH25Y                                   49
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH26X                                   50
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH26Y                                   51
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH27X                                   52
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH27Y                                   53
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH28X                                   54
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH28Y                                   55
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH29X                                   56
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH29Y                                   57
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH30X                                   58
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH30Y                                   59
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH31X                                   60
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH31Y                                   61
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH32X                                   62
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH32Y                                   63
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH33X                                   64
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH33Y                                   65
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH34X                                   66
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH34Y                                   67
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH35X                                   68
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH35Y                                   69
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH36X                                   70
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH36Y                                   71
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH37X                                   72
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH37Y                                   73
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH38X                                   74
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH38Y                                   75
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH39X                                   76
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH39Y                                   77
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH40X                                   78
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH40Y                                   79
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH41X                                   80
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH41Y                                   81
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH42X                                   82
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH42Y                                   83
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH43X                                   84
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH43Y                                   85
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH44X                                   86
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH44Y                                   87
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH45X                                   88
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH45Y                                   89
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH46X                                   90
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH46Y                                   91
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH47X                                   92
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH47Y                                   93
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH48X                                   94
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH48Y                                   95
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH49X                                   96
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH49Y                                   97
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH50X                                   98
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH50Y                                   99
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH51X                                   100
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH51Y                                   101
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH52X                                   102
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH52Y                                   103
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH53X                                   104
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH53Y                                   105
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH54X                                   106
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH54Y                                   107
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH55X                                   108
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH55Y                                   109
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH56X                                   110
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH56Y                                   111
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH57X                                   112
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH57Y                                   113
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH58X                                   114
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH58Y                                   115
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH59X                                   116
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH59Y                                   117
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH60X                                   118
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH60Y                                   119
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH61X                                   120
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH61Y                                   121
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH62X                                   122
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH62Y                                   123
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH63X                                   124
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH63Y                                   125
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH64X                                   126
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH64Y                                   127
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH65X                                   128
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH65Y                                   129
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH66X                                   130
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH66Y                                   131
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH67X                                   132
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH67Y                                   133
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH68X                                   134
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH68Y                                   135
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH69X                                   136
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH69Y                                   137
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH70X                                   138
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH70Y                                   139
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH71X                                   140
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH71Y                                   141
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH72X                                   142
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH72Y                                   143
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH73X                                   144
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH73Y                                   145
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH74X                                   146
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH74Y                                   147
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH75X                                   148
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH75Y                                   149
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH76X                                   150
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH76Y                                   151
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH77X                                   152
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH77Y                                   153
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH78X                                   154
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH78Y                                   155
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH79X                                   156
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH79Y                                   157
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH80X                                   158
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH80Y                                   159
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH81X                                   160
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH81Y                                   161
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH82X                                   162
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH82Y                                   163
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH83X                                   164
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH83Y                                   165
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH84X                                   166
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH84Y                                   167
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH85X                                   168
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH85Y                                   169
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH86X                                   170
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH86Y                                   171
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH87X                                   172
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH87Y                                   173
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH88X                                   174
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH88Y                                   175
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH89X                                   176
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH89Y                                   177
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH90X                                   178
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH90Y                                   179
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH91X                                   180
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH91Y                                   181
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH92X                                   182
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH92Y                                   183
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH93X                                   184
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH93Y                                   185
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH94X                                   186
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH94Y                                   187
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH95X                                   188
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH95Y                                   189
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH96X                                   190
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH96Y                                   191
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH97X                                   192
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH97Y                                   193
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH98X                                   194
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH98Y                                   195
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH99X                                   196
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH99Y                                   197
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH100X                                  198
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH100Y                                  199
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH101X                                  200
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH101Y                                  201
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH102X                                  202
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH102Y                                  203
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH103X                                  204
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH103Y                                  205
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH104X                                  206
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH104Y                                  207
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH105X                                  208
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH105Y                                  209
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH106X                                  210
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH106Y                                  211
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH107X                                  212
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH107Y                                  213
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH108X                                  214
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH108Y                                  215
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH109X                                  216
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH109Y                                  217
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH110X                                  218
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH110Y                                  219
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH111X                                  220
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH111Y                                  221
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH112X                                  222
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH112Y                                  223
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH113X                                  224
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH113Y                                  225
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH114X                                  226
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH114Y                                  227
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH115X                                  228
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH115Y                                  229
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH116X                                  230
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH116Y                                  231
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH117X                                  232
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH117Y                                  233
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH118X                                  234
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH118Y                                  235
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH119X                                  236
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH119Y                                  237
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH120X                                  238
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH120Y                                  239
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH121X                                  240
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH121Y                                  241
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH122X                                  242
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH122Y                                  243
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH123X                                  244
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH123Y                                  245
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH124X                                  246
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH124Y                                  247
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH125X                                  248
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH125Y                                  249
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH126X                                  250
#define RSRFSIGGEN_DME_ICAO_CHANNEL_CH126Y                                  251

// RsRFSigGen_rngDMEPulseInputSource
#define RSRFSIGGEN_VAL_DME_PULSE_INPUT_SOURCE_EXT                           0
#define RSRFSIGGEN_VAL_DME_PULSE_INPUT_SOURCE_PSEN                          1

// RsRFSigGen_rngDMEPulseShape
#define RSRFSIGGEN_VAL_DME_PULSE_SHAPE_COSCOS2                              0
#define RSRFSIGGEN_VAL_DME_PULSE_SHAPE_COS2                                 1
#define RSRFSIGGEN_VAL_DME_PULSE_SHAPE_LINEAR                               2
#define RSRFSIGGEN_VAL_DME_PULSE_SHAPE_GAUSS                                3

// RsRFSigGen_rngDMEAdjustmentFactorsUsed
#define RSRFSIGGEN_VAL_DME_USED_FACTOR_INT                                  0
#define RSRFSIGGEN_VAL_DME_USED_FACTOR_PSEN                                 1

// RsRFSigGen_rngFSIMMIMOSCMEWinnerClusterDistribution
#define RSRFSIGGEN_VAL_FSIM_DISTRIBUTION_LAPL                               0
#define RSRFSIGGEN_VAL_FSIM_DISTRIBUTION_EQU                                1
#define RSRFSIGGEN_VAL_FSIM_DISTRIBUTION_GAUS                               2

// RsRFSigGen_rngFSIMMIMOPolarizationSlantAngle
#define RSRFSIGGEN_VAL_FSIM_SLANT_ANGLE_POLCROSS45                          0
#define RSRFSIGGEN_VAL_FSIM_SLANT_ANGLE_POLCROSS90                          1
#define RSRFSIGGEN_VAL_FSIM_SLANT_ANGLE_POLCO0                              2
#define RSRFSIGGEN_VAL_FSIM_SLANT_ANGLE_POLCO90                             3

// RsRFSigGen_rngFSIMMIMOAntennaArraySize
#define RSRFSIGGEN_VAL_FSIM_ANTENNA_ARRAY_SIZE_ANT01                        0
#define RSRFSIGGEN_VAL_FSIM_ANTENNA_ARRAY_SIZE_ANT02                        1
#define RSRFSIGGEN_VAL_FSIM_ANTENNA_ARRAY_SIZE_ANT03                        2
#define RSRFSIGGEN_VAL_FSIM_ANTENNA_ARRAY_SIZE_ANT04                        3
#define RSRFSIGGEN_VAL_FSIM_ANTENNA_ARRAY_SIZE_ANT08                        4

// RsRFSigGen_rngFSIMMIMOAntennaArrayPattern
#define RSRFSIGGEN_VAL_FSIM_ANTENNA_ARRAY_PATTERN_ISO                       0
#define RSRFSIGGEN_VAL_FSIM_ANTENNA_ARRAY_PATTERN_USER                      1
#define RSRFSIGGEN_VAL_FSIM_ANTENNA_ARRAY_PATTERN_SEC3                      2
#define RSRFSIGGEN_VAL_FSIM_ANTENNA_ARRAY_PATTERN_SEC6                      3
#define RSRFSIGGEN_VAL_FSIM_ANTENNA_ARRAY_PATTERN_DIP                       4

// RsRFSigGen_rngFSIMTwoChannelInterferProfile
#define RSRFSIGGEN_VAL_FSIM_INTERFERER_PROFILE_SPAT                         0
#define RSRFSIGGEN_VAL_FSIM_INTERFERER_PROFILE_PDOP                         1
#define RSRFSIGGEN_VAL_FSIM_INTERFERER_PROFILE_RAYL                         2

// RsRFSigGen_rngFSIMTwoChannelInterferMovingMode
#define RSRFSIGGEN_FSIM_INTERFERER_MODE_SLID                                0
#define RSRFSIGGEN_FSIM_INTERFERER_MODE_HOPP                                1

// RsRFSigGen_rngFSIMCopyToDestination
#define RSRFSIGGEN_VAL_DESTINATION_FADA                                     0
#define RSRFSIGGEN_VAL_DESTINATION_FADB                                     1
#define RSRFSIGGEN_VAL_DESTINATION_FADC                                     2
#define RSRFSIGGEN_VAL_DESTINATION_FADD                                     3
#define RSRFSIGGEN_VAL_DESTINATION_FADE                                     4
#define RSRFSIGGEN_VAL_DESTINATION_FADF                                     5
#define RSRFSIGGEN_VAL_DESTINATION_FADG                                     6
#define RSRFSIGGEN_VAL_DESTINATION_FADH                                     7
#define RSRFSIGGEN_VAL_DESTINATION_ALL                                      8

// RsRFSigGen_rngFSIMClockRate
#define RSRFSIGGEN_VAL_FSIM_CLOCK_RATE_CR025                                0
#define RSRFSIGGEN_VAL_FSIM_CLOCK_RATE_CR050                                1
#define RSRFSIGGEN_VAL_FSIM_CLOCK_RATE_CR100                                2
#define RSRFSIGGEN_VAL_FSIM_CLOCK_RATE_CR200                                3
#define RSRFSIGGEN_VAL_FSIM_CLOCK_RATE_CR062                                4
#define RSRFSIGGEN_VAL_FSIM_CLOCK_RATE_CR125                                5
#define RSRFSIGGEN_VAL_FSIM_CLOCK_RATE_CR250                                6

// RsRFSigGen_rngFSIMMIMOPath
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_AA                                    0
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_AB                                    1
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_AC                                    2
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_AD                                    3
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_AE                                    4
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_AF                                    5
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_AG                                    6
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_AH                                    7
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_BA                                    8
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_BB                                    9
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_BC                                    10
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_BD                                    11
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_BE                                    12
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_BF                                    13
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_BG                                    14
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_BH                                    15
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_CA                                    16
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_CB                                    17
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_CC                                    18
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_CD                                    19
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_CE                                    20
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_CF                                    21
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_CG                                    22
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_CH                                    23
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_DA                                    24
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_DB                                    25
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_DC                                    26
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_DD                                    27
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_DE                                    28
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_DF                                    29
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_DG                                    30
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_DH                                    31
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_EA                                    32
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_EB                                    33
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_EC                                    34
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_ED                                    35
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_EE                                    36
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_EF                                    37
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_EG                                    38
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_EH                                    39
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_FA                                    40
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_FB                                    41
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_FC                                    42
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_FD                                    43
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_FE                                    44
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_FF                                    45
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_FG                                    46
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_FH                                    47
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_GA                                    48
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_GB                                    49
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_GC                                    50
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_GD                                    51
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_GE                                    52
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_GF                                    53
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_GG                                    54
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_GH                                    55
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_HA                                    56
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_HB                                    57
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_HC                                    58
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_HD                                    59
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_HE                                    60
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_HF                                    61
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_HG                                    62
#define RSRFSIGGEN_VAL_FSIM_MIMO_PATH_HH                                    63

// RsRFSigGen_rngFSIMDedicatedConnector
#define RSRFSIGGEN_VAL_FSIM_DEDICATED_CONNECTOR_RFA                         0
#define RSRFSIGGEN_VAL_FSIM_DEDICATED_CONNECTOR_BBMM1                       1
#define RSRFSIGGEN_VAL_FSIM_DEDICATED_CONNECTOR_RFB                         2
#define RSRFSIGGEN_VAL_FSIM_DEDICATED_CONNECTOR_BBMM2                       3
#define RSRFSIGGEN_VAL_FSIM_DEDICATED_CONNECTOR_QOUT1                       4
#define RSRFSIGGEN_VAL_FSIM_DEDICATED_CONNECTOR_QOUT2                       5
#define RSRFSIGGEN_VAL_FSIM_DEDICATED_CONNECTOR_FAD1                        6
#define RSRFSIGGEN_VAL_FSIM_DEDICATED_CONNECTOR_FAD2                        7
#define RSRFSIGGEN_VAL_FSIM_DEDICATED_CONNECTOR_FAD3                        8
#define RSRFSIGGEN_VAL_FSIM_DEDICATED_CONNECTOR_FAD4                        9
#define RSRFSIGGEN_VAL_FSIM_DEDICATED_CONNECTOR_DEF                         10

// RsRFSigGen_rngFSIMCustomFadingProfileDopplerShape
#define FSIM_PROFILE_DOPPLER_SHAPE_FLAT                                     0
#define FSIM_PROFILE_DOPPLER_SHAPE_RAYL                                     1

// RsRFSigGen_rngDMEMode
#define RSRFSIGGEN_VAL_DME_MODE_INTERROGATION                               0
#define RSRFSIGGEN_VAL_DME_MODE_REPLY                                       1

// RsRFSigGen_rngDMEMarkerMode
#define RSRFSIGGEN_VAL_DME_MARKER_MODE_FPST                                 0
#define RSRFSIGGEN_VAL_DME_MARKER_MODE_FP50P                                1
#define RSRFSIGGEN_VAL_DME_MARKER_MODE_PST                                  2
#define RSRFSIGGEN_VAL_DME_MARKER_MODE_P50P                                 3
#define RSRFSIGGEN_VAL_DME_MARKER_MODE_PREC                                 4

// RsRFSigGen_rngNavigationDataMode
#define RSRFSIGGEN_VAL_SBAS_NAVIGATION_MODE_MESSAGE                         0
#define RSRFSIGGEN_VAL_SBAS_NAVIGATION_MODE_RAW                             1

// RsRFSigGen_rngEUTRADLBaseband
#define RSRFSIGGEN_VAL_EUTRA_BASEBAND_PC                                    0
#define RSRFSIGGEN_VAL_EUTRA_BASEBAND_SC1                                   1
#define RSRFSIGGEN_VAL_EUTRA_BASEBAND_SC2                                   2
#define RSRFSIGGEN_VAL_EUTRA_BASEBAND_SC3                                   3
#define RSRFSIGGEN_VAL_EUTRA_BASEBAND_SC4                                   4

// RsRFSigGen_rngEUTRADLPMCHModulation
#define RSRFSIGGEN_VAL_EUTRA_DL_PMCH_MODULATION_QPSK                        0
#define RSRFSIGGEN_VAL_EUTRA_DL_PMCH_MODULATION_QAM16                       1
#define RSRFSIGGEN_VAL_EUTRA_DL_PMCH_MODULATION_QAM64                       2
#define RSRFSIGGEN_VAL_EUTRA_DL_PMCH_MODULATION_QAM256                      3

// RsRFSigGen_rngEUTRAWizardTestSpecification
#define RSRFSIGGEN_VAL_EUTRA_WIZARD_TEST_SPECIFICATION_TS36141              0

// RsRFSigGen_rngEUTRADLMBSFNPMCHCommonSubframeAP
#define RSRFSIGGEN_VAL_EUTRA_DL_COMMON_SUBFRAME_AP4                         0
#define RSRFSIGGEN_VAL_EUTRA_DL_COMMON_SUBFRAME_AP8                         1
#define RSRFSIGGEN_VAL_EUTRA_DL_COMMON_SUBFRAME_AP16                        2
#define RSRFSIGGEN_VAL_EUTRA_DL_COMMON_SUBFRAME_AP32                        3
#define RSRFSIGGEN_VAL_EUTRA_DL_COMMON_SUBFRAME_AP64                        4
#define RSRFSIGGEN_VAL_EUTRA_DL_COMMON_SUBFRAME_AP128                       5
#define RSRFSIGGEN_VAL_EUTRA_DL_COMMON_SUBFRAME_AP256                       6

// RsRFSigGen_rngOFDMModulationType
#define RSRFSIGGEN_VAL_OFDM_MODULATION_TYPE_UFMC                            0
#define RSRFSIGGEN_VAL_OFDM_MODULATION_TYPE_FBMC                            1
#define RSRFSIGGEN_VAL_OFDM_MODULATION_TYPE_GFDM                            2
#define RSRFSIGGEN_VAL_OFDM_MODULATION_TYPE_FOFDM                           3
#define RSRFSIGGEN_VAL_OFDM_MODULATION_TYPE_OFDM                            4

// RsRFSigGen_rngOFDMAllocationModulation
#define RSRFSIGGEN_VAL_OFDM_ALLOC_MODULATION_BPSK                           0
#define RSRFSIGGEN_VAL_OFDM_ALLOC_MODULATION_QPSK                           1
#define RSRFSIGGEN_VAL_OFDM_ALLOC_MODULATION_QAM16                          2
#define RSRFSIGGEN_VAL_OFDM_ALLOC_MODULATION_QAM64                          3
#define RSRFSIGGEN_VAL_OFDM_ALLOC_MODULATION_QAM256                         4
#define RSRFSIGGEN_VAL_OFDM_ALLOC_MODULATION_SCMA                           5
#define RSRFSIGGEN_VAL_OFDM_ALLOC_MODULATION_CIQ                            6
#define RSRFSIGGEN_VAL_OFDM_ALLOC_MODULATION_ZAD                            7
#define RSRFSIGGEN_VAL_OFDM_ALLOC_MODULATION_CUSC                           8

// RsRFSigGen_rngOFDMAllocationDataSource
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_USER0                         0
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_USER1                         1
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_USER2                         2
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_USER3                         3
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_USER4                         4
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_USER5                         5
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_PN9                           6
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_PN11                          7
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_PN15                          8
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_PN16                          9
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_PN20                          10
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_PN21                          11
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_PN23                          12
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_PATTERN                       13
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_DLIST                         14
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_ZERO                          15
#define RSRFSIGGEN_VAL_OFDM_ALLOC_DATA_SOURCE_ONE                           16

// RsRFSigGen_rngOFDMAllocationContentType
#define RSRFSIGGEN_VAL_OFDM_ALLOC_CONTENT_DATA                              0
#define RSRFSIGGEN_VAL_OFDM_ALLOC_CONTENT_PREAMBLE                          1
#define RSRFSIGGEN_VAL_OFDM_ALLOC_CONTENT_PILOT                             2
#define RSRFSIGGEN_VAL_OFDM_ALLOC_CONTENT_RESERVED                          3

// RsRFSigGen_rngOFDMLayerMappingUser
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_USER0                                1
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_USER1                                2
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_USER2                                3
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_USER3                                4
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_USER4                                5
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_USER5                                6
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_PN9                                  7
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_PN11                                 8
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_PN15                                 9
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_PN16                                 10
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_PN20                                 11
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_PN21                                 12
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_PN23                                 13
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_PATTERN                              14
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_DLIST                                15
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_ZERO                                 16
#define RSRFSIGGEN_VAL_OFDM_LAYER_USER_ONE                                  17

// RsRFSigGen_rngOFDMFilterType
#define RSRFSIGGEN_VAL_OFDM_FILTER_TYPE_USER                                0
#define RSRFSIGGEN_VAL_OFDM_FILTER_TYPE_RC                                  1
#define RSRFSIGGEN_VAL_OFDM_FILTER_TYPE_RRC                                 2
#define RSRFSIGGEN_VAL_OFDM_FILTER_TYPE_DIRICHLET                           3
#define RSRFSIGGEN_VAL_OFDM_FILTER_TYPE_RECT                                4
#define RSRFSIGGEN_VAL_OFDM_FILTER_TYPE_DCH                                 5
#define RSRFSIGGEN_VAL_OFDM_FILTER_TYPE_STRUNC                              6
#define RSRFSIGGEN_VAL_OFDM_FILTER_TYPE_PHYDYAS                             7

// RsRFSigGen_rngOFDMFilterWindowing
#define RSRFSIGGEN_VAL_OFDM_WINDOWING_NONE                                  0
#define RSRFSIGGEN_VAL_OFDM_WINDOWING_HANNING                               1
#define RSRFSIGGEN_VAL_OFDM_WINDOWING_HAMMING                               2

// RsRFSigGen_rngOFDMTriggerSource
#define RSRFSIGGEN_VAL_OFDM_TRIGGER_SOURCE_INTERNAL                         0
#define RSRFSIGGEN_VAL_OFDM_TRIGGER_SOURCE_INTERNALA                        1
#define RSRFSIGGEN_VAL_OFDM_TRIGGER_SOURCE_INTERNALB                        2
#define RSRFSIGGEN_VAL_OFDM_TRIGGER_SOURCE_EGT1                             3
#define RSRFSIGGEN_VAL_OFDM_TRIGGER_SOURCE_EGT2                             4
#define RSRFSIGGEN_VAL_OFDM_TRIGGER_SOURCE_EGC1                             5
#define RSRFSIGGEN_VAL_OFDM_TRIGGER_SOURCE_EGC2                             6
#define RSRFSIGGEN_VAL_OFDM_TRIGGER_SOURCE_ELT                              7
#define RSRFSIGGEN_VAL_OFDM_TRIGGER_SOURCE_ELC                              8
#define RSRFSIGGEN_VAL_OFDM_TRIGGER_SOURCE_OBAS                             9
#define RSRFSIGGEN_VAL_OFDM_TRIGGER_SOURCE_BEXT                             10
#define RSRFSIGGEN_VAL_OFDM_TRIGGER_SOURCE_EXT                              11

// RsRFSigGen_rngOFDMTriggerSignalDurationUnit
#define RSRFSIGGEN_VAL_OFDM_SIGNAL_DURATION_UNIT_SEQUENCE                   0
#define RSRFSIGGEN_VAL_OFDM_SIGNAL_DURATION_UNIT_SAMPLE                     1

// RsRFSigGen_rngOFDMExternalTriggerDelayUnit
#define RSRFSIGGEN_VAL_OFDM_EXT_TRIG_DELAY_UNIT_SAMPLE                      0
#define RSRFSIGGEN_VAL_OFDM_EXT_TRIG_DELAY_UNIT_TIME                        1

// RsRFSigGen_rngOFDMMarkerMode
#define RSRFSIGGEN_VAL_OFDM_MARKER_MODE_RESTART                             0

// RsRFSigGen_rngOFDMClockMode
#define RSRFSIGGEN_VAL_OFDM_CLOCK_MODE_SAMPLE                               0
#define RSRFSIGGEN_VAL_OFDM_CLOCK_MODE_MSAMP                                1
#define RSRFSIGGEN_VAL_OFDM_CLOCK_MODE_CUSTOM                               2

// RsRFSigGen_rngSatNavStandard
#define RSRFSIGGEN_VAL_SATNAV_STANDARD_QZSS                                 4
#define RSRFSIGGEN_VAL_SATNAV_STANDARD_SBAS                                 5
#define RSRFSIGGEN_VAL_SATNAV_STANDARD_NAVIC                                6

// RsRFSigGen_rngSatNavRTDisplayType
#define RSRFSIGGEN_VAL_SATNAV_RT_DISPLAY_TYPE_SKY                           0
#define RSRFSIGGEN_VAL_SATNAV_RT_DISPLAY_TYPE_MAP                           1
#define RSRFSIGGEN_VAL_SATNAV_RT_DISPLAY_TYPE_POWER                         2
#define RSRFSIGGEN_VAL_SATNAV_RT_DISPLAY_TYPE_TRAJECTORY                    3
#define RSRFSIGGEN_VAL_SATNAV_RT_DISPLAY_TYPE_ATTITUDE                      4

// RsRFSigGen_rngSatNavSignalDynamicsConfig
#define RSRFSIGGEN_VAL_SATNAV_SIGNAL_DYNAMICS_USER                          0
#define RSRFSIGGEN_VAL_SATNAV_SIGNAL_DYNAMICS_VEL1                          1
#define RSRFSIGGEN_VAL_SATNAV_SIGNAL_DYNAMICS_VEL2                          2

// RsRFSigGen_rngSatNavSignalDynamicsDopplerShiftUnit
#define RSRFSIGGEN_VAL_SIGNAL_DYNAMICS_DOPPLER_UNIT_HZ                      0
#define RSRFSIGGEN_VAL_SIGNAL_DYNAMICS_DOPPLER_UNIT_MPS                     1

// RsRFSigGen_rngSatNavSignalDynamicsProfile
#define RSRFSIGGEN_VAL_SATNAV_SIGNAL_DYNAMICS_PROFILE_CONSTANT              0
#define RSRFSIGGEN_VAL_SATNAV_SIGNAL_DYNAMICS_PROFILE_HIGH                  1

// RsRFSigGen_rngSatNavLogMode
#define RSRFSIGGEN_VAL_SATNAV_LOG_MODE_RT                                   0
#define RSRFSIGGEN_VAL_SATNAV_LOG_MODE_OFFLINE                              1

// RsRFSigGen_rngSatNavLogDestination
#define RSRFSIGGEN_VAL_SATNAV_LOG_DESTINATION_FILE                          0
#define RSRFSIGGEN_VAL_SATNAV_LOG_DESTINATION_STREAM                        1

// RsRFSigGen_rngSatNavLogFormat
#define RSRFSIGGEN_VAL_SATNAV_LOG_FORMAT_CSV                                0

// RsRFSigGen_rngSatNavLogUMotionStep
#define RSRFSIGGEN_VAL_SATNAV_LOG_STEP_R1S                                  0
#define RSRFSIGGEN_VAL_SATNAV_LOG_STEP_R2S                                  1
#define RSRFSIGGEN_VAL_SATNAV_LOG_STEP_R5S                                  2
#define RSRFSIGGEN_VAL_SATNAV_LOG_STEP_R10S                                 3
#define RSRFSIGGEN_VAL_SATNAV_LOG_STEP_R02S                                 4
#define RSRFSIGGEN_VAL_SATNAV_LOG_STEP_R04S                                 5
#define RSRFSIGGEN_VAL_SATNAV_LOG_STEP_R08S                                 6

// RsRFSigGen_rngSatNavSBASRegion
#define RSRFSIGGEN_VAL_SATNAV_SBAS_REGION_WAAS                              0
#define RSRFSIGGEN_VAL_SATNAV_SBAS_REGION_MSAS                              1
#define RSRFSIGGEN_VAL_SATNAV_SBAS_REGION_EGNOS                             2
#define RSRFSIGGEN_VAL_SATNAV_SBAS_REGION_GAGAN                             3

// RsRFSigGen_rngDMERangeDistanceUnit
#define RSRFSIGGEN_VAL_DME_DISTANCE_US                                      0
#define RSRFSIGGEN_VAL_DME_DISTANCE_NM                                      1

// RsRFSigGen_rngSatNavMConDataRate
#define RSRFSIGGEN_VAL_SATNAV_MCONT_DRATE_D50HZ                             0
#define RSRFSIGGEN_VAL_SATNAV_MCONT_DRATE_D100HZ                            1
#define RSRFSIGGEN_VAL_SATNAV_MCONT_DRATE_D250HZ                            2
#define RSRFSIGGEN_VAL_SATNAV_MCONT_DRATE_D1000HZ                           3

// RsRFSigGen_rngDMReceiverState
#define RSRFSIGGEN_VAL_DM_RX_STATE_OFF                                      0
#define RSRFSIGGEN_VAL_DM_RX_STATE_OPERATIONAL                              1
#define RSRFSIGGEN_VAL_DM_RX_STATE_UNDERFLOW                                2
#define RSRFSIGGEN_VAL_DM_RX_STATE_OVERFLOW                                 3

// RsRFSigGen_rngExternalInputCouplingMode
#define RSRFSIGGEN_VAL_COUPLING_AC                                          0
#define RSRFSIGGEN_VAL_COUPLING_DC                                          1

// RsRFSigGen_rngHardCopyRegion
#define RSRFSIGGEN_VAL_HCOPY_SNAPSHOT_ALL                                   0
#define RSRFSIGGEN_VAL_HCOPY_SNAPSHOT_DIALOG                                1

// RsRFSigGen_rngOutputConnectorUserSignal
#define RSRFSIGGEN_VAL_OUTPUT_MARKER_A1                                     1
#define RSRFSIGGEN_VAL_OUTPUT_MARKER_A2                                     2
#define RSRFSIGGEN_VAL_OUTPUT_MARKER_A3                                     3
#define RSRFSIGGEN_VAL_OUTPUT_MARKER_B1                                     4
#define RSRFSIGGEN_VAL_OUTPUT_MARKER_B2                                     5
#define RSRFSIGGEN_VAL_OUTPUT_MARKER_B3                                     6
#define RSRFSIGGEN_VAL_OUTPUT_MARKER_C1                                     7
#define RSRFSIGGEN_VAL_OUTPUT_MARKER_C2                                     8
#define RSRFSIGGEN_VAL_OUTPUT_MARKER_C3                                     9
#define RSRFSIGGEN_VAL_OUTPUT_MARKER_D1                                     10
#define RSRFSIGGEN_VAL_OUTPUT_MARKER_D2                                     11
#define RSRFSIGGEN_VAL_OUTPUT_MARKER_D3                                     12
#define RSRFSIGGEN_VAL_OUTPUT_SIGNAL_A                                      13
#define RSRFSIGGEN_VAL_OUTPUT_SIGNAL_B                                      14
#define RSRFSIGGEN_VAL_OUTPUT_PULSE_A                                       15
#define RSRFSIGGEN_VAL_OUTPUT_PULSE_B                                       16
#define RSRFSIGGEN_VAL_OUTPUT_SYNCH_A                                       17
#define RSRFSIGGEN_VAL_OUTPUT_SYNCH_B                                       18
#define RSRFSIGGEN_VAL_OUTPUT_VIDEO_A                                       19
#define RSRFSIGGEN_VAL_OUTPUT_VIDEO_B                                       20
#define RSRFSIGGEN_VAL_OUTPUT_NONE                                          21

// RsRFSigGen_rngRFFrequencyModeNew
#define RSRFSIGGEN_VAL_RF_FREQUENCY_CW                                      0
#define RSRFSIGGEN_VAL_RF_FREQUENCY_FIXED                                   1
#define RSRFSIGGEN_VAL_RF_FREQUENCY_SWEEP                                   2
#define RSRFSIGGEN_VAL_RF_FREQUENCY_LIST                                    3
#define RSRFSIGGEN_VAL_RF_FREQUENCY_COMB                                    4

// RsRFSigGen_rngSatNavRoMode
#define RSRFSIGGEN_VAL_SATNAV_ROMODE_CYCL                                   0
#define RSRFSIGGEN_VAL_SATNAV_ROMODE_OWAY                                   1
#define RSRFSIGGEN_VAL_SATNAV_ROMODE_RTR                                    2

// RsRFSigGen_rngIQDigitalSampleRateSource
#define RSRFSIGGEN_VAL_SAMPLE_RATE_SOURCE_USER                              0
#define RSRFSIGGEN_VAL_SAMPLE_RATE_SOURCE_DOUT                              1
#define RSRFSIGGEN_VAL_SAMPLE_RATE_SOURCE_DIN                               2

// RsRFSigGen_rngARBTriggerStatus
#define RSRFSIGGEN_VAL_ARB_TRIGGER_STATUS_STOP                              0
#define RSRFSIGGEN_VAL_ARB_TRIGGER_STATUS_RUN                               1

// RsRFSigGen_rngARBExternalTriggerDelayUnit
#define RSRFSIGGEN_VAL_EXTERNAL_TRIGGER_DELAY_UNIT_CHIP                     2

// RsRFSigGen_rngSweepTriggerSource
#define RSRFSIGGEN_VAL_SWEEP_TRIGGER_SOURCE_AUTO                            0
#define RSRFSIGGEN_VAL_SWEEP_TRIGGER_SOURCE_IMMEDIATE                       1
#define RSRFSIGGEN_VAL_SWEEP_TRIGGER_SOURCE_SINGLE                          2
#define RSRFSIGGEN_VAL_SWEEP_TRIGGER_SOURCE_BUS                             3
#define RSRFSIGGEN_VAL_SWEEP_TRIGGER_SOURCE_EXTERNAL                        4
#define RSRFSIGGEN_VAL_SWEEP_TRIGGER_SOURCE_EXTERNAL_AUTO                   5

// RsRFSigGen_rngLFSweepState
#define RSRFSIGGEN_VAL_LF_SWEEP_STATE_CW                                    0
#define RSRFSIGGEN_VAL_LF_SWEEP_STATE_FIXED                                 1
#define RSRFSIGGEN_VAL_LF_SWEEP_STATE_SWEEP                                 2

// RsRFSigGen_rngRFPowerMode
#define RSRFSIGGEN_VAL_RF_POWER_CW                                          0
#define RSRFSIGGEN_VAL_RF_POWER_FIXED                                       1
#define RSRFSIGGEN_VAL_RF_POWER_SWEEP                                       2

// RsRFSigGen_rngOutputConnectorDirection
#define RSRFSIGGEN_VAL_OUTPUT_DIRECTION_INPUT                               0
#define RSRFSIGGEN_VAL_OUTPUT_DIRECTION_OUTPUT                              1
#define RSRFSIGGEN_VAL_OUTPUT_DIRECTION_UNUSED                              2

// RsRFSigGen_rngOutputImpedance
#define RSRFSIGGEN_VAL_IMPEDANCE_G10K                                       2

// RsRFSigGen_rngTMCConnectorInputSignal
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_TRIGGER                                 0
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_CLOCK                                   1
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_DATA                                    2
#define RSRFSIGGEN_VAL_INPUT_SIGNAL_FEEDBACK                                3

// RsRFSigGen_rngTMCConnectorOututSignal
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_MARKER_A_1                          0
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_MARKER_A_2                          1
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_MARKER_A_3                          2
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_MARKER_B_1                          3
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_MARKER_B_2                          4
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_MARKER_B_3                          5
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_MARKER_C_1                          6
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_MARKER_C_2                          7
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_MARKER_C_3                          8
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_MARKER_D_1                          9
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_MARKER_D_2                          10
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_MARKER_D_3                          11
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_SYMBOL_CLOCK_A                      12
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_SYMBOL_CLOCK_B                      13
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_SYMBOL_CLOCK_C                      14
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_SYMBOL_CLOCK_D                      15
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_LEV_ATT_A                           16
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_LEV_ATT_B                           17
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_LEV_ATT_C                           18
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_LEV_ATT_D                           19
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_HOP_A                               20
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_HOP_B                               21
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_HOP_C                               22
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_HOP_D                               23
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_BURST_GATE_A                        24
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_BURST_GATE_B                        25
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_BURST_GATE_C                        26
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_BURST_GATE_D                        27
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_CW_MOD_A                            28
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_CW_MOD_B                            29
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_CW_MOD_C                            30
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_CW_MOD_D                            31
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_TRIGGERED_A                         32
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_TRIGGERED_B                         33
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_TRIGGERED_C                         34
#define RSRFSIGGEN_VAL_OUTPUT_CONNECTOR_TRIGGERED_D                         35

// RsRFSigGen_rngExternalLFSignalBandwidth
#define RSRFSIGGEN_VAL_EXT_LF_BANDWIDTH_200K                                0
#define RSRFSIGGEN_VAL_EXT_LF_BANDWIDTH_10M                                 1

// RsRFSigGen_rngLFOutputSourcePath
#define RSRFSIGGEN_PATH_A                                                   0
#define RSRFSIGGEN_PATH_B                                                   1

// RsRFSigGen_rngBBINSampleRateSource
#define RSRFSIGGEN_VAL_SAMPLE_RATE_SOURCE_HSDIN                             3

// RsRFSigGen_rngWLANADTriggerSource
#define RSRFSIGGEN_VAL_WLANAD_TRIGGER_SOURCE_INT                            0
#define RSRFSIGGEN_VAL_WLANAD_TRIGGER_SOURCE_INTA                           1
#define RSRFSIGGEN_VAL_WLANAD_TRIGGER_SOURCE_INTB                           2
#define RSRFSIGGEN_VAL_WLANAD_TRIGGER_SOURCE_EGT1                           3
#define RSRFSIGGEN_VAL_WLANAD_TRIGGER_SOURCE_EGT2                           4
#define RSRFSIGGEN_VAL_WLANAD_TRIGGER_SOURCE_OBAS                           5
#define RSRFSIGGEN_VAL_WLANAD_TRIGGER_SOURCE_BEXT                           6
#define RSRFSIGGEN_VAL_WLANAD_TRIGGER_SOURCE_EXT                            7

// RsRFSigGen_rngWLANADMarkerMode
#define RSRFSIGGEN_VAL_WLANAD_MARKER_MODE_RESTART                           0
#define RSRFSIGGEN_VAL_WLANAD_MARKER_MODE_FRAME                             1
#define RSRFSIGGEN_VAL_WLANAD_MARKER_MODE_FAPART                            2
#define RSRFSIGGEN_VAL_WLANAD_MARKER_MODE_PATT                              3
#define RSRFSIGGEN_VAL_WLANAD_MARKER_MODE_PULSE                             4
#define RSRFSIGGEN_VAL_WLANAD_MARKER_MODE_RATIO                             5
#define RSRFSIGGEN_VAL_WLANAD_MARKER_MODE_FIPART                            6
#define RSRFSIGGEN_VAL_WLANAD_MARKER_MODE_FBL                               7

// RsRFSigGen_rngWLANADClockSource
#define RSRFSIGGEN_VAL_WLANAD_CLOCK_SOURCE_INT                              0

// RsRFSigGen_rngWLANADPPDUMCS
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS0                                     0
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS1                                     1
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS2                                     2
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS3                                     3
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS4                                     4
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS5                                     5
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS6                                     6
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS7                                     7
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS8                                     8
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS9                                     9
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS10                                    10
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS11                                    11
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS12                                    12
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS13                                    13
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS14                                    14
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS15                                    15
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS16                                    16
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS17                                    17
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS18                                    18
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS19                                    19
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS20                                    20
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS21                                    21
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS22                                    22
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS23                                    23
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS24                                    24
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS25                                    25
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS26                                    26
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS27                                    27
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS28                                    28
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS29                                    29
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS30                                    30
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS31                                    31
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS91                                    91
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS121                                   121
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS122                                   122
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS123                                   123
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS124                                   124
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS125                                   125
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MCS126                                   126

// RsRFSigGen_rngWLANADPPDUModulation
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MODULATION_DBPSK                         0
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MODULATION_SQPSK                         1
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MODULATION_QPSK                          2
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MODULATION_QAM16                         3
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MODULATION_QAM64                         4
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MODULATION_P2BPSK                        5
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MODULATION_P2QPSK                        6
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MODULATION_P2QAM16                       7
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MODULATION_P2QAM64                       8
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MODULATION_P2PSK8                        9
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MODULATION_P2NUC64                       10
#define RSRFSIGGEN_VAL_WLANAD_PPDU_MODULATION_DCMP2BPSK                     11

// RsRFSigGen_rngWLANADPPDUChannelCoding
#define RSRFSIGGEN_VAL_WLANAD_PPDU_CHANNEL_CODING_LDPC                      0
#define RSRFSIGGEN_VAL_WLANAD_PPDU_CHANNEL_CODING_RB8                       1
#define RSRFSIGGEN_VAL_WLANAD_PPDU_CHANNEL_CODING_RB12                      2
#define RSRFSIGGEN_VAL_WLANAD_PPDU_CHANNEL_CODING_RB16                      3
#define RSRFSIGGEN_VAL_WLANAD_PPDU_CHANNEL_CODING_RS9                       4

// RsRFSigGen_rngWLANADPPDUCodeRate
#define RSRFSIGGEN_VAL_WLANAD_PPDU_CODE_RATE_CR1D2                          0
#define RSRFSIGGEN_VAL_WLANAD_PPDU_CODE_RATE_CR3D4                          1
#define RSRFSIGGEN_VAL_WLANAD_PPDU_CODE_RATE_CR5D8                          2
#define RSRFSIGGEN_VAL_WLANAD_PPDU_CODE_RATE_CR13D14                        3
#define RSRFSIGGEN_VAL_WLANAD_PPDU_CODE_RATE_CR13D16                        4
#define RSRFSIGGEN_VAL_WLANAD_PPDU_CODE_RATE_CR13D21                        5
#define RSRFSIGGEN_VAL_WLANAD_PPDU_CODE_RATE_CR13D28                        6
#define RSRFSIGGEN_VAL_WLANAD_PPDU_CODE_RATE_CR52D63                        7
#define RSRFSIGGEN_VAL_WLANAD_PPDU_CODE_RATE_CR7D8                          8
#define RSRFSIGGEN_VAL_WLANAD_PPDU_CODE_RATE_CR2D3                          9
#define RSRFSIGGEN_VAL_WLANAD_PPDU_CODE_RATE_CR5D6                          10

// RsRFSigGen_rngWLANADDataSource
#define RSRFSIGGEN_VAL_WLANAD_DATA_SOURCE_ZERO                              0
#define RSRFSIGGEN_VAL_WLANAD_DATA_SOURCE_ONE                               1
#define RSRFSIGGEN_VAL_WLANAD_DATA_SOURCE_PATT                              2
#define RSRFSIGGEN_VAL_WLANAD_DATA_SOURCE_PN9                               3
#define RSRFSIGGEN_VAL_WLANAD_DATA_SOURCE_PN11                              4
#define RSRFSIGGEN_VAL_WLANAD_DATA_SOURCE_PN15                              5
#define RSRFSIGGEN_VAL_WLANAD_DATA_SOURCE_PN16                              6
#define RSRFSIGGEN_VAL_WLANAD_DATA_SOURCE_PN20                              7
#define RSRFSIGGEN_VAL_WLANAD_DATA_SOURCE_PN21                              8
#define RSRFSIGGEN_VAL_WLANAD_DATA_SOURCE_PN23                              9
#define RSRFSIGGEN_VAL_WLANAD_DATA_SOURCE_DLIST                             10
#define RSRFSIGGEN_VAL_WLANAD_DATA_SOURCE_AMPDU                             11

// RsRFSigGen_rngWLANADPPDUHeaderPacketType
#define RSRFSIGGEN_VAL_WLANAD_PPDU_HEADER_PTYPE_TRNR                        0
#define RSRFSIGGEN_VAL_WLANAD_PPDU_HEADER_PTYPE_TRNT                        1
#define RSRFSIGGEN_VAL_WLANAD_PPDU_HEADER_PTYPE_TRNTR                       2

// RsRFSigGen_rngWLANADLastRSSI
#define RSRFSIGGEN_VAL_WLANAD_LAST_RSSI_NA                                  0
#define RSRFSIGGEN_VAL_WLANAD_LAST_RSSI_M68                                 1
#define RSRFSIGGEN_VAL_WLANAD_LAST_RSSI_M67                                 2
#define RSRFSIGGEN_VAL_WLANAD_LAST_RSSI_M65                                 3
#define RSRFSIGGEN_VAL_WLANAD_LAST_RSSI_M63                                 4
#define RSRFSIGGEN_VAL_WLANAD_LAST_RSSI_M61                                 5
#define RSRFSIGGEN_VAL_WLANAD_LAST_RSSI_M59                                 6
#define RSRFSIGGEN_VAL_WLANAD_LAST_RSSI_M57                                 7
#define RSRFSIGGEN_VAL_WLANAD_LAST_RSSI_M55                                 8
#define RSRFSIGGEN_VAL_WLANAD_LAST_RSSI_M53                                 9
#define RSRFSIGGEN_VAL_WLANAD_LAST_RSSI_M51                                 10
#define RSRFSIGGEN_VAL_WLANAD_LAST_RSSI_M49                                 11
#define RSRFSIGGEN_VAL_WLANAD_LAST_RSSI_M47                                 12
#define RSRFSIGGEN_VAL_WLANAD_LAST_RSSI_M45                                 13
#define RSRFSIGGEN_VAL_WLANAD_LAST_RSSI_M43                                 14
#define RSRFSIGGEN_VAL_WLANAD_LAST_RSSI_M42                                 15

// RsRFSigGen_rngWLANADTonePairingType
#define RSRFSIGGEN_VAL_WLANAD_TONE_PAIRING_TYPE_STATIC                      0
#define RSRFSIGGEN_VAL_WLANAD_TONE_PAIRING_TYPE_DYNAMIC                     1

// RsRFSigGen_rngWLANADDMGPHYMode
#define RSRFSIGGEN_VAL_WLANAD_DMG_MODE_CONTROL                              0
#define RSRFSIGGEN_VAL_WLANAD_DMG_MODE_SINGLE                               1
#define RSRFSIGGEN_VAL_WLANAD_DMG_MODE_OFDM                                 2
#define RSRFSIGGEN_VAL_WLANAD_DMG_MODE_LPOW                                 3
#define RSRFSIGGEN_VAL_WLANAD_DMG_MODE_ESINGLE                              4

// RsRFSigGen_rngWLANADFrameType
#define RSRFSIGGEN_VAL_WLANAD_FRAME_TYPE_DATA                               0
#define RSRFSIGGEN_VAL_WLANAD_FRAME_TYPE_BEACON                             1

// RsRFSigGen_rngDVBFilterRolloffRange
#define RSRFSIGGEN_VAL_DVB_FILTER_ROLLOFF_HIGH                              0
#define RSRFSIGGEN_VAL_DVB_FILTER_ROLLOFF_LOW                               1

// RsRFSigGen_rngDVBFilterRolloffFactor
#define RSRFSIGGEN_VAL_DVB_FILTER_ROLLOFF_FACTOR_RO35                       0
#define RSRFSIGGEN_VAL_DVB_FILTER_ROLLOFF_FACTOR_RO25                       1
#define RSRFSIGGEN_VAL_DVB_FILTER_ROLLOFF_FACTOR_RO20                       2
#define RSRFSIGGEN_VAL_DVB_FILTER_ROLLOFF_FACTOR_RO15                       3
#define RSRFSIGGEN_VAL_DVB_FILTER_ROLLOFF_FACTOR_RO10                       4
#define RSRFSIGGEN_VAL_DVB_FILTER_ROLLOFF_FACTOR_RO05                       5

// RsRFSigGen_rngDVBSStreamType
#define RSRFSIGGEN_VAL_DVBS_STREAM_TYPE_TRANSPORT                           0
#define RSRFSIGGEN_VAL_DVBS_STREAM_TYPE_GP                                  1
#define RSRFSIGGEN_VAL_DVBS_STREAM_TYPE_GC                                  2
#define RSRFSIGGEN_VAL_DVBS_STREAM_TYPE_GHEM                                3

// RsRFSigGen_rngDVBSDataSource
#define RSRFSIGGEN_VAL_DVBS_DATA_SOURCE_ZERO                                0
#define RSRFSIGGEN_VAL_DVBS_DATA_SOURCE_ONE                                 1
#define RSRFSIGGEN_VAL_DVBS_DATA_SOURCE_PATTERN                             2
#define RSRFSIGGEN_VAL_DVBS_DATA_SOURCE_PN9                                 3
#define RSRFSIGGEN_VAL_DVBS_DATA_SOURCE_PN11                                4
#define RSRFSIGGEN_VAL_DVBS_DATA_SOURCE_PN15                                5
#define RSRFSIGGEN_VAL_DVBS_DATA_SOURCE_PN16                                6
#define RSRFSIGGEN_VAL_DVBS_DATA_SOURCE_PN20                                7
#define RSRFSIGGEN_VAL_DVBS_DATA_SOURCE_PN21                                8
#define RSRFSIGGEN_VAL_DVBS_DATA_SOURCE_PN23                                9
#define RSRFSIGGEN_VAL_DVBS_DATA_SOURCE_DLIST                               10
#define RSRFSIGGEN_VAL_DVBS_DATA_SOURCE_TSFILE                              11
#define RSRFSIGGEN_VAL_DVBS_DATA_SOURCE_GSEFILE                             12

// RsRFSigGen_rngDVBSInnerCoderRate
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR1D4                          0
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR1D3                          1
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR2D5                          2
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR1D2                          3
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR3D5                          4
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR2D3                          5
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR3D4                          6
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR4D5                          7
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR5D6                          8
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR8D9                          9
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR9D10                         10
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR2D9                          11
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR13D45                        12
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR9D20                         13
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR90D180                       14
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR96D180                       15
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR11D20                        16
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR100D180                      17
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR104D180                      18
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR26D45                        19
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR18D30                        20
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR28D45                        21
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR23D36                        22
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR116D180                      23
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR20D30                        24
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR124D180                      25
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR25D36                        26
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR128D180                      27
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR13D18                        28
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR132D180                      29
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR22D30                        30
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR135D180                      31
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR140D180                      32
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR7D9                          33
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR154D180                      34
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR1D5                          35
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR11D45                        36
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR4D15                         37
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR14D45                        38
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR7D15                         39
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR8D15                         40
#define RSRFSIGGEN_VAL_DVBS_INNER_CODER_RATE_CR32D45                        41

// RsRFSigGen_rngDVBSCodeType
#define RSRFSIGGEN_VAL_DVBS_CODE_TYPE_NORMAL                                0
#define RSRFSIGGEN_VAL_DVBS_CODE_TYPE_MEDIUM                                1
#define RSRFSIGGEN_VAL_DVBS_CODE_TYPE_SHORT                                 2

// RsRFSigGen_rngDVBS2MODCOD
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_S_14                                0
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_S_13                                1
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_S_25                                2
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_S_12                                3
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_S_35                                4
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_S_23                                5
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_S_34                                6
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_S_45                                7
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_S_56                                8
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_S_89                                9
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_S_910                               10
#define RSRFSIGGEN_VAL_DVBS_MODCOD_PSK8_S_35                                11
#define RSRFSIGGEN_VAL_DVBS_MODCOD_PSK8_S_23                                12
#define RSRFSIGGEN_VAL_DVBS_MODCOD_PSK8_S_34                                13
#define RSRFSIGGEN_VAL_DVBS_MODCOD_PSK8_S_56                                14
#define RSRFSIGGEN_VAL_DVBS_MODCOD_PSK8_S_89                                15
#define RSRFSIGGEN_VAL_DVBS_MODCOD_PSK8_S_910                               16
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_S_23                              17
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_S_34                              18
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_S_45                              19
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_S_56                              20
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_S_89                              21
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_S_910                             22
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK32_S_34                              23
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK32_S_45                              24
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK32_S_56                              25
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK32_S_89                              26
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK32_S_910                             27
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_X_N1345                             28
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_X_N920                              29
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_X_N1120                             30
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK8_X_N59L                             31
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK8_X_N2645L                           32
#define RSRFSIGGEN_VAL_DVBS_MODCOD_PSK8_X_N2336                             33
#define RSRFSIGGEN_VAL_DVBS_MODCOD_PSK8_X_N2536                             34
#define RSRFSIGGEN_VAL_DVBS_MODCOD_PSK8_X_N1318                             35
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_N12L                            36
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_N815L                           37
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_N59L                            38
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_N2645                           39
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_N35                             40
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_N35L                            41
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_N2845                           42
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_N2336                           43
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_N23L                            44
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_N2536                           45
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_N1318                           46
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_N79                             47
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_N7790                           48
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK32_X_N23L                            49
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK32_X_N3245                           50
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK32_X_N1115                           51
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK32_X_N79                             52
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK64_X_N3245L                          53
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK64_X_N1115                           54
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK64_X_N79                             55
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK64_X_N45                             56
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK64_X_N56                             57
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK128_X_N34                            58
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK128_X_N79                            59
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK256_X_N2945                          60
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK256_X_N23L                           61
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK256_X_3145L                          62
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK256_X_N3245                          63
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK256_X_1115L                          64
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK256_X_N34                            65
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_X_S1145                             66
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_X_S415                              67
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_X_S1445                             68
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_X_S715                              69
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_X_S815                              70
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_X_S3245                             71
#define RSRFSIGGEN_VAL_DVBS_MODCOD_PSK8_X_S715                              72
#define RSRFSIGGEN_VAL_DVBS_MODCOD_PSK8_X_S815                              73
#define RSRFSIGGEN_VAL_DVBS_MODCOD_PSK8_X_S2645                             74
#define RSRFSIGGEN_VAL_DVBS_MODCOD_PSK8_X_S3245                             75
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_S715                            76
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_S815                            77
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_S2645                           78
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_S35                             79
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK16_X_S3245                           80
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK32_X_S23                             81
#define RSRFSIGGEN_VAL_DVBS_MODCOD_APSK32_X_S3245                           82
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_X_VN29                              83
#define RSRFSIGGEN_VAL_DVBS_MODCOD_BPSK_X_VM15                              84
#define RSRFSIGGEN_VAL_DVBS_MODCOD_BPSK_X_VM1145                            85
#define RSRFSIGGEN_VAL_DVBS_MODCOD_BPSK_X_VM13                              86
#define RSRFSIGGEN_VAL_DVBS_MODCOD_BPSK_X_VS15                              87
#define RSRFSIGGEN_VAL_DVBS_MODCOD_BPSK_X_VS1145                            88
#define RSRFSIGGEN_VAL_DVBS_MODCOD_BPSK_X_VS415                             89
#define RSRFSIGGEN_VAL_DVBS_MODCOD_BPSK_X_VS13                              90
#define RSRFSIGGEN_VAL_DVBS_MODCOD_QPSK_X_M15                               91

// RsRFSigGen_rngDVBSModulation
#define RSRFSIGGEN_VAL_DVBS_MODULATION_QPSK                                 0
#define RSRFSIGGEN_VAL_DVBS_MODULATION_APSK16                               1
#define RSRFSIGGEN_VAL_DVBS_MODULATION_APSK32                               2
#define RSRFSIGGEN_VAL_DVBS_MODULATION_PSK8                                 3
#define RSRFSIGGEN_VAL_DVBS_MODULATION_P2BPSK                               4
#define RSRFSIGGEN_VAL_DVBS_MODULATION_APSK16_8_8                           5
#define RSRFSIGGEN_VAL_DVBS_MODULATION_APSK32_4_12_16R                      6
#define RSRFSIGGEN_VAL_DVBS_MODULATION_APSK64_8_16_20_20                    7
#define RSRFSIGGEN_VAL_DVBS_MODULATION_APSK8_2_4_2                          8
#define RSRFSIGGEN_VAL_DVBS_MODULATION_APSK32_4_8_4_16                      9
#define RSRFSIGGEN_VAL_DVBS_MODULATION_APSK64_16_16_16_16                   10
#define RSRFSIGGEN_VAL_DVBS_MODULATION_APSK64_4_12_20_28                    11
#define RSRFSIGGEN_VAL_DVBS_MODULATION_APSK128                              12
#define RSRFSIGGEN_VAL_DVBS_MODULATION_APSK256                              13

// RsRFSigGen_rngDVBSBBCCMACM
#define RSRFSIGGEN_VAL_DVBS_BB_CCM                                          0
#define RSRFSIGGEN_VAL_DVBS_BB_ACM                                          1

// RsRFSigGen_rngFSIMMIMOSCMAntColRows
#define RSRFSIGGEN_VAL_FSIM_MIMO_SCM_ANT_COL_ROWS_R01                       0
#define RSRFSIGGEN_VAL_FSIM_MIMO_SCM_ANT_COL_ROWS_R02                       1
#define RSRFSIGGEN_VAL_FSIM_MIMO_SCM_ANT_COL_ROWS_R03                       2
#define RSRFSIGGEN_VAL_FSIM_MIMO_SCM_ANT_COL_ROWS_R04                       3
#define RSRFSIGGEN_VAL_FSIM_MIMO_SCM_ANT_COL_ROWS_R08                       4

// RsRFSigGen_rngFSIMMIMOSCMAntCalculationMode
#define RSRFSIGGEN_VAL_MIMO_SCM_ANT_CALCULATION_MODE_SPACING                0
#define RSRFSIGGEN_VAL_MIMO_SCM_ANT_CALCULATION_MODE_RELATIVE               1
#define RSRFSIGGEN_VAL_MIMO_SCM_ANT_CALCULATION_MODE_BFORMING               2

// RsRFSigGen_rngFSIMMIMOSCMAntPattern
#define RSRFSIGGEN_VAL_FSIM_MIMO_SCM_ANT_PATTERN_ISOTROPIC                  0
#define RSRFSIGGEN_VAL_FSIM_MIMO_SCM_ANT_PATTERN_USER                       1
#define RSRFSIGGEN_VAL_FSIM_MIMO_SCM_ANT_PATTERN_SEC3                       2
#define RSRFSIGGEN_VAL_FSIM_MIMO_SCM_ANT_PATTERN_SEC6                       3
#define RSRFSIGGEN_VAL_FSIM_MIMO_SCM_ANT_PATTERN_DIPOLE                     4

// RsRFSigGen_rngFSIMCustomDynamicFadingProfile
#define RSRFSIGGEN_VAL_FSIM_CUSTOM_DYNAMIC_PROFILE_PDOP                     0
#define RSRFSIGGEN_VAL_FSIM_CUSTOM_DYNAMIC_PROFILE_RAYL                     1
#define RSRFSIGGEN_VAL_FSIM_CUSTOM_DYNAMIC_PROFILE_SPAT                     2

// RsRFSigGen_rngPowerSensorMapping
#define RSRFSIGGEN_VAL_POWER_SENSOR_MAPPING_SENSOR1                         0
#define RSRFSIGGEN_VAL_POWER_SENSOR_MAPPING_SENSOR2                         1
#define RSRFSIGGEN_VAL_POWER_SENSOR_MAPPING_SENSOR3                         2
#define RSRFSIGGEN_VAL_POWER_SENSOR_MAPPING_SENSOR4                         3
#define RSRFSIGGEN_VAL_POWER_SENSOR_MAPPING_UNMAPPED                        4

// RsRFSigGen_rngSatNavADGDataFormatGLONASS
#define RSRFSIGGEN_VAL_GNSS_ADG_DATA_FORMAT_GLON_3GPP                       0
#define RSRFSIGGEN_VAL_GNSS_ADG_DATA_FORMAT_GLON_GRS                        1

// RsRFSigGen_rngEUTRAEPDCCHTransmissionType
#define RSRFSIGGEN_VAL_EUTRA_EPDCCH_TRANS_TYPE_LOCALIZED                    0
#define RSRFSIGGEN_VAL_EUTRA_EPDCCH_TRANS_TYPE_DISTRIBUTED                  1

// RsRFSigGen_rngEUTRAEPDCCHPRBPairs
#define RSRFSIGGEN_VAL_EUTRA_EPDCCH_PRB_PRB2                                0
#define RSRFSIGGEN_VAL_EUTRA_EPDCCH_PRB_PRB4                                1
#define RSRFSIGGEN_VAL_EUTRA_EPDCCH_PRB_PRB8                                2

// RsRFSigGen_rngEUTRAPDCCHType
#define RSRFSIGGEN_VAL_EUTRA_PDCCH_TYPE_PDCCH                               0
#define RSRFSIGGEN_VAL_EUTRA_PDCCH_TYPE_EPDCCH1                             1
#define RSRFSIGGEN_VAL_EUTRA_PDCCH_TYPE_EPDCCH2                             2

// RsRFSigGen_rngGraphicsFFTSize
#define RSRFSIGGEN_VAL_GRAPHICS_FFT_LEN256                                  0
#define RSRFSIGGEN_VAL_GRAPHICS_FFT_LEN512                                  1
#define RSRFSIGGEN_VAL_GRAPHICS_FFT_LEN1024                                 2
#define RSRFSIGGEN_VAL_GRAPHICS_FFT_LEN2048                                 3
#define RSRFSIGGEN_VAL_GRAPHICS_FFT_LEN4096                                 4
#define RSRFSIGGEN_VAL_GRAPHICS_FFT_LEN8192                                 5

// RsRFSigGen_rngREGTestSetup
#define RSRFSIGGEN_VAL_REG_TSET_COND                                        0
#define RSRFSIGGEN_VAL_REG_TSET_OTA                                         1

// RsRFSigGen_rngREGRadarRxPower
#define RSRFSIGGEN_VAL_REG_POWER_MODE_REQUATION                             0
#define RSRFSIGGEN_VAL_REG_POWER_MODE_MANUAL                                1

// RsRFSigGen_rngREGAnalyzerReferenceLevelStatus
#define RSRFSIGGEN_VAL_REG_ANALYZER_STATUS_NCONECTED                        0
#define RSRFSIGGEN_VAL_REG_ANALYZER_STATUS_INVALID                          1
#define RSRFSIGGEN_VAL_REG_ANALYZER_STATUS_VALID                            2
#define RSRFSIGGEN_VAL_REG_ANALYZER_STATUS_UPDATED                          3

// RsRFSigGen_rngREGSimulationSystemLatencyCalibration
#define RSRFSIGGEN_VAL_REG_SIM_SYSTEM_LATENCY_MANUAL                        0
#define RSRFSIGGEN_VAL_REG_SIM_SYSTEM_LATENCY_AUTOMATIC                     1

// RsRFSigGen_rngREGSimulationCalibrationSuccessful
#define RSRFSIGGEN_VAL_REG_SIM_CALIBRATION_STATE_FAILED                     0
#define RSRFSIGGEN_VAL_REG_SIM_CALIBRATION_STATE_SUCCESS                    1

// RsRFSigGen_rngREGSimulationDedicatedConnector
#define RSRFSIGGEN_VAL_REG_SIM_CONNECTOR_RFA                                0
#define RSRFSIGGEN_VAL_REG_SIM_CONNECTOR_RFB                                1
#define RSRFSIGGEN_VAL_REG_SIM_CONNECTOR_BBMM1                              2
#define RSRFSIGGEN_VAL_REG_SIM_CONNECTOR_BBMM2                              3
#define RSRFSIGGEN_VAL_REG_SIM_CONNECTOR_IQOUT1                             4
#define RSRFSIGGEN_VAL_REG_SIM_CONNECTOR_IQOUT2                             5
#define RSRFSIGGEN_VAL_REG_SIM_CONNECTOR_FAD1                               6
#define RSRFSIGGEN_VAL_REG_SIM_CONNECTOR_FAD2                               7
#define RSRFSIGGEN_VAL_REG_SIM_CONNECTOR_FAD3                               8
#define RSRFSIGGEN_VAL_REG_SIM_CONNECTOR_FAD4                               9
#define RSRFSIGGEN_VAL_REG_SIM_CONNECTOR_DEF                                10

// RsRFSigGen_rngREGObject
#define RSRFSIGGEN_VAL_REG_OBJECT_ALL                                       0
#define RSRFSIGGEN_VAL_REG_OBJECT_1                                         1
#define RSRFSIGGEN_VAL_REG_OBJECT_2                                         2
#define RSRFSIGGEN_VAL_REG_OBJECT_3                                         3
#define RSRFSIGGEN_VAL_REG_OBJECT_4                                         4
#define RSRFSIGGEN_VAL_REG_OBJECT_5                                         5
#define RSRFSIGGEN_VAL_REG_OBJECT_6                                         6
#define RSRFSIGGEN_VAL_REG_OBJECT_7                                         7
#define RSRFSIGGEN_VAL_REG_OBJECT_8                                         8
#define RSRFSIGGEN_VAL_REG_OBJECT_9                                         9
#define RSRFSIGGEN_VAL_REG_OBJECT_10                                        10
#define RSRFSIGGEN_VAL_REG_OBJECT_11                                        11
#define RSRFSIGGEN_VAL_REG_OBJECT_12                                        12

// RsRFSigGen_rngREGObjectType
#define RSRFSIGGEN_VAL_REG_OBJECT_TYPE_OFF                                  0
#define RSRFSIGGEN_VAL_REG_OBJECT_TYPE_STATIC                               1
#define RSRFSIGGEN_VAL_REG_OBJECT_TYPE_MOVING                               2
#define RSRFSIGGEN_VAL_REG_OBJECT_TYPE_SMOVING                              3

// RsRFSigGen_rngREGObjectSimulationMode
#define RSRFSIGGEN_VAL_REG_OBJECT_SIM_MODE_ROUNDTRIP                        0
#define RSRFSIGGEN_VAL_REG_OBJECT_SIM_MODE_ONEW                             1
#define RSRFSIGGEN_VAL_REG_OBJECT_SIM_MODE_CYCL                             2

// RsRFSigGen_rngREGObjectDirection
#define RSRFSIGGEN_VAL_REG_OBJECT_DIRECTION_APPR                            0
#define RSRFSIGGEN_VAL_REG_OBJECT_DIRECTION_DEP                             1

// RsRFSigGen_rngREGObjectRadarRxPowerDedicated
#define RSRFSIGGEN_VAL_REG_OBJECT_POWER_RX_DEDICATED_ALL                    0
#define RSRFSIGGEN_VAL_REG_OBJECT_POWER_RX_DEDICATED_START                  1
#define RSRFSIGGEN_VAL_REG_OBJECT_POWER_RX_DEDICATED_END                    2

// RsRFSigGen_rngREGObjectRCSModel
#define RSRFSIGGEN_VAL_REG_OBJECT_RCS_MODEL_SWE0                            0
#define RSRFSIGGEN_VAL_REG_OBJECT_RCS_MODEL_SWE1                            1
#define RSRFSIGGEN_VAL_REG_OBJECT_RCS_MODEL_SWE2                            2
#define RSRFSIGGEN_VAL_REG_OBJECT_RCS_MODEL_SWE3                            3
#define RSRFSIGGEN_VAL_REG_OBJECT_RCS_MODEL_SWE4                            4

// RsRFSigGen_rngREGObjectPreviewDiagramType
#define RSRFSIGGEN_VAL_REG_DIAGRAM_TYPE_VELOCITY                            0
#define RSRFSIGGEN_VAL_REG_DIAGRAM_TYPE_POLAR                               1
#define RSRFSIGGEN_VAL_REG_DIAGRAM_TYPE_POWER                               2

// RsRFSigGen_rngREGUnitAngle
#define RSRFSIGGEN_VAL_REG_UNIT_ANGLE_DEG                                   0
#define RSRFSIGGEN_VAL_REG_UNIT_ANGLE_RAD                                   1

// RsRFSigGen_rngREGUnitLength
#define RSRFSIGGEN_VAL_REG_UNIT_LENGTH_MI                                   0
#define RSRFSIGGEN_VAL_REG_UNIT_LENGTH_NM                                   1
#define RSRFSIGGEN_VAL_REG_UNIT_LENGTH_KM                                   2
#define RSRFSIGGEN_VAL_REG_UNIT_LENGTH_M                                    3

// RsRFSigGen_rngREGUnitTime
#define RSRFSIGGEN_VAL_REG_UNIT_TIME_S                                      0
#define RSRFSIGGEN_VAL_REG_UNIT_TIME_MS                                     1

// RsRFSigGen_rngUnitVelocity
#define RSRFSIGGEN_VAL_REG_UNIT_VELOCITY_MPS                                0
#define RSRFSIGGEN_VAL_REG_UNIT_VELOCITY_KMH                                1
#define RSRFSIGGEN_VAL_REG_UNIT_VELOCITY_MPH                                2
#define RSRFSIGGEN_VAL_REG_UNIT_VELOCITY_NMPH                               3

// RsRFSigGen_rngBTLEExtendedHeaderACAD
#define RSRFSIGGEN_VAL_BT_LE_ACAD_ALL0                                      0
#define RSRFSIGGEN_VAL_BT_LE_ACAD_ALL1                                      1
#define RSRFSIGGEN_VAL_BT_LE_ACAD_PATTERN                                   2
#define RSRFSIGGEN_VAL_BT_LE_ACAD_PN09                                      3
#define RSRFSIGGEN_VAL_BT_LE_ACAD_PN11                                      4
#define RSRFSIGGEN_VAL_BT_LE_ACAD_PN15                                      5
#define RSRFSIGGEN_VAL_BT_LE_ACAD_PN16                                      6
#define RSRFSIGGEN_VAL_BT_LE_ACAD_PN20                                      7
#define RSRFSIGGEN_VAL_BT_LE_ACAD_PN21                                      8
#define RSRFSIGGEN_VAL_BT_LE_ACAD_PN23                                      9
#define RSRFSIGGEN_VAL_BT_LE_ACAD_DLIST                                     10

// RsRFSigGen_rngBTLEAuxPtrClockAccuracy
#define RSRFSIGGEN_VAL_BT_LE_CACC_T500                                      0
#define RSRFSIGGEN_VAL_BT_LE_CACC_T50                                       1

// RsRFSigGen_rngBTLEAuxPtrOffsetUnits
#define RSRFSIGGEN_VAL_BT_LE_AUX_OFFSET_UNIT_U30                            0
#define RSRFSIGGEN_VAL_BT_LE_AUX_OFFSET_UNIT_U300                           1

// RsRFSigGen_rngBTLEAuxPtrAUXPHY
#define RSRFSIGGEN_VAL_BT_LE_AUX_PHY_L1M                                    0
#define RSRFSIGGEN_VAL_BT_LE_AUX_PHY_L2M                                    1
#define RSRFSIGGEN_VAL_BT_LE_AUX_PHY_LCOD                                   2

// RsRFSigGen_rngBTLESyncOffsetUnits
#define RSRFSIGGEN_VAL_BT_LE_SYNC_OFFSET_UNIT_U30                           0
#define RSRFSIGGEN_VAL_BT_LE_SYNC_OFFSET_UNIT_U300                          1

// RsRFSigGen_rngBTLEFeatureSet
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_0                                  0
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_1                                  1
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_2                                  2
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_3                                  3
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_4                                  4
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_5                                  5
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_6                                  6
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_7                                  7
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_8                                  8
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_9                                  9
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_10                                 10
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_11                                 11
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_12                                 12
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_13                                 13
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_14                                 14
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_15                                 15
#define RSRFSIGGEN_VAL_BT_LE_FEATURE_SET_16                                 16

// RsRFSigGen_rngBTLEModulationFormat
#define RSRFSIGGEN_VAL_BT_LE_MFORMAT_L1M                                    0
#define RSRFSIGGEN_VAL_BT_LE_MFORMAT_L2M                                    1
#define RSRFSIGGEN_VAL_BT_LE_MFORMAT_LCOD                                   2

// RsRFSigGen_rngBTLEMainPayloadAdvertisingMode
#define RSRFSIGGEN_VAL_BT_LE_AMODE_NCNS                                     0
#define RSRFSIGGEN_VAL_BT_LE_AMODE_CNS                                      1
#define RSRFSIGGEN_VAL_BT_LE_AMODE_NCS                                      2

// RsRFSigGen_rngBTDTTModulationIndexMode
#define RSRFSIGGEN_VAL_BT_DTT_MIMODE_STANDARD                               0
#define RSRFSIGGEN_VAL_BT_DTT_MIMODE_STABLE                                 1

// RsRFSigGen_rngBTLEChannelSelection
#define RSRFSIGGEN_VAL_BT_LE_CSELECTION_CS1                                 0
#define RSRFSIGGEN_VAL_BT_LE_CSELECTION_CS2                                 1

// RsRFSigGen_rngEUTRAeMTCNarrowbandsHoppingInterval
#define RSRFSIGGEN_VAL_EUTRA_EMTC_NB_HINTERVAL_H1                           0
#define RSRFSIGGEN_VAL_EUTRA_EMTC_NB_HINTERVAL_H2                           1
#define RSRFSIGGEN_VAL_EUTRA_EMTC_NB_HINTERVAL_H4                           2
#define RSRFSIGGEN_VAL_EUTRA_EMTC_NB_HINTERVAL_H5                           3
#define RSRFSIGGEN_VAL_EUTRA_EMTC_NB_HINTERVAL_H8                           4
#define RSRFSIGGEN_VAL_EUTRA_EMTC_NB_HINTERVAL_H10                          5
#define RSRFSIGGEN_VAL_EUTRA_EMTC_NB_HINTERVAL_H16                          6
#define RSRFSIGGEN_VAL_EUTRA_EMTC_NB_HINTERVAL_H20                          7
#define RSRFSIGGEN_VAL_EUTRA_EMTC_NB_HINTERVAL_H40                          8

// RsRFSigGen_rngEUTRAeMTCBitmapSubframes
#define RSRFSIGGEN_VAL_EUTRA_EMTC_BMP_SUBFRAMES_10                          0
#define RSRFSIGGEN_VAL_EUTRA_EMTC_BMP_SUBFRAMES_40                          1

// RsRFSigGen_rngEUTRAeMTCSearchSpaceMPDCCHMax
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_MPD_1                                 0
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_MPD_2                                 1
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_MPD_4                                 2
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_MPD_8                                 3
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_MPD_16                                4
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_MPD_32                                5
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_MPD_64                                6
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_MPD_128                               7
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_MPD_256                               8

// RsRFSigGen_rngEUTRAeMTCSearchSpaceStartSubframe
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_STSF_S1                               0
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_STSF_S1_5                             1
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_STSF_S2                               2
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_STSF_S2_5                             3
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_STSF_S5                               4
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_STSF_S8                               5
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_STSF_S10                              6
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_STSF_S20                              7
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_STSF_S4                               8

// RsRFSigGen_rngEUTRAeMTCSearchSpacePDSCHMax
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_PDSA_NON                              0
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_PDSA_16                               1
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_PDSA_32                               2
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_PDSA_64                               3
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_PDSA_192                              4
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_PDSA_256                              5
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_PDSA_384                              6
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_PDSA_512                              7
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_PDSA_786                              8
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_PDSA_1024                             9
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_PDSA_1536                             10
#define RSRFSIGGEN_VAL_EUTRA_EMTC_SSP_PDSA_2048                             11

// RsRFSigGen_rngEUTRAeMTCDCIUser
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_USER_1                                0
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_USER_2                                1
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_USER_3                                2
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_USER_4                                3
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_USER_PRNTI                            4
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_USER_RARNTI                           5

// RsRFSigGen_rngEUTRAeMTCDCIFormat
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_FORMAT_F3                             0
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_FORMAT_F3A                            1
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_FORMAT_F60A                           2
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_FORMAT_F60B                           3
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_FORMAT_F61A                           4
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_FORMAT_F61B                           5
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_FORMAT_F62                            6

// RsRFSigGen_rngEUTRAeMTCDCISearchSpace
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_SEARCH_SPACE_UE                       0
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_SEARCH_SPACE_T1CM                     1
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_SEARCH_SPACE_T2CM                     2
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_SEARCH_SPACE_T0CM                     3

// RsRFSigGen_rngEUTRAeMTCAllocationContentType
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_CONTENT_TYPE_MPD1                   0
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_CONTENT_TYPE_MPD2                   1
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_CONTENT_TYPE_PSIB                   2
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_CONTENT_TYPE_PDSCH                  3
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_CONTENT_TYPE_PBCH                   4

// RsRFSigGen_rngEUTRAeMTCAllocationModulation
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_MODULATION_QAM16                    0
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_MODULATION_QPSK                     1

// RsRFSigGen_rngEUTRANIOTAllocationDataSource
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_USER1                   0
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_USER2                   1
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_USER3                   2
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_USER4                   3
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_PN9                     4
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_PN11                    5
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_PN15                    6
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_PN16                    7
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_PN20                    8
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_PN21                    9
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_PN23                    10
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_PATTERN                 11
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_DLIST                   12
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_ZERO                    13
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_ONE                     14
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_MIB                     15
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_SIB1NB                  16
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_PRNTI                   17
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_DATA_SOURCE_RARNTI                  18

// RsRFSigGen_rngEUTRAeMTCPDSCHPrecodingScheme
#define RSRFSIGGEN_VAL_EUTRA_EMTC_PRECODING_SCHEME_NONE                     0
#define RSRFSIGGEN_VAL_EUTRA_EMTC_PRECODING_SCHEME_SPM                      1
#define RSRFSIGGEN_VAL_EUTRA_EMTC_PRECODING_SCHEME_TXD                      2
#define RSRFSIGGEN_VAL_EUTRA_EMTC_PRECODING_SCHEME_BF                       3

// RsRFSigGen_rngEUTRAeMTCDCIFormat61ABMode
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_FORMAT61AB_MODE_STD                   0
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_FORMAT61AB_MODE_PRACH                 1

// RsRFSigGen_rngEUTRAeMTCAllocationDataSource
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_USER1                   0
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_USER2                   1
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_USER3                   2
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_USER4                   3
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_PN9                     4
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_PN11                    5
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_PN15                    6
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_PN16                    7
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_PN20                    8
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_PN21                    9
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_PN23                    10
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_PATTERN                 11
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_DLIST                   12
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_ZERO                    13
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_ONE                     14
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_MIB                     15
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_SIB1NB                  16
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_PRNTI                   17
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_RARNTI                  18
#define RSRFSIGGEN_VAL_EUTRA_EMTC_ALLOC_DATA_SOURCE_SIBB                    19

// RsRFSigGen_rngEUTRANIOTAllocationStartSymbol
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_START_SYMBOL_0                      0
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_START_SYMBOL_1                      1
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_START_SYMBOL_2                      2
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_START_SYMBOL_3                      3

// RsRFSigGen_rngEUTRANIOTAllocationModulation
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_MODULATION_QPSK                     0

// RsRFSigGen_rngEUTRANIOTAllocationContentType
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_CONTENT_TYPE_NPBCH                  0
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_CONTENT_TYPE_NSIB                   1
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_CONTENT_TYPE_NPDCCH                 2
#define RSRFSIGGEN_VAL_EUTRA_NIOT_ALLOC_CONTENT_TYPE_NPDSCH                 3

// RsRFSigGen_rngEUTRANIOTNPBCHPrecodingScheme
#define RSRFSIGGEN_VAL_EUTRA_NIOT_PRECODING_SCHEME_NONE                     0
#define RSRFSIGGEN_VAL_EUTRA_NIOT_PRECODING_SCHEME_TXD                      1

// RsRFSigGen_rngEUTRADLLAACell
#define RSRFSIGGEN_VAL_EUTRA_LAA_CELL_NONE                                  0
#define RSRFSIGGEN_VAL_EUTRA_LAA_CELL_SC1                                   1
#define RSRFSIGGEN_VAL_EUTRA_LAA_CELL_SC2                                   2
#define RSRFSIGGEN_VAL_EUTRA_LAA_CELL_SC3                                   3
#define RSRFSIGGEN_VAL_EUTRA_LAA_CELL_SC4                                   4

// RsRFSigGen_rngEUTRADLLAAStartingSymbol
#define RSRFSIGGEN_VAL_EUTRA_DL_LAA_START_SLOT_FIRST                        0
#define RSRFSIGGEN_VAL_EUTRA_DL_LAA_START_SLOT_SECOND                       1

// RsRFSigGen_rngEUTRADLLAANumberOfEndingSymbols
#define RSRFSIGGEN_VAL_EUTRA_DL_LAA_LAST_SYMB_SY3                           0
#define RSRFSIGGEN_VAL_EUTRA_DL_LAA_LAST_SYMB_SY6                           1
#define RSRFSIGGEN_VAL_EUTRA_DL_LAA_LAST_SYMB_SY9                           2
#define RSRFSIGGEN_VAL_EUTRA_DL_LAA_LAST_SYMB_SY10                          3
#define RSRFSIGGEN_VAL_EUTRA_DL_LAA_LAST_SYMB_SY11                          4
#define RSRFSIGGEN_VAL_EUTRA_DL_LAA_LAST_SYMB_SY12                          5
#define RSRFSIGGEN_VAL_EUTRA_DL_LAA_LAST_SYMB_SY14                          6

// RsRFSigGen_rngEUTRADLLAADCI1CMode
#define RSRFSIGGEN_VAL_EUTRA_DL_LAA_DCI_1C_MODE_MANUAL                      0
#define RSRFSIGGEN_VAL_EUTRA_DL_LAA_DCI_1C_MODE_N1                          1
#define RSRFSIGGEN_VAL_EUTRA_DL_LAA_DCI_1C_MODE_N                           2
#define RSRFSIGGEN_VAL_EUTRA_DL_LAA_DCI_1C_MODE_N1N                         3

// RsRFSigGen_rngEUTRADLLAAEPDCCHFormat
#define RSRFSIGGEN_VAL_EUTRA_DL_LAA_EPDCCH_FORMAT_F2                        0
#define RSRFSIGGEN_VAL_EUTRA_DL_LAA_EPDCCH_FORMAT_F3                        1

// RsRFSigGen_rngEUTRADLDRSPeriodicity
#define RSRFSIGGEN_VAL_EUTRA_DL_DRS_PERIODICITY_P40                         0
#define RSRFSIGGEN_VAL_EUTRA_DL_DRS_PERIODICITY_P80                         1
#define RSRFSIGGEN_VAL_EUTRA_DL_DRS_PERIODICITY_P160                        2

// RsRFSigGen_rngEUTRADLDRSDuration
#define RSRFSIGGEN_VAL_EUTRA_DL_DRS_DURATION_DUR1                           0
#define RSRFSIGGEN_VAL_EUTRA_DL_DRS_DURATION_DUR2                           1
#define RSRFSIGGEN_VAL_EUTRA_DL_DRS_DURATION_DUR3                           2
#define RSRFSIGGEN_VAL_EUTRA_DL_DRS_DURATION_DUR4                           3
#define RSRFSIGGEN_VAL_EUTRA_DL_DRS_DURATION_DUR5                           4

// RsRFSigGen_rngEUTRANIOTSearchSpaceUEMaxRepetitions
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_R1                                   0
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_R2                                   1
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_R4                                   2
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_R8                                   3
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_R16                                  4
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_R32                                  5
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_R64                                  6
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_R128                                 7
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_R256                                 8
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_R512                                 9
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_R1024                                10
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_R2048                                11

// RsRFSigGen_rngCorrFreqOptimizationMode
#define RSRFSIGGEN_VAL_CORRECTION_FREQ_OPTIMIZATION_MODE_FAST               0
#define RSRFSIGGEN_VAL_CORRECTION_FREQ_OPTIMIZATION_MODE_QHT                1
#define RSRFSIGGEN_VAL_CORRECTION_FREQ_OPTIMIZATION_MODE_QHIG               2

// RsRFSigGen_rngCorrFreqBandwidthMode
#define RSRFSIGGEN_VAL_CORRECTION_BW_MODE_AUTO                              0
#define RSRFSIGGEN_VAL_CORRECTION_BW_MODE_MANUAL                            1

// RsRFSigGen_rngSystemConfigurationMultiinstrumentMode
#define RSRFSIGGEN_VAL_SCON_MULTIINSTR_MODE_SLAVE                           0
#define RSRFSIGGEN_VAL_SCON_MULTIINSTR_MODE_MASTER                          1

// RsRFSigGen_rngSystConfMultiinstSync
#define RSRFSIGGEN_VAL_SYST_CONFIG_MULTI_INSTR_SYNC_SYNC                    0
#define RSRFSIGGEN_VAL_SYST_CONFIG_MULTI_INSTR_SYNC_NOSYNC                  1

// RsRFSigGen_rngExtSeqNetworkAddressMode
#define RSRFSIGGEN_VAL_EXTSEQ_ADDR_MODE_AUTO                                0
#define RSRFSIGGEN_VAL_EXTSEQ_ADDR_MODE_STATIC                              1

// RsRFSigGen_rngExtSeqNetworkProtocol
#define RSRFSIGGEN_VAL_EXTSEQ_NETWORK_PROTOCOL_TCP                          0
#define RSRFSIGGEN_VAL_EXTSEQ_NETWORK_PROTOCOL_UDP                          1

// RsRFSigGen_rngExtSeqTriggerDelayUnit
#define RSRFSIGGEN_VAL_EXTSEQ_TRIGGER_DELAY_UNIT_SAMPLE                     0
#define RSRFSIGGEN_VAL_EXTSEQ_TRIGGER_DELAY_UNIT_TIME                       1

// RsRFSigGen_rngExtSeqTriggerSource
#define RSRFSIGGEN_VAL_EXTSEQ_TRIGGER_SOURCE_INTB                           0
#define RSRFSIGGEN_VAL_EXTSEQ_TRIGGER_SOURCE_INTERNAL                       1
#define RSRFSIGGEN_VAL_EXTSEQ_TRIGGER_SOURCE_OBAS                           2
#define RSRFSIGGEN_VAL_EXTSEQ_TRIGGER_SOURCE_EGT1                           3
#define RSRFSIGGEN_VAL_EXTSEQ_TRIGGER_SOURCE_EGT2                           4
#define RSRFSIGGEN_VAL_EXTSEQ_TRIGGER_SOURCE_EGC1                           5
#define RSRFSIGGEN_VAL_EXTSEQ_TRIGGER_SOURCE_EGC2                           6
#define RSRFSIGGEN_VAL_EXTSEQ_TRIGGER_SOURCE_ELTR                           7
#define RSRFSIGGEN_VAL_EXTSEQ_TRIGGER_SOURCE_INTA                           8
#define RSRFSIGGEN_VAL_EXTSEQ_TRIGGER_SOURCE_ELCL                           9
#define RSRFSIGGEN_VAL_EXTSEQ_TRIGGER_SOURCE_BEXT                           10
#define RSRFSIGGEN_VAL_EXTSEQ_TRIGGER_SOURCE_EXT                            11
#define RSRFSIGGEN_VAL_EXTSEQ_TRIGGER_SOURCE_BBSY                           12

// RsRFSigGen_rngExtSeqMarkerMode
#define RSRFSIGGEN_VAL_EXTSEQ_MARKER_MODE_UNCHANGED                         0
#define RSRFSIGGEN_VAL_EXTSEQ_MARKER_MODE_START                             1
#define RSRFSIGGEN_VAL_EXTSEQ_MARKER_MODE_ENTRY                             2
#define RSRFSIGGEN_VAL_EXTSEQ_MARKER_MODE_PULS                              3
#define RSRFSIGGEN_VAL_EXTSEQ_MARKER_MODE_PDW                               4
#define RSRFSIGGEN_VAL_EXTSEQ_MARKER_MODE_READY                             5
#define RSRFSIGGEN_VAL_EXTSEQ_MARKER_MODE_ADW                               6
#define RSRFSIGGEN_VAL_EXTSEQ_MARKER_MODE_LINDEX                            7

// RsRFSigGen_rngExtSeqClockMode
#define RSRFSIGGEN_VAL_EXTSEQ_CLOCK_MODE_SAMPLE                             0
#define RSRFSIGGEN_VAL_EXTSEQ_CLOCK_MODE_MSAMPLE                            1

// RsRFSigGen_rngExtSeqClockSource
#define RSRFSIGGEN_VAL_EXTSEQ_CLOCK_SOURCE_INT                              0
#define RSRFSIGGEN_VAL_EXTSEQ_CLOCK_SOURCE_ELCL                             1
#define RSRFSIGGEN_VAL_EXTSEQ_CLOCK_SOURCE_EXT                              2

// RsRFSigGen_rngExtSeqMode
#define RSRFSIGGEN_VAL_EXTSEQ_MODE_USER                                     0
#define RSRFSIGGEN_VAL_EXTSEQ_MODE_PSEQ                                     1
#define RSRFSIGGEN_VAL_EXTSEQ_MODE_DFIN                                     2
#define RSRFSIGGEN_VAL_EXTSEQ_MODE_RTCI                                     3
#define RSRFSIGGEN_VAL_EXTSEQ_MODE_ASEQ                                     4
#define RSRFSIGGEN_VAL_EXTSEQ_MODE_PLAY                                     5

// RsRFSigGen_rngWLANNFBlRUSelectionContentChannel
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU0                                0
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU1                                1
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU2                                2
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU3                                3
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU4                                4
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU5                                5
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU6                                6
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU7                                7
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU8                                8
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU9                                9
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU10                               10
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU11                               11
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU12                               12
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU13                               13
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU14                               14
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU15                               15
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU18                               16
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU19                               17
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU20                               18
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU21                               19
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU22                               20
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU23                               21
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU24                               22
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU25                               23
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU34                               24
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU35                               25
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU36                               26
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU37                               27
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU38                               28
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU16                               29
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU17                               30
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU26                               31
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU27                               32
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU28                               33
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU29                               34
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU30                               35
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU31                               36
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU32                               37
#define RSRFSIGGEN_VAL_WLANN_RU_SLECTION_RU33                               38

// RsRFSigGen_rngWLANNHELinkDirection
#define RSRFSIGGEN_VAL_WLANN_HE_LINK_DOWN                                   0
#define RSRFSIGGEN_VAL_WLANN_HE_LINK_UP                                     1

// RsRFSigGen_rngWLANNHEGuardInterval
#define RSRFSIGGEN_VAL_WLANN_HE_GUARD_INTERVAL_SHORT                        0
#define RSRFSIGGEN_VAL_WLANN_HE_GUARD_INTERVAL_LONG                         1
#define RSRFSIGGEN_VAL_WLANN_HE_GUARD_INTERVAL_GD08                         2
#define RSRFSIGGEN_VAL_WLANN_HE_GUARD_INTERVAL_GD16                         3
#define RSRFSIGGEN_VAL_WLANN_HE_GUARD_INTERVAL_GD32                         4

// RsRFSigGen_rngWLANNHEPacketExtension
#define RSRFSIGGEN_VAL_WLANN_HE_PE_PE0                                      0
#define RSRFSIGGEN_VAL_WLANN_HE_PE_PE8                                      1
#define RSRFSIGGEN_VAL_WLANN_HE_PE_PE16                                     2
#define RSRFSIGGEN_VAL_WLANN_HE_PE_PE20                                     3

// RsRFSigGen_rngWLANNHEPPDUFormat
#define RSRFSIGGEN_VAL_WLANN_HE_PPDU_FORMAT_SU                              0
#define RSRFSIGGEN_VAL_WLANN_HE_PPDU_FORMAT_MU                              1
#define RSRFSIGGEN_VAL_WLANN_HE_PPDU_FORMAT_EXT                             2
#define RSRFSIGGEN_VAL_WLANN_HE_PPDU_FORMAT_TRIG                            3

// RsRFSigGen_rngWLANNHELTF
#define RSRFSIGGEN_VAL_WLANN_HE_SD32                                        0
#define RSRFSIGGEN_VAL_WLANN_HE_SD64                                        1
#define RSRFSIGGEN_VAL_WLANN_HE_SD128                                       2

// RsRFSigGen_rngEUTRANIOTSearchSpaceUEOffset
#define RSRFSIGGEN_VAL_EUTRA_NIOT_SSOFFSET_O0                               0
#define RSRFSIGGEN_VAL_EUTRA_NIOT_SSOFFSET_O18                              1
#define RSRFSIGGEN_VAL_EUTRA_NIOT_SSOFFSET_O14                              2
#define RSRFSIGGEN_VAL_EUTRA_NIOT_SSOFFSET_O38                              3

// RsRFSigGen_rngEUTRANBIOTSearchSpaceUEStartSubframe
#define RSRFSIGGEN_VAL_EUTRA_NIOT_STSFRAME_S15                              0
#define RSRFSIGGEN_VAL_EUTRA_NIOT_STSFRAME_S2                               1
#define RSRFSIGGEN_VAL_EUTRA_NIOT_STSFRAME_S4                               2
#define RSRFSIGGEN_VAL_EUTRA_NIOT_STSFRAME_S8                               3
#define RSRFSIGGEN_VAL_EUTRA_NIOT_STSFRAME_S16                              4
#define RSRFSIGGEN_VAL_EUTRA_NIOT_STSFRAME_S32                              5
#define RSRFSIGGEN_VAL_EUTRA_NIOT_STSFRAME_S48                              6
#define RSRFSIGGEN_VAL_EUTRA_NIOT_STSFRAME_S64                              7

// RsRFSigGen_rngEUTRANIOTSearchSpaceCommonMaxRepetitionsType1
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE1_R1                             0
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE1_R2                             1
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE1_R4                             2
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE1_R8                             3
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE1_R16                            4
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE1_R32                            5
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE1_R64                            6
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE1_R128                           7
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE1_R256                           8
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE1_R512                           9
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE1_R1024                          10
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE1_R2048                          11

// RsRFSigGen_rngEUTRANIOTSearchSpaceCommonMaxRepetitionsType2
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE2_R1                             0
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE2_R2                             1
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE2_R4                             2
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE2_R8                             3
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE2_R16                            4
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE2_R32                            5
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE2_R64                            6
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE2_R128                           7
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE2_R256                           8
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE2_R512                           9
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE2_R1024                          10
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RMAX_TYPE2_R2048                          11

// RsRFSigGen_rngEUTRANIOTSearchSpaceCommonStartSubframe
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RAND_STSFRAME_S15                         0
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RAND_STSFRAME_S2                          1
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RAND_STSFRAME_S4                          2
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RAND_STSFRAME_S8                          3
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RAND_STSFRAME_S16                         4
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RAND_STSFRAME_S32                         5
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RAND_STSFRAME_S48                         6
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RAND_STSFRAME_S64                         7

// RsRFSigGen_rngEUTRANIOTSearchSpaceCommonOffset
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RAND_SSOFFSET_O0                          0
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RAND_SSOFFSET_O18                         1
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RAND_SSOFFSET_O14                         2
#define RSRFSIGGEN_VAL_EUTRA_NIOT_RAND_SSOFFSET_O38                         3

// RsRFSigGen_rngEUTRANIOTDCIAllocationUser
#define RSRFSIGGEN_VAL_EUTRA_NIOT_DCI_ALLOC_USER_1                          0
#define RSRFSIGGEN_VAL_EUTRA_NIOT_DCI_ALLOC_USER_2                          1
#define RSRFSIGGEN_VAL_EUTRA_NIOT_DCI_ALLOC_USER_3                          2
#define RSRFSIGGEN_VAL_EUTRA_NIOT_DCI_ALLOC_USER_4                          3
#define RSRFSIGGEN_VAL_EUTRA_NIOT_DCI_ALLOC_USER_PRNTI                      4
#define RSRFSIGGEN_VAL_EUTRA_NIOT_DCI_ALLOC_USER_RARNTI                     5

// RsRFSigGen_rngEUTRANIOTDCIAllocationFormat
#define RSRFSIGGEN_VAL_EUTRA_NIOT_DCI_ALLOC_FORMAT_N0                       0
#define RSRFSIGGEN_VAL_EUTRA_NIOT_DCI_ALLOC_FORMAT_N1                       1
#define RSRFSIGGEN_VAL_EUTRA_NIOT_DCI_ALLOC_FORMAT_N2                       2

// RsRFSigGen_rngEUTRANIOTDCISearchSpace
#define RSRFSIGGEN_VAL_EUTRA_NIOT_DCI_ALLOC_SEARCH_SPACE_UE                 0
#define RSRFSIGGEN_VAL_EUTRA_NIOT_DCI_ALLOC_SEARCH_SPACE_T1CM               1
#define RSRFSIGGEN_VAL_EUTRA_NIOT_DCI_ALLOC_SEARCH_SPACE_T2CM               2

// RsRFSigGen_rngEUTRADLNRSNSYNCTxAntenna
#define RSRFSIGGEN_VAL_EUTRA_DL_NSYNC_TX_ANTENNA_NONE                       0
#define RSRFSIGGEN_VAL_EUTRA_DL_NSYNC_TX_ANTENNA_ANT1                       1
#define RSRFSIGGEN_VAL_EUTRA_DL_NSYNC_TX_ANTENNA_ANT2                       2
#define RSRFSIGGEN_VAL_EUTRA_DL_NSYNC_TX_ANTENNA_ALL                        3

// RsRFSigGen_rngEUTRAeMTCDCIMPDCCHSet
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_MPDCCH_SET_MPD1                       0
#define RSRFSIGGEN_VAL_EUTRA_EMTC_DCI_MPDCCH_SET_MPD2                       1

// RsRFSigGen_rngEUTRADLNIOTCarrierAllocationMode
#define RSRFSIGGEN_VAL_EUTRA_DL_CARRIER_NIOT_MODE_INBD                      0
#define RSRFSIGGEN_VAL_EUTRA_DL_CARRIER_NIOT_MODE_GBD                       1
#define RSRFSIGGEN_VAL_EUTRA_DL_CARRIER_NIOT_MODE_ALON                      2

// RsRFSigGen_rngEUTRADLNIOTCarrierAllocationSubframeNumber
#define RSRFSIGGEN_VAL_EUTRA_DL_CARRIER_NIOT_SUBFRAME_NUMBER_10             0
#define RSRFSIGGEN_VAL_EUTRA_DL_CARRIER_NIOT_SUBFRAME_NUMBER_40             1

// RsRFSigGen_rngEUTRAEPDCCHSearchSpaceStartSubframe
#define RSRFSIGGEN_VAL_EUTRA_EPDCCH_SEARCH_START_SUBFRAME_S1                0
#define RSRFSIGGEN_VAL_EUTRA_EPDCCH_SEARCH_START_SUBFRAME_S15               1
#define RSRFSIGGEN_VAL_EUTRA_EPDCCH_SEARCH_START_SUBFRAME_S2                2
#define RSRFSIGGEN_VAL_EUTRA_EPDCCH_SEARCH_START_SUBFRAME_S25               3
#define RSRFSIGGEN_VAL_EUTRA_EPDCCH_SEARCH_START_SUBFRAME_S4                4
#define RSRFSIGGEN_VAL_EUTRA_EPDCCH_SEARCH_START_SUBFRAME_S5                5
#define RSRFSIGGEN_VAL_EUTRA_EPDCCH_SEARCH_START_SUBFRAME_S8                6
#define RSRFSIGGEN_VAL_EUTRA_EPDCCH_SEARCH_START_SUBFRAME_S10               7
#define RSRFSIGGEN_VAL_EUTRA_EPDCCH_SEARCH_START_SUBFRAME_S20               8

// RsRFSigGen_rngEUTRADLMIMONIOTConfiguration
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_MIMO_NIOT_TX1                         0
#define RSRFSIGGEN_VAL_EUTRA_DOWNLINK_MIMO_NIOT_TX2                         1

// RsRFSigGen_rngEUTRAULUENIOTSubcarrierSpacing
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_SCSPACING_S375                    0
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_SCSPACING_S15                     1

// RsRFSigGen_rngEUTRAULUENIOTMode
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_MODE_INBD                         0
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_MODE_GBD                          1
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_MODE_ALON                         2

// RsRFSigGen_rngEUTRAULUENIOTNPUSCHFormat
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_NPUSCH_FORMAT_F1                  0
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_NPUSCH_FORMAT_F2                  1

// RsRFSigGen_rngEUTRAULUENIOTModulation
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_MODULATION_PI2BPSK                0
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_MODULATION_PI4QPSK                1
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_MODULATION_QPSK                   2
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_MODULATION_QAM16                  3

// RsRFSigGen_rngEUTRAULUENIOTRepetitions
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_REPETITIONS_R1                    0
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_REPETITIONS_R2                    1
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_REPETITIONS_R4                    2
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_REPETITIONS_R8                    3
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_REPETITIONS_R16                   4
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_REPETITIONS_R32                   5
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_REPETITIONS_R64                   6
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_REPETITIONS_R128                  7

// RsRFSigGen_rngEUTRAULUENIOTResourceUnitsNumber
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_NRUNITS_RU1                       0
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_NRUNITS_RU2                       1
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_NRUNITS_RU3                       2
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_NRUNITS_RU4                       3
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_NRUNITS_RU5                       4
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_NRUNITS_RU6                       5
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_NRUNITS_RU8                       6
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NIOT_NRUNITS_RU10                      7

// RsRFSigGen_rngEUTRAPRACHNIOTPreambleFormat
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PREAMBLE_FORMAT_0                0
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PREAMBLE_FORMAT_1                1
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PREAMBLE_FORMAT_F0               2
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PREAMBLE_FORMAT_F1               3
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PREAMBLE_FORMAT_F2               4
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PREAMBLE_FORMAT_F0A              5
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PREAMBLE_FORMAT_F1A              6

// RsRFSigGen_rngEUTRAPRACHNIOTPeriodicity
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PERIODICITY_40                   0
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PERIODICITY_80                   1
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PERIODICITY_160                  2
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PERIODICITY_240                  3
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PERIODICITY_320                  4
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PERIODICITY_640                  5
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PERIODICITY_1280                 6
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PERIODICITY_2560                 7
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PERIODICITY_5120                 8
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_PERIODICITY_10240                9

// RsRFSigGen_rngEUTRAPRACHNIOTStartingTime
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_R8                     0
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_R16                    1
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_R32                    2
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_R64                    3
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_R128                   4
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_R256                   5
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_R512                   6
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_R1024                  7
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_10                     8
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_20                     9
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_40                     10
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_80                     11
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_160                    12
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_320                    13
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_640                    14
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_1280                   15
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_2560                   16
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_STARTTIME_5120                   17

// RsRFSigGen_rngEUTRAPRACHNIOTRepetitionsNumber
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R1                   0
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R2                   1
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R4                   2
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R8                   3
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R16                  4
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R32                  5
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R64                  6
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R128                 7
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R192                 8
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R256                 9
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R384                 10
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R512                 11
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R768                 12
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R1024                13
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R1536                14
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R2048                15
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R12                  16
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_REPETITIONS_R24                  17

// RsRFSigGen_rngEUTRAPRACHNIOTSubcarriersNumber
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIERS_12                   0
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIERS_24                   1
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIERS_36                   2
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIERS_48                   3

// RsRFSigGen_rngEUTRAPRACHNIOTSubcarrierOffset
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_0              0
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_2              1
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_12             2
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_18             3
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_24             4
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_34             5
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_36             6
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_6              7
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_42             8
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_48             9
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_54             10
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_60             11
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_72             12
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_78             13
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_84             14
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_90             15
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_102            16
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_NIOT_SUBCARRIER_OFFSET_108            17

// RsRFSigGen_rngEUTRAULUENPRACHMode
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NPRACH_MODE_INBD                       0
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NPRACH_MODE_GBD                        1
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NPRACH_MODE_ALON                       2

// RsRFSigGen_rngEUTRAULUENPRACHRepetitionsNumber
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NPRACH_REPETITIONS_R1                  0
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NPRACH_REPETITIONS_R2                  1
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NPRACH_REPETITIONS_R4                  2
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NPRACH_REPETITIONS_R8                  3
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NPRACH_REPETITIONS_R16                 4
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NPRACH_REPETITIONS_R32                 5
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NPRACH_REPETITIONS_R64                 6
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_NPRACH_REPETITIONS_R128                7

// RsRFSigGen_rngEUTRAULUEeMTCCELevel
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_CELEVEL_CE01                      0
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_CELEVEL_CE23                      1

// RsRFSigGen_rngEUTRAULUEeMTCNarrowbandHoppingInterval
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_HOPPING_H1                        0
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_HOPPING_H2                        1
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_HOPPING_H4                        2
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_HOPPING_H5                        3
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_HOPPING_H8                        4
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_HOPPING_H10                       5
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_HOPPING_H16                       6
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_HOPPING_H20                       7
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_HOPPING_H40                       8

// RsRFSigGen_rngEUTRAULUEeMTCContent
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_CONTENT_PUSCH                     0
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_CONTENT_PUCCH                     1

// RsRFSigGen_rngEUTRAULUEeMTCModulation
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_MODULATION_QPSK                   0
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_MODULATION_QAM16                  1
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_MODULATION_QAM64                  2

// RsRFSigGen_rngEUTRAULUEeMTCFormat
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_FORMAT_F1                         0
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_FORMAT_F1A                        1
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_FORMAT_F1B                        2
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_FORMAT_F2                         3
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_FORMAT_F2A                        4
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_FORMAT_F2B                        5

// RsRFSigGen_rngEUTRAULUEeMTCPUSCHHARQACKMode
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_HARQ_MODE_MUX                     0

// RsRFSigGen_rngEUTRAULUEeMTCRepetitions
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R1                    0
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R2                    1
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R4                    2
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R8                    3
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R16                   4
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R32                   5
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R64                   6
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R128                  7
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R192                  8
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R256                  9
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R384                  10
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R512                  11
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R768                  12
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R1024                 13
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R1536                 14
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R2048                 15
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R12                   16
#define RSRFSIGGEN_VAL_EUTRA_UL_USER_EMTC_REPETITIONS_R24                   17

// RsRFSigGen_rngEUTRAULPRACHeMTCRepetitionsNumber
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_REPETITIONS_R1                   0
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_REPETITIONS_R2                   1
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_REPETITIONS_R4                   2
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_REPETITIONS_R8                   3
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_REPETITIONS_R16                  4
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_REPETITIONS_R32                  5
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_REPETITIONS_R64                  6
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_REPETITIONS_R128                 7

// RsRFSigGen_rngEUTRAULPRACHeMTCStartingSFPeriodicity
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_SSFPERIOD_NONE                   0
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_SSFPERIOD_2                      1
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_SSFPERIOD_4                      2
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_SSFPERIOD_8                      3
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_SSFPERIOD_16                     4
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_SSFPERIOD_32                     5
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_SSFPERIOD_64                     6
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_SSFPERIOD_128                    7
#define RSRFSIGGEN_VAL_EUTRA_UL_PRACH_EMTC_SSFPERIOD_256                    8

// RsRFSigGen_rngOneWebConfigMode
#define RSRFSIGGEN_VAL_ONEWEB_MODE_PREDEFINED                               0
#define RSRFSIGGEN_VAL_ONEWEB_MODE_USER                                     1

// RsRFSigGen_rngOneWebDuplexing
#define RSRFSIGGEN_VAL_ONEWEB_DUPLEX_TDD                                    0
#define RSRFSIGGEN_VAL_ONEWEB_DUPLEX_FDD                                    1

// RsRFSigGen_rngOneWebLinkDirection
#define RSRFSIGGEN_VAL_ONEWEB_LINK_UP                                       0
#define RSRFSIGGEN_VAL_ONEWEB_LINK_DOWN                                     1

// RsRFSigGen_rngOneWebTriggerSource
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_SOURCE_INTB                           0
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_SOURCE_INTERNAL                       1
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_SOURCE_OBAS                           2
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_SOURCE_EGT1                           3
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_SOURCE_EGT2                           4
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_SOURCE_EGC1                           5
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_SOURCE_EGC2                           6
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_SOURCE_ELTR                           7
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_SOURCE_INTA                           8
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_SOURCE_ELCL                           9

// RsRFSigGen_rngOneWebTrgSignalDurationUnit
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_SIGNAL_DURATION_UNIT_SEQ              0
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_SIGNAL_DURATION_UNIT_FRAM             1
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_SIGNAL_DURATION_UNIT_SUBF             2
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_SIGNAL_DURATION_UNIT_SLOT             3
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_SIGNAL_DURATION_UNIT_SAMP             4

// RsRFSigGen_rngOneWebTriggerDelayUnit
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_DELAY_UNIT_SAMPLE                     0
#define RSRFSIGGEN_VAL_ONEWEB_TRIGGER_DELAY_UNIT_TIME                       1

// RsRFSigGen_rngOneWebMarkerMode
#define RSRFSIGGEN_VAL_ONEWEB_MARKER_MODE_RESTART                           0

// RsRFSigGen_rngOneWebClockMode
#define RSRFSIGGEN_VAL_ONEWEB_CLOCK_MODE_SAMPLE                             0

// RsRFSigGen_rngOneWebScheduling
#define RSRFSIGGEN_VAL_ONEWEB_SCHEDULING_MANUAL                             0
#define RSRFSIGGEN_VAL_ONEWEB_SCHEDULING_AUTO                               1
#define RSRFSIGGEN_VAL_ONEWEB_SCHEDULING_ASEQ                               2

// RsRFSigGen_rngOneWebBandwidth
#define RSRFSIGGEN_VAL_ONEWEB_BW_20                                         0
#define RSRFSIGGEN_VAL_ONEWEB_BW_250                                        1
#define RSRFSIGGEN_VAL_ONEWEB_BW_USER                                       2

// RsRFSigGen_rngOneWebMIMOConfiguration
#define RSRFSIGGEN_VAL_MIMO_CONFIGURATION_TX1                               0
#define RSRFSIGGEN_VAL_MIMO_CONFIGURATION_TX2                               1
#define RSRFSIGGEN_VAL_MIMO_CONFIGURATION_TX4                               2
#define RSRFSIGGEN_VAL_MIMO_CONFIGURATION_SIBF                              3

// RsRFSigGen_rngOneWebMIMOAntenna
#define RSRFSIGGEN_VAL_ONEWEB_MIMO_ANTENNA_ANT1                             0
#define RSRFSIGGEN_VAL_ONEWEB_MIMO_ANTENNA_ANT2                             1
#define RSRFSIGGEN_VAL_ONEWEB_MIMO_ANTENNA_ANT3                             2
#define RSRFSIGGEN_VAL_ONEWEB_MIMO_ANTENNA_ANT4                             3

// RsRFSigGen_rngOneWebMIMOMapCoor
#define RSRFSIGGEN_VAL_ONEWEB_MIMO_MAP_COOR_CARTESIAN                       0
#define RSRFSIGGEN_VAL_ONEWEB_MIMO_MAP_COOR_CYLINDRICAL                     1

// RsRFSigGen_rngOneWebMIMOBBMaps
#define RSRFSIGGEN_VAL_ONEWEB_MIMO_BB_PC                                    0
#define RSRFSIGGEN_VAL_ONEWEB_MIMO_BB_SC1                                   1

// RsRFSigGen_rngSystemFadingConfiguration
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_FAAFBNONE                       0
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_FANFBB                          1
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_FAAFBB                          2
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_FAAFBA                          3
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_FABFBB                          4
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_FAABFBN                         5
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_FANFBAB                         6
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_FAABFBAB                        7
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO1X2                         8
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X2                         9
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X3                         10
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X4                         11
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO3X2                         12
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO3X3                         13
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO3X4                         14
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO4X2                         15
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO4X3                         16
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO4X4                         17
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO1X8                         18
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO8X1                         19
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X8                         20
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO8X2                         21
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X1                         22
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X1X2                       23
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X2X1                       24
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X1X3                       25
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X1X4                       26
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X2X2                       27
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO1X3                         28
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO3X1                         29
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO1X4                         30
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO4X1                         31
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO3X1X2                       32
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO3X2X1                       33
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO4X1X2                       34
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO3X2X2                       35
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO4X2X2                       36
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO4X2X1                       37
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_SISO2X1X1                       38
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_SISO3X1X1                       39
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_SISO4X1X1                       40
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_SISO5X1X1                       41
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_SISO6X1X1                       42
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_SISO7X1X1                       43
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_SISO8X1X1                       44
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X2X4                       45
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X4X2                       46
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X2X3                       47
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X3X1                       48
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X3X2                       49
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X4X1                       50
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO4X8                         51
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO8X4                         52
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X4X4                       53
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X3X3                       54
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X3X4                       55
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO2X4X3                       56
#define RSRFSIGGEN_VAL_SYSTEM_CONFIG_FADING_MIMO8X8                         57

// RsRFSigGen_rngSystemUserInterfaceLock
#define RSRFSIGGEN_VAL_SYSTEM_ULOCK_TOFF                                    0
#define RSRFSIGGEN_VAL_SYSTEM_ULOCK_ENABLED                                 1
#define RSRFSIGGEN_VAL_SYSTEM_ULOCK_DISABLED                                2
#define RSRFSIGGEN_VAL_SYSTEM_ULOCK_DONLY                                   3
#define RSRFSIGGEN_VAL_SYSTEM_ULOCK_VNCONLY                                 4

// RsRFSigGen_rngAWGNPowersForOutput
#define RSRFSIGGEN_VAL_AWGN_OUTPUT_RFA                                      0
#define RSRFSIGGEN_VAL_AWGN_OUTPUT_RFB                                      1
#define RSRFSIGGEN_VAL_AWGN_OUTPUT_IQOUT1                                   2
#define RSRFSIGGEN_VAL_AWGN_OUTPUT_IQOUT2                                   3
#define RSRFSIGGEN_VAL_AWGN_OUTPUT_BBMM1                                    4
#define RSRFSIGGEN_VAL_AWGN_OUTPUT_BBMM2                                    5
#define RSRFSIGGEN_VAL_AWGN_OUTPUT_FADER1                                   6
#define RSRFSIGGEN_VAL_AWGN_OUTPUT_FADER2                                   7
#define RSRFSIGGEN_VAL_AWGN_OUTPUT_FADER3                                   8
#define RSRFSIGGEN_VAL_AWGN_OUTPUT_FADER4                                   9

// RsRFSigGen_rngAWGNReferenceMode
#define RSRFSIGGEN_VAL_AWGN_REF_MODE_CARRIER                                0
#define RSRFSIGGEN_VAL_AWGN_REF_MODE_NOISE                                  1

// RsRFSigGen_rngLevelSweepAttenuatorMode
#define RSRFSIGGEN_VAL_SWEEP_AMODE_NORMAL                                   0
#define RSRFSIGGEN_VAL_SWEEP_AMODE_HPOWER                                   1

// RsRFSigGen_rngExternalIQCheckConnection
#define RSRFSIGGEN_VAL_FAILED                                               0
#define RSRFSIGGEN_VAL_PASSED                                               1
#define RSRFSIGGEN_VAL_UNUSED                                               2

// RsRFSigGen_rngBBINDigitalInterface
#define RSRFSIGGEN_VAL_DIGITAL_INTERFACE_HSDIN                              0
#define RSRFSIGGEN_VAL_DIGITAL_INTERFACE_DIN                                1

// RsRFSigGen_rngBBINMappedChannel
#define RSRFSIGGEN_VAL_CHANNEL_MAP_NONE                                     0
#define RSRFSIGGEN_VAL_CHANNEL_MAP_A                                        1
#define RSRFSIGGEN_VAL_CHANNEL_MAP_B                                        2
#define RSRFSIGGEN_VAL_CHANNEL_MAP_C                                        3
#define RSRFSIGGEN_VAL_CHANNEL_MAP_D                                        4
#define RSRFSIGGEN_VAL_CHANNEL_MAP_E                                        5
#define RSRFSIGGEN_VAL_CHANNEL_MAP_F                                        6
#define RSRFSIGGEN_VAL_CHANNEL_MAP_G                                        7
#define RSRFSIGGEN_VAL_CHANNEL_MAP_H                                        8

// RsRFSigGen_rngOneWebModulation
#define RSRFSIGGEN_VAL_ONEWEB_MODULATION_QPSK                               0
#define RSRFSIGGEN_VAL_ONEWEB_MODULATION_PSK8                               1
#define RSRFSIGGEN_VAL_ONEWEB_MODULATION_QAM16                              2
#define RSRFSIGGEN_VAL_ONEWEB_MODULATION_QAM64                              3
#define RSRFSIGGEN_VAL_ONEWEB_MODULATION_IQFILE                             4
#define RSRFSIGGEN_VAL_ONEWEB_MODULATION_QAM256                             5
#define RSRFSIGGEN_VAL_ONEWEB_MODULATION_PI2BPSK                            6
#define RSRFSIGGEN_VAL_ONEWEB_MODULATION_PI4QPSK                            7

// RsRFSigGen_rngOneWebDataSource
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_ZERO                              0
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_ONE                               1
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_PATTERN                           2
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_PN9                               3
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_PN11                              4
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_PN15                              5
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_PN16                              6
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_PN20                              7
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_PN21                              8
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_PN23                              9
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_DLIST                             10
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_USER1                             11
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_USER2                             12
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_USER3                             13
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_USER4                             14
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_MIB                               15
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_MCCH                              16
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_MTCH                              17
#define RSRFSIGGEN_VAL_ONEWEB_DATA_SOURCE_SIB1NB                            18

// RsRFSigGen_rngOneWebClippingMode
#define RSRFSIGGEN_VAL_ONEWEB_CLIPPING_VECTOR                               0
#define RSRFSIGGEN_VAL_ONEWEB_CLIPPING_SCALAR                               1

// RsRFSigGen_rngOneWebContentType
#define RSRFSIGGEN_VAL_ONEWEB_CONTENT_TYPE_PDSCH                            0
#define RSRFSIGGEN_VAL_ONEWEB_CONTENT_TYPE_PBCH                             1
#define RSRFSIGGEN_VAL_ONEWEB_CONTENT_TYPE_PDCCH                            2
#define RSRFSIGGEN_VAL_ONEWEB_CONTENT_TYPE_PUSCH                            3
#define RSRFSIGGEN_VAL_ONEWEB_CONTENT_TYPE_PUCCH                            4
#define RSRFSIGGEN_VAL_ONEWEB_CONTENT_TYPE_PUACH                            5
#define RSRFSIGGEN_VAL_ONEWEB_CONTENT_TYPE_PRACH                            6
#define RSRFSIGGEN_VAL_ONEWEB_CONTENT_TYPE_EPD1                             7
#define RSRFSIGGEN_VAL_ONEWEB_CONTENT_TYPE_EPD2                             8
#define RSRFSIGGEN_VAL_ONEWEB_CONTENT_TYPE_NPBCH                            9
#define RSRFSIGGEN_VAL_ONEWEB_CONTENT_TYPE_NSIB                             10
#define RSRFSIGGEN_VAL_ONEWEB_CONTENT_TYPE_NPDCCH                           11
#define RSRFSIGGEN_VAL_ONEWEB_CONTENT_TYPE_NPDSCH                           12
#define RSRFSIGGEN_VAL_ONEWEB_CONTENT_TYPE_EMTC                             13
#define RSRFSIGGEN_VAL_ONEWEB_CONTENT_TYPE_NIOT                             14

// RsRFSigGen_rngOneWebULUEMode
#define RSRFSIGGEN_VAL_ONEWEB_UL_UE_MODE_STD                                0
#define RSRFSIGGEN_VAL_ONEWEB_UL_UE_MODE_PRACH                              1

// RsRFSigGen_rngOneWebAllocationFormat
#define RSRFSIGGEN_VAL_ONEWEB_ALL_FORMAT_F1                                 0
#define RSRFSIGGEN_VAL_ONEWEB_ALL_FORMAT_F1A                                1
#define RSRFSIGGEN_VAL_ONEWEB_ALL_FORMAT_F1B                                2
#define RSRFSIGGEN_VAL_ONEWEB_ALL_FORMAT_F2                                 3
#define RSRFSIGGEN_VAL_ONEWEB_ALL_FORMAT_F2A                                4
#define RSRFSIGGEN_VAL_ONEWEB_ALL_FORMAT_F2B                                5
#define RSRFSIGGEN_VAL_ONEWEB_ALL_FORMAT_F3                                 6

// RsRFSigGen_rngOneWebPDCCHFormat
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_FORMAT_VAR                              0
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_FORMAT_FM1                              1
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_FORMAT_F0                               2
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_FORMAT_F1                               3
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_FORMAT_F2                               4
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_FORMAT_F3                               5

// RsRFSigGen_rngOneWebCyclicPrefix
#define RSRFSIGGEN_VAL_ONEWEB_CYCLIC_PREFIX_NORMAL                          0
#define RSRFSIGGEN_VAL_ONEWEB_CYCLIC_PREFIX_EXTENDED                        1
#define RSRFSIGGEN_VAL_ONEWEB_CYCLIC_PREFIX_USER                            2

// RsRFSigGen_rngOneWebHARQMode
#define RSRFSIGGEN_VAL_OW_HARQ_MUX                                          0
#define RSRFSIGGEN_VAL_OW_HARQ_BUNDLING                                     1

// RsRFSigGen_rngOneWebPDCCHDCIFormat
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_DCI_FORMAT_F0                           0
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_DCI_FORMAT_F1A                          1
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_DCI_FORMAT_F1OW                         2
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_DCI_FORMAT_F2OW                         3
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_DCI_FORMAT_F3                           4
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_DCI_FORMAT_F3A                          5
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_DCI_FORMAT_F3OW                         6

// RsRFSigGen_rngOneWebPDCCHFormat1a
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_FORMAT1A_PDSCH                          0
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_FORMAT1A_PRACH                          1

// RsRFSigGen_rngOneWebPDCCHItemUser
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_ITEM_USER_USER1                         0
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_ITEM_USER_USER2                         1
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_ITEM_USER_USER3                         2
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_ITEM_USER_USER4                         3
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_ITEM_USER_PRNTI                         4
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_ITEM_USER_SIRNTI                        5
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_ITEM_USER_RARNTI                        6
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_ITEM_USER_NONE                          7

// RsRFSigGen_rngOneWebPDCCHSearchSpace
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_SEARCH_SPACE_COMMON                     0
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_SEARCH_SPACE_UE                         1
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_SEARCH_SPACE_OFF                        2
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_SEARCH_SPACE_AUTO                       3

// RsRFSigGen_rngOneWebULBw
#define RSRFSIGGEN_VAL_ONEWEB_UL_BW_USER                                    0
#define RSRFSIGGEN_VAL_ONEWEB_UL_BW_BW1_25                                  1
#define RSRFSIGGEN_VAL_ONEWEB_UL_BW_BW1_40                                  2
#define RSRFSIGGEN_VAL_ONEWEB_UL_BW_BW2_50                                  3
#define RSRFSIGGEN_VAL_ONEWEB_UL_BW_BW3_00                                  4
#define RSRFSIGGEN_VAL_ONEWEB_UL_BW_BW5_00                                  5
#define RSRFSIGGEN_VAL_ONEWEB_UL_BW_BW10_00                                 6
#define RSRFSIGGEN_VAL_ONEWEB_UL_BW_BW15_00                                 7
#define RSRFSIGGEN_VAL_ONEWEB_UL_BW_BW20_00                                 8
#define RSRFSIGGEN_VAL_ONEWEB_UL_BW_BW0_20                                  9

// RsRFSigGen_rngOneWebFrameUECategory
#define RSRFSIGGEN_VAL_ONEWEB_FRAME_UE_CAT_C1                               1
#define RSRFSIGGEN_VAL_ONEWEB_FRAME_UE_CAT_C2                               2
#define RSRFSIGGEN_VAL_ONEWEB_FRAME_UE_CAT_C3                               3
#define RSRFSIGGEN_VAL_ONEWEB_FRAME_UE_CAT_C4                               4
#define RSRFSIGGEN_VAL_ONEWEB_FRAME_UE_CAT_C5                               5

// RsRFSigGen_rngOneWebPUACHMode
#define RSRFSIGGEN_VAL_ONEWEB_PUACH_MODE_COMBINED                           0
#define RSRFSIGGEN_VAL_ONEWEB_PUACH_MODE_ULSCHONLY                          1
#define RSRFSIGGEN_VAL_ONEWEB_PUACH_MODE_UCIONLY                            2

// RsRFSigGen_rngOneWebFrameUserTx
#define RSRFSIGGEN_VAL_ONEWEB_FRAME_USER_1OW                                0
#define RSRFSIGGEN_VAL_ONEWEB_FRAME_USER_2OW                                1
#define RSRFSIGGEN_VAL_ONEWEB_FRAME_USER_3OW                                2

// RsRFSigGen_rngOneWebPDCCHItemType
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_ITEM_TYPE_PDCCH                         0
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_ITEM_TYPE_EPD1                          1
#define RSRFSIGGEN_VAL_ONEWEB_PDCCH_ITEM_TYPE_EPD2                          2

// RsRFSigGen_rngOneWebULContentType
#define RSRFSIGGEN_VAL_ONEWEB_UL_CONTENT_TYPE_PUSCH                         0
#define RSRFSIGGEN_VAL_ONEWEB_UL_CONTENT_TYPE_PUCCH                         1
#define RSRFSIGGEN_VAL_ONEWEB_UL_CONTENT_TYPE_PUACH                         2

// RsRFSigGen_rngV5GModulation
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_MODULATION_QPSK                         0
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_MODULATION_QAM16                        1
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_MODULATION_QAM64                        2
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_MODULATION_QAM256                       3

// RsRFSigGen_rngV5GDLSubframeDataSource
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_DATA_SOURCE_USER1                       1
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_DATA_SOURCE_USER2                       2
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_DATA_SOURCE_USER3                       3
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_DATA_SOURCE_USER4                       4
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_DATA_SOURCE_MIB                         5
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_DATA_SOURCE_XPDCCH                      6

// RsRFSigGen_rngV5GDLSubframeAllocationContentType
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_CONTENT_TYPE_XPDSCH                     0
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_CONTENT_TYPE_XPBCH                      1
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_CONTENT_TYPE_XPDCCH                     2
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_CONTENT_TYPE_CSI                        3

// RsRFSigGen_rngV5GULFrameUEMode
#define RSRFSIGGEN_VAL_V5G_UL_UE_MODE_STANDARD                              0
#define RSRFSIGGEN_VAL_V5G_UL_UE_MODE_PRACH                                 1

// RsRFSigGen_rngV5GULSubframeAllocationContent
#define RSRFSIGGEN_VAL_V5G_UL_SUBFRAME_CONTENT_TYPE_XPUCCH                  0
#define RSRFSIGGEN_VAL_V5G_UL_SUBFRAME_CONTENT_TYPE_XPUSCH                  1

// RsRFSigGen_rngV5GSubframePrecodingScheme
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_PRECODING_SCHEME_NONE                   0
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_PRECODING_SCHEME_SMUX                   1
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_PRECODING_SCHEME_TXD                    2

// RsRFSigGen_rngV5GULFrameUECellsChannelCodingAndMultiplexingMode
#define RSRFSIGGEN_VAL_V5G_UL_UE_CHANNEL_CODING_MODE_COMBINED               0
#define RSRFSIGGEN_VAL_V5G_UL_UE_CHANNEL_CODING_MODE_UL_SCH_ONLY            1
#define RSRFSIGGEN_VAL_V5G_UL_UE_CHANNEL_CODING_MODE_UCI_ONLY               2

// RsRFSigGen_rngV5GDLFramexPDCCHDummyCCExREGs
#define RSRFSIGGEN_VAL_V5G_XPDCCH_DYMMY_CCE_XREGS_DATA                      0
#define RSRFSIGGEN_VAL_V5G_XPDCCH_DYMMY_CCE_XREGS_DTX                       1

// RsRFSigGen_rngV5GDLFramexPDCCHDCIFormat
#define RSRFSIGGEN_VAL_V5G_XPDCCH_DCI_FORMAT_A1                             0
#define RSRFSIGGEN_VAL_V5G_XPDCCH_DCI_FORMAT_A2                             1
#define RSRFSIGGEN_VAL_V5G_XPDCCH_DCI_FORMAT_B1                             2
#define RSRFSIGGEN_VAL_V5G_XPDCCH_DCI_FORMAT_B2                             3

// RsRFSigGen_rngV5GxPDSCHScheduling
#define RSRFSIGGEN_VAL_XPDSCH_SCHEDULING_MANUAL                             0
#define RSRFSIGGEN_VAL_XPDSCH_SCHEDULING_AUTO                               1

// RsRFSigGen_rngV5GDLFramexPDCCHDCIUser
#define RSRFSIGGEN_VAL_V5G_XPDCCH_DCI_USER_NONE                             1
#define RSRFSIGGEN_VAL_V5G_XPDCCH_DCI_USER_1                                2
#define RSRFSIGGEN_VAL_V5G_XPDCCH_DCI_USER_2                                3
#define RSRFSIGGEN_VAL_V5G_XPDCCH_DCI_USER_3                                4
#define RSRFSIGGEN_VAL_V5G_XPDCCH_DCI_USER_4                                0

// RsRFSigGen_rngV5GTriggerSignalDurationUnit
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SIGNAL_DURATION_UNIT_SEQUENCE            0
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SIGNAL_DURATION_UNIT_FRAME               1
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SIGNAL_DURATION_UNIT_SUBFRAME            2
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SIGNAL_DURATION_UNIT_SLOT                3
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SIGNAL_DURATION_UNIT_SAMPLE              4

// RsRFSigGen_rngV5GDLSubframeAllocationReferenceSignalAPConfiguration
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_AP_CONFIGURATION_A00                    0
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_AP_CONFIGURATION_A01                    1
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_AP_CONFIGURATION_A10                    2
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_AP_CONFIGURATION_A11                    3

// RsRFSigGen_rngV5GDLFramexPDCCHDCISRSRequest
#define RSRFSIGGEN_VAL_V5G_SRS_REQUEST_NONE                                 0
#define RSRFSIGGEN_VAL_V5G_SRS_REQUEST_C0                                   1
#define RSRFSIGGEN_VAL_V5G_SRS_REQUEST_C1                                   2
#define RSRFSIGGEN_VAL_V5G_SRS_REQUEST_C2                                   3

// RsRFSigGen_rngV5GULFrameUECellsTransmissionMode
#define RSRFSIGGEN_VAL_V5G_UL_UE_TX_MODE_M1                                 1
#define RSRFSIGGEN_VAL_V5G_UL_UE_TX_MODE_M2                                 2

// RsRFSigGen_rngV5GMarkerMode
#define RSRFSIGGEN_VAL_V5G_MARKER_MODE_RESTART                              0

// RsRFSigGen_rngV5GDLSubframeAllocationPrecodingAntennaPorts
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP0                       0
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP1                       1
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP2                       2
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP3                       3
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP4                       4
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP5                       5
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP6                       6
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP7                       7
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP8                       8
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP9                       9
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP10                      10
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP11                      11
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP12                      12
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP13                      13
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP14                      14
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP15                      15
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP0_1                     16
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP2_3                     17
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP4_5                     18
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP6_7                     19
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP8_9                     20
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP8_12                    21
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP9_13                    22
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP10_11                   23
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP10_14                   24
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP11_15                   25
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP12_13                   26
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP14_15                   27
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP107                     28
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP109                     29
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_ANTENNA_PORTS_AP107_109                 30

// RsRFSigGen_rngV5GDLFrameUserConfigurationMappingCoordinates
#define RSRFSIGGEN_VAL_MAPPING_COORDINATES_CARTESIAN                        0
#define RSRFSIGGEN_VAL_MAPPING_COORDINATES_CYLINDRICAL                      1

// RsRFSigGen_rngV5GDLFrameUserTxMode
#define RSRFSIGGEN_VAL_USER_TX_MODE_M1                                      1
#define RSRFSIGGEN_VAL_USER_TX_MODE_M2                                      2
#define RSRFSIGGEN_VAL_USER_TX_MODE_M3                                      3

// RsRFSigGen_rngV5GClockMode
#define RSRFSIGGEN_VAL_V5G_CLOCK_MODE_SAMPLE                                0

// RsRFSigGen_rngV5GTriggerSource
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SOURCE_INTERNAL                          0
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SOURCE_INTERNALA                         1
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SOURCE_INTERNALB                         2
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SOURCE_EGT1                              3
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SOURCE_EGT2                              4
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SOURCE_EGC1                              5
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SOURCE_EGC2                              6
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SOURCE_ELT                               7
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SOURCE_ELC                               8
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SOURCE_OBAS                              9
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SOURCE_BEXT                              10
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SOURCE_EXT                               11
#define RSRFSIGGEN_VAL_V5G_TRIGGER_SOURCE_BBSY                              12

// RsRFSigGen_rngV5GExternalTriggerDelayUnit
#define RSRFSIGGEN_VAL_V5G_EXT_TRIG_DELAY_UNIT_SAMPLE                       0
#define RSRFSIGGEN_VAL_V5G_EXT_TRIG_DELAY_UNIT_TIME                         1

// RsRFSigGen_rngV5GClockSource
#define RSRFSIGGEN_VAL_CLOCK_SOURCE_EXTERNAL                                1

// RsRFSigGen_rngV5GDLSignalBRSNumberofAntennaPorts
#define RSRFSIGGEN_VAL_V5G_DL_BRS_ANTENNA_PORTS_1                           0
#define RSRFSIGGEN_VAL_V5G_DL_BRS_ANTENNA_PORTS_2                           1
#define RSRFSIGGEN_VAL_V5G_DL_BRS_ANTENNA_PORTS_4                           2
#define RSRFSIGGEN_VAL_V5G_DL_BRS_ANTENNA_PORTS_8                           3

// RsRFSigGen_rngV5GDLSignalBRSTransmissionPeriod
#define RSRFSIGGEN_VAL_V5G_BRS_TRANSMISSION_PERIOD_1_SLOT                   0
#define RSRFSIGGEN_VAL_V5G_BRS_TRANSMISSION_PERIOD_1_SUBFRAME               1
#define RSRFSIGGEN_VAL_V5G_BRS_TRANSMISSION_PERIOD_2_SUBFRAME               2
#define RSRFSIGGEN_VAL_V5G_BRS_TRANSMISSION_PERIOD_4_SUBFRAME               3

// RsRFSigGen_rngV5GDLSubframeAllocationReferenceSignalDMRSN_IDSource
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_N_ID_SOURCE_CELL                        0
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_N_ID_SOURCE_DMRS                        1

// RsRFSigGen_rngV5GDLSubframeAllocationReferenceSignalPCRSN_IDSource
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_N_ID_SOURCE_PCRS                        1

// RsRFSigGen_rngV5GDLFramexPDCCHDCILastxPUSCHSymbol
#define RSRFSIGGEN_VAL_V5G_LAST_XPUSCH_SYMBOL_12                            12
#define RSRFSIGGEN_VAL_V5G_LAST_XPUSCH_SYMBOL_13                            13
#define RSRFSIGGEN_VAL_V5G_LAST_XPUSCH_SYMBOL_14                            14

// RsRFSigGen_rngV5GDLFramexPDCCHDCICSIBSIBRIRequest
#define RSRFSIGGEN_VAL_V5G_CSI_BSI_BRI_REQUEST_NONE                         0
#define RSRFSIGGEN_VAL_V5G_CSI_BSI_BRI_REQUEST_CSI_RS                       1

// RsRFSigGen_rngV5GDLFramexPDCCHDCICSI_RS_BRRS_Symbol
#define RSRFSIGGEN_VAL_V5G_CSI_RS_BRRS_SYMBOL_12                            0
#define RSRFSIGGEN_VAL_V5G_CSI_RS_BRRS_SYMBOL_13                            1
#define RSRFSIGGEN_VAL_V5G_CSI_RS_BRRS_SYMBOL_12_13                         2

// RsRFSigGen_rngV5GDLFramexPDCCHDCICSI_RS_BRRS_Process
#define RSRFSIGGEN_VAL_V5G_CSI_RS_BRRS_PROCESS_0                            0
#define RSRFSIGGEN_VAL_V5G_CSI_RS_BRRS_PROCESS_1                            1
#define RSRFSIGGEN_VAL_V5G_CSI_RS_BRRS_PROCESS_2                            2
#define RSRFSIGGEN_VAL_V5G_CSI_RS_BRRS_PROCESS_3                            3

// RsRFSigGen_rngV5GDLFramexPDCCHDCISRSSymbol
#define RSRFSIGGEN_VAL_V5G_SRS_SYMBOL_12                                    12
#define RSRFSIGGEN_VAL_V5G_SRS_SYMBOL_13                                    13

// RsRFSigGen_rngV5GDLFramexPDCCHDCIxPDSCHStart
#define RSRFSIGGEN_VAL_V5G_XPDSCH_START_S1                                  1
#define RSRFSIGGEN_VAL_V5G_XPDSCH_START_S2                                  2

// RsRFSigGen_rngV5GDLFramexPDCCHDCIxPDSCHEnd
#define RSRFSIGGEN_VAL_V5G_XPDSCH_END_S11                                   11
#define RSRFSIGGEN_VAL_V5G_XPDSCH_END_S13                                   13

// RsRFSigGen_rngV5GDLFramexPDCCHDCIDL_PCRS
#define RSRFSIGGEN_VAL_V5G_DL_PCRS_NONE                                     0
#define RSRFSIGGEN_VAL_V5G_DL_PCRS_AP_60                                    1
#define RSRFSIGGEN_VAL_V5G_DL_PCRS_AP_61                                    2
#define RSRFSIGGEN_VAL_V5G_DL_PCRS_AP_60_61                                 3

// RsRFSigGen_rngV5GULFrameUENumberofAntennaPortsforxPUCCH
#define RSRFSIGGEN_VAL_V5G_UL_UE_XPUCCH_AP_1                                1
#define RSRFSIGGEN_VAL_V5G_UL_UE_XPUCCH_AP_2                                2

// RsRFSigGen_rngV5GULSubframeAllocationModulation
#define RSRFSIGGEN_VAL_V5G_SUBFRAME_MODULATION_PSK8                         4

// RsRFSigGen_rngV5GULSubframeAllocationChannelCodingCodeRate
#define RSRFSIGGEN_VAL_V5G_UL_CHANNEL_CODING_CODE_RATE_12                   0
#define RSRFSIGGEN_VAL_V5G_UL_CHANNEL_CODING_CODE_RATE_23                   1
#define RSRFSIGGEN_VAL_V5G_UL_CHANNEL_CODING_CODE_RATE_34                   2
#define RSRFSIGGEN_VAL_V5G_UL_CHANNEL_CODING_CODE_RATE_56                   3

// RsRFSigGen_rngEUTRAStandardMode
#define RSRFSIGGEN_VAL_EUTRA_LTE                                            0
#define RSRFSIGGEN_VAL_EUTRA_IOT                                            1
#define RSRFSIGGEN_VAL_EUTRA_LIOT                                           2

// RsRFSigGen_rngPredistortionXUnit
#define RSRFSIGGEN_VAL_PREDIST_UNIT_DBM                                     0
#define RSRFSIGGEN_VAL_PREDIST_UNIT_V                                       1

// RsRFSigGen_rngBTLEAdvertisingEventDutyCycle
#define RSRFSIGGEN_VAL_DCYCLE_LOW                                           0
#define RSRFSIGGEN_VAL_DCYCLE_HIGH                                          1

// RsRFSigGen_rngBTDTTNumberOfPacketsPerSet
#define RSRFSIGGEN_VAL_BT_DTT_PACKETS_PER_SET_50                            0
#define RSRFSIGGEN_VAL_BT_DTT_PACKETS_PER_SET_2                             1
#define RSRFSIGGEN_VAL_BT_DTT_PACKETS_PER_SET_1                             2

// RsRFSigGen_rngBTDTTTPCSymbolsPerABit
#define RSRFSIGGEN_VAL_BT_TPC_SYMBOLS_TWO                                   0
#define RSRFSIGGEN_VAL_BT_TPC_SYMBOLS_EIGHT                                 1

// RsRFSigGen_rngBTLEPacketFormat
#define RSRFSIGGEN_VAL_BTO_PACKET_FORMAT_L1M                                0
#define RSRFSIGGEN_VAL_BTO_PACKET_FORMAT_L2M                                1
#define RSRFSIGGEN_VAL_BTO_PACKET_FORMAT_LCOD                               2

// RsRFSigGen_rngEUTRAeMTCPDSCHChannelCodingSFNRestartPeriod
#define RSRFSIGGEN_VAL_EUTRA_SFN_RESTART_PERIOD_SLEN                        0
#define RSRFSIGGEN_VAL_EUTRA_SFN_RESTART_PERIOD_3GPP                        1

// RsRFSigGen_rngEUTRANBIoTDCIContentDistanceFromNPDCCHtoNPDSCH
#define RSRFSIGGEN_VAL_NIOT_DISTANCE_ZERO                                   0
#define RSRFSIGGEN_VAL_NIOT_DISTANCE_MIN                                    1
#define RSRFSIGGEN_VAL_NIOT_DISTANCE_STD                                    2

// RsRFSigGen_rngEUTRADLUser3GPPRelease
#define RSRFSIGGEN_VAL_EUTRA_DL_RELEASE_R89                                 0
#define RSRFSIGGEN_VAL_EUTRA_DL_RELEASE_EMA                                 1
#define RSRFSIGGEN_VAL_EUTRA_DL_RELEASE_EMB                                 2
#define RSRFSIGGEN_VAL_EUTRA_DL_RELEASE_NIOT                                3
#define RSRFSIGGEN_VAL_EUTRA_DL_RELEASE_LADV                                4

// RsRFSigGen_rngEUTRAeMTCWidebandConfig
#define RSRFSIGGEN_VAL_EUTRA_WIDEBAND_CONFIG_OFF                            0
#define RSRFSIGGEN_VAL_EUTRA_WIDEBAND_CONFIG_BW5                            1
#define RSRFSIGGEN_VAL_EUTRA_WIDEBAND_CONFIG_BW20                           2

// RsRFSigGen_rngEUTRAULUEeMTCWidebandOffsetVRB
#define RSRFSIGGEN_VAL_EUTRA_WIDE_VRB_OS0                                   0
#define RSRFSIGGEN_VAL_EUTRA_WIDE_VRB_OS3                                   1
#define RSRFSIGGEN_VAL_EUTRA_WIDE_VRB_OS6                                   2
#define RSRFSIGGEN_VAL_EUTRA_WIDE_VRB_OS9                                   3
#define RSRFSIGGEN_VAL_EUTRA_WIDE_VRB_OS12                                  4
#define RSRFSIGGEN_VAL_EUTRA_WIDE_VRB_OS15                                  5
#define RSRFSIGGEN_VAL_EUTRA_WIDE_VRB_OS18                                  6
#define RSRFSIGGEN_VAL_EUTRA_WIDE_VRB_OS21                                  7

// RsRFSigGen_rngEUTRAULUEeMTCWidebandResourceBlocks
#define RSRFSIGGEN_VAL_EUTRA_WRBLOCKS_CN3                                   0
#define RSRFSIGGEN_VAL_EUTRA_WRBLOCKS_CN6                                   1
#define RSRFSIGGEN_VAL_EUTRA_WRBLOCKS_CN9                                   2
#define RSRFSIGGEN_VAL_EUTRA_WRBLOCKS_CN12                                  3
#define RSRFSIGGEN_VAL_EUTRA_WRBLOCKS_CN15                                  4
#define RSRFSIGGEN_VAL_EUTRA_WRBLOCKS_CN18                                  5
#define RSRFSIGGEN_VAL_EUTRA_WRBLOCKS_CN21                                  6
#define RSRFSIGGEN_VAL_EUTRA_WRBLOCKS_CN24                                  7

// RsRFSigGen_rngEUTRAULNIoTFRCType
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A141                                   0
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A142                                   1
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A143                                   2
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A144                                   3
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A151                                   4
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A152                                   5
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A161                                   6
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A162                                   7
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A163                                   8
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A164                                   9
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A165                                   10
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A241                                   11
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A242                                   12
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A243                                   13
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A244                                   14
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A245                                   15
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A246                                   16
#define RSRFSIGGEN_VAL_NIOT_FRC_TYPE_A247                                   17

// RsRFSigGen_rngEUTRAULNIoTFRCSubcarriersSpacing
#define RSRFSIGGEN_VAL_NIOT_FRC_SCSP_S15                                    0
#define RSRFSIGGEN_VAL_NIOT_FRC_SCSP_S375                                   1

// RsRFSigGen_rngEUTRAULNIoTFRCModulation
#define RSRFSIGGEN_VAL_NIOT_FRC_MODULATION_QPSK                             0
#define RSRFSIGGEN_VAL_NIOT_FRC_MODULATION_PI2B                             1
#define RSRFSIGGEN_VAL_NIOT_FRC_MODULATION_PI4Q                             2

// RsRFSigGen_rngEUTRADLCSINZPFrequencyDensity
#define RSRFSIGGEN_VAL_EUTRA_NZP_FRD_D1                                     0
#define RSRFSIGGEN_VAL_EUTRA_NZP_FRD_D12                                    1
#define RSRFSIGGEN_VAL_EUTRA_NZP_FRD_D13                                    2

// RsRFSigGen_rngEUTRAULSidelinkMode
#define RSRFSIGGEN_VAL_EUTRA_SIDELINK_MODE_COMM                             0
#define RSRFSIGGEN_VAL_EUTRA_SIDELINK_MODE_DISC                             1
#define RSRFSIGGEN_VAL_EUTRA_SIDELINK_MODE_V2X                              2

// RsRFSigGen_rngEUTRAULSidelinkAllocationContent
#define RSRFSIGGEN_VAL_EUTRAL_SL_CONTENT_PSCCH                              0
#define RSRFSIGGEN_VAL_EUTRAL_SL_CONTENT_PSSCH                              1
#define RSRFSIGGEN_VAL_EUTRAL_SL_CONTENT_PSDCH                              2
#define RSRFSIGGEN_VAL_EUTRAL_SL_CONTENT_PSBCH                              3

// RsRFSigGen_rngEUTRAULSidelinkAllocationDiscoveryType
#define RSRFSIGGEN_VAL_EUTRA_SL_DISCOVERY_D1                                0
#define RSRFSIGGEN_VAL_EUTRA_SL_DISCOVERY_D2B                               1

// RsRFSigGen_rngEUTRAULSidelinkAllocationModulation
#define RSRFSIGGEN_VAL_EUTRA_SL_MODULATION_QPSK                             0
#define RSRFSIGGEN_VAL_EUTRA_SL_MODULATION_QAM16                            1

// RsRFSigGen_rngIQDigitalDohertyShapingMode
#define RSRFSIGGEN_VAL_DOHERTY_SHAPING_TABLE                                0
#define RSRFSIGGEN_VAL_DOHERTY_SHAPING_POLY                                 1
#define RSRFSIGGEN_VAL_DOHERTY_SHAPING_NORM                                 2
#define RSRFSIGGEN_VAL_DOHERTY_SHAPING_DOHERTY                              3

// RsRFSigGen_rngIQDigitalPredistortionScale
#define RSRFSIGGEN_VAL_PREDISTORTION_SCALE_POWER                            0
#define RSRFSIGGEN_VAL_PREDISTORTION_SCALE_VOLTAGE                          1

// RsRFSigGen_rngIQDigitalPredistortionLinearizeRFAdjustLinearizationCurrentFrequency
#define RSRFSIGGEN_VAL_LINEARIZATION_STOPPED                                0
#define RSRFSIGGEN_VAL_LINEARIZATION_RUNNING                                1

// RsRFSigGen_rngIQEnvelopeVoltageAdaptation
#define RSRFSIGGEN_VAL_ADAPTATION_AUTO_NORMALIZED                           0
#define RSRFSIGGEN_VAL_ADAPTATION_AUTO_POWER                                1
#define RSRFSIGGEN_VAL_ADAPTATION_AUTO_MANUAL                               2

// RsRFSigGen_rngIQEnvelopeeTrakInterfaceType
#define RSRFSIGGEN_VAL_ETRAK_USER                                           0
#define RSRFSIGGEN_VAL_ETRAK_ET1V2                                          1
#define RSRFSIGGEN_VAL_ETRAK_ET1V5                                          2
#define RSRFSIGGEN_VAL_ETRAK_ET2V0                                          3

// RsRFSigGen_rngIQOutputEnvelopeTablesInterpolation
#define RSRFSIGGEN_VAL_ENVELOPE_INTERPOLATION_OFF                           0
#define RSRFSIGGEN_VAL_ENVELOPE_INTERPOLATION_LINEAR                        1
#define RSRFSIGGEN_VAL_ENVELOPE_INTERPOLATION_POWER                         2

// RsRFSigGen_rngIQEnvelopeVccForXUnit
#define RSRFSIGGEN_VAL_ENVELOPE_XUNIT_NORMALIZED                            0
#define RSRFSIGGEN_VAL_ENVELOPE_XUNIT_DBM                                   1
#define RSRFSIGGEN_VAL_ENVELOPE_XUNIT_V                                     2

// RsRFSigGen_rngIQEnvelopeVccForXScale
#define RSRFSIGGEN_VAL_ENVELOPE_XSCALE_VOLTAGE                              0
#define RSRFSIGGEN_VAL_ENVELOPE_XSCALE_POWER                                1

// RsRFSigGen_rngExtSeqRTCIWaveformStreamingRate
#define RSRFSIGGEN_VAL_ESEQ_STREAMING_RATE_250K                             0
#define RSRFSIGGEN_VAL_ESEQ_STREAMING_RATE_500K                             1
#define RSRFSIGGEN_VAL_ESEQ_STREAMING_RATE_750K                             2
#define RSRFSIGGEN_VAL_ESEQ_STREAMING_RATE_1M                               3

// RsRFSigGen_rngFSIMMIMOChannelPolarizationMode
#define RSRFSIGGEN_VAL_FSIM_POLARIZATION_SINGLE                             0
#define RSRFSIGGEN_VAL_FSIM_POLARIZATION_SEPARATE                           1

// RsRFSigGen_rngFSIMMIMOSCMEDistribution
#define RSRFSIGGEN_VAL_FSIM_DISTRIBUTION_LAPLACE                            0
#define RSRFSIGGEN_VAL_FSIM_DISTRIBUTION_GAUSS                              1
#define RSRFSIGGEN_VAL_FSIM_DISTRIBUTION_EQUAL                              2

// RsRFSigGen_rngGSMHSRFilterType
#define RSRFSIGGEN_VAL_GSM_HSR_FILTER_NARROW                                0
#define RSRFSIGGEN_VAL_GSM_HSR_FILTER_WIDE                                  1

// RsRFSigGen_rngGSMSCPIR
#define RSRFSIGGEN_VAL_GSM_SCPIR0                                           0
#define RSRFSIGGEN_VAL_GSM_SCPIR1                                           1
#define RSRFSIGGEN_VAL_GSM_SCPIR2                                           2
#define RSRFSIGGEN_VAL_GSM_SCPIR3                                           3
#define RSRFSIGGEN_VAL_GSM_SCPIR4                                           4
#define RSRFSIGGEN_VAL_GSM_SCPIR5                                           5
#define RSRFSIGGEN_VAL_GSM_SCPIR6                                           6
#define RSRFSIGGEN_VAL_GSM_SCPIR7                                           7

// RsRFSigGen_rngWLANPSDUModulation
#define RSRFSIGGEN_VAL_PSDU_MODULATION_BPSK                                 0
#define RSRFSIGGEN_VAL_PSDU_MODULATION_QPSK                                 1
#define RSRFSIGGEN_VAL_PSDU_MODULATION_DBPSK                                2
#define RSRFSIGGEN_VAL_PSDU_MODULATION_DQPSK                                3
#define RSRFSIGGEN_VAL_PSDU_MODULATION_CCK                                  4
#define RSRFSIGGEN_VAL_PSDU_MODULATION_PBCC                                 5

// RsRFSigGen_rngWLANNUserInfoRUType
#define RSRFSIGGEN_VAL_WLNN_RU_TYPE_26                                      0
#define RSRFSIGGEN_VAL_WLNN_RU_TYPE_52                                      1
#define RSRFSIGGEN_VAL_WLNN_RU_TYPE_106                                     2
#define RSRFSIGGEN_VAL_WLNN_RU_TYPE_242                                     3
#define RSRFSIGGEN_VAL_WLNN_RU_TYPE_484                                     4
#define RSRFSIGGEN_VAL_WLNN_RU_TYPE_996                                     5
#define RSRFSIGGEN_VAL_WLNN_RU_TYPE_2996                                    6
#define RSRFSIGGEN_VAL_WLNN_RU_TYPE_C26                                     7

// RsRFSigGen_rngW3GPPUEReferenceLevel
#define RSRFSIGGEN_VAL_W3GPP_REFLEV_RMS                                     0
#define RSRFSIGGEN_VAL_W3GPP_REFLEV_DPCC                                    1
#define RSRFSIGGEN_VAL_W3GPP_REFLEV_PMP                                     2
#define RSRFSIGGEN_VAL_W3GPP_REFLEV_LPP                                     3
#define RSRFSIGGEN_VAL_W3GPP_REFLEV_EDCH                                    4
#define RSRFSIGGEN_VAL_W3GPP_REFLEV_HACK                                    5
#define RSRFSIGGEN_VAL_W3GPP_REFLEV_PCQI                                    6

// RsRFSigGen_rngOneWebFilterLTEOptimization
#define RSRFSIGGEN_VAL_FILTER_LTE_EVM                                       0
#define RSRFSIGGEN_VAL_FILTER_LTE_ACP                                       1
#define RSRFSIGGEN_VAL_FILTER_LTE_ACPN                                      2
#define RSRFSIGGEN_VAL_FILTER_LTE_BENU                                      3

// RsRFSigGen_rngSatNavGNSSAntenna
#define RSRFSIGGEN_VAL_GNSS_ANT_A1                                          0
#define RSRFSIGGEN_VAL_GNSS_ANT_A2                                          1
#define RSRFSIGGEN_VAL_GNSS_ANT_A3                                          2
#define RSRFSIGGEN_VAL_GNSS_ANT_A4                                          3

// RsRFSigGen_rngSatNavGNSSStreamRFBand
#define RSRFSIGGEN_VAL_GNSS_STREAM_RF_BAND_L1                               0
#define RSRFSIGGEN_VAL_GNSS_STREAM_RF_BAND_L2                               1
#define RSRFSIGGEN_VAL_GNSS_STREAM_RF_BAND_L5                               2

// RsRFSigGen_rngSatNavGNSSMonitorType
#define RSRFSIGGEN_VAL_SATNAV_GNSS_MONITOR_TYPE_SKY                         0
#define RSRFSIGGEN_VAL_SATNAV_GNSS_MONITOR_TYPE_MAP                         1
#define RSRFSIGGEN_VAL_SATNAV_GNSS_MONITOR_TYPE_POWER                       2
#define RSRFSIGGEN_VAL_SATNAV_GNSS_MONITOR_TYPE_TRAJECTORY                  3
#define RSRFSIGGEN_VAL_SATNAV_GNSS_MONITOR_TYPE_ATTITUDE                    4
#define RSRFSIGGEN_VAL_SATNAV_GNSS_MONITOR_TYPE_TRACKS                      5
#define RSRFSIGGEN_VAL_SATNAV_GNSS_MONITOR_TYPE_CHANNELS                    6

// RsRFSigGen_rngSatNavGNSSMonitorVehicle
#define RSRFSIGGEN_VAL_SATNAV_GNSS_MONITOR_VEHICLE_V1                       0
#define RSRFSIGGEN_VAL_SATNAV_GNSS_MONITOR_VEHICLE_V2                       1

// RsRFSigGen_rngSatNavGNSSMonitorMapAxis
#define RSRFSIGGEN_VAL_SATNAV_GNSS_MONITOR_MAP_AXIS_GRID                    0
#define RSRFSIGGEN_VAL_SATNAV_GNSS_MONITOR_MAP_AXIS_CIRCLES                 1

// RsRFSigGen_rngSatNavGNSSMonitorShowSVID
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_ALL                            0
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_1                              1
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_2                              2
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_3                              3
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_4                              4
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_5                              5
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_6                              6
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_7                              7
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_8                              8
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_9                              9
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_10                             10
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_11                             11
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_12                             12
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_13                             13
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_14                             14
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_15                             15
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_16                             16
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_17                             17
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_18                             18
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_19                             19
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_20                             20
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_21                             21
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_22                             22
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_23                             23
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_24                             24
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_25                             25
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_26                             26
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_27                             27
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_28                             28
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_29                             29
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_30                             30
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_31                             31
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_32                             32
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_33                             33
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_34                             34
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_35                             35
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_36                             36
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_37                             37
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_38                             38
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_39                             39
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_40                             40
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_41                             41
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_42                             42
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_43                             43
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_44                             44
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_45                             45
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_46                             46
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_47                             47
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_48                             48
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_49                             49
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_50                             50
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_51                             51
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_52                             52
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_53                             53
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_54                             54
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_55                             55
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_56                             56
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_57                             57
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_58                             58
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_59                             59
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_60                             60
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_61                             61
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_62                             62
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_63                             63
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_64                             64
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_65                             65
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_66                             66
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_67                             67
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_68                             68
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_69                             69
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_70                             70
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_71                             71
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_72                             72
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_73                             73
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_74                             74
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_75                             75
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_76                             76
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_77                             77
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_78                             78
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_79                             79
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_80                             80
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_81                             81
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_82                             82
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_83                             83
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_84                             84
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_85                             85
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_86                             86
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_87                             87
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_88                             88
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_89                             89
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_90                             90
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_91                             91
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_92                             92
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_93                             93
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_94                             94
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_95                             95
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_96                             96
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_97                             97
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_98                             98
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_99                             99
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_100                            100
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_101                            101
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_102                            102
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_103                            103
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_104                            104
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_105                            105
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_106                            106
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_107                            107
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_108                            108
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_109                            109
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_110                            110
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_111                            111
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_112                            112
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_113                            113
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_114                            114
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_115                            115
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_116                            116
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_117                            117
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_118                            118
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_119                            119
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_120                            120
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_121                            121
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_122                            122
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_123                            123
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_124                            124
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_125                            125
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_126                            126
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_127                            127
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_128                            128
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_129                            129
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_130                            130
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_131                            131
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_132                            132
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_133                            133
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_134                            134
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_135                            135
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_136                            136
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_137                            137
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_138                            138
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_139                            139
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_140                            140
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_141                            141
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_142                            142
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_143                            143
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_144                            144
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_145                            145
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_146                            146
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_147                            147
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_148                            148
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_149                            149
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_150                            150
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_151                            151
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_152                            152
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_153                            153
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_154                            154
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_155                            155
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_156                            156
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_157                            157
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_158                            158
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_159                            159
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_160                            160
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_161                            161
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_162                            162
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_163                            163
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_164                            164
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_165                            165
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_166                            166
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_167                            167
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_168                            168
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_169                            169
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_170                            170
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_171                            171
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_172                            172
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_173                            173
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_174                            174
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_175                            175
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_176                            176
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_177                            177
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_178                            178
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_179                            179
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_180                            180
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_181                            181
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_182                            182
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_183                            183
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_184                            184
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_185                            185
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_186                            186
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_187                            187
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_188                            188
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_189                            189
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_190                            190
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_191                            191
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_192                            192
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_193                            193
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_194                            194
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_195                            195
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_196                            196
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_197                            197
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_198                            198
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_199                            199
#define RSRFSIGGEN_VAL_SATNAV_GNSS_SHOW_SVID_200                            200

// RsRFSigGen_rngSatNavGNSSStream
#define RSRFSIGGEN_VAL_SATNAV_GNSS_STREAM_S1                                0
#define RSRFSIGGEN_VAL_SATNAV_GNSS_STREAM_S2                                1
#define RSRFSIGGEN_VAL_SATNAV_GNSS_STREAM_S3                                2
#define RSRFSIGGEN_VAL_SATNAV_GNSS_STREAM_S4                                3

// RsRFSigGen_rngSatNavGNSSTroposphericModel
#define RSRFSIGGEN_VAL_GNSS_TROPOSPHERIC_MODEL_NONE                         0
#define RSRFSIGGEN_VAL_GNSS_TROPOSPHERIC_MODEL_STANAG                       1
#define RSRFSIGGEN_VAL_GNSS_TROPOSPHERIC_MODEL_MOPS                         2

// RsRFSigGen_rngSatNavGNSSIonosphericModel
#define RSRFSIGGEN_VAL_SATNAV_GNSS_IONOSPHERIC_MODEL_NONE                   0
#define RSRFSIGGEN_VAL_SATNAV_GNSS_IONOSPHERIC_MODEL_KLOBUCHAR              1
#define RSRFSIGGEN_VAL_SATNAV_GNSS_IONOSPHERIC_MODEL_MOPS                   2
#define RSRFSIGGEN_VAL_SATNAV_GNSS_IONOSPHERIC_MODEL_NEQUICK                3

// RsRFSigGen_rngSatNavGNSSIonosphericMOPSDisplay
#define RSRFSIGGEN_VAL_SATNAV_GNSS_MOPS_DISPLAY_GIVEI                       0
#define RSRFSIGGEN_VAL_SATNAV_GNSS_MOPS_DISPLAY_VDEL                        1

// RsRFSigGen_rngSatNavGNSSADGDataFormat
#define RSRFSIGGEN_VAL_SATNAV_GNSS_ADG_DATA_FORMAT_LNAV                     0
#define RSRFSIGGEN_VAL_SATNAV_GNSS_ADG_DATA_FORMAT_CNAV                     1

// RsRFSigGen_rngSatNavGNSSADGReferenceFrame
#define RSRFSIGGEN_VAL_SATNAV_GNSS_ADG_REF_FRAME_PZ90                       0
#define RSRFSIGGEN_VAL_SATNAV_GNSS_ADG_REF_FRAME_WGS84                      1

// RsRFSigGen_rngSatNavGNSSCodeOnL2Mode
#define RSRFSIGGEN_VAL_GNSS_CODE_ON_L2_MODE_RES                             0
#define RSRFSIGGEN_VAL_GNSS_CODE_ON_L2_MODE_PCOD                            1
#define RSRFSIGGEN_VAL_GNSS_CODE_ON_L2_MODE_CAC                             2

// RsRFSigGen_rngSatNavGNSSGLONSatType
#define RSRFSIGGEN_VAL_GNSS_GLONASS_SAT_TYPE_GLO                            0
#define RSRFSIGGEN_VAL_GNSS_GLONASS_SAT_TYPE_GLOM                           1
#define RSRFSIGGEN_VAL_GNSS_GLONASS_SAT_TYPE_GLOK                           2

// RsRFSigGen_rngSatNavGNSSAdditionalDataGLONAOE
#define RSRFSIGGEN_VAL_GNSS_GLONASS_AOE_A30M                                0
#define RSRFSIGGEN_VAL_GNSS_GLONASS_AOE_A45M                                1
#define RSRFSIGGEN_VAL_GNSS_GLONASS_AOE_A60M                                2

// RsRFSigGen_rngSatNavGNSSGLONTbAlignment
#define RSRFSIGGEN_VAL_GNSS_TB_ALIGNMENT_EVEN                               0
#define RSRFSIGGEN_VAL_GNSS_TB_ALIGNMENT_ODD                                1

// RsRFSigGen_rngSatNavGNSSNavMessageControl
#define RSRFSIGGEN_VAL_GNSS_NAV_MESSAGE_CONTROL_OFF                         0
#define RSRFSIGGEN_VAL_GNSS_NAV_MESSAGE_CONTROL_EDIT                        1
#define RSRFSIGGEN_VAL_GNSS_NAV_MESSAGE_CONTROL_AUTO                        2

// RsRFSigGen_rngSatNavGNSSNavMessageType
#define RSRFSIGGEN_VAL_GNSS_NAV_MESSAGE_TYPE_RND                            0
#define RSRFSIGGEN_VAL_GNSS_NAV_MESSAGE_TYPE_ZEROS                          1
#define RSRFSIGGEN_VAL_GNSS_NAV_MESSAGE_TYPE_ONES                           2
#define RSRFSIGGEN_VAL_GNSS_NAV_MESSAGE_TYPE_PATTERN                        3
#define RSRFSIGGEN_VAL_GNSS_NAV_MESSAGE_TYPE_PN9                            4
#define RSRFSIGGEN_VAL_GNSS_NAV_MESSAGE_TYPE_PN11                           5
#define RSRFSIGGEN_VAL_GNSS_NAV_MESSAGE_TYPE_PN15                           6
#define RSRFSIGGEN_VAL_GNSS_NAV_MESSAGE_TYPE_PN16                           7
#define RSRFSIGGEN_VAL_GNSS_NAV_MESSAGE_TYPE_PN20                           8
#define RSRFSIGGEN_VAL_GNSS_NAV_MESSAGE_TYPE_PN21                           9
#define RSRFSIGGEN_VAL_GNSS_NAV_MESSAGE_TYPE_PN23                           10
#define RSRFSIGGEN_VAL_GNSS_NAV_MESSAGE_TYPE_DATA_LIST                      11
#define RSRFSIGGEN_VAL_GNSS_NAV_MESSAGE_TYPE_ZERO_NAV_DATA                  12

// RsRFSigGen_rngSatNavGNSSHILInterfaceType
#define RSRFSIGGEN_VAL_GNSS_HIL_INTERFACE_TYPE_SCPI                         0
#define RSRFSIGGEN_VAL_GNSS_HIL_INTERFACE_TYPE_UDP                          1

// RsRFSigGen_rngSatNavGNSSReceiverPositioning
#define RSRFSIGGEN_VAL_SATNAV_GNSS_RECEIVER_POSITIONING_STATIC              0
#define RSRFSIGGEN_VAL_SATNAV_GNSS_RECEIVER_POSITIONING_MOVING              1
#define RSRFSIGGEN_VAL_SATNAV_GNSS_RECEIVER_POSITIONING_HIL                 2

// RsRFSigGen_rngSatNavGNSSAttitudeBehaviour
#define RSRFSIGGEN_VAL_GNSS_ATTITUDE_BEHAVIOUR_CONSTANT                     0
#define RSRFSIGGEN_VAL_GNSS_ATTITUDE_BEHAVIOUR_FILE                         1
#define RSRFSIGGEN_VAL_GNSS_ATTITUDE_BEHAVIOUR_MOTION                       2
#define RSRFSIGGEN_VAL_GNSS_ATTITUDE_BEHAVIOUR_SPINNING                     3
#define RSRFSIGGEN_VAL_GNSS_ATTITUDE_BEHAVIOUR_REMOTE                       4

// RsRFSigGen_rngSatNavGNSSROMode
#define RSRFSIGGEN_VAL_GNSS_RO_MODE_CYCLIC                                  0
#define RSRFSIGGEN_VAL_GNSS_RO_MODE_RTRIP                                   1
#define RSRFSIGGEN_VAL_GNSS_RO_MODE_OWAY                                    2

// RsRFSigGen_rngSatNavGNSSAntennaView
#define RSRFSIGGEN_VAL_GNSS_ANTENNA_VIEW_APOW                               0
#define RSRFSIGGEN_VAL_GNSS_ANTENNA_VIEW_APH                                1
#define RSRFSIGGEN_VAL_GNSS_ANTENNA_VIEW_BODY                               2
#define RSRFSIGGEN_VAL_GNSS_ANTENNA_VIEW_POS                                3

// RsRFSigGen_rngSatNavGNSSLoggingMode
#define RSRFSIGGEN_VAL_GNSS_LOGGING_MODE_RT                                 0
#define RSRFSIGGEN_VAL_GNSS_LOGGING_MODE_OFFL                               1

// RsRFSigGen_rngSatNavGNSSLoggingStep
#define RSRFSIGGEN_VAL_GNSS_LOGGING_STEP_R1S                                0
#define RSRFSIGGEN_VAL_GNSS_LOGGING_STEP_R2S                                1
#define RSRFSIGGEN_VAL_GNSS_LOGGING_STEP_R5S                                2
#define RSRFSIGGEN_VAL_GNSS_LOGGING_STEP_R10S                               3
#define RSRFSIGGEN_VAL_GNSS_LOGGING_STEP_R02S                               4
#define RSRFSIGGEN_VAL_GNSS_LOGGING_STEP_R04S                               5
#define RSRFSIGGEN_VAL_GNSS_LOGGING_STEP_R08S                               6

// RsRFSigGen_rngREGRestartMode
#define RSRFSIGGEN_VAL_REG_RESTART_AUTO                                     0
#define RSRFSIGGEN_VAL_REG_RESTART_AAUT                                     1

// RsRFSigGen_rngREGRestartSource
#define RSRFSIGGEN_VAL_REG_RESTART_SOURCE_INTERNAL                          0
#define RSRFSIGGEN_VAL_REG_RESTART_SOURCE_ERRTA                             1
#define RSRFSIGGEN_VAL_REG_RESTART_SOURCE_ERRTB                             2

// RsRFSigGen_rngDeviationMode
#define RSRFSIGGEN_VAL_DEVIATION_UNCOUPLED                                  0
#define RSRFSIGGEN_VAL_DEVIATION_TOTAL                                      1
#define RSRFSIGGEN_VAL_DEVIATION_RATIO                                      2

// RsRFSigGen_rngVariationStepMode
#define RSRFSIGGEN_VAL_STEP_MODE_DECIMAL                                    0
#define RSRFSIGGEN_VAL_STEP_MODE_USER                                       1

// RsRFSigGen_rngSystemConfigurationHSChannels
#define RSRFSIGGEN_VAL_HS_CHANNEL_CH0                                       0
#define RSRFSIGGEN_VAL_HS_CHANNEL_CH1                                       1
#define RSRFSIGGEN_VAL_HS_CHANNEL_CH2                                       2
#define RSRFSIGGEN_VAL_HS_CHANNEL_CH3                                       3
#define RSRFSIGGEN_VAL_HS_CHANNEL_CH4                                       4
#define RSRFSIGGEN_VAL_HS_CHANNEL_CH5                                       5
#define RSRFSIGGEN_VAL_HS_CHANNEL_CH6                                       6
#define RSRFSIGGEN_VAL_HS_CHANNEL_CH7                                       7
#define RSRFSIGGEN_VAL_HS_CHANNEL_CH8                                       8

// RsRFSigGen_rngGraphicsSelectedStream
#define RSRFSIGGEN_VAL_GRAPHIC_STREAM_A                                     0
#define RSRFSIGGEN_VAL_GRAPHIC_STREAM_B                                     1
#define RSRFSIGGEN_VAL_GRAPHIC_STREAM_C                                     2
#define RSRFSIGGEN_VAL_GRAPHIC_STREAM_D                                     3
#define RSRFSIGGEN_VAL_GRAPHIC_STREAM_E                                     4
#define RSRFSIGGEN_VAL_GRAPHIC_STREAM_F                                     5
#define RSRFSIGGEN_VAL_GRAPHIC_STREAM_G                                     6
#define RSRFSIGGEN_VAL_GRAPHIC_STREAM_H                                     7

// RsRFSigGen_rngARBTestSignalForm
#define RSRFSIGGEN_VAL_ARB_TESTSIGNAL_SINE                                  0
#define RSRFSIGGEN_VAL_ARB_TESTSIGNAL_RECT                                  1
#define RSRFSIGGEN_VAL_ARB_TESTSIGNAL_CIQ                                   2
#define RSRFSIGGEN_VAL_ARB_TESTSIGNAL_AWGN                                  3

// RsRFSigGen_rngDMAPSK16Gamma
#define RSRFSIGGEN_VAL_DM_APSK16_G2D3                                       0
#define RSRFSIGGEN_VAL_DM_APSK16_G3D4                                       1
#define RSRFSIGGEN_VAL_DM_APSK16_G4D5                                       2
#define RSRFSIGGEN_VAL_DM_APSK16_G5D6                                       3
#define RSRFSIGGEN_VAL_DM_APSK16_G8D9                                       4
#define RSRFSIGGEN_VAL_DM_APSK16_G9D10                                      5

// RsRFSigGen_rngDM32APSKGamma
#define RSRFSIGGEN_VAL_DM_APSK32_G3D4                                       0
#define RSRFSIGGEN_VAL_DM_APSK32_G4D5                                       1
#define RSRFSIGGEN_VAL_DM_APSK32_G5D6                                       2
#define RSRFSIGGEN_VAL_DM_APSK32_G8D9                                       3
#define RSRFSIGGEN_VAL_DM_APSK32_G9D10                                      4

// RsRFSigGen_rngNR5GSSPBCHOffsetRelativeTo
#define RSRFSIGGEN_VAL_5GNR_OFFSET_RELATIVE_TO_TXBW                         0
#define RSRFSIGGEN_VAL_5GNR_OFFSET_RELATIVE_TO_POINT_A                      1

// RsRFSigGen_rng5GNRPowerMode
#define RSRFSIGGEN_VAL_5GNR_POWER_MODE_AVERAGE                              0
#define RSRFSIGGEN_VAL_5GNR_POWER_MODE_AVERAGE_ACTIVE_SUBFRAMES             1
#define RSRFSIGGEN_VAL_5GNR_POWER_MODE_CONSTANT_PSD                         2
#define RSRFSIGGEN_VAL_5GNR_POWER_MODE_BURST                                3
#define RSRFSIGGEN_VAL_5GNR_POWER_MODE_AAS                                  4

// RsRFSigGen_rng5GNRPUSCHUCIMode
#define RSRFSIGGEN_VAL_5GNR_PUSCH_UCI_MODE_UCI_ULSCH                        0
#define RSRFSIGGEN_VAL_5GNR_PUSCH_UCI_MODE_UCI_ONLY                         1

// RsRFSigGen_rng5GNRTriggerSource
#define RSRFSIGGEN_VAL_5GNR_TRIGGER_SOURCE_INTERNAL                         0
#define RSRFSIGGEN_VAL_5GNR_TRIGGER_SOURCE_INTERNALA                        1
#define RSRFSIGGEN_VAL_5GNR_TRIGGER_SOURCE_INTERNALB                        2
#define RSRFSIGGEN_VAL_5GNR_TRIGGER_SOURCE_EGT1                             3
#define RSRFSIGGEN_VAL_5GNR_TRIGGER_SOURCE_EGT2                             4
#define RSRFSIGGEN_VAL_5GNR_TRIGGER_SOURCE_EGC1                             5
#define RSRFSIGGEN_VAL_5GNR_TRIGGER_SOURCE_EGC2                             6
#define RSRFSIGGEN_VAL_5GNR_TRIGGER_SOURCE_ELT                              7
#define RSRFSIGGEN_VAL_5GNR_TRIGGER_SOURCE_ELC                              8
#define RSRFSIGGEN_VAL_5GNR_TRIGGER_SOURCE_OBAS                             9
#define RSRFSIGGEN_VAL_5GNR_TRIGGER_SOURCE_BEXT                             10
#define RSRFSIGGEN_VAL_5GNR_TRIGGER_SOURCE_EXT                              11
#define RSRFSIGGEN_VAL_5GNR_TRIGGER_SOURCE_BBSY                             12

// RsRFSigGen_rng5GNRTriggerSignalDurationUnit
#define RSRFSIGGEN_VAL_5GNR_TRIGGER_SIGNAL_DURATION_UNIT_SEQUENCE           0
#define RSRFSIGGEN_VAL_5GNR_TRIGGER_SIGNAL_DURATION_UNIT_SAMPLE             4

// RsRFSigGen_rng5GNRExternalTriggerDelayUnit
#define RSRFSIGGEN_VAL_5GNR_EXT_TRIG_DELAY_UNIT_SAMPLE                      0
#define RSRFSIGGEN_VAL_5GNR_EXT_TRIG_DELAY_UNIT_TIME                        1

// RsRFSigGen_rng5GNRMarkerMode
#define RSRFSIGGEN_VAL_5GNR_MARKER_MODE_RESTART                             0
#define RSRFSIGGEN_VAL_5GNR_MARKER_MODE_FRAME                               1
#define RSRFSIGGEN_VAL_5GNR_MARKER_MODE_PERIOD                              2
#define RSRFSIGGEN_VAL_5GNR_MARKER_MODE_SUBFRAM                             3
#define RSRFSIGGEN_VAL_5GNR_MARKER_MODE_RATIO                               4
#define RSRFSIGGEN_VAL_5GNR_MARKER_TYPE_SFNRESTART                          5

// RsRFSigGen_rng5GNRClockMode
#define RSRFSIGGEN_VAL_5GNR_CLOCK_MODE_SAMPLE                               0

// RsRFSigGen_rng5GNRNodeCarrierCellDeployment
#define RSRFSIGGEN_VAL_5GNR_DEPLOYMENT_LT3                                  0
#define RSRFSIGGEN_VAL_5GNR_DEPLOYMENT_BT36                                 1
#define RSRFSIGGEN_VAL_5GNR_DEPLOYMENT_GT6                                  2
#define RSRFSIGGEN_VAL_5GNR_DEPLOYMENT_FR2_2                                3

// RsRFSigGen_rng5GNRNodeCarrierCellChannelBW
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_5                               0
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_10                              1
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_15                              2
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_20                              3
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_25                              4
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_30                              5
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_40                              6
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_50                              7
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_60                              8
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_70                              9
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_80                              10
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_90                              11
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_100                             12
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_200                             13
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_400                             14
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_800                             15
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_1600                            16
#define RSRFSIGGEN_VAL_5GNR_CARRIER_CELL_BW_2000                            17

// RsRFSigGen_rng5GNRNodeSSPBCHPatternSCSpacingCP
#define RSRFSIGGEN_VAL_5GNR_SC_SPACING_CP_15                                0
#define RSRFSIGGEN_VAL_5GNR_SC_SPACING_CP_30                                1
#define RSRFSIGGEN_VAL_5GNR_SC_SPACING_CP_60                                2
#define RSRFSIGGEN_VAL_5GNR_SC_SPACING_CP_120                               3
#define RSRFSIGGEN_VAL_5GNR_SC_SPACING_CP_240                               4
#define RSRFSIGGEN_VAL_5GNR_SC_SPACING_CP_60_EXTENDED                       5
#define RSRFSIGGEN_VAL_5GNR_SC_SPACING_CP_480                               6
#define RSRFSIGGEN_VAL_5GNR_SC_SPACING_CP_960                               7

// RsRFSigGen_rngNR5GSSPBCHPatternCase
#define RSRFSIGGEN_VAL_SS_PBCH_PATTERN_CASE_A                               0
#define RSRFSIGGEN_VAL_SS_PBCH_PATTERN_CASE_B                               1
#define RSRFSIGGEN_VAL_SS_PBCH_PATTERN_CASE_C                               2
#define RSRFSIGGEN_VAL_SS_PBCH_PATTERN_CASE_D                               3
#define RSRFSIGGEN_VAL_SS_PBCH_PATTERN_CASE_E                               4

// RsRFSigGen_rngNR5GSSPBCHPatternBurstSetPeriodicity
#define RSRFSIGGEN_VAL_5GNR_PATTERN_BURST_SET_PERIODICITY_5                 0
#define RSRFSIGGEN_VAL_5GNR_PATTERN_BURST_SET_PERIODICITY_10                1
#define RSRFSIGGEN_VAL_5GNR_PATTERN_BURST_SET_PERIODICITY_20                2
#define RSRFSIGGEN_VAL_5GNR_PATTERN_BURST_SET_PERIODICITY_40                3
#define RSRFSIGGEN_VAL_5GNR_PATTERN_BURST_SET_PERIODICITY_80                4
#define RSRFSIGGEN_VAL_5GNR_PATTERN_BURST_SET_PERIODICITY_160               5
#define RSRFSIGGEN_VAL_5GNR_PATTERN_BURST_SET_PERIODICITY_320               6
#define RSRFSIGGEN_VAL_5GNR_PATTERN_BURST_SET_PERIODICITY_640               7

// RsRFSigGen_rng5GNRPatternChannelCodingDataSource
#define RSRFSIGGEN_VAL_5GNR_DATA_SOURCE_ZERO                                0
#define RSRFSIGGEN_VAL_5GNR_DATA_SOURCE_ONE                                 1
#define RSRFSIGGEN_VAL_5GNR_DATA_SOURCE_PATTERN                             2
#define RSRFSIGGEN_VAL_5GNR_DATA_SOURCE_PN_9                                3
#define RSRFSIGGEN_VAL_5GNR_DATA_SOURCE_PN_11                               4
#define RSRFSIGGEN_VAL_5GNR_DATA_SOURCE_PN_15                               5
#define RSRFSIGGEN_VAL_5GNR_DATA_SOURCE_PN_16                               6
#define RSRFSIGGEN_VAL_5GNR_DATA_SOURCE_PN_20                               7
#define RSRFSIGGEN_VAL_5GNR_DATA_SOURCE_PN_21                               8
#define RSRFSIGGEN_VAL_5GNR_DATA_SOURCE_PN_23                               9
#define RSRFSIGGEN_VAL_5GNR_DATA_SOURCE_DLIST                               10

// RsRFSigGen_rng5GNRPatternMIBSCSCommon
#define RSRFSIGGEN_VAL_5GNR_COMMON_SCS_15_60                                0
#define RSRFSIGGEN_VAL_5GNR_COMMON_SCS_30_120                               1

// RsRFSigGen_rng5GNRPatternMIBCellBarred
#define RSRFSIGGEN_VAL_5GNR_MIB_CELL_NOT_BARRED                             0
#define RSRFSIGGEN_VAL_5GNR_MIB_CELL_BARRED                                 1

// RsRFSigGen_rng5GNRPatternMIBIntraFreqReselection
#define RSRFSIGGEN_VAL_5GNR_MIB_INTRA_FREQ_RESELECTION_NOT_ALLOWED          0
#define RSRFSIGGEN_VAL_5GNR_MIB_INTRA_FREQ_RESELECTION_ALLOWED              1

// RsRFSigGen_rng5GNRNodeDummyREsSCSpacingCP
#define RSRFSIGGEN_VAL_5GNR_SC_SPACING_CP_60_EPC                            5

// RsRFSigGen_rng5GNRNodeDummyREsModulation
#define RSRFSIGGEN_VAL_5GNR_DUMMY_RES_MODULATION_BPSK                       0
#define RSRFSIGGEN_VAL_5GNR_DUMMY_RES_MODULATION_BPSK_2                     1
#define RSRFSIGGEN_VAL_5GNR_DUMMY_RES_MODULATION_QPSK                       2
#define RSRFSIGGEN_VAL_5GNR_DUMMY_RES_MODULATION_QAM16                      3
#define RSRFSIGGEN_VAL_5GNR_DUMMY_RES_MODULATION_QAM64                      4
#define RSRFSIGGEN_VAL_5GNR_DUMMY_RES_MODULATION_QAM256                     5
#define RSRFSIGGEN_VAL_5GNR_DUMMY_RES_MODULATION_QAM1024                    6

// RsRFSigGen_rng5GNRDLBWPPDSCHConfigType
#define RSRFSIGGEN_VAL_5GNR_PDSCH_CONFIG_TYPE_1                             1
#define RSRFSIGGEN_VAL_5GNR_PDSCH_CONFIG_TYPE_2                             2

// RsRFSigGen_rng5GNRPDSCHMCSTable
#define RSRFSIGGEN_VAL_5GNR_PDSCH_MSC_TABLE_QAM64                           0
#define RSRFSIGGEN_VAL_5GNR_PDSCH_MSC_TABLE_QAM256                          1
#define RSRFSIGGEN_VAL_5GNR_PDSCH_MSC_TABLE_QAM64_LOW_SE                    2
#define RSRFSIGGEN_VAL_5GNR_PDSCH_MSC_TABLE_QAM1024                         3

// RsRFSigGen_rng5GNRULBWPFRCType
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_1A11                                 0
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_1A12                                 1
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_1A13                                 2
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_1A14                                 3
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_1A15                                 4
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_1A16                                 5
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_1A17                                 6
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_1A18                                 7
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_1A19                                 8
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_2A11                                 9
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_2A12                                 10
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_2A13                                 11
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_2A14                                 12
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_2A15                                 13
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_1A21                                 14
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_1A22                                 15
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_1A23                                 16
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_1A24                                 17
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_1A25                                 18
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_1A26                                 19
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_NA                                   20
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A38                               21
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A39                               22
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A310                              23
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A311                              24
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A312                              25
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A313                              26
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A314                              27
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A322                              28
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A323                              29
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A324                              30
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A325                              31
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A326                              32
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A327                              33
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A328                              34
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A48                               35
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A49                               36
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A410                              37
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A411                              38
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A412                              39
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A413                              40
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A414                              41
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A422                              42
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A423                              43
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A424                              44
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A425                              45
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A426                              46
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A427                              47
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A428                              48
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A58                               49
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A59                               50
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A510                              51
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A511                              52
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A512                              53
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A513                              54
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A514                              55
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A331                              56
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A332                              57
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A31                               58
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A32                               59
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A33                               60
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A34                               61
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A35                               62
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A36                               63
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A37                               64
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A38                               65
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A39                               66
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A310                              67
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A311                              68
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A312                              69
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A41                               70
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A42                               71
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A43                               72
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A44                               73
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A45                               74
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A46                               75
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A47                               76
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A48                               77
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A49                               78
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A410                              79
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A51                               80
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A52                               81
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A53                               82
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A54                               83
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A55                               84
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A313                              85
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A314                              86
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A315                              87
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A316                              88
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A317                              89
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A318                              90
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A319                              91
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A320                              92
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A321                              93
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A322                              94
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A323                              95
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A324                              96
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A411                              97
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A412                              98
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A413                              99
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A414                              100
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A415                              101
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A416                              102
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A417                              103
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A418                              104
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A419                              105
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A420                              106
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A56                               107
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A57                               108
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A58                               109
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A59                               110
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A510                              111
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A31                               112
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A32                               113
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A33                               114
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A34                               115
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A35                               116
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A36                               117
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A37                               118
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A315                              119
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A316                              120
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A317                              121
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A318                              122
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A319                              123
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A320                              124
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A321                              125
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A329                              126
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A330                              127
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A41                               128
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A42                               129
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A43                               130
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A44                               131
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A45                               132
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A46                               133
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A47                               134
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A415                              135
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A416                              136
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A417                              137
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A418                              138
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A419                              139
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A420                              140
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A421                              141
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A51                               142
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A52                               143
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A53                               144
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A54                               145
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A55                               146
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A56                               147
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A57                               148
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A110                              149
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A111                              150
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A333                              151
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A333A                             152
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A334                              153
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A334A                             154
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A71                               155
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A72                               156
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A73                               157
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A74                               158
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A75                               159
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A76                               160
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A77                               161
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A78                               162
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A79                               163
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A710                              164
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A429                              165
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A429A                             166
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A430                              167
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A430A                             168
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A431A                             169
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A431                              170
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A432A                             171
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A432                              172
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A3A1                              173
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A3A2                              174
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A3A3                              175
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A3A4                              176
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A3B1                              177
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A3B2                              178
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A3B3                              179
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A3B4                              180
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381411_FR1A71                      181
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381411_FR1A72                      182
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381411_FR1A73                      183
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381411_FR1A74                      184
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381412_FR1A81                      185
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381412_FR1A82                      186
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381412_FR1A83                      187
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381412_FR1A84                      188
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A325                              189
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A326                              190
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A3A1                              191
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A3A2                              192
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A3A3                              193
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A3A4                              194
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A3A5                              195
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A3A6                              196
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A3A7                              197
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A3A8                              198
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A211                      199
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A212                      200
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A213                      201
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A214                      202
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A215                      203
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A216                      204
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A217                      205
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A218                      206
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A219                      207
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A2110                     208
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A2111                     209
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A2112                     210
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A2113                     211
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A2114                     212
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A2115                     213
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A2116                     214
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A231                      215
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A232                      216
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A233                      217
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A234                      218
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A235                      219
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A236                      220
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A237                      221
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A238                      222
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A239                      223
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A2310                     224
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A2311                     225
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A2312                     226
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A2313                     227
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A2314                     228
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A241                      229
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A242                      230
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A243                      231
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A244                      232
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A245                      233
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A246                      234
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR1A247                      235
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A211                      236
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A212                      237
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A213                      238
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A214                      239
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A215                      240
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A216                      241
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A217                      242
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A218                      243
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A219                      244
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2110                     245
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2111                     246
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2112                     247
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2113                     248
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2114                     249
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2115                     250
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2116                     251
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2117                     252
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2118                     253
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2119                     254
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2120                     255
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2121                     256
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2122                     257
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2123                     258
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2124                     259
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A221                      260
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A222                      261
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A223                      262
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A224                      263
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A225                      264
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A226                      265
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A227                      266
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A228                      267
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A229                      268
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2210                     269
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A231                      270
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A232                      271
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A233                      272
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A234                      273
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A235                      274
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A236                      275
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A237                      276
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A238                      277
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A239                      278
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2310                     279
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2311                     280
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2312                     281
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2313                     282
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2314                     283
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2315                     284
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2316                     285
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2317                     286
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2318                     287
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2319                     288
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2320                     289
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A241                      290
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A242                      291
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A243                      292
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A244                      293
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A245                      294
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A246                      295
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A247                      296
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A248                      297
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A249                      298
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38176_FR2A2410                     299
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A112                              300
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A113                              301
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A114                              302
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A115                              303
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A116                              304
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A117                              305
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A118                              306
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A119                              307
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A27                               308
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A28                               309
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A29                               310
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A210                              311
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A211                              312
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A212                              313
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A213                              314
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A214                              315
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A215                              316
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A216                              317
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381411_FR1A82                      318
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381411_FR1A83                      319
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381411_FR1A84                      320
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381411_FR1A81                      321
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381411_FR1A85                      322
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381412_FR1A91                      323
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381412_FR1A92                      324
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381412_FR1A93                      325
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381412_FR1A94                      326
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS381412_FR1A95                      327
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A335                              328
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A336                              329
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A337                              330
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A338                              331
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A3B5                              332
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A3B6                              333
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A3B7                              334
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR1A3B8                              335
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A101                              336
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A1010                             337
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A1011                             338
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A1012                             339
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A102                              340
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A103                              341
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A104                              342
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A105                              343
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A106                              344
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A107                              345
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A108                              346
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A109                              347
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A327                              348
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A3B1                              349
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_FR2A3B2                              350
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A11                       351
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A12                       352
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A13                       353
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A14                       354
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A15                       355
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A16                       356
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A17                       357
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A18                       358
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A19                       359
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A21                       360
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A22                       361
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A23                       362
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A24                       363
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A25                       364
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A26                       365
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A31                       366
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A32                       367
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A33                       368
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A34                       369
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A35                       370
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A36                       371
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A3A1                      372
#define RSRFSIGGEN_VAL_5GNR_UL_BWP_FRC_TS38181_FR1A3A3                      373

// RsRFSigGen_rng5GNRFRCModulation
#define RSRFSIGGEN_VAL_5GNR_FRC_MODULATION_BPSK                             0
#define RSRFSIGGEN_VAL_5GNR_FRC_MODULATION_BPSK_2                           1
#define RSRFSIGGEN_VAL_5GNR_FRC_MODULATION_QPSK                             2
#define RSRFSIGGEN_VAL_5GNR_FRC_MODULATION_QAM16                            3
#define RSRFSIGGEN_VAL_5GNR_FRC_MODULATION_QAM64                            4
#define RSRFSIGGEN_VAL_5GNR_FRC_MODULATION_QAM256                           5
#define RSRFSIGGEN_VAL_5GNR_FRC_MODULATION_NSQAM1024                        6
#define RSRFSIGGEN_VAL_5GNR_FRC_MODULATION_NSQAM2048                        7
#define RSRFSIGGEN_VAL_5GNR_FRC_MODULATION_NSQAM4096                        8
#define RSRFSIGGEN_VAL_5GNR_FRC_MODULATION_PSK8                             9
#define RSRFSIGGEN_VAL_5GNR_FRC_MODULATION_QAM1024                          10

// RsRFSigGen_rng5GNRDLBWPPUSCHConfigType
#define RSRFSIGGEN_VAL_5GNR_PUSCH_CONFIG_TYPE_1                             1
#define RSRFSIGGEN_VAL_5GNR_PUSCH_CONFIG_TYPE_2                             2

// RsRFSigGen_rng5GNRULBWPPUSCHTxConfig
#define RSRFSIGGEN_VAL_5GNR_PUSCH_TX_CONFIG_NON_CODEBOOK                    0
#define RSRFSIGGEN_VAL_5GNR_PUSCH_TX_CONFIG_CODEBOOK                        1

// RsRFSigGen_rng5GNRPUSCHMCSTable
#define RSRFSIGGEN_VAL_5GNR_PUSCH_MSC_TABLE_QAM64                           0
#define RSRFSIGGEN_VAL_5GNR_PUSCH_MSC_TABLE_QAM256                          1
#define RSRFSIGGEN_VAL_5GNR_PUSCH_MSC_TABLE_QAM64_LOW_SE                    2

// RsRFSigGen_rng5GNRPUSCHUCIScalingAlpha
#define RSRFSIGGEN_VAL_5GNR_PUSCH_UCI_SCALING_ALPHA_0_5                     0
#define RSRFSIGGEN_VAL_5GNR_PUSCH_UCI_SCALING_ALPHA_0_65                    1
#define RSRFSIGGEN_VAL_5GNR_PUSCH_UCI_SCALING_ALPHA_0_8                     2
#define RSRFSIGGEN_VAL_5GNR_PUSCH_UCI_SCALING_ALPHA_1_0                     3

// RsRFSigGen_rng5GNRSchedulingContent
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_PDSCH                        0
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_CORESET                      1
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_PUSCH                        2
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_PUCCH                        3
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_PRACH                        4
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_DUMR                         5
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_SPBC                         6
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_CSIR                         7
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_SRS                          8
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_LTEC                         9
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_PRS                          10
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_SSSPBCH                      11
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_PSBCH                        12
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_PSCCH                        13
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_PSSCH                        14
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_PSFCH                        15
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_PSCSS                        16
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CONTENT_PUNC                         17

// RsRFSigGen_rng5GNRSchedulingMappingType
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_MAPPING_TYPE_A                       0
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_MAPPING_TYPE_B                       1

// RsRFSigGen_rng5GNRSchedulingPUCCHFormat
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PUCCH_FORMAT_0                       0
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PUCCH_FORMAT_1                       1
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PUCCH_FORMAT_2                       2
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PUCCH_FORMAT_3                       3
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PUCCH_FORMAT_4                       4

// RsRFSigGen_rng5GNRSchedulingPRACHSCSpacingCP
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_SC_SPACING_1_25                0
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_SC_SPACING_5                   1
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_SC_SPACING_15                  2
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_SC_SPACING_30                  3
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_SC_SPACING_60                  4
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_SC_SPACING_120                 5
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_SC_SPACING_480                 6
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_SC_SPACING_960                 7

// RsRFSigGen_rng5GNRSchedulingRepetition
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_REPETITION_OFF                       0
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_REPETITION_SUBFRAME                  1
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_REPETITION_FRAME                     2
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_REPETITION_SLOT                      3
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_REPETITION_CUST                      4
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_REPETITION_TA                        5

// RsRFSigGen_rng5GNRSchedulingType
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_TYPE_F00                             0
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_TYPE_F01                             1
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_TYPE_F10                             2
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_TYPE_F11                             3
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_TYPE_F02                             4
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_TYPE_F12                             5

// RsRFSigGen_rng5GNRSchedulingPDSCHModulation
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_MODULATION_BPSK                      0
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_MODULATION_BPSK_2                    1
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_MODULATION_QPSK                      2
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_MODULATION_QAM16                     3
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_MODULATION_QAM64                     4
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_MODULATION_QAM256                    5
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_MODULATION_QAM1024                   6

// RsRFSigGen_rng5GNRSchedulingCORESETBundleSize
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_BUNDLE_SIZE_2                2
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_BUNDLE_SIZE_3                3
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_BUNDLE_SIZE_6                6

// RsRFSigGen_rng5GNRSchedulingCORESETSize
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_SIZE_2                       2
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_SIZE_3                       3
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_SIZE_6                       6

// RsRFSigGen_rng5GNRSchedulingCORESETDCIUsage
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_C                  0
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_CS                 1
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_P                  2
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_SI                 3
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_RA                 4
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_TC                 5
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_SPCS               6
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_SFI                7
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_INT                8
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_TPUS               9
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_TPUC               10
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_TSRS               11
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_MCSC               12
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_CI                 13
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_PS                 14
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_AI                 15
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_MSGB               16
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_USAGE_CUSTOM             17

// RsRFSigGen_rng5GNRSchedulingCORESETDCIFormat
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_0_0               0
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_0_1               1
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_1_0               2
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_1_1               3
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_2_0               4
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_2_1               5
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_2_2               6
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_2_3               7
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_CUSTOM            8
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_F24               9
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_F25               10
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_F26               11
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_F02               12
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_F12               13
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_F27               14
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_3_0               15
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_3_1               16
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_4_0               17
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_4_1               18
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_FORMAT_4_2               19

// RsRFSigGen_rng5GNRSchedulingCORESETDCISearchSpace
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_SEARCH_SPACE_USS         0
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_SEARCH_SPACE_CSS_0       1
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_SEARCH_SPACE_CSS_1       2
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_SEARCH_SPACE_CSS_2       3
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_SEARCH_SPACE_CSS_3       4
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_SEARCH_SPACE_CSS_0A      5

// RsRFSigGen_rng5GNRSchedulingCORESETDCIAggregationLevel
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_AGGREGATION_LEVEL_1      1
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_AGGREGATION_LEVEL_2      2
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_AGGREGATION_LEVEL_4      4
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_AGGREGATION_LEVEL_8      8
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_CORESET_DCI_AGGREGATION_LEVEL_16     16

// RsRFSigGen_rng5GNRSchedulingAllocationPUCCHGroupHopping
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PUCCH_GROUP_HOPPING_DISABLE          0
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PUCCH_GROUP_HOPPING_ENABLE           1
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PUCCH_GROUP_HOPPING_NEIGHER          2

// RsRFSigGen_rng5GNRSchedulingAllocationPUCCHOCCLength
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PUCCH_OCC_LENGTH_N2                  2
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PUCCH_OCC_LENGTH_N4                  4

// RsRFSigGen_rng5GNRSchedulingPRACHFormat
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_FORMAT_0                       0
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_FORMAT_1                       1
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_FORMAT_2                       2
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_FORMAT_3                       3
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_FORMAT_A1                      4
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_FORMAT_A2                      5
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_FORMAT_A3                      6
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_FORMAT_B1                      7
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_FORMAT_B2                      8
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_FORMAT_B3                      9
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_FORMAT_B4                      10
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_FORMAT_C0                      11
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_FORMAT_C2                      12

// RsRFSigGen_rng5GNRSchedulingPRACHRestrictedSet
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_RESTRICTED_SET_URES            0
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_RESTRICTED_SET_ARES            1
#define RSRFSIGGEN_VAL_5GNR_SCHEDULING_PRACH_RESTRICTED_SET_BRES            2

// RsRFSigGen_rng5GNROutputFilterMode
#define RSRFSIGGEN_VAL_5GNR_OUTPUT_FILTER_MODE_CHANNEL_BW                   0
#define RSRFSIGGEN_VAL_5GNR_OUTPUT_FILTER_MODE_PER_BWP                      1
#define RSRFSIGGEN_VAL_5GNR_OUTPUT_FILTER_MODE_OFF                          2
#define RSRFSIGGEN_VAL_5GNR_OUTPUT_FILTER_MODE_FAST                         3
#define RSRFSIGGEN_VAL_5GNR_OUTPUT_FILTER_MODE_USER                         4
#define RSRFSIGGEN_VAL_5GNR_OUTPUT_FILTER_MODE_EVM                          5

// RsRFSigGen_rng5GNROutputSampleRateMode
#define RSRFSIGGEN_VAL_5GNR_OUTPUT_SAMPLE_RATE_MODE_FFT                     0
#define RSRFSIGGEN_VAL_5GNR_OUTPUT_SAMPLE_RATE_MODE_MIN                     1

// RsRFSigGen_rngBERBLERTestGeneratorTrigger
#define RSRFSIGGEN_VAL_TEST_GENERATOR_TRIGGER_NONE                          0
#define RSRFSIGGEN_VAL_TEST_GENERATOR_TRIGGER_DENEBLE                       1
#define RSRFSIGGEN_VAL_TEST_GENERATOR_TRIGGER_RESTART                       2

// RsRFSigGen_rngBERBLERTestGeneratorMeasurementMode
#define RSRFSIGGEN_VAL_TEST_GENERATOR_MEAS_TYPE_BER                         0
#define RSRFSIGGEN_VAL_TEST_GENERATOR_MEAS_TYPE_BLER                        1

// RsRFSigGen_rngBERBLERTestGeneratorExternalIQMode
#define RSRFSIGGEN_VAL_TEST_GENERATOR_EXT_IQ_MODE_IN                        0
#define RSRFSIGGEN_VAL_TEST_GENERATOR_EXT_IQ_MODE_OUT                       1

// RsRFSigGen_rngBERTDataConnector
#define RSRFSIGGEN_VAL_DATA_CONNECTOR_TRIGGER                               0
#define RSRFSIGGEN_VAL_DATA_CONNECTOR_MARKER_1                              1

// RsRFSigGen_rngBLERCRCOrder
#define RSRFSIGGEN_VAL_BLER_CRC_ORDER_LSB                                   0
#define RSRFSIGGEN_VAL_BLER_CRC_ORDER_MSB                                   1

// RsRFSigGen_rngCalibrationExternalLevelAdjustment
#define RSRFSIGGEN_VAL_EXTERNAL_LEVEL_ADJUSTMENT_FACTORY                    0
#define RSRFSIGGEN_VAL_EXTERNAL_LEVEL_ADJUSTMENT_CUSTOMER                   1

// RsRFSigGen_rngLFOutputSourceImpedance
#define RSRFSIGGEN_VAL_LF_OUTPUT_SOURCE_IMPEDANCE_LOW                       0
#define RSRFSIGGEN_VAL_LF_OUTPUT_SOURCE_IMPEDANCE_G600                      1

// RsRFSigGen_rngBBINSampleRateFIFOStatus
#define RSRFSIGGEN_VAL_BBIN_FIFO_STATUS_OK                                  0
#define RSRFSIGGEN_VAL_BBIN_FIFO_STATUS_OFL                                 1
#define RSRFSIGGEN_VAL_BBIN_FIFO_STATUS_URUN                                2

// RsRFSigGen_rngIQOutputDigitalSetLevelVia
#define RSRFSIGGEN_VAL_IQ_OUTPUT_SET_LEVEL_VIA_PEP                          0
#define RSRFSIGGEN_VAL_IQ_OUTPUT_SET_LEVEL_VIA_LEVEL                        1

// RsRFSigGen_rngALCOffMode
#define RSRFSIGGEN_VAL_ALC_OFF_MODE_SAMPLE_HOLD                             0
#define RSRFSIGGEN_VAL_ALC_OFF_MODE_HIGH_ACCURACY                           1
#define RSRFSIGGEN_VAL_ALC_OFF_MODE_TABLE                                   2

// RsRFSigGen_rng5GNRRTFeedbackConnector
#define RSRFSIGGEN_VAL_5G_NR_RT_FEEDBACK_CONN_LOCAL                         0
#define RSRFSIGGEN_VAL_5G_NR_RT_FEEDBACK_CONN_GLOBAL                        1

// RsRFSigGen_rng5GNRCORESETState
#define RSRFSIGGEN_VAL_5G_NR_CORESET_STATE_0                                0
#define RSRFSIGGEN_VAL_5G_NR_CORESET_STATE_1                                1
#define RSRFSIGGEN_VAL_5G_NR_CORESET_STATE_ALLOW_PDSCH                      2

// RsRFSigGen_rng5GNRCORESETPrecoderGranula
#define RSRFSIGGEN_VAL_5G_NR_CORESET_PRECODER_GRANULA_REG                   0
#define RSRFSIGGEN_VAL_5G_NR_CORESET_PRECODER_GRANULA_ACRB                  1

// RsRFSigGen_rng5GNRSchedulingMode
#define RSRFSIGGEN_VAL_5G_NR_SCHED_MODE_MANUAL                              0
#define RSRFSIGGEN_VAL_5G_NR_SCHED_MODE_AUTO                                1

// RsRFSigGen_rng5GNRVrbToPrb
#define RSRFSIGGEN_VAL_5G_NR_VRB_TO_PRB_VPN                                 0
#define RSRFSIGGEN_VAL_5G_NR_VRB_TO_PRB_VP2                                 1
#define RSRFSIGGEN_VAL_5G_NR_VRB_TO_PRB_VP4                                 2

// RsRFSigGen_rng5GNRCodebookSubset
#define RSRFSIGGEN_VAL_5G_NR_CODEBOOK_SUBSET_FPNC                           0
#define RSRFSIGGEN_VAL_5G_NR_CODEBOOK_SUBSET_PNC                            1
#define RSRFSIGGEN_VAL_5G_NR_CODEBOOK_SUBSET_NC                             2

// RsRFSigGen_rng5GNRSRSHopping
#define RSRFSIGGEN_VAL_5G_NR_SRS_HOPP_N                                     0
#define RSRFSIGGEN_VAL_5G_NR_SRS_HOPP_GRP                                   1
#define RSRFSIGGEN_VAL_5G_NR_SRS_HOPP_SEQ                                   2

// RsRFSigGen_rng5GNRRTFeedbackMode
#define RSRFSIGGEN_VAL_RT_FEEDBACK_MODE_OFF                                 0
#define RSRFSIGGEN_VAL_RT_FEEDBACK_MODE_SERIAL                              1
#define RSRFSIGGEN_VAL_RT_FEEDBACK_MODE_S3X8                                2

// RsRFSigGen_rng5GNRRTFeedbackSerialRate
#define RSRFSIGGEN_VAL_5G_NR_RT_FEEDBACK_SRATE_R115                         0
#define RSRFSIGGEN_VAL_5G_NR_RT_FEEDBACK_SRATE_R1M6                         1
#define RSRFSIGGEN_VAL_5G_NR_RT_FEEDBACK_SRATE_R1M9                         2

// RsRFSigGen_rng5GNRNodeLTECRSBW
#define RSRFSIGGEN_VAL_5G_NR_NODE_LTE_CRS_BW_N6                             0
#define RSRFSIGGEN_VAL_5G_NR_NODE_LTE_CRS_BW_N15                            1
#define RSRFSIGGEN_VAL_5G_NR_NODE_LTE_CRS_BW_N25                            2
#define RSRFSIGGEN_VAL_5G_NR_NODE_LTE_CRS_BW_N50                            3
#define RSRFSIGGEN_VAL_5G_NR_NODE_LTE_CRS_BW_N75                            4
#define RSRFSIGGEN_VAL_5G_NR_NODE_LTE_CRS_BW_N100                           5

// RsRFSigGen_rng5GNRNodeLTECRSAntennaPorts
#define RSRFSIGGEN_VAL_5G_NR_NODE_LTE_CRS_ANTENNA_AP1                       0
#define RSRFSIGGEN_VAL_5G_NR_NODE_LTE_CRS_ANTENNA_AP2                       1
#define RSRFSIGGEN_VAL_5G_NR_NODE_LTE_CRS_ANTENNA_AP4                       2

// RsRFSigGen_rng5GNRNodeSSPBCHPatternL
#define RSRFSIGGEN_VAL_5G_NR_SSPBCH_PATTERN_L4                              0
#define RSRFSIGGEN_VAL_5G_NR_SSPBCH_PATTERN_L8                              1
#define RSRFSIGGEN_VAL_5G_NR_SSPBCH_PATTERN_L64                             2
#define RSRFSIGGEN_VAL_5G_NR_SSPBCH_PATTERN_L10                             3
#define RSRFSIGGEN_VAL_5G_NR_SSPBCH_PATTERN_L20                             4

// RsRFSigGen_rng5GNRCORESETDCIAggregationLevels
#define RSRFSIGGEN_VAL_5G_NR_CORESET_AGG_LEVEL_AL1                          0
#define RSRFSIGGEN_VAL_5G_NR_CORESET_AGG_LEVEL_AL2                          1
#define RSRFSIGGEN_VAL_5G_NR_CORESET_AGG_LEVEL_AL4                          2
#define RSRFSIGGEN_VAL_5G_NR_CORESET_AGG_LEVEL_AL8                          3
#define RSRFSIGGEN_VAL_5G_NR_CORESET_AGG_LEVEL_AL16                         4

// RsRFSigGen_rng5GNRPUSCHPTRSMaxPorts
#define RSRFSIGGEN_VAL_PUSCH_PTRS_MAX_PORT1                                 0
#define RSRFSIGGEN_VAL_PUSCH_PTRS_MAX_PORT2                                 1

// RsRFSigGen_rng5GNRPUSCHPTRSPower
#define RSRFSIGGEN_VAL_5G_NR_PUSCH_PTRS_POWER_P00                           0
#define RSRFSIGGEN_VAL_5G_NR_PUSCH_PTRS_POWER_P01                           1

// RsRFSigGen_rng5GNREPRERatio
#define RSRFSIGGEN_VAL_5G_NR_EPRE_RATIO0                                    0
#define RSRFSIGGEN_VAL_5G_NR_EPRE_RATIO1                                    1

// RsRFSigGen_rng5GNRPTRSFrequencyDensity
#define RSRFSIGGEN_VAL_5G_NR_FREQ_DENSITY_2                                 0
#define RSRFSIGGEN_VAL_5G_NR_FREQ_DENSITY_4                                 1

// RsRFSigGen_rng5GNRPTRSMode
#define RSRFSIGGEN_VAL_5G_NR_PTRS_MODE_MANUAL                               0
#define RSRFSIGGEN_VAL_5G_NR_PTRS_MODE_AUTO                                 1

// RsRFSigGen_rng5GNRPTRSREOffset
#define RSRFSIGGEN_VAL_5G_NR_PTRS_RE00                                      0
#define RSRFSIGGEN_VAL_5G_NR_PTRS_RE01                                      1
#define RSRFSIGGEN_VAL_5G_NR_PTRS_RE10                                      2
#define RSRFSIGGEN_VAL_5G_NR_PTRS_RE11                                      3

// RsRFSigGen_rng5GNRPTRSTimeDensity
#define RSRFSIGGEN_VAL_5G_NR_PTRS_TIME_DENSITY_TD1                          0
#define RSRFSIGGEN_VAL_5G_NR_PTRS_TIME_DENSITY_TD2                          1
#define RSRFSIGGEN_VAL_5G_NR_PTRS_TIME_DENSITY_TD4                          2

// RsRFSigGen_rng5GNRSRSTransmissionType
#define RSRFSIGGEN_VAL_5G_NR_SRS_TRANS_TYPE_PER                             0
#define RSRFSIGGEN_VAL_5G_NR_SRS_TRANS_TYPE_APER                            1
#define RSRFSIGGEN_VAL_5G_NR_SRS_TRANS_TYPE_SP                              2

// RsRFSigGen_rng5GNRSRSTransmissioUsage
#define RSRFSIGGEN_VAL_5G_NR_TRANS_TYPE_NCB                                 0
#define RSRFSIGGEN_VAL_5G_NR_TRANS_TYPE_CB                                  1
#define RSRFSIGGEN_VAL_5G_NR_TRANS_TYPE_BM                                  2
#define RSRFSIGGEN_VAL_5G_NR_TRANS_TYPE_ASW                                 3

// RsRFSigGen_rng5GNRSRSPeriodicity
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL1                            0
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL2                            1
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL4                            2
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL5                            3
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL8                            4
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL10                           5
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL16                           6
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL20                           7
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL32                           8
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL40                           9
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL64                           10
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL80                           11
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL160                          12
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL320                          13
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL640                          14
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL1280                         15
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL2560                         16
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL5120                         17
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL10240                        18
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL40960                        19
#define RSRFSIGGEN_VAL_5G_NR_SRS_PERIODICITY_SL81920                        20

// RsRFSigGen_rng5GNRSRSSymbols
#define RSRFSIGGEN_VAL_5G_NR_SRS_SYMBOLS_SYM1                               0
#define RSRFSIGGEN_VAL_5G_NR_SRS_SYMBOLS_SYM2                               1
#define RSRFSIGGEN_VAL_5G_NR_SRS_SYMBOLS_SYM4                               2
#define RSRFSIGGEN_VAL_5G_NR_SRS_SYMBOLS_SYM8                               3
#define RSRFSIGGEN_VAL_5G_NR_SRS_SYMBOLS_SYM12                              4
#define RSRFSIGGEN_VAL_5G_NR_SRS_SYMBOLS_SYM10                              5
#define RSRFSIGGEN_VAL_5G_NR_SRS_SYMBOLS_SYM14                              6

// RsRFSigGen_rng5GNRSRSRepetitionFactor
#define RSRFSIGGEN_VAL_5G_NR_REP_FACT_REP1                                  0
#define RSRFSIGGEN_VAL_5G_NR_REP_FACT_REP2                                  1
#define RSRFSIGGEN_VAL_5G_NR_REP_FACT_REP4                                  2
#define RSRFSIGGEN_VAL_5G_NR_REP_FACT_REP5                                  3
#define RSRFSIGGEN_VAL_5G_NR_REP_FACT_REP6                                  4
#define RSRFSIGGEN_VAL_5G_NR_REP_FACT_REP7                                  5
#define RSRFSIGGEN_VAL_5G_NR_REP_FACT_REP8                                  6
#define RSRFSIGGEN_VAL_5G_NR_REP_FACT_REP10                                 7
#define RSRFSIGGEN_VAL_5G_NR_REP_FACT_REP12                                 8
#define RSRFSIGGEN_VAL_5G_NR_REP_FACT_REP14                                 9

// RsRFSigGen_rng5GNRSRSTransmissionComb
#define RSRFSIGGEN_VAL_5G_NR_TRANS_COMB_TC2                                 0
#define RSRFSIGGEN_VAL_5G_NR_TRANS_COMB_TC4                                 1
#define RSRFSIGGEN_VAL_5G_NR_TRANS_COMB_TC8                                 2

// RsRFSigGen_rng5GNRSRSAntennaPort
#define RSRFSIGGEN_VAL_5G_NR_SRS_ANT_PORT_AP1                               0
#define RSRFSIGGEN_VAL_5G_NR_SRS_ANT_PORT_AP2                               1
#define RSRFSIGGEN_VAL_5G_NR_SRS_ANT_PORT_AP4                               2

// RsRFSigGen_rng5GNRNZPDensity
#define RSRFSIGGEN_VAL_5G_NR_NZP_DENSITY_EVE5                               0
#define RSRFSIGGEN_VAL_5G_NR_NZP_DENSITY_ODD5                               1
#define RSRFSIGGEN_VAL_5G_NR_NZP_DENSITY_DEN1                               2
#define RSRFSIGGEN_VAL_5G_NR_NZP_DENSITY_DEN3                               3

// RsRFSigGen_rng5GNRNZPCDMType
#define RSRFSIGGEN_VAL_5G_NR_CDM_TYPE_NOCD                                  0
#define RSRFSIGGEN_VAL_5G_NR_CDM_TYPE_CDM2                                  1
#define RSRFSIGGEN_VAL_5G_NR_CDM_TYPE_CDM4                                  2
#define RSRFSIGGEN_VAL_5G_NR_CDM_TYPE_CDM8                                  3

// RsRFSigGen_rng5GNRPortIndex
#define RSRFSIGGEN_VAL_5G_NR_PORT_INDEX_P0                                  0
#define RSRFSIGGEN_VAL_5G_NR_PORT_INDEX_P1                                  1

// RsRFSigGen_rng5GNRResourceBlockGroupSize
#define RSRFSIGGEN_VAL_5G_NR_RBGS_C1                                        0
#define RSRFSIGGEN_VAL_5G_NR_RBGS_C2                                        1

// RsRFSigGen_rng5GNRTDAMappingType
#define RSRFSIGGEN_VAL_5G_NR_MAPPING_TYPE_A                                 0
#define RSRFSIGGEN_VAL_5G_NR_MAPPING_TYPE_B                                 1

// RsRFSigGen_rng5GNRPDSCHResourceAllocation
#define RSRFSIGGEN_VAL_5G_NR_PDSCH_RES_ALLOC_T0                             0
#define RSRFSIGGEN_VAL_5G_NR_PDSCH_RES_ALLOC_T1                             1
#define RSRFSIGGEN_VAL_5G_NR_PDSCH_RES_ALLOC_DS                             2

// RsRFSigGen_rng5GNRRATMGrid
#define RSRFSIGGEN_VAL_5G_NR_RATM_GRID_N                                    0
#define RSRFSIGGEN_VAL_5G_NR_RATM_GRID_G1                                   1
#define RSRFSIGGEN_VAL_5G_NR_RATM_GRID_G2                                   2

// RsRFSigGen_rng5GNRFilterTestModel
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_ALL                                     0
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_TM1_1                                   1
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_TM1_2                                   2
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_TM2                                     3
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_TM2A                                    4
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_TM3_1                                   5
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_TM3_1A                                  6
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_TM3_2                                   7
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_TM3_3                                   8
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_TM2B                                    9
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_TM3_1B                                  10

// RsRFSigGen_rngFSIMMIMOSCMAntennaRXStructure
#define RSRFSIGGEN_VAL_FSIM_MIMO_SCM_ANTENNA_RX_STRUCTURE_LIN               0
#define RSRFSIGGEN_VAL_FSIM_MIMO_SCM_ANTENNA_RX_STRUCTURE_CROSS             1

// RsRFSigGen_rng5GNRFilterTestModelFreq
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_FREQ_ALL                                0
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_FREQ_FR1                                1
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_FREQ_FR2                                2

// RsRFSigGen_rng5GNRFilterTestModelDuplexing
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_DUPLEX_ALL                              0
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_DUPLEX_FDD                              1
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_DUPLEX_TDD                              2

// RsRFSigGen_rng5GNRFilterTestModelBandwidth
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_ALL                                  0
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F5                                   1
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F10                                  2
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F15                                  3
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F20                                  4
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F25                                  5
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F30                                  6
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F40                                  7
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F50                                  8
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F60                                  9
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F70                                  10
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F80                                  11
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F90                                  12
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F100                                 13
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F200                                 14
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F400                                 15
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F35                                  16
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F45                                  17
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F800                                 18
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F1600                                19
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_BW_F2000                                20

// RsRFSigGen_rng5GNRFilterTestModelSCS
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_SCS_ALL                                 0
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_SCS_F15                                 1
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_SCS_F30                                 2
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_SCS_F60                                 3
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_SCS_F120                                4
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_SCS_F480                                5
#define RSRFSIGGEN_VAL_5G_NR_TMODEL_SCS_F960                                6

// RsRFSigGen_rng5GNRFRCMappingType
#define RSRFSIGGEN_VAL_5G_NR_FRC_MAPPING_TYPE_A                             0
#define RSRFSIGGEN_VAL_5G_NR_FRC_MAPPING_TYPE_B                             1

// RsRFSigGen_rng5GNRPTRSGroups
#define RSRFSIGGEN_VAL_5G_NR_PTRS_GROUPS_G2                                 0
#define RSRFSIGGEN_VAL_5G_NR_PTRS_GROUPS_G4                                 1
#define RSRFSIGGEN_VAL_5G_NR_PTRS_GROUPS_G8                                 2

// RsRFSigGen_rng5GNRPTRSSamplesPerGroup
#define RSRFSIGGEN_VAL_5G_NR_PTRS_SAMPLES_GROUP_S2                          0
#define RSRFSIGGEN_VAL_5G_NR_PTRS_SAMPLES_GROUP_S4                          1

// RsRFSigGen_rngBTLEAdressType
#define RSRFSIGGEN_VAL_BT_LE_ADRESS_TYPE_PUBL                               0
#define RSRFSIGGEN_VAL_BT_LE_ADRESS_TYPE_RAND                               1

// RsRFSigGen_rngBTLECTETypeReq
#define RSRFSIGGEN_VAL_BT_LE_CTE_TYPE_REQ_AOA                               0
#define RSRFSIGGEN_VAL_BT_LE_CTE_TYPE_REQ_AOD1                              1
#define RSRFSIGGEN_VAL_BT_LE_CTE_TYPE_REQ_AOD2                              2

// RsRFSigGen_rngPreamblePuncturingMode
#define RSRFSIGGEN_VAL_PREAMBLE_PUNCTURING_BANDWIDTH_MODE_4                 4
#define RSRFSIGGEN_VAL_PREAMBLE_PUNCTURING_BANDWIDTH_MODE_5                 5
#define RSRFSIGGEN_VAL_PREAMBLE_PUNCTURING_BANDWIDTH_MODE_6                 6
#define RSRFSIGGEN_VAL_PREAMBLE_PUNCTURING_BANDWIDTH_MODE_7                 7

// RsRFSigGen_rngWLANNNumberOfBasebands
#define RSRFSIGGEN_VAL_WLANN_NUMBER_BASEBANDS_NBB8                          0
#define RSRFSIGGEN_VAL_WLANN_NUMBER_BASEBANDS_NBB1                          1
#define RSRFSIGGEN_VAL_WLANN_NUMBER_BASEBANDS_NBB2                          2
#define RSRFSIGGEN_VAL_WLANN_NUMBER_BASEBANDS_NBB3                          3
#define RSRFSIGGEN_VAL_WLANN_NUMBER_BASEBANDS_NBB4                          4

// RsRFSigGen_rngARBCFRFilteringMode
#define RSRFSIGGEN_VAL_ARB_CFR_FILTERING_MODE_SIMP                          0
#define RSRFSIGGEN_VAL_ARB_CFR_FILTERING_MODE_ENH                           1

// RsRFSigGen_rngARBCFRAlgorithm
#define RSRFSIGGEN_VAL_ARB_CFR_ALGORITHM_CLIPPING_FILTERING                 0
#define RSRFSIGGEN_VAL_ARB_CFR_ALGORITHM_PEAK_CANCELLATION                  1

// RsRFSigGen_rngGBASMode
#define RSRFSIGGEN_VAL_GBAS_MODE_GBAS                                       0
#define RSRFSIGGEN_VAL_GBAS_MODE_SCAT                                       1

// RsRFSigGen_rngSBASGroundStationSSID
#define RSRFSIGGEN_VAL_SBAS_GROUND_STATION_SSID_A                           0
#define RSRFSIGGEN_VAL_SBAS_GROUND_STATION_SSID_B                           1
#define RSRFSIGGEN_VAL_SBAS_GROUND_STATION_SSID_C                           2
#define RSRFSIGGEN_VAL_SBAS_GROUND_STATION_SSID_D                           3
#define RSRFSIGGEN_VAL_SBAS_GROUND_STATION_SSID_E                           4
#define RSRFSIGGEN_VAL_SBAS_GROUND_STATION_SSID_F                           5
#define RSRFSIGGEN_VAL_SBAS_GROUND_STATION_SSID_G                           6
#define RSRFSIGGEN_VAL_SBAS_GROUND_STATION_SSID_H                           7

// RsRFSigGen_rngLoRaSyncMode
#define RSRFSIGGEN_VAL_LORA_SYNC_MODE_PRIVATE                               0
#define RSRFSIGGEN_VAL_LORA_SYNC_MODE_PUBLIC                                1

// RsRFSigGen_rngLoRaFDRType
#define RSRFSIGGEN_VAL_LORA_FDR_TYPE_LINEAR                                 0
#define RSRFSIGGEN_VAL_LORA_FDR_TYPE_SINE                                   1

// RsRFSigGen_rngLoRaBandwidth
#define RSRFSIGGEN_VAL_LORA_BANDWIDTH_BW7                                   0
#define RSRFSIGGEN_VAL_LORA_BANDWIDTH_BW10                                  1
#define RSRFSIGGEN_VAL_LORA_BANDWIDTH_BW15                                  2
#define RSRFSIGGEN_VAL_LORA_BANDWIDTH_BW20                                  3
#define RSRFSIGGEN_VAL_LORA_BANDWIDTH_BW31                                  4
#define RSRFSIGGEN_VAL_LORA_BANDWIDTH_BW41                                  5
#define RSRFSIGGEN_VAL_LORA_BANDWIDTH_BW62                                  6
#define RSRFSIGGEN_VAL_LORA_BANDWIDTH_BW125                                 7
#define RSRFSIGGEN_VAL_LORA_BANDWIDTH_BW250                                 8
#define RSRFSIGGEN_VAL_LORA_BANDWIDTH_BW500                                 9

// RsRFSigGen_rngLoRaTriggerSignalDurationUnit
#define RSRFSIGGEN_VAL_LORA_TRIGGER_SIGNAL_DURATION_UNIT_SEQ_LEN            0
#define RSRFSIGGEN_VAL_LORA_TRIGGER_SIGNAL_DURATION_UNIT_SAMPLES            1

// RsRFSigGen_rngLoRaMarkerMode
#define RSRFSIGGEN_VAL_LORA_MARKER_MODE_RESTART                             0
#define RSRFSIGGEN_VAL_LORA_MARKER_MODE_FRAME                               1
#define RSRFSIGGEN_VAL_LORA_MARKER_MODE_PULSE                               2
#define RSRFSIGGEN_VAL_LORA_MARKER_MODE_PATTERN                             3
#define RSRFSIGGEN_VAL_LORA_MARKER_MODE_RATIO                               4

// RsRFSigGen_rngLoRaCodingRate
#define RSRFSIGGEN_VAL_LORA_CODING_RATE_CR0                                 0
#define RSRFSIGGEN_VAL_LORA_CODING_RATE_CR1                                 1
#define RSRFSIGGEN_VAL_LORA_CODING_RATE_CR2                                 2
#define RSRFSIGGEN_VAL_LORA_CODING_RATE_CR3                                 3
#define RSRFSIGGEN_VAL_LORA_CODING_RATE_CR4                                 4

// RsRFSigGen_rngLoRaSpreadingFactor
#define RSRFSIGGEN_VAL_LORA_SPREADING_FACTOR_SF6                            0
#define RSRFSIGGEN_VAL_LORA_SPREADING_FACTOR_SF7                            1
#define RSRFSIGGEN_VAL_LORA_SPREADING_FACTOR_SF8                            2
#define RSRFSIGGEN_VAL_LORA_SPREADING_FACTOR_SF9                            3
#define RSRFSIGGEN_VAL_LORA_SPREADING_FACTOR_SF10                           4
#define RSRFSIGGEN_VAL_LORA_SPREADING_FACTOR_SF11                           5
#define RSRFSIGGEN_VAL_LORA_SPREADING_FACTOR_SF12                           6

// RsRFSigGen_rngEUTRADLNBIotCarrierAllocationGapThreshold
#define RSRFSIGGEN_VAL_CARREIER_ALLOCATION_GAP_THRESHOLD_32                 0
#define RSRFSIGGEN_VAL_CARREIER_ALLOCATION_GAP_THRESHOLD_64                 1
#define RSRFSIGGEN_VAL_CARREIER_ALLOCATION_GAP_THRESHOLD_128                2
#define RSRFSIGGEN_VAL_CARREIER_ALLOCATION_GAP_THRESHOLD_256                3

// RsRFSigGen_rngEUTRADLNBIoTCarrierAllocationGapPeriod
#define RSRFSIGGEN_VAL_CARRIER_ALLOCATION_GAP_PERIOD_64                     0
#define RSRFSIGGEN_VAL_CARRIER_ALLOCATION_GAP_PERIOD_128                    1
#define RSRFSIGGEN_VAL_CARRIER_ALLOCATION_GAP_PERIOD_256                    2
#define RSRFSIGGEN_VAL_CARRIER_ALLOCATION_GAP_PERIOD_512                    3

// RsRFSigGen_rngEUTRADLNPRSParameter
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_TYPE_PA_A                              0
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_TYPE_PA_B                              1
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_TYPE_PA_AB                             2

// RsRFSigGen_rngEUTRADLNPRSBitmap
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_BITMAP_10                              0
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_BITMAP_40                              1

// RsRFSigGen_rngEUTRADLNPRSPeriod
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_PERIOD_160MS                           0
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_PERIOD_320MS                           1
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_PERIOD_640MS                           2
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_PERIOD_1280MS                          3

// RsRFSigGen_rngEUTRADLNPRSStartSubrame
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_START_SUBFRAME0                        0
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_START_SUBFRAME1                        1
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_START_SUBFRAME2                        2
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_START_SUBFRAME3                        3
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_START_SUBFRAME4                        4
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_START_SUBFRAME5                        5
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_START_SUBFRAME6                        6
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_START_SUBFRAME7                        7

// RsRFSigGen_rngEUTRADLNPRSNumberofSubframes
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_SUBFRAME_NUMBER_10                     0
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_SUBFRAME_NUMBER_20                     1
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_SUBFRAME_NUMBER_40                     2
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_SUBFRAME_NUMBER_80                     3
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_SUBFRAME_NUMBER_160                    4
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_SUBFRAME_NUMBER_320                    5
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_SUBFRAME_NUMBER_640                    6
#define RSRFSIGGEN_VAL_EUTRA_DL_NPRS_SUBFRAME_NUMBER_1280                   7

// RsRFSigGen_rngEUTRAeMTCPDSCHPrecodingTransmissionScheme
#define RSRFSIGGEN_VAL_EUTRA_EMTC_TRANSMISSION_SCHEME_TM9                   0
#define RSRFSIGGEN_VAL_EUTRA_EMTC_TRANSMISSION_SCHEME_TM7                   1

// RsRFSigGen_rngEUTRADLNBIoTCarrierAllocationGapDurationCoefficient
#define RSRFSIGGEN_VAL_CARRIER_ALLOCATION_GAP_DURATION_COEFFICIENT_1_8      0
#define RSRFSIGGEN_VAL_CARRIER_ALLOCATION_GAP_DURATION_COEFFICIENT_1_4      1
#define RSRFSIGGEN_VAL_CARRIER_ALLOCATION_GAP_DURATION_COEFFICIENT_3_8      2
#define RSRFSIGGEN_VAL_CARRIER_ALLOCATION_GAP_DURATION_COEFFICIENT_1_2      3

// RsRFSigGen_rngEUTRAULUEAntennaOutput
#define RSRFSIGGEN_VAL_EUTRA_UL_UE_ANTENNA_OUTPUT_BBA                       0
#define RSRFSIGGEN_VAL_EUTRA_UL_UE_ANTENNA_OUTPUT_BBB                       1
#define RSRFSIGGEN_VAL_EUTRA_UL_UE_ANTENNA_OUTPUT_BBC                       2
#define RSRFSIGGEN_VAL_EUTRA_UL_UE_ANTENNA_OUTPUT_BBD                       3
#define RSRFSIGGEN_VAL_EUTRA_UL_UE_ANTENNA_OUTPUT_BBE                       4
#define RSRFSIGGEN_VAL_EUTRA_UL_UE_ANTENNA_OUTPUT_BBF                       5
#define RSRFSIGGEN_VAL_EUTRA_UL_UE_ANTENNA_OUTPUT_BBG                       6
#define RSRFSIGGEN_VAL_EUTRA_UL_UE_ANTENNA_OUTPUT_BBH                       7

// RsRFSigGen_rngEUTRABitmapSubframes
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAMES_IN_BITMAP_10                         0
#define RSRFSIGGEN_VAL_EUTRA_SUBFRAMES_IN_BITMAP_40                         1

// RsRFSigGen_rngSatNavGNSSAWGNMode
#define RSRFSIGGEN_VAL_GNSS_AWGN_MODE_ADD                                   0
#define RSRFSIGGEN_VAL_GNSS_AWGN_MODE_CW                                    1

// RsRFSigGen_rngSatNavGNSSSARMode
#define RSRFSIGGEN_VAL_GNSS_SAR_MODE_SPARE                                  0
#define RSRFSIGGEN_VAL_GNSS_SAR_MODE_SRLM                                   1
#define RSRFSIGGEN_VAL_GNSS_SAR_MODE_LRLM                                   2

// RsRFSigGen_rngEUTRADLUserModulationAndCodingTable
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_TABLE1                                 0
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_TABLE1A                                1
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_TABLE1B                                2
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_TABLE1C                                3

// RsRFSigGen_rngEUTRADLUserCellTransportBlockSize
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_SELECT_TRANSPORT_BLOCK_SIZE_T1         0
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_SELECT_TRANSPORT_BLOCK_SIZE_T2         1
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_SELECT_TRANSPORT_BLOCK_SIZE_T3         2
#define RSRFSIGGEN_VAL_EUTRA_DL_USER_SELECT_TRANSPORT_BLOCK_SIZE_T4         3

// RsRFSigGen_rngEUTRAULSidelinkReferenceMeasurementChannel
#define RSRFSIGGEN_VAL_EUTRA_UL_SIDELINK_RMC_R821                           0
#define RSRFSIGGEN_VAL_EUTRA_UL_SIDELINK_RMC_R822                           1
#define RSRFSIGGEN_VAL_EUTRA_UL_SIDELINK_RMC_R823                           2

// RsRFSigGen_rngEUTRAULSidelinkReferenceMeasurementChannelModulationScheme
#define RSRFSIGGEN_VAL_EUTRA_UL_SIDELINK_RMC_MODULATION_SCHEME_QPSK         0
#define RSRFSIGGEN_VAL_EUTRA_UL_SIDELINK_RMC_MODULATION_SCHEME_QAM16        1
#define RSRFSIGGEN_VAL_EUTRA_UL_SIDELINK_RMC_MODULATION_SCHEME_QAM64        2
#define RSRFSIGGEN_VAL_EUTRA_UL_SIDELINK_RMC_MODULATION_SCHEME_QAM256       3
#define RSRFSIGGEN_VAL_EUTRA_UL_SIDELINK_RMC_MODULATION_SCHEME_QAM1024      4

// RsRFSigGen_rngRFPortsAlignmentCalibrationFrequencyMode
#define RSRFSIGGEN_CALIBRATION_FREQUENCY_MODE_RANGE                         0
#define RSRFSIGGEN_CALIBRATION_FREQUENCY_MODE_LIST                          1

// RsRFSigGen_rngRFPortsAlignmentCalibrationPEPMode
#define RSRFSIGGEN_VAL_CALIBRATION_PEP_MODE_RANGE                           0
#define RSRFSIGGEN_VAL_CALIBRATION_PEP_MODE_LIST                            1

// RsRFSigGen_rngRFPortsAlignmentLocalOscillatorCoupling
#define RSRFSIGGEN_VAL_RF_OSCILLATOR_COUPLING_ACTIVE                        0
#define RSRFSIGGEN_VAL_RF_OSCILLATOR_COUPLING_INACTIVE                      1

// RsRFSigGen_rngRFPortsAlignmentStatus
#define RSRFSIGGEN_RF_ALIGNMENT_STATUS_NOTALIGNED                           0
#define RSRFSIGGEN_RF_ALIGNMENT_STATUS_ALIGNED                              1
#define RSRFSIGGEN_RF_ALIGNMENT_STATUS_ERROR                                2
#define RSRFSIGGEN_RF_ALIGNMENT_STATUS_WARNING                              3
#define RSRFSIGGEN_RF_ALIGNMENT_STATUS_INACTIVE                             4
#define RSRFSIGGEN_RF_ALIGNMENT_STATUS_NOSETUP                              5
#define RSRFSIGGEN_RF_ALIGNMENT_STATUS_INVALID                              6

// RsRFSigGen_rngRFPortsAlignmentLocalOscillatorConnectionMethod
#define RSRFSIGGEN_VAL_LOCAL_OSCILLATOR_CONNECTION_METHOD_DAISY_CHAIN       0
#define RSRFSIGGEN_VAL_LOCAL_OSCILLATOR_CONNECTION_METHOD_STAR              1

// RsRFSigGen_rngRFPortsAlignmentLocalOscillatorSource
#define RSRFSIGGEN_VAL_LOCAL_OSCILLATOR_SOURCE_MAST                         0
#define RSRFSIGGEN_VAL_LOCAL_OSCILLATOR_SOURCE_EXT                          1

// RsRFSigGen_rngRFPortsAlignmentLocalOscillatorReferenceSource
#define RSRFSIGGEN_VAL_LOCAL_OSCILLATOR_REFERENCE_SOURCE_MAST               0
#define RSRFSIGGEN_VAL_LOCAL_OSCILLATOR_REFERENCE_SOURCE_EXT                1

// RsRFSigGen_rngARBMultisegmentNextSegmentSource
#define RSRFSIGGEN_VAL_NEXT_SEGMENT_INT                                     0
#define RSRFSIGGEN_VAL_NEXT_SEGMENT_1                                       1
#define RSRFSIGGEN_VAL_NEXT_SEGMENT_2                                       2

// RsRFSigGen_rngFrontendSettingsReferenceFrequency
#define RSRFSIGGEN_VAL_FRONTEND_REF_FREQ_CURRENT                            0
#define RSRFSIGGEN_VAL_FRONTEND_REF_FREQ_50MHZ                              1
#define RSRFSIGGEN_VAL_FRONTEND_REF_FREQ_64MHZ                              2
#define RSRFSIGGEN_VAL_FRONTEND_REF_FREQ_1GHZ                               3
#define RSRFSIGGEN_VAL_FRONTEND_REF_FREQ_10MHZ                              4

// RsRFSigGen_rngFrontendSettingsRFOutputConnector
#define RSRFSIGGEN_VAL_FEOUTPPATH_NONE                                      0
#define RSRFSIGGEN_VAL_FEOUTPPATH_RFB                                       1
#define RSRFSIGGEN_VAL_FEOUTPPATH_RFA                                       2

// RsRFSigGen_rngLocationFormat
#define RSRFSIGGEN_VAL_LOCFORM_DMS                                          0
#define RSRFSIGGEN_VAL_LOCFORM_DECIMAL                                      1

// RsRFSigGen_rngALCMode
#define RSRFSIGGEN_VAL_POWER_ALC_STATE_ON_PRESET                            6

// RsRFSigGen_rngPowerSensorMappingClear
#define RSRFSIGGEN_VAL_CLEAR_ALL                                            0
#define RSRFSIGGEN_VAL_CLEAR_USB                                            1
#define RSRFSIGGEN_VAL_CLEAR_LAN                                            2

// RsRFSigGen_rng5GNRQuickDuplexing
#define RSRFSIGGEN_VAL_5GNR_QUICK_DUPLEXING_TDD                             0
#define RSRFSIGGEN_VAL_5GNR_QUICK_DUPLEXING_FDD                             1

// RsRFSigGen_rng5GNRQuickDeployment
#define RSRFSIGGEN_VAL_5GNR_QUICK_DEPLOYMENT_FR1LT3                         0
#define RSRFSIGGEN_VAL_5GNR_QUICK_DEPLOYMENT_FR1GT3                         1
#define RSRFSIGGEN_VAL_5GNR_QUICK_DEPLOYMENT_FR2_1                          2
#define RSRFSIGGEN_VAL_5GNR_QUICK_DEPLOYMENT_FR2_2                          3

// RsRFSigGen_rng5GNRQuickRaster
#define RSRFSIGGEN_VAL_5GNR_QUICK_RASTER_15KHZ                              0
#define RSRFSIGGEN_VAL_5GNR_QUICK_RASTER_60KHZ                              1
#define RSRFSIGGEN_VAL_5GNR_QUICK_RASTER_100KHZ                             2

// RsRFSigGen_rng5GNRSCSpacing
#define RSRFSIGGEN_VAL_5GNR_SC_SPACING_15KHZ                                0
#define RSRFSIGGEN_VAL_5GNR_SC_SPACING_30KHZ                                1
#define RSRFSIGGEN_VAL_5GNR_SC_SPACING_60KHZ                                2
#define RSRFSIGGEN_VAL_5GNR_SC_SPACING_120KHZ                               3
#define RSRFSIGGEN_VAL_5GNR_SC_SPACING_240KHZ                               4
#define RSRFSIGGEN_VAL_5GNR_SC_SPACING_480KHZ                               5
#define RSRFSIGGEN_VAL_5GNR_SC_SPACING_960KHZ                               6

// RsRFSigGen_rng5GNRQuickRBConfig
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_MANUAL                          0
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_EDGE_FULL_LEFT                  1
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_EDGE_FULL_RIGHT                 2
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_EDGE_1RB_LEFT                   3
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_EDGE_1RB_RIGHT                  4
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_OUTER_FULL                      5
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_INNER_FULL                      6
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_INNER_1RB_LEFT                  7
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_INNER_1RB_RIGHT                 8
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_OUTER_FULL_PC1                  9
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_OUTER_1RB_LEFT_PC1              10
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_OUTER_1RB_RIGHT_PC1             11
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_INNER_FULL_REGION1_PC1          12
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_INNER_PARTIAL_LEFT_REGION1_PC1  13
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_INNER_PARTIAL_RIGHT_REGION1_PC1 14
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_INNER_FULL_REGION2_PC1          15
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_INNER_PARTIAL_LEFT_REGION2_PC1  16
#define RSRFSIGGEN_VAL_5GNR_QUICK_RB_CONFIG_INNER_PARTIAL_RIGHT_REGION2_PC1 17

// RsRFSigGen_rng5GNRQuickModulation
#define RSRFSIGGEN_VAL_5GNR_QUICK_MODULATION_QPSK                           0
#define RSRFSIGGEN_VAL_5GNR_QUICK_MODULATION_QAM16                          1
#define RSRFSIGGEN_VAL_5GNR_QUICK_MODULATION_QAM64                          2
#define RSRFSIGGEN_VAL_5GNR_QUICK_MODULATION_QAM256                         3
#define RSRFSIGGEN_VAL_5GNR_QUICK_MODULATION_BPSK2                          4
#define RSRFSIGGEN_VAL_5GNR_QUICK_MODULATION_QAM1024                        5

// RsRFSigGen_rng5GNRMarkerDuplexing
#define RSRFSIGGEN_VAL_5GNR_MARKER_DUPLEXING_TDD                            0
#define RSRFSIGGEN_VAL_5GNR_MARKER_DUPLEXING_FDD                            1

// RsRFSigGen_rng5GNRRFPhaseCompensation
#define RSRFSIGGEN_VAL_5GNR_RF_PHASE_COMP_OFF                               0
#define RSRFSIGGEN_VAL_5GNR_RF_PHASE_COMP_AUTO                              1
#define RSRFSIGGEN_VAL_5GNR_RF_PHASE_COMP_MANUAL                            2

// RsRFSigGen_rng5GNRHarqCodebook
#define RSRFSIGGEN_VAL_5GNR_HARQ_CODEBOOK_SEMISTATIC                        0
#define RSRFSIGGEN_VAL_5GNR_HARQ_CODEBOOK_DYNAMIC                           1

// RsRFSigGen_rng5GNRRestartData
#define RSRFSIGGEN_VAL_5GNR_DATA_RESTART_OFF                                0
#define RSRFSIGGEN_VAL_5GNR_DATA_RESTART_CODEWORD_ALLOCATION                1
#define RSRFSIGGEN_VAL_5GNR_DATA_RESTART_FRAME                              2
#define RSRFSIGGEN_VAL_5GNR_DATA_RESTART_SLOT                               3

// RsRFSigGen_rng5GNRCodeBlockGroups
#define RSRFSIGGEN_VAL_5GNR_CODE_BLOCK_GROUPS_DISABLED                      0
#define RSRFSIGGEN_VAL_5GNR_CODE_BLOCK_GROUPS_G2                            1
#define RSRFSIGGEN_VAL_5GNR_CODE_BLOCK_GROUPS_G4                            2
#define RSRFSIGGEN_VAL_5GNR_CODE_BLOCK_GROUPS_G6                            3
#define RSRFSIGGEN_VAL_5GNR_CODE_BLOCK_GROUPS_G8                            4

// RsRFSigGen_rng5GNRPRBBundlingType
#define RSRFSIGGEN_VAL_5GNR_PRB_BUNDLING_NOT_CONFIGURED                     0
#define RSRFSIGGEN_VAL_5GNR_PRB_BUNDLING_STATIC                             1
#define RSRFSIGGEN_VAL_5GNR_PRB_BUNDLING_DYNAMIC                            2

// RsRFSigGen_rng5GNRPRBBundleSize
#define RSRFSIGGEN_VAL_5GNR_STATIC_BUNDLE_SIZE_N4                           0
#define RSRFSIGGEN_VAL_5GNR_STATIC_BUNDLE_SIZE_WIDEBAND                     1
#define RSRFSIGGEN_VAL_5GNR_STATIC_BUNDLE_SIZE_N2_WIDEBAND                  2
#define RSRFSIGGEN_VAL_5GNR_STATIC_BUNDLE_SIZE_N4_WIDEBAND                  3

// RsRFSigGen_rng5GNRSRS_TPC_PDCCH_GroupType
#define RSRFSIGGEN_VAL_5GNR_CONTROL_SRS_TPC_GROUP_TYPE_A                    0
#define RSRFSIGGEN_VAL_5GNR_CONTROL_SRS_TPC_GROUP_TYPE_b                    1

// RsRFSigGen_rng5GNRPUSCHResourceAllocation
#define RSRFSIGGEN_VAL_5GNR_PUSCH_RES_ALLOC_T0                              0
#define RSRFSIGGEN_VAL_5GNR_PUSCH_RES_ALLOC_T1                              1
#define RSRFSIGGEN_VAL_5GNR_PUSCH_RES_ALLOC_DS                              2

// RsRFSigGen_rng5GNRFreqHopping
#define RSRFSIGGEN_VAL_5GNR_FREQ_HOPPING_DISABLED                           0
#define RSRFSIGGEN_VAL_5GNR_FREQ_HOPPING_INTRA_SLOT                         1
#define RSRFSIGGEN_VAL_5GNR_FREQ_HOPPING_INTER_SLOT                         2

// RsRFSigGen_rng5GNRDMRS_n_ID
#define RSRFSIGGEN_VAL_5GNR_DMRS_N_ID_CELL                                  0
#define RSRFSIGGEN_VAL_5GNR_DMRS_N_ID_PUSCH                                 1

// RsRFSigGen_rng5GNRSchedulingResAlloc
#define RSRFSIGGEN_VAL_5GNR_PDSCH_RES_ALLOC_T0                              0
#define RSRFSIGGEN_VAL_5GNR_PDSCH_RES_ALLOC_T1                              1
#define RSRFSIGGEN_VAL_5GNR_PDSCH_RES_ALLOC_T2                              2

// RsRFSigGen_rng5GNRPDSCHPPrecodingGranularity
#define RSRFSIGGEN_VAL_5GNR_PDSCH_PRECODING_GRANULARITY_N2                  0
#define RSRFSIGGEN_VAL_5GNR_PDSCH_PRECODING_GRANULARITY_N4                  1
#define RSRFSIGGEN_VAL_5GNR_PDSCH_PRECODING_GRANULARITY_WIDEBAND            2

// RsRFSigGen_rng5GNRDMRSSequenceGeneration
#define RSRFSIGGEN_VAL_5GNR_DMRS_SEQUENCE_GEN_N_ID_CELL                     0
#define RSRFSIGGEN_VAL_5GNR_DMRS_SEQUENCE_GEN_N_ID_DMRS                     1

// RsRFSigGen_rng5GNRDMRSSeqHopping
#define RSRFSIGGEN_VAL_5GNR_DMRS_SEQ_HOPPING_NEITHER                        0
#define RSRFSIGGEN_VAL_5GNR_DMRS_SEQ_HOPPING_GROUP                          1
#define RSRFSIGGEN_VAL_5GNR_DMRS_SEQ_HOPPING_SEQUENCE                       2

// RsRFSigGen_rng5GNRDMRSPDSCHLayerAntennaPort
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_1000                          0
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_1001                          1
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_1002                          2
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_1003                          3
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_1004                          4
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_1005                          5
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_1006                          6
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_1007                          7
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_1008                          8
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_1009                          9
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_1010                          10
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_1011                          11

// RsRFSigGen_rng5GNRDMRSPUSCHLayerAntennaPort
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_0                             0
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_1                             1
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_2                             2
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_3                             3
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_4                             4
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_5                             5
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_6                             6
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_7                             7
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_8                             8
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_9                             9
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_10                            10
#define RSRFSIGGEN_VAL_5GNR_DMRS_ANTENNA_PORT_11                            11

// RsRFSigGen_rng5GNRPUSCHPTRSScramblingID
#define RSRFSIGGEN_VAL_5GNR_PTRS_SCRAMBLING_ID_N_ID_CELL                    0
#define RSRFSIGGEN_VAL_5GNR_PTRS_SCRAMBLING_ID_N_ID_DMRS                    1

// RsRFSigGen_rng5GNRCFReductionAlgorithm
#define RSRFSIGGEN_VAL_5GNR_CF_REDUCTION_ALGORITHM_CLF                      0

// RsRFSigGen_rng5GNRTestCaseWizardSpecification
#define RSRFSIGGEN_VAL_5GNR_TCW_SPEC_TS381411                               0
#define RSRFSIGGEN_VAL_5GNR_TCW_SPEC_TS381412                               1
#define RSRFSIGGEN_VAL_5GNR_TCW_SPEC_TS38104                                2

// RsRFSigGen_rng5GNRTestCaseWizardRelease
#define RSRFSIGGEN_VAL_5GNR_TCW_RELEASE_15                                  0
#define RSRFSIGGEN_VAL_5GNR_TCW_RELEASE_16                                  1
#define RSRFSIGGEN_VAL_5GNR_TCW_RELEASE_17                                  2

// RsRFSigGen_rng5GNRTestCaseWizardBSClass
#define RSRFSIGGEN_VAL_5GNR_TCW_BS_CLASS_WIDE                               0
#define RSRFSIGGEN_VAL_5GNR_TCW_BS_CLASS_MEDIUM                             1
#define RSRFSIGGEN_VAL_5GNR_TCW_BS_CLASS_LOCAL                              2

// RsRFSigGen_rng5GNRTestCase
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC67                     0
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC72                     1
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC73                     2
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC741                    3
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC742A                   4
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC742B                   5
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC75                     6
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC77                     7
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC78                     8
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC821                    9
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC822                    10
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC823                    11
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC831                    12
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC8321                   13
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC8322                   14
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC8331                   15
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC8332                   16
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC834                    17
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC835                    18
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC8361A                  19
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC8361B                  20
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC841                    21
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC67                     22
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC72                     23
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC73                     24
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC74                     25
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC751                    26
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC752A                   27
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC752B                   28
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC76                     29
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC78                     30
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC79                     31
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC821                    32
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC822                    33
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC823                    34
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC831                    35
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC8321                   36
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC8322                   37
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC8331                   38
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC8332                   39
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC834                    40
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC835                    41
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC8361A                  42
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC8361B                  43
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC841                    44
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC824                    45
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC825                    46
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC826                    47
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC827                    48
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC828                    49
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC829                    50
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC824                    51
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC825                    52
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC826                    53
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC827                    54
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC828                    55
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC829                    56
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC8210                   57
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC8210                   58
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC8211                   59
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC8211                   60
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC837                    61
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC837                    62
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC8381                   63
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC8381                   64
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC8382                   65
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC8382                   66
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC839                    67
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC839                    68
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC8310                   69
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC8310                   70
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC8212                   71
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC8212                   72
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC8213                   73
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC8213                   74
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC8311                   75
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC8311                   76
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC83122                  77
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC83121                  78
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC83121                  79
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381411_TC8313                   80
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC83122                  81
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_CASE_TS381412_TC8313                   82

// RsRFSigGen_rng5GNRTCWizardTriggerConfig
#define RSRFSIGGEN_VAL_5GNR_TCW_TRIGGER_UNCHANGED                           0
#define RSRFSIGGEN_VAL_5GNR_TCW_TRIGGER_ARMED_AUTO                          1

// RsRFSigGen_rng5GNRTCWizardMarkerConfig
#define RSRFSIGGEN_VAL_5GNR_TCW_MARKER_UNCHANGED                            0
#define RSRFSIGGEN_VAL_5GNR_TCW_MARKER_FRAME_START                          1

// RsRFSigGen_rng5GNRTCWizardTXAntennas
#define RSRFSIGGEN_VAL_5GNR_TCW_ANTENNAS_1                                  0
#define RSRFSIGGEN_VAL_5GNR_TCW_ANTENNAS_2                                  1

// RsRFSigGen_rng5GNRTCWizardRXAntennas
#define RSRFSIGGEN_VAL_5GNR_TCW_ANTENNAS_4                                  2
#define RSRFSIGGEN_VAL_5GNR_TCW_ANTENNAS_8                                  3

// RsRFSigGen_rng5GNRTCWizardCSIPart
#define RSRFSIGGEN_VAL_5GNR_TCW_CSI_PART_1                                  0
#define RSRFSIGGEN_VAL_5GNR_TCW_CSI_PART_2                                  1

// RsRFSigGen_rng5GNRTCWizardChannelBW
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_5                                0
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_10                               1
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_15                               2
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_20                               3
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_25                               4
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_30                               5
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_40                               6
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_50                               7
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_60                               8
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_70                               9
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_80                               10
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_90                               11
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_100                              12
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_200                              13
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_400                              14
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_800                              15
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_1600                             16
#define RSRFSIGGEN_VAL_5GNR_TCW_CHANNEL_BW_2000                             17

// RsRFSigGen_rng5GNRTCWizardDuplexing
#define RSRFSIGGEN_VAL_5GNR_TCW_DUPLEXING_TDD                               0
#define RSRFSIGGEN_VAL_5GNR_TCW_DUPLEXING_FDD                               1

// RsRFSigGen_rng5GNRTCWizardMaxThroughput
#define RSRFSIGGEN_VAL_5GNR_TCW_MAX_THROUGHPUT_70                           0

// RsRFSigGen_rng5GNRTCWizardFRC
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_NA                                      0
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A11                                  1
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A12                                  2
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A13                                  3
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A14                                  4
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A15                                  5
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A16                                  6
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A17                                  7
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A18                                  8
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A19                                  9
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A21                                  10
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A22                                  11
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A23                                  12
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A24                                  13
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A25                                  14
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A26                                  15
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A38                                  16
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A39                                  17
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A310                                 18
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A311                                 19
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A312                                 20
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A313                                 21
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A314                                 22
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A322                                 23
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A323                                 24
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A324                                 25
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A325                                 26
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A326                                 27
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A327                                 28
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A328                                 29
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A331                                 30
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A332                                 31
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A48                                  32
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A49                                  33
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A410                                 34
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A411                                 35
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A412                                 36
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A413                                 37
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A414                                 38
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A422                                 39
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A423                                 40
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A424                                 41
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A425                                 42
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A426                                 43
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A427                                 44
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A428                                 45
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A58                                  46
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A59                                  47
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A510                                 48
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A511                                 49
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A512                                 50
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A513                                 51
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A514                                 52
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A11                                  53
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A12                                  54
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A13                                  55
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A14                                  56
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A15                                  57
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A311                                 58
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A312                                 59
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A313                                 60
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A314                                 61
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A315                                 62
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A316                                 63
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A317                                 64
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A318                                 65
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A319                                 66
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A320                                 67
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A321                                 68
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A322                                 69
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A323                                 70
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A324                                 71
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A41                                  72
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A42                                  73
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A43                                  74
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A44                                  75
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A45                                  76
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A46                                  77
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A47                                  78
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A48                                  79
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A49                                  80
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A410                                 81
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A411                                 82
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A412                                 83
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A413                                 84
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A414                                 85
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A415                                 86
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A416                                 87
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A417                                 88
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A418                                 89
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A419                                 90
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A420                                 91
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A51                                  92
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A52                                  93
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A53                                  94
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A54                                  95
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A55                                  96
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A56                                  97
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A57                                  98
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A58                                  99
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A59                                  100
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A510                                 101
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A31                                  102
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A32                                  103
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A33                                  104
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A34                                  105
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A35                                  106
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A36                                  107
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A37                                  108
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A38                                  109
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A39                                  110
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A310                                 111
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A31                                  112
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A32                                  113
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A33                                  114
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A34                                  115
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A35                                  116
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A36                                  117
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A37                                  118
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A315                                 119
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A316                                 120
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A317                                 121
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A318                                 122
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A319                                 123
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A320                                 124
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A321                                 125
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A329                                 126
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A330                                 127
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A41                                  128
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A42                                  129
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A43                                  130
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A44                                  131
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A45                                  132
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A46                                  133
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A47                                  134
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A415                                 135
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A416                                 136
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A417                                 137
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A418                                 138
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A419                                 139
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A420                                 140
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A421                                 141
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A51                                  142
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A52                                  143
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A53                                  144
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A54                                  145
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A55                                  146
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A56                                  147
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A57                                  148
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A110                                 149
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A111                                 150
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A333                                 151
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A333A                                152
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A334                                 153
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A334A                                154
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A71                                  155
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A72                                  156
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A73                                  157
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A74                                  158
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A75                                  159
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A76                                  160
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A77                                  161
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A78                                  162
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A79                                  163
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A710                                 164
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A429                                 165
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A430                                 166
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A430A                                167
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A431A                                168
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A431                                 169
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A432A                                170
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A432                                 171
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A3A1                                 172
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A3A2                                 173
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A3A3                                 174
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A3A4                                 175
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A3B1                                 176
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A3B2                                 177
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A3B3                                 178
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A3B4                                 179
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381411_FR1A71                         180
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381411_FR1A72                         181
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381411_FR1A73                         182
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381411_FR1A74                         183
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381412_FR1A81                         184
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381412_FR1A82                         185
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381412_FR1A83                         186
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381412_FR1A84                         187
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A325                                 188
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A326                                 189
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A3A1                                 190
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A3A2                                 191
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A3A3                                 192
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A3A4                                 193
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A3A5                                 194
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A3A6                                 195
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A3A7                                 196
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A3A8                                 197
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A211                         198
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A212                         199
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A213                         200
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A214                         201
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A215                         202
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A216                         203
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A217                         204
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A218                         205
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A219                         206
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A2110                        207
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A2111                        208
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A2112                        209
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A2113                        210
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A2114                        211
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A2115                        212
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A2116                        213
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A231                         214
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A232                         215
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A233                         216
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A234                         217
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A235                         218
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A236                         219
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A237                         220
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A238                         221
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A239                         222
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A2310                        223
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A2311                        224
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A2312                        225
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A2313                        226
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A2314                        227
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A241                         228
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A242                         229
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A243                         230
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A244                         231
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A245                         232
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A246                         233
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR1A247                         234
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A211                         235
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A212                         236
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A213                         237
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A214                         238
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A215                         239
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A216                         240
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A217                         241
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A218                         242
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A219                         243
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2110                        244
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2111                        245
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2112                        246
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2113                        247
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2114                        248
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2115                        249
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2116                        250
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2117                        251
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2118                        252
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2119                        253
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2120                        254
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2121                        255
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2122                        256
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2123                        257
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2124                        258
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A221                         259
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A222                         260
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A223                         261
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A224                         262
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A225                         263
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A226                         264
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A227                         265
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A228                         266
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A229                         267
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2210                        268
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A231                         269
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A232                         270
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A233                         271
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A234                         272
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A235                         273
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A236                         274
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A237                         275
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A238                         276
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A239                         277
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2310                        278
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2311                        279
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2312                        280
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2313                        281
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2314                        282
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2315                        283
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2316                        284
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2317                        285
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2318                        286
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2319                        287
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2320                        288
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A241                         289
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A242                         290
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A243                         291
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A244                         292
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A245                         293
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A246                         294
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A247                         295
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A248                         296
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A249                         297
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38176_FR2A2410                        298
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A112                                 299
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A113                                 300
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A114                                 301
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A115                                 302
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A116                                 303
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A117                                 304
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A118                                 305
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A119                                 306
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A27                                  307
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A28                                  308
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A29                                  309
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A210                                 310
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A211                                 311
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A212                                 312
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A213                                 313
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A214                                 314
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A215                                 315
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A216                                 316
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A335                                 317
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A336                                 318
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A337                                 319
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A338                                 320
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A3B5                                 321
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A3B6                                 322
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A3B7                                 323
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A3B8                                 324
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR1A429A                                325
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A101                                 326
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A1010                                327
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A1011                                328
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A1012                                329
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A102                                 330
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A103                                 331
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A104                                 332
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A105                                 333
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A106                                 334
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A107                                 335
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A108                                 336
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A109                                 337
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A327                                 338
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A3B1                                 339
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_FR2A3B2                                 340
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381411_FR1A81                         341
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381411_FR1A82                         342
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381411_FR1A83                         343
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381411_FR1A84                         344
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381411_FR1A85                         345
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381412_FR1A91                         346
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381412_FR1A92                         347
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381412_FR1A93                         348
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381412_FR1A94                         349
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS381412_FR1A95                         350
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A11                          351
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A12                          352
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A13                          353
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A14                          354
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A15                          355
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A16                          356
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A17                          357
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A18                          358
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A19                          359
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A21                          360
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A22                          361
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A23                          362
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A24                          363
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A25                          364
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A26                          365
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A31                          366
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A32                          367
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A33                          368
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A34                          369
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A35                          370
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A36                          371
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A3A1                         372
#define RSRFSIGGEN_VAL_5GNR_TCW_FRC_TS38181_FR1A3A3                         373

// RsRFSigGen_rng5GNRTCWizardFrequencyOffset
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_OFFSET_0HZ                             0
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_OFFSET_400HZ                           1
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_OFFSET_4000HZ                          2
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_OFFSET_625HZ                           3
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_OFFSET_1340HZ                          4
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_OFFSET_1740HZ                          5
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_OFFSET_2334HZ                          6
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_OFFSET_3334HZ                          7

// RsRFSigGen_rng5GNRTCWizardMappingType
#define RSRFSIGGEN_VAL_5GNR_TCW_MAPPING_TYPE_A                              0
#define RSRFSIGGEN_VAL_5GNR_TCW_MAPPING_TYPE_B                              1

// RsRFSigGen_rng5GNRTCWizardMode
#define RSRFSIGGEN_VAL_5GNR_TCW_MODE_DETECTION_RATE                         0
#define RSRFSIGGEN_VAL_5GNR_TCW_MODE_FALSE_DETECTION_RATE                   1

// RsRFSigGen_rng5GNRTCWizardPreambleFormat
#define RSRFSIGGEN_VAL_5GNR_TCW_PREAMBLE_FORMAT_0                           0
#define RSRFSIGGEN_VAL_5GNR_TCW_PREAMBLE_FORMAT_A1                          1
#define RSRFSIGGEN_VAL_5GNR_TCW_PREAMBLE_FORMAT_A2                          2
#define RSRFSIGGEN_VAL_5GNR_TCW_PREAMBLE_FORMAT_A3                          3
#define RSRFSIGGEN_VAL_5GNR_TCW_PREAMBLE_FORMAT_B4                          4
#define RSRFSIGGEN_VAL_5GNR_TCW_PREAMBLE_FORMAT_C0                          5
#define RSRFSIGGEN_VAL_5GNR_TCW_PREAMBLE_FORMAT_C2                          6

// RsRFSigGen_rng5GNRTCWizardPropagationCondition
#define RSRFSIGGEN_VAL_5GNR_PROPAGATION_AWGN                                0
#define RSRFSIGGEN_VAL_5GNR_PROPAGATION_TDLA30D10                           1
#define RSRFSIGGEN_VAL_5GNR_PROPAGATION_TDLB100D400                         2
#define RSRFSIGGEN_VAL_5GNR_PROPAGATION_TDLC300D100                         3
#define RSRFSIGGEN_VAL_5GNR_PROPAGATION_TDLA30D300                          4
#define RSRFSIGGEN_VAL_5GNR_PROPAGATION_TDLA30D75                           5
#define RSRFSIGGEN_VAL_5GNR_PROPAGATION_HST1NR350                           6
#define RSRFSIGGEN_VAL_5GNR_PROPAGATION_HST3NR350                           7
#define RSRFSIGGEN_VAL_5GNR_PROPAGATION_HST1NR500                           8
#define RSRFSIGGEN_VAL_5GNR_PROPAGATION_HST3NR500                           9
#define RSRFSIGGEN_VAL_5GNR_PROPAGATION_TDLC300D600                         10
#define RSRFSIGGEN_VAL_5GNR_PROPAGATION_TDLC300D1200                        11
#define RSRFSIGGEN_VAL_5GNR_PROPAGATION_MPX                                 12
#define RSRFSIGGEN_VAL_5GNR_PROPAGATION_MPY                                 13
#define RSRFSIGGEN_VAL_5GNR_PROPAGATION_MPZ                                 14

// RsRFSigGen_rng5GNRTCWizardSCSpacing
#define RSRFSIGGEN_VAL_5GNR_TCW_SC_SPACING_15KHZ                            1
#define RSRFSIGGEN_VAL_5GNR_TCW_SC_SPACING_30KHZ                            2
#define RSRFSIGGEN_VAL_5GNR_TCW_SC_SPACING_60KHZ                            3
#define RSRFSIGGEN_VAL_5GNR_TCW_SC_SPACING_120KHZ                           4
#define RSRFSIGGEN_VAL_5GNR_TCW_SC_SPACING_240KHZ                           5
#define RSRFSIGGEN_VAL_5GNR_TCW_SC_SPACING_60KHZ_EXTENDED                   6
#define RSRFSIGGEN_VAL_5GNR_TCW_SC_SPACING_480KHZ                           7
#define RSRFSIGGEN_VAL_5GNR_TCW_SC_SPACING_960KHZ                           8

// RsRFSigGen_rng5GNRTCWizardSCSpacingPRACH
#define RSRFSIGGEN_VAL_5GNR_TCW_SC_SPACING_1_25KHZ                          0

// RsRFSigGen_rng5GNRTCWizardTestSetup
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_SETUP_1                                0
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_SETUP_2                                1

// RsRFSigGen_rng5GNRTCWizardUCIBits
#define RSRFSIGGEN_VAL_5GNR_TCW_UCI_BITS_7                                  0
#define RSRFSIGGEN_VAL_5GNR_TCW_UCI_BITS_40                                 1

// RsRFSigGen_rng5GNRTCWizardFreqAlloc
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_ALLOC_LOW                              0
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_ALLOC_HIGH                             1

// RsRFSigGen_rng5GNRTCWizardISBand
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N1                                  0
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N2                                  1
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N3                                  2
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N5                                  3
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N7                                  4
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N8                                  5
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N12                                 6
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N20                                 7
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N25                                 8
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N28                                 9
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N34                                 10
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N38                                 11
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N39                                 12
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N40                                 13
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N41                                 14
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N50                                 15
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N51                                 16
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N66                                 17
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N70                                 18
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N71                                 19
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N74                                 20
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N75                                 21
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N76                                 22
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N77                                 23
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N78                                 24
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N79                                 25
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N80                                 26
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N81                                 27
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N82                                 28
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N83                                 29
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N84                                 30
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_BAND_N86                                 31

// RsRFSigGen_rng5GNRTestCaseWizardISOffsetFactor
#define RSRFSIGGEN_VAL_5GNR_TCW_OFFSET_FACTOR_N_1                           0
#define RSRFSIGGEN_VAL_5GNR_TCW_OFFSET_FACTOR_N_2                           1
#define RSRFSIGGEN_VAL_5GNR_TCW_OFFSET_FACTOR_N_3                           2

// RsRFSigGen_rng5GNRTCWizardISTestModel
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_MODEL_1_1                              0

// RsRFSigGen_rng5GNRTCWizardISInterfererType
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_INTERFERER_TYPE_NR                       0
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_INTERFERER_TYPE_NARROWBAND_NR            1
#define RSRFSIGGEN_VAL_5GNR_TCW_IS_INTERFERER_TYPE_CW                       2

// RsRFSigGen_rng5GNRTCWizardISTestRequirement
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_REQ_BLOCKING_PERFORMANCE               0
#define RSRFSIGGEN_VAL_5GNR_TCW_TEST_REQ_COLOCATED_BS                       1

// RsRFSigGen_rng5GNRTCWizardISFrequencyShift
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_SHIFT_M_0                              0
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_SHIFT_M_1                              1
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_SHIFT_M_2                              2
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_SHIFT_M_3                              3
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_SHIFT_M_4                              4
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_SHIFT_M_9                              5
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_SHIFT_M_14                             6
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_SHIFT_M_19                             7
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_SHIFT_M_24                             8
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_SHIFT_M_29                             9
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_SHIFT_M_54                             10
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_SHIFT_M_79                             11
#define RSRFSIGGEN_VAL_5GNR_TCW_FREQ_SHIFT_M_99                             12

// RsRFSigGen_rng5GNRTCWizardFeedbackRealtimeMode
#define RSRFSIGGEN_VAL_5GNR_TCW_FEEDBACK_MODE_SERIAL                        0
#define RSRFSIGGEN_VAL_5GNR_TCW_FEEDBACK_MODE_SERIAL_3X8                    1

// RsRFSigGen_rng5GNRTCWizardFeedbackSerialRate
#define RSRFSIGGEN_VAL_5GNR_TCW_FEEDBACK_RATE_115_2KBPS                     0
#define RSRFSIGGEN_VAL_5GNR_TCW_FEEDBACK_RATE_1_6MBPS                       1
#define RSRFSIGGEN_VAL_5GNR_TCW_FEEDBACK_RATE_1_92MBPS                      2

// RsRFSigGen_rng5GNRTCWizardFeedbackConnector
#define RSRFSIGGEN_VAL_5GNR_TCW_FEEDBACK_CONNECTOR_LOCAL                    0
#define RSRFSIGGEN_VAL_5GNR_TCW_FEEDBACK_CONNECTOR_GLOBAL                   1

// RsRFSigGen_rngSatNavGNSSPseudorangeMode
#define RSRFSIGGEN_VAL_PSEUDORANGE_MODE_FSBAS                               0
#define RSRFSIGGEN_VAL_PSEUDORANGE_MODE_CONSTANT                            1
#define RSRFSIGGEN_VAL_PSEUDORANGE_MODE_PROFILE                             2

// RsRFSigGen_rngSatNavGNSSSignalDynamicsVelocityProfile
#define RSRFSIGGEN_VAL_GNSS_VELOCITY_PROFILE_CONSTANT                       0
#define RSRFSIGGEN_VAL_GNSS_VELOCITY_PROFILE_HIGH                           1

// RsRFSigGen_rngSatNavGNSSSignalDynamicsPredefinedConfig
#define RSRFSIGGEN_VAL_GNSS_SIGNAL_DYNAMICS_CONFIG_USER                     0
#define RSRFSIGGEN_VAL_GNSS_SIGNAL_DYNAMICS_CONFIG_VEL1                     1
#define RSRFSIGGEN_VAL_GNSS_SIGNAL_DYNAMICS_CONFIG_VEL2                     2

// RsRFSigGen_rngSatNavGNSSEnvVerticalPredefined
#define RSRFSIGGEN_VAL_GNSS_RECEIVER_ENV_PREDEFINED_USER                    0
#define RSRFSIGGEN_VAL_GNSS_RECEIVER_ENV_PREDEFINED_URBAN_SQRT              1
#define RSRFSIGGEN_VAL_GNSS_RECEIVER_ENV_PREDEFINED_URBAN_LONG              2

// RsRFSigGen_rngSatNavGNSSReceiverEnvPhysicalModel
#define RSRFSIGGEN_VAL_GNSS_RECEIVER_ENV_PHYSICAL_MODEL_OBSC                0
#define RSRFSIGGEN_VAL_GNSS_RECEIVER_ENV_PHYSICAL_MODEL_OMP                 1

// RsRFSigGen_rngSatNavGNSSReceiverEnvRoadsideDisplay
#define RSRFSIGGEN_VAL_GNSS_RECEIVER_ENV_ROADSIDE_DISPLAY_DIST              0
#define RSRFSIGGEN_VAL_GNSS_RECEIVER_ENV_ROADSIDE_DISPLAY_HEIGHT            1

// RsRFSigGen_rngSatNavGNSSEnvGroundSeaMaterialProperty
#define RSRFSIGGEN_VAL_GNSS_ENV_GROUND_SEA_MATERIAL_PROPERTY_PERMITTIVITY   0
#define RSRFSIGGEN_VAL_GNSS_ENV_GROUND_SEA_MATERIAL_PROPERTY_PLOSS          1

// RsRFSigGen_rngSatNavGNSSEnvGroundSeaSurfaceType
#define RSRFSIGGEN_VAL_GNSS_ENV_GROUND_SEA_SURFACE_TYPE_USER                0
#define RSRFSIGGEN_VAL_GNSS_ENV_GROUND_SEA_SURFACE_TYPE_DRY                 1
#define RSRFSIGGEN_VAL_GNSS_ENV_GROUND_SEA_SURFACE_TYPE_MDRY                2
#define RSRFSIGGEN_VAL_GNSS_ENV_GROUND_SEA_SURFACE_TYPE_WET                 3
#define RSRFSIGGEN_VAL_GNSS_ENV_GROUND_SEA_SURFACE_TYPE_WATER               4
#define RSRFSIGGEN_VAL_GNSS_ENV_GROUND_SEA_SURFACE_TYPE_SEA                 5

// RsRFSigGen_rngSatNavGNSSReceiverEnvFullScale
#define RSRFSIGGEN_VAL_GNSS_RECEIVER_ENVIRONMENT_FULL_SCALE_TIME            0
#define RSRFSIGGEN_VAL_GNSS_RECEIVER_ENVIRONMENT_FULL_SCALE_DIST            1

// RsRFSigGen_rngSatNavGNSSAWGNAutoConfiguration
#define RSRFSIGGEN_VAL_GNSS_AWGN_CONFIG_AUTO                                0
#define RSRFSIGGEN_VAL_GNSS_AWGN_CONFIG_MANUAL                              1

// RsRFSigGen_rngSatNavGNSSStreamRFOutput
#define RSRFSIGGEN_VAL_GNSS_STREAM_OUT_RFA                                  0
#define RSRFSIGGEN_VAL_GNSS_STREAM_OUT_RFB                                  1
#define RSRFSIGGEN_VAL_GNSS_STREAM_OUT_NONE                                 2

// RsRFSigGen_rng5GNRPRSResourceSetCombSize
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_COMB_SIZE_2                    0
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_COMB_SIZE_4                    1
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_COMB_SIZE_6                    2
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_COMB_SIZE_12                   3

// RsRFSigGen_rng5GNRPRSResourceSetPeriodicity
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_PERIODICITY_4                  0
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_PERIODICITY_5                  1
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_PERIODICITY_8                  2
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_PERIODICITY_10                 3
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_PERIODICITY_16                 4
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_PERIODICITY_20                 5
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_PERIODICITY_32                 6
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_PERIODICITY_40                 7
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_PERIODICITY_64                 8
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_PERIODICITY_160                9
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_PERIODICITY_320                10
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_PERIODICITY_640                11
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_PERIODICITY_1280               12
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_PERIODICITY_2560               13
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_PERIODICITY_5120               14
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_PERIODICITY_10240              15

// RsRFSigGen_rng5GNRPRSResourceNumberOfSymbols
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SYMBOLS_2                          0
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SYMBOLS_4                          1
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SYMBOLS_6                          2
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SYMBOLS_12                         3

// RsRFSigGen_rng5GNRPRSResourceSetTimeGapT_gap
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_TIME_GAP_1                     0
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_TIME_GAP_2                     1
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_TIME_GAP_4                     2
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_TIME_GAP_8                     3
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_TIME_GAP_16                    4
#define RSRFSIGGEN_VAL_5GNR_PRS_RESOURCE_SET_TIME_GAP_32                    5

// RsRFSigGen_rngNR5GHARQACKCodebookR16
#define RSRFSIGGEN_VAL_NR5G_HARQ_CODEBOOK_R16_NOT_CONFIGURED                0
#define RSRFSIGGEN_VAL_NR5G_HARQ_CODEBOOK_R16_ENHANCED_DYNAMIC              1

// RsRFSigGen_rngNR5GSysInfoTimingAdvanceOffset
#define RSRFSIGGEN_VAL_NR5G_TIMING_ADVANCE_OFFSET_0                         0
#define RSRFSIGGEN_VAL_NR5G_TIMING_ADVANCE_OFFSET_25600                     1
#define RSRFSIGGEN_VAL_NR5G_TIMING_ADVANCE_OFFSET_39936                     2
#define RSRFSIGGEN_VAL_NR5G_TIMING_ADVANCE_OFFSET_13792                     3

// RsRFSigGen_rngNR5GTCISizeInDCI12
#define RSRFSIGGEN_VAL_NR5G_TCI_SIZE_UNCONFIGURED                           0
#define RSRFSIGGEN_VAL_NR5G_TCI_SIZE_1_BIT                                  1
#define RSRFSIGGEN_VAL_NR5G_TCI_SIZE_2_BITS                                 2
#define RSRFSIGGEN_VAL_NR5G_TCI_SIZE_3_BITS                                 3

// RsRFSigGen_rng5GNRFilterTestModelStandard
#define RSRFSIGGEN_VAL_5GNR_FILTER_TEST_MODEL_STANDARD_3GPP_NR              0
#define RSRFSIGGEN_VAL_5GNR_FILTER_TEST_MODEL_STANDARD_ORAN                 1

// RsRFSigGen_rng5GNROTABaseStationType
#define RSRFSIGGEN_VAL_5GNR_OTA_BASE_STATION_TYPE_1H                        0
#define RSRFSIGGEN_VAL_5GNR_OTA_BASE_STATION_TYPE_1O                        1
#define RSRFSIGGEN_VAL_5GNR_OTA_BASE_STATION_TYPE_2O                        2

// RsRFSigGen_rng5GNROTADeclaredDirection
#define RSRFSIGGEN_VAL_5GNR_OTA_DECLARED_DIRECTION_OTHER                    0
#define RSRFSIGGEN_VAL_5GNR_OTA_DECLARED_DIRECTION_MINSENS                  1
#define RSRFSIGGEN_VAL_5GNR_OTA_DECLARED_DIRECTION_REFSENS                  2

// RsRFSigGen_rng5GNROTAFrequencyRange
#define RSRFSIGGEN_VAL_5GNR_OTA_FREQUENCY_RANGE_LESS_THAN_33GHZ             0
#define RSRFSIGGEN_VAL_5GNR_OTA_FREQUENCY_RANGE_GREATER_THAN_37GHZ          1

// RsRFSigGen_rng5GNRMarkerInvert
#define RSRFSIGGEN_VAL_5GNR_MARKER_ACTIVE_HIGH                              0
#define RSRFSIGGEN_VAL_5GNR_MARKER_ACTIVE_LOW                               1

// RsRFSigGen_rng5GNRType1Granularity
#define RSRFSIGGEN_VAL_5GNR_TYPE_1_ALLOC_GRANULARITY_NOT_CONFIGURED         0
#define RSRFSIGGEN_VAL_5GNR_TYPE_1_ALLOC_GRANULARITY_2                      1
#define RSRFSIGGEN_VAL_5GNR_TYPE_1_ALLOC_GRANULARITY_4                      2
#define RSRFSIGGEN_VAL_5GNR_TYPE_1_ALLOC_GRANULARITY_8                      3
#define RSRFSIGGEN_VAL_5GNR_TYPE_1_ALLOC_GRANULARITY_16                     4

// RsRFSigGen_rng5GNRFullPowerTransmission
#define RSRFSIGGEN_VAL_5GNR_FULL_POWER_TRANSMISSION_NOT_CONFIGURED          0
#define RSRFSIGGEN_VAL_5GNR_FULL_POWER_TRANSMISSION_FULL_POWER              1
#define RSRFSIGGEN_VAL_5GNR_FULL_POWER_TRANSMISSION_FULL_POWER_MODE_1       2
#define RSRFSIGGEN_VAL_5GNR_FULL_POWER_TRANSMISSION_FULL_POWER_MODE_2       3

// RsRFSigGen_rng5GNROLPCParameterSet
#define RSRFSIGGEN_VAL_5GNR_OLPC_PARAMETER_NOT_CONFIGURED                   0
#define RSRFSIGGEN_VAL_5GNR_OLPC_PARAMETER_1_BIT                            1
#define RSRFSIGGEN_VAL_5GNR_OLPC_PARAMETER_2_BIT                            2

// RsRFSigGen_rng5GNRSRSConfiguredBy
#define RSRFSIGGEN_VAL_5GNR_CONFIGURED_BY_STANDARD_IE                       0
#define RSRFSIGGEN_VAL_5GNR_CONFIGURED_BY_IE_RELEASE_16                     1
#define RSRFSIGGEN_VAL_5GNR_CONFIGURED_BY_IENP_RELEASE_16                   2
#define RSRFSIGGEN_VAL_5GNR_CONFIGURED_BY_IE_RELEASE_17                     3

// RsRFSigGen_rng5GNRBitsForSRSRequest
#define RSRFSIGGEN_VAL_5GNR_BITS_FOR_SRS_REQUEST_NOT_CONFIGURED             0
#define RSRFSIGGEN_VAL_5GNR_BITS_FOR_SRS_REQUEST_1_BIT                      1
#define RSRFSIGGEN_VAL_5GNR_BITS_FOR_SRS_REQUEST_2_BITS                     2

// RsRFSigGen_rng5GNRAckNackFeedbackMode
#define RSRFSIGGEN_VAL_5GNR_ACK_NACK_FEEDBACK_MODE_NOT_CONFIGURED           0
#define RSRFSIGGEN_VAL_5GNR_ACK_NACK_FEEDBACK_MODE_JOINT                    1
#define RSRFSIGGEN_VAL_5GNR_ACK_NACK_FEEDBACK_MODE_SEPARATE                 2

// RsRFSigGen_rng5GNRSchedulingAllocationResultsMCSTable
#define RSRFSIGGEN_VAL_5GNR_MCS_TABLE_1                                     0
#define RSRFSIGGEN_VAL_5GNR_MCS_TABLE_2                                     1
#define RSRFSIGGEN_VAL_5GNR_MCS_TABLE_3                                     2
#define RSRFSIGGEN_VAL_5GNR_MCS_TABLE_TRANSFORM_PRECODING_1                 3
#define RSRFSIGGEN_VAL_5GNR_MCS_TABLE_TRANSFORM_PRECODING_2                 4

// RsRFSigGen_rng5GNRPTRSTPTimeDensity
#define RSRFSIGGEN_VAL_5G_NR_PTRS_TP_TIME_DENSITY_TD1                       0
#define RSRFSIGGEN_VAL_5G_NR_PTRS_TP_TIME_DENSITY_TD2                       1

// RsRFSigGen_rng5GNRRefMeasChannel
#define RSRFSIGGEN_VAL_5GNR_RMC_FDD_QPSK_15KHZ                              0
#define RSRFSIGGEN_VAL_5GNR_RMC_FDD_QPSK_30KHZ                              1
#define RSRFSIGGEN_VAL_5GNR_RMC_FDD_QPSK_60KHZ                              2
#define RSRFSIGGEN_VAL_5GNR_RMC_FDD_64QAM_15KHZ                             3
#define RSRFSIGGEN_VAL_5GNR_RMC_FDD_64QAM_30KHZ                             4
#define RSRFSIGGEN_VAL_5GNR_RMC_FDD_64QAM_60KHZ                             5
#define RSRFSIGGEN_VAL_5GNR_RMC_FDD_256QAM_15KHZ                            6
#define RSRFSIGGEN_VAL_5GNR_RMC_FDD_256QAM_30KHZ                            7
#define RSRFSIGGEN_VAL_5GNR_RMC_FDD_256QAM_60KHZ                            8
#define RSRFSIGGEN_VAL_5GNR_RMC_TDD_QPSK_15KHZ                              9
#define RSRFSIGGEN_VAL_5GNR_RMC_TDD_QPSK_30KHZ                              10
#define RSRFSIGGEN_VAL_5GNR_RMC_TDD_QPSK_60KHZ                              11
#define RSRFSIGGEN_VAL_5GNR_RMC_TDD_64QAM_15KHZ                             12
#define RSRFSIGGEN_VAL_5GNR_RMC_TDD_64QAM_30KHZ                             13
#define RSRFSIGGEN_VAL_5GNR_RMC_TDD_64QAM_60KHZ                             14
#define RSRFSIGGEN_VAL_5GNR_RMC_TDD_256QAM_15KHZ                            15
#define RSRFSIGGEN_VAL_5GNR_RMC_TDD_256QAM_30KHZ                            16
#define RSRFSIGGEN_VAL_5GNR_RMC_TDD_256QAM_60KHZ                            17
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR1A311                             18
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR1A312                             19
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR1A313                             20
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR1A314                             21
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR1A315                             22
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR2A311                             23
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR2A312                             24
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR2A313                             25
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR1A321                             26
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR2A321                             27
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR2A322                             28
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR1A331                             29
#define RSRFSIGGEN_VAL_5GNR_RMC_FR2TQ60                                     30
#define RSRFSIGGEN_VAL_5GNR_RMC_FR2TQ120                                    31
#define RSRFSIGGEN_VAL_5GNR_RMC_FR2T660                                     32
#define RSRFSIGGEN_VAL_5GNR_RMC_FR2T6120                                    33
#define RSRFSIGGEN_VAL_5GNR_RMC_FR2T260                                     34
#define RSRFSIGGEN_VAL_5GNR_RMC_FR2T2120                                    35
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR1A351                             36
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR1A352                             37
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR1A353                             38
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR1A354                             39
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR1A355                             40
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR1A356                             41
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR2A351                             42
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR2A352                             43
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR2A353                             44
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR1A341                             45
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR1A342                             46
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR1A343                             47
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR2A341                             48
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR2A342                             49
#define RSRFSIGGEN_VAL_5GNR_RMC_TS38176_FR2A343                             50

// RsRFSigGen_rng5GNRRMCModulation
#define RSRFSIGGEN_VAL_5GNR_RMC_MODULATION_QPSK                             0
#define RSRFSIGGEN_VAL_5GNR_RMC_MODULATION_64QAM                            1
#define RSRFSIGGEN_VAL_5GNR_RMC_MODULATION_256QAM                           2

// RsRFSigGen_rng5GNRRMCSubcarrierSpacing
#define RSRFSIGGEN_VAL_RMC_SCS_15KHZ                                        0
#define RSRFSIGGEN_VAL_RMC_SCS_30KHZ                                        1
#define RSRFSIGGEN_VAL_RMC_SCS_60KHZ                                        2

// RsRFSigGen_rng5GNRPRSSCSpacingCP
#define RSRFSIGGEN_VAL_5GNR_SRS_SCS_CP_NORMAL_15KHZ                         0
#define RSRFSIGGEN_VAL_5GNR_SRS_SCS_CP_NORMAL_30KHZ                         1
#define RSRFSIGGEN_VAL_5GNR_SRS_SCS_CP_NORMAL_60KHZ                         2
#define RSRFSIGGEN_VAL_5GNR_SRS_SCS_CP_NORMAL_120KHZ                        3
#define RSRFSIGGEN_VAL_5GNR_SRS_SCS_CP_EXTENDED_60KHZ                       4
#define RSRFSIGGEN_VAL_5GNR_SRS_SCS_CP_NORMAL_480KHZ                        5
#define RSRFSIGGEN_VAL_5GNR_SRS_SCS_CP_NORMAL_960KHZ                        6

// RsRFSigGen_rng5GNRPRSResourceSetRepetitionFactorT_rep
#define RSRFSIGGEN_VAL_5GNR_PRS_REPETITION_FACTOR_1                         0
#define RSRFSIGGEN_VAL_5GNR_PRS_REPETITION_FACTOR_2                         1
#define RSRFSIGGEN_VAL_5GNR_PRS_REPETITION_FACTOR_4                         2
#define RSRFSIGGEN_VAL_5GNR_PRS_REPETITION_FACTOR_8                         3
#define RSRFSIGGEN_VAL_5GNR_PRS_REPETITION_FACTOR_16                        4
#define RSRFSIGGEN_VAL_5GNR_PRS_REPETITION_FACTOR_32                        5

// RsRFSigGen_rngHRPUWBClippingMode
#define RSRFSIGGEN_VAL_HRP_UWB_CLIPPING_MODE_VECTOR                         0
#define RSRFSIGGEN_VAL_HRP_UWB_CLIPPING_MODE_SCALAR                         1

// RsRFSigGen_rngFrameSTSActiveSegmentsNumber
#define RSRFSIGGEN_VAL_FRAME_STS_ASN_1                                      0
#define RSRFSIGGEN_VAL_FRAME_STS_ASN_2                                      1
#define RSRFSIGGEN_VAL_FRAME_STS_ASN_3                                      2
#define RSRFSIGGEN_VAL_FRAME_STS_ASN_4                                      3

// RsRFSigGen_rngConvolutionalCodeConstraintLength
#define RSRFSIGGEN_VAL_FRAME_DATA_CCCL_CL3                                  0
#define RSRFSIGGEN_VAL_FRAME_DATA_CCCL_CL7                                  1

// RsRFSigGen_rngHRPUWBExternalClockMode
#define RSRFSIGGEN_VAL_HRP_UWB_EXTERNAL_CLOCK_MODE_SAMPLE                   0
#define RSRFSIGGEN_VAL_HRP_UWB_EXTERNAL_CLOCK_MODE_MSAMPLE                  1
#define RSRFSIGGEN_VAL_HRP_UWB_EXTERNAL_CLOCK_MODE_CSAMPLE                  2

// RsRFSigGen_rngHRPUWBClockSource
#define RSRFSIGGEN_VAL_HRP_UWB_CLOCK_SOURCE_INTERNAL                        0
#define RSRFSIGGEN_VAL_HRP_UWB_CLOCK_SOURCE_ELCLOCK                         1
#define RSRFSIGGEN_VAL_HRP_UWB_CLOCK_SOURCE_EXTERNAL                        2

// RsRFSigGen_rngFrameCodeIndex
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_1                                0
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_2                                1
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_3                                2
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_4                                3
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_5                                4
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_6                                5
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_7                                6
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_8                                7
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_9                                8
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_10                               9
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_11                               10
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_12                               11
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_13                               12
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_14                               13
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_15                               14
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_16                               15
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_17                               16
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_18                               17
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_19                               18
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_20                               19
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_21                               20
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_22                               21
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_23                               22
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_24                               23
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_25                               24
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_26                               25
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_27                               26
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_28                               27
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_29                               28
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_30                               29
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_31                               30
#define RSRFSIGGEN_VAL_FRAME_CODE_INDEX_CI_32                               31

// RsRFSigGen_rngFrameDataChipsPerBurst
#define RSRFSIGGEN_VAL_FRAME_DATA_CHIPS_PER_BURST_CPB_1                     0
#define RSRFSIGGEN_VAL_FRAME_DATA_CHIPS_PER_BURST_CPB_2                     1
#define RSRFSIGGEN_VAL_FRAME_DATA_CHIPS_PER_BURST_CPB_4                     2
#define RSRFSIGGEN_VAL_FRAME_DATA_CHIPS_PER_BURST_CPB_16                    3
#define RSRFSIGGEN_VAL_FRAME_DATA_CHIPS_PER_BURST_CPB_8                     4
#define RSRFSIGGEN_VAL_FRAME_DATA_CHIPS_PER_BURST_CPB_32                    5
#define RSRFSIGGEN_VAL_FRAME_DATA_CHIPS_PER_BURST_CPB_64                    6
#define RSRFSIGGEN_VAL_FRAME_DATA_CHIPS_PER_BURST_CPB_128                   7
#define RSRFSIGGEN_VAL_FRAME_DATA_CHIPS_PER_BURST_CPB_512                   8

// RsRFSigGen_rngFrameDataSource
#define RSRFSIGGEN_VAL_FRAME_DATA_SOURCE_ALL0                               0
#define RSRFSIGGEN_VAL_FRAME_DATA_SOURCE_ALL1                               1
#define RSRFSIGGEN_VAL_FRAME_DATA_SOURCE_DLIST                              2
#define RSRFSIGGEN_VAL_FRAME_DATA_SOURCE_PATT                               3
#define RSRFSIGGEN_VAL_FRAME_DATA_SOURCE_PN9                                4
#define RSRFSIGGEN_VAL_FRAME_DATA_SOURCE_PN11                               5
#define RSRFSIGGEN_VAL_FRAME_DATA_SOURCE_PN15                               6
#define RSRFSIGGEN_VAL_FRAME_DATA_SOURCE_PN20                               7
#define RSRFSIGGEN_VAL_FRAME_DATA_SOURCE_PN16                               8
#define RSRFSIGGEN_VAL_FRAME_DATA_SOURCE_PN21                               9
#define RSRFSIGGEN_VAL_FRAME_DATA_SOURCE_PN23                               10

// RsRFSigGen_rngFrameDeltaLength
#define RSRFSIGGEN_VAL_FRAME_DELTA_LENGTH_DL_4                              0
#define RSRFSIGGEN_VAL_FRAME_DELTA_LENGTH_DL_16                             1
#define RSRFSIGGEN_VAL_FRAME_DELTA_LENGTH_DL_64                             2

// RsRFSigGen_rngFrameDataHopBursts
#define RSRFSIGGEN_VAL_FRAME_DATA_HOP_BURSTS_HB_2                           0
#define RSRFSIGGEN_VAL_FRAME_DATA_HOP_BURSTS_HB_8                           1
#define RSRFSIGGEN_VAL_FRAME_DATA_HOP_BURSTS_HB_32                          2

// RsRFSigGen_rngFrameSFDLength
#define RSRFSIGGEN_VAL_FRAME_SFD_LENGTH_SFDL_8                              0
#define RSRFSIGGEN_VAL_FRAME_SFD_LENGTH_SFDL_64                             1
#define RSRFSIGGEN_VAL_FRAME_SFD_LENGTH_SFDL_4                              2
#define RSRFSIGGEN_VAL_FRAME_SFD_LENGTH_SFDL_16                             3
#define RSRFSIGGEN_VAL_FRAME_SFD_LENGTH_SFDL_32                             4

// RsRFSigGen_rngFrameSyncLength
#define RSRFSIGGEN_VAL_FRAME_SYNC_LENGTH_SL_16                              0
#define RSRFSIGGEN_VAL_FRAME_SYNC_LENGTH_SL_24                              1
#define RSRFSIGGEN_VAL_FRAME_SYNC_LENGTH_SL_32                              2
#define RSRFSIGGEN_VAL_FRAME_SYNC_LENGTH_SL_48                              3
#define RSRFSIGGEN_VAL_FRAME_SYNC_LENGTH_SL_64                              4
#define RSRFSIGGEN_VAL_FRAME_SYNC_LENGTH_SL_96                              5
#define RSRFSIGGEN_VAL_FRAME_SYNC_LENGTH_SL_128                             6
#define RSRFSIGGEN_VAL_FRAME_SYNC_LENGTH_SL_256                             7
#define RSRFSIGGEN_VAL_FRAME_SYNC_LENGTH_SL_1024                            8
#define RSRFSIGGEN_VAL_FRAME_SYNC_LENGTH_SL_4096                            9

// RsRFSigGen_rngHRPUWBFilterOversamplingFactor
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_OVERSAMPLING_OS_1                     0
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_OVERSAMPLING_OS_2                     1
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_OVERSAMPLING_OS_3                     2
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_OVERSAMPLING_OS_4                     3
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_OVERSAMPLING_OS_5                     4
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_OVERSAMPLING_OS_6                     5
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_OVERSAMPLING_OS_7                     6
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_OVERSAMPLING_OS_8                     7

// RsRFSigGen_rngHRPUWBFilterLTEOptimization
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_OPTIMIZATION_EVM                      0
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_OPTIMIZATION_STD                      1
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_OPTIMIZATION_ACP                      2
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_OPTIMIZATION_ACPN                     3
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_OPTIMIZATION_BENU                     4

// RsRFSigGen_rngHRPUWBFilterType
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_RCOSINE                          0
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_COSINE                           1
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_GAUSS                            2
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_LGAUSS                           3
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_CONE                             4
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_COF705                           5
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_COEQUALIZER                      6
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_COFEQUALIZER                     7
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_C2K3X                            8
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_APCO25                           9
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_SPHASE                           10
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_RECTANGLE                        11
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_USER                             12
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_PGAUSS                           13
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_LPASS                            14
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_DIRAC                            15
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_ENPSHAPE                         16
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_EWPSHAPE                         17
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_LTEFILTER                        18
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_LPASSEVM                         19
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_APCO25HCPM                       20
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_APCO25LSM                        21
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_HRP                              22
#define RSRFSIGGEN_VAL_HRP_UWB_FILTER_TYPE_SOQPSK                           23

// RsRFSigGen_rngMACHeaderFrameControlLength
#define RSRFSIGGEN_VAL_MAC_HEADER_FRAME_CONTROL_LEN_L1                      0
#define RSRFSIGGEN_VAL_MAC_HEADER_FRAME_CONTROL_LEN_L2                      1

// RsRFSigGen_rngMACHeaderAddressLength
#define RSRFSIGGEN_VAL_MAC_HEADER_ADDRESS_LEN_L0                            0
#define RSRFSIGGEN_VAL_MAC_HEADER_ADDRESS_LEN_L2                            1
#define RSRFSIGGEN_VAL_MAC_HEADER_ADDRESS_LEN_L8                            2

// RsRFSigGen_rngMACHeaderSequenceNumberLength
#define RSRFSIGGEN_VAL_MAC_HEADER_SEQUENCE_NUMBER_LEN_L0                    0
#define RSRFSIGGEN_VAL_MAC_HEADER_SEQUENCE_NUMBER_LEN_L1                    1

// RsRFSigGen_rngMACHeaderPANIDLength
#define RSRFSIGGEN_VAL_MAC_HEADER_PAN_ID_LEN_L0                             0
#define RSRFSIGGEN_VAL_MAC_HEADER_PAN_ID_LEN_L2                             1

// RsRFSigGen_rngFramePHRDataRateMode
#define RSRFSIGGEN_VAL_FRAME_PHR_DATA_RATE_MODE_BMLP                        0
#define RSRFSIGGEN_VAL_FRAME_PHR_DATA_RATE_MODE_BMHP                        1
#define RSRFSIGGEN_VAL_FRAME_PHR_DATA_RATE_MODE_HMLR                        2
#define RSRFSIGGEN_VAL_FRAME_PHR_DATA_RATE_MODE_HMHR                        3

// RsRFSigGen_rngFrameSFD
#define RSRFSIGGEN_VAL_FRAME_SFD_0                                          0
#define RSRFSIGGEN_VAL_FRAME_SFD_1                                          1
#define RSRFSIGGEN_VAL_FRAME_SFD_2                                          2
#define RSRFSIGGEN_VAL_FRAME_SFD_3                                          3
#define RSRFSIGGEN_VAL_FRAME_SFD_4                                          4
#define RSRFSIGGEN_VAL_FRAME_SFD_5                                          5
#define RSRFSIGGEN_VAL_FRAME_SFD_6                                          6
#define RSRFSIGGEN_VAL_FRAME_SFD_7                                          7
#define RSRFSIGGEN_VAL_FRAME_SFD_8                                          8

// RsRFSigGen_rngFrameSTSDeltaLength
#define RSRFSIGGEN_VAL_FRAME_STS_DELTA_LENGTH_DL_4                          0
#define RSRFSIGGEN_VAL_FRAME_STS_DELTA_LENGTH_DL_8                          1

// RsRFSigGen_rngSTSPacketConfiguration
#define RSRFSIGGEN_VAL_FRAME_STS_PACKET_CONFIG_SPC_0                        0
#define RSRFSIGGEN_VAL_FRAME_STS_PACKET_CONFIG_SPC_1                        1
#define RSRFSIGGEN_VAL_FRAME_STS_PACKET_CONFIG_SPC_2                        2
#define RSRFSIGGEN_VAL_FRAME_STS_PACKET_CONFIG_SPC_3                        3

// RsRFSigGen_rngHRPUWBMode
#define RSRFSIGGEN_VAL_HRP_UWB_MODE_NON_ERDEV                               0
#define RSRFSIGGEN_VAL_HRP_UWB_MODE_BPRF                                    1
#define RSRFSIGGEN_VAL_HRP_UWB_MODE_HPRF                                    2

// RsRFSigGen_rngHRPUWBMarkerMode
#define RSRFSIGGEN_VAL_HRP_UWB_MARKER_MODE_RESTART                          0

// RsRFSigGen_rngTriggerSignalGenerationStatus
#define RSRFSIGGEN_VAL_TRIGGER_SIGNAL_GENERATION_STATUS_STOP                0
#define RSRFSIGGEN_VAL_TRIGGER_SIGNAL_GENERATION_STATUS_RUN                 1

// RsRFSigGen_rngHRPUWBFrameActiveSegmentLength
#define RSRFSIGGEN_VAL_HRP_UWB_FRAME_ACTIVE_SEGMENT_LEN_16                  0
#define RSRFSIGGEN_VAL_HRP_UWB_FRAME_ACTIVE_SEGMENT_LEN_32                  1
#define RSRFSIGGEN_VAL_HRP_UWB_FRAME_ACTIVE_SEGMENT_LEN_64                  2
#define RSRFSIGGEN_VAL_HRP_UWB_FRAME_ACTIVE_SEGMENT_LEN_128                 3
#define RSRFSIGGEN_VAL_HRP_UWB_FRAME_ACTIVE_SEGMENT_LEN_256                 4
#define RSRFSIGGEN_VAL_HRP_UWB_FRAME_ACTIVE_SEGMENT_LEN_512                 5
#define RSRFSIGGEN_VAL_HRP_UWB_FRAME_ACTIVE_SEGMENT_LEN_1024                6
#define RSRFSIGGEN_VAL_HRP_UWB_FRAME_ACTIVE_SEGMENT_LEN_2048                7

// RsRFSigGen_rngHRPUWBFrameDataViterbiRate
#define RSRFSIGGEN_VAL_HRP_UWB_FRAME_VITERBI_RATE_HALF                      0
#define RSRFSIGGEN_VAL_HRP_UWB_FRAME_VITERBI_RATE_ONE                       1

// RsRFSigGen_rngFrontedAttenuationMode
#define RSRFSIGGEN_VAL_FRONTED_ATTENUATION_MODE_AUTO                        0
#define RSRFSIGGEN_VAL_FRONTED_ATTENUATION_MODE_MANUAL                      1
#define RSRFSIGGEN_VAL_FRONTED_ATTENUATION_MODE_ADDED_OFFSET                2

// RsRFSigGen_rngFrontendConnectionMode
#define RSRFSIGGEN_VAL_FRONTEND_CONNECTION_MODE_AUTO                        0
#define RSRFSIGGEN_VAL_FRONTEND_CONNECTION_MODE_LOCK                        1
#define RSRFSIGGEN_VAL_FRONTEND_CONNECTION_MODE_RXTX                        2

// RsRFSigGen_rngBasebandBandwidth
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BB_BANDWIDTH_BB040              0
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BB_BANDWIDTH_BB050              1
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BB_BANDWIDTH_BB080              2
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BB_BANDWIDTH_BB100              3
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BB_BANDWIDTH_BB120              4
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BB_BANDWIDTH_BB160              5
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BB_BANDWIDTH_BB200              6
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BB_BANDWIDTH_BB240              7
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BB_BANDWIDTH_BB400              8
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BB_BANDWIDTH_BB500              9
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BB_BANDWIDTH_BB800              10
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BB_BANDWIDTH_BB1G               11
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BB_BANDWIDTH_BB2G               12
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BB_BBOUTDEF                     13

// RsRFSigGen_rngSystemConfigurationHSChannelsperBBMM
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BBM_CH0                         0
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BBM_CH1                         1
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BBM_CH2                         2
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BBM_CH3                         3
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BBM_CH4                         4
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BBM_CH5                         5
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BBM_CH6                         6
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BBM_CH7                         7
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_BBM_CH8                         8

// RsRFSigGen_rngSystemGPIBLineTerminator
#define RSRFSIGGEN_VAL_SYSTEM_GPIB_LINE_TERMINATOR_EOI                      0
#define RSRFSIGGEN_VAL_SYSTEM_GPIB_LINE_TERMINATOR_STANDARD                 1

// RsRFSigGen_rngSystemIdentificationMode
#define RSRFSIGGEN_VAL_SYSTEM_IDENTIFICATION_MODE_AUTO                      0
#define RSRFSIGGEN_VAL_SYSTEM_IDENTIFICATION_MODE_USER                      1

// RsRFSigGen_rngHUMSDataFormat
#define RSRFSIGGEN_VAL_DIAGNOSTIC_HUMS_DATA_FORMAT_JSON                     0
#define RSRFSIGGEN_VAL_DIAGNOSTIC_HUMS_DATA_FORMAT_XML                      1

// RsRFSigGen_rngSystemConfigurationCABandwidth
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_CA_BANDWIDTH_BB800              0
#define RSRFSIGGEN_VAL_SYSTEM_CONFIGURATION_CA_BANDWIDTH_BB200              1

// RsRFSigGen_rngTestDirectParameter
#define RSRFSIGGEN_VAL_TEST_DIRECT_PARAMETER_SSYN                           0
#define RSRFSIGGEN_VAL_TEST_DIRECT_PARAMETER_SSYNEX                         1
#define RSRFSIGGEN_VAL_TEST_DIRECT_PARAMETER_IQOP3                          2
#define RSRFSIGGEN_VAL_TEST_DIRECT_PARAMETER_IQOP6                          3
#define RSRFSIGGEN_VAL_TEST_DIRECT_PARAMETER_SATT3                          4
#define RSRFSIGGEN_VAL_TEST_DIRECT_PARAMETER_SATT6                          5
#define RSRFSIGGEN_VAL_TEST_DIRECT_PARAMETER_BBINS                          6
#define RSRFSIGGEN_VAL_TEST_DIRECT_PARAMETER_DIRECTLAST                     7

// RsRFSigGen_rngSecurityUpdatePolicy
#define RSRFSIGGEN_VAL_SECURITY_UPDATE_POLICY_STRICT                        0
#define RSRFSIGGEN_VAL_SECURITY_UPDATE_POLICY_CONFIRM                       1
#define RSRFSIGGEN_VAL_SECURITY_UPDATE_POLICY_IGNORE                        2

// RsRFSigGen_rngWLANNFrameUserMRUIndex
#define RSRFSIGGEN_VAL_WLANN_FRAME_USER_MRU1                                0
#define RSRFSIGGEN_VAL_WLANN_FRAME_USER_MRU2                                1
#define RSRFSIGGEN_VAL_WLANN_FRAME_USER_MRU3                                2
#define RSRFSIGGEN_VAL_WLANN_FRAME_USER_MRU4                                3
#define RSRFSIGGEN_VAL_WLANN_FRAME_USER_MRU5                                4
#define RSRFSIGGEN_VAL_WLANN_FRAME_USER_MRU6                                5
#define RSRFSIGGEN_VAL_WLANN_FRAME_USER_MRU7                                6
#define RSRFSIGGEN_VAL_WLANN_FRAME_USER_MRU8                                7
#define RSRFSIGGEN_VAL_WLANN_FRAME_USER_MRU9                                8
#define RSRFSIGGEN_VAL_WLANN_FRAME_USER_MRU10                               9
#define RSRFSIGGEN_VAL_WLANN_FRAME_USER_MRU11                               10
#define RSRFSIGGEN_VAL_WLANN_FRAME_USER_MRU12                               11

// RsRFSigGen_rngEUTRADLNBIoTWakeUpSignalDuration
#define RSRFSIGGEN_VAL_EUTRA_NB_IOT_WAKE_UP_DN_1                            0
#define RSRFSIGGEN_VAL_EUTRA_NB_IOT_WAKE_UP_DN_2                            1
#define RSRFSIGGEN_VAL_EUTRA_NB_IOT_WAKE_UP_DN_4                            2
#define RSRFSIGGEN_VAL_EUTRA_NB_IOT_WAKE_UP_DN_8                            3
#define RSRFSIGGEN_VAL_EUTRA_NB_IOT_WAKE_UP_DN_16                           4
#define RSRFSIGGEN_VAL_EUTRA_NB_IOT_WAKE_UP_DN_32                           5
#define RSRFSIGGEN_VAL_EUTRA_NB_IOT_WAKE_UP_DN_64                           6
#define RSRFSIGGEN_VAL_EUTRA_NB_IOT_WAKE_UP_DN_128                          7
#define RSRFSIGGEN_VAL_EUTRA_NB_IOT_WAKE_UP_DN_256                          8
#define RSRFSIGGEN_VAL_EUTRA_NB_IOT_WAKE_UP_DN_512                          9
#define RSRFSIGGEN_VAL_EUTRA_NB_IOT_WAKE_UP_DN_1024                         10

// RsRFSigGen_rngEUTRADLNBIoTWakeUpSignalTimeOffset
#define RSRFSIGGEN_VAL_EUTRA_NB_IOT_WAKE_UP_TIME_OFFSET_40                  0
#define RSRFSIGGEN_VAL_EUTRA_NB_IOT_WAKE_UP_TIME_OFFSET_80                  1
#define RSRFSIGGEN_VAL_EUTRA_NB_IOT_WAKE_UP_TIME_OFFSET_160                 2
#define RSRFSIGGEN_VAL_EUTRA_NB_IOT_WAKE_UP_TIME_OFFSET_240                 3

// RsRFSigGen_rngEUTRATestCaseWizardDIP
#define RSRFSIGGEN_VAL_EUTRA_TEST_CASE_WIZARD_DIP_SET1                      0
#define RSRFSIGGEN_VAL_EUTRA_TEST_CASE_WIZARD_DIP_SET2                      1

// RsRFSigGen_rngEUTRATestCaseWizardCEMode
#define RSRFSIGGEN_VAL_EUTRA_TEST_CASE_CE_MODE_A                            0
#define RSRFSIGGEN_VAL_EUTRA_TEST_CASE_CE_MODE_B                            1

// RsRFSigGen_rngEUTRATestCaseWizardRepetitions
#define RSRFSIGGEN_VAL_EUTRA_TEST_CASE_WIZARD_REPETITIONS_R1                0
#define RSRFSIGGEN_VAL_EUTRA_TEST_CASE_WIZARD_REPETITIONS_R2                1
#define RSRFSIGGEN_VAL_EUTRA_TEST_CASE_WIZARD_REPETITIONS_R4                2
#define RSRFSIGGEN_VAL_EUTRA_TEST_CASE_WIZARD_REPETITIONS_R8                3
#define RSRFSIGGEN_VAL_EUTRA_TEST_CASE_WIZARD_REPETITIONS_R16               4
#define RSRFSIGGEN_VAL_EUTRA_TEST_CASE_WIZARD_REPETITIONS_R32               5
#define RSRFSIGGEN_VAL_EUTRA_TEST_CASE_WIZARD_REPETITIONS_R64               6

// RsRFSigGen_rngEUTRAFRC
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A11                0
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A12                1
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A13                2
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A14                3
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A15                4
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A21                5
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A22                6
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A23                7
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A31                8
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A32                9
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A33                10
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A34                11
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A35                12
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A36                13
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A37                14
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A41                15
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A42                16
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A43                17
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A44                18
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A45                19
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A46                20
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A47                21
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A48                22
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A51                23
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A52                24
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A53                25
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A54                26
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A55                27
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A56                28
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A57                29
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A71                30
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A72                31
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A73                32
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A74                33
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A75                34
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A76                35
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A81                36
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A82                37
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A83                38
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A84                39
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A85                40
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A86                41
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_UE11               42
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_UE12               43
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_UE21               44
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_UE22               45
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_UE3                46
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A16                47
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A17                48
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A121               49
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A122               50
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A123               51
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A124               52
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A125               53
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A126               54
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A131               55
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A132               56
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A133               57
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A134               58
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A135               59
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A136               60
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A171               61
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A172               62
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A173               63
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A174               64
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A175               65
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A176               66
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A181               67
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A182               68
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A183               69
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A184               70
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A185               71
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A186               72
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A191               73
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A192               74
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A193               75
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A194               76
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A195               77
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A196               78
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A211               79
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A212               80
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A213               81
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A214               82
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A215               83
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A216               84
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A221               85
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A222               86
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A223               87
#define RSRFSIGGEN_VAL_EUTRA_LTE_FIXED_REFERENCE_CHANNEL_A224               88

// RsRFSigGen_rngExtSeqStreamOutput
#define RSRFSIGGEN_VAL_EXT_SEQ_STREAM_OUTPUT_NONE                           0
#define RSRFSIGGEN_VAL_EXT_SEQ_STREAM_OUTPUT_RFA                            1
#define RSRFSIGGEN_VAL_EXT_SEQ_STREAM_OUTPUT_RFB                            2

// RsRFSigGen_rngExtSeqRTCIPDWFormat
#define RSRFSIGGEN_VAL_EXT_SEQUENCER_PDW_FORMAT_BASIC                       0
#define RSRFSIGGEN_VAL_EXT_SEQUENCER_PDW_FORMAT_EXPERT                      1

// RsRFSigGen_rngSatNavClockSource
#define RSRFSIGGEN_VAL_SATNAV_CLOCK_SOURCE_INTERNAL                         0
#define RSRFSIGGEN_VAL_SATNAV_CLOCK_SOURCE_EXTERNAL_LOCAL                   1
#define RSRFSIGGEN_VAL_SATNAV_CLOCK_SOURCE_EXTERNAL_LEGACY                  2

// RsRFSigGen_rngSatNavErrorCorrectionMode
#define RSRFSIGGEN_VAL_SATNAV_ERROR_CORRECTION_AUTO                         0
#define RSRFSIGGEN_VAL_SATNAV_ERROR_CORRECTION_SYNC                         1
#define RSRFSIGGEN_VAL_SATNAV_ERROR_CORRECTION_USER                         2

// RsRFSigGen_rngGNSSStaticMultipathSVID
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_ALL                       0
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_1                         1
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_2                         2
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_3                         3
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_5                         4
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_4                         5
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_6                         6
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_7                         7
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_8                         8
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_9                         9
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_10                        10
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_11                        11
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_12                        12
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_13                        13
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_14                        14
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_15                        15
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_16                        16
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_17                        17
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_19                        18
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_18                        19
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_20                        20
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_21                        21
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_22                        22
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_23                        23
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_24                        24
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_25                        25
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_26                        26
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_27                        27
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_28                        28
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_29                        29
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_30                        30
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_31                        31
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_32                        32
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_33                        33
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_34                        34
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_35                        35
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_36                        36
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_37                        37
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_38                        38
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_39                        39
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_40                        40
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_41                        41
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_42                        42
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_43                        43
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_44                        44
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_45                        45
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_46                        46
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_47                        47
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_48                        48
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_49                        49
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_50                        50
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_51                        51
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_52                        52
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_53                        53
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_54                        54
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_55                        55
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_56                        56
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_57                        57
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_58                        58
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_59                        59
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_60                        60
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_61                        61
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_62                        62
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_63                        63
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_64                        64
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_65                        65
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_66                        66
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_67                        67
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_68                        68
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_69                        69
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_70                        70
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_71                        71
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_72                        72
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_73                        73
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_74                        74
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_75                        75
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_76                        76
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_77                        77
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_78                        78
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_79                        79
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_80                        80
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_81                        81
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_82                        82
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_83                        83
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_84                        84
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_85                        85
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_86                        86
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_87                        87
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_88                        88
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_89                        89
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_90                        90
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_91                        91
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_92                        92
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_93                        93
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_94                        94
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_95                        95
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_96                        96
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_97                        97
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_98                        98
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_99                        99
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_100                       100
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_101                       101
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_102                       102
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_103                       103
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_104                       104
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_105                       105
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_106                       106
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_107                       107
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_108                       108
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_109                       109
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_110                       110
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_111                       111
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_112                       112
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_113                       113
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_114                       114
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_115                       115
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_116                       116
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_117                       117
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_118                       118
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_119                       119
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_120                       120
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_121                       121
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_122                       122
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_123                       123
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_124                       124
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_125                       125
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_126                       126
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_127                       127
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_128                       128
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_129                       129
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_130                       130
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_131                       131
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_132                       132
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_133                       133
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_134                       134
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_135                       135
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_136                       136
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_137                       137
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_138                       138
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_139                       139
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_140                       140
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_141                       141
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_142                       142
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_143                       143
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_144                       144
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_145                       145
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_146                       146
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_147                       147
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_148                       148
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_149                       149
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_150                       150
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_151                       151
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_152                       152
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_153                       153
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_154                       154
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_155                       155
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_156                       156
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_157                       157
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_158                       158
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_159                       159
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_160                       160
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_161                       161
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_162                       162
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_163                       163
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_164                       164
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_165                       165
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_166                       166
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_167                       167
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_168                       168
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_169                       169
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_170                       170
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_171                       171
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_172                       172
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_173                       173
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_174                       174
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_175                       175
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_176                       176
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_177                       177
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_178                       178
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_179                       179
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_180                       180
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_181                       181
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_182                       182
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_183                       183
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_184                       184
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_185                       185
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_186                       186
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_187                       187
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_188                       188
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_189                       189
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_190                       190
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_191                       191
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_192                       192
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_193                       193
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_194                       194
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_195                       195
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_196                       196
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_197                       197
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_198                       198
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_199                       199
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_SVID_200                       200

// RsRFSigGen_rngGNSSStaticMultipathStandard
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_STANDARD_GPS                   0
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_STANDARD_GALILEO               1
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_STANDARD_GLONASS               2
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_STANDARD_BEIDOU                3
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_STANDARD_QZSS                  4
#define RSRFSIGGEN_VAL_GNSS_STATIC_MULTIPATH_STANDARD_SBAS                  5

// RsRFSigGen_rngGNSSEnvironmentModel
#define RSRFSIGGEN_VAL_GNSS_ENVIRONMENT_MODEL_LINE_OF_SIGHT                 0
#define RSRFSIGGEN_VAL_GNSS_ENVIRONMENT_MODEL_MULTIPATH                     1

// RsRFSigGen_rngSatNavVehicle
#define RSRFSIGGEN_VAL_SAT_NAV_VEHICLE_1                                    1
#define RSRFSIGGEN_VAL_SAT_NAV_VEHICLE_2                                    2

// RsRFSigGen_rngSatNavGNSSEarthObscurationReference
#define RSRFSIGGEN_VAL_SATNAV_EARTH_OBSCURATION_EARTH_TANGENT               0
#define RSRFSIGGEN_VAL_SATNAV_EARTH_OBSCURATION_LOCAL_HORIZON               1

// RsRFSigGen_rngSatNavSVSelectionMode
#define RSRFSIGGEN_VAL_SATNAV_SV_SELECTION_MODE_MANUAL                      0
#define RSRFSIGGEN_VAL_SATNAV_SV_SELECTION_MODE_ELEVATION                   1
#define RSRFSIGGEN_VAL_SATNAV_SV_SELECTION_MODE_VISIBILITY                  2
#define RSRFSIGGEN_VAL_SATNAV_SV_SELECTION_MODE_DOP                         3
#define RSRFSIGGEN_VAL_SATNAV_SV_SELECTION_MODE_ADOP                        4

// RsRFSigGen_rngSatNavTestMode
#define RSRFSIGGEN_VAL_SATNAV_TEST_MODE_NAVIGATION                          0
#define RSRFSIGGEN_VAL_SATNAV_TEST_MODE_TRACKING                            1

// RsRFSigGen_rngSatNavGNSSMarkerMode
#define RSRFSIGGEN_VAL_GNSS_MARKER_MODE_PULSE                               0
#define RSRFSIGGEN_VAL_GNSS_MARKER_MODE_PATTERN                             1
#define RSRFSIGGEN_VAL_GNSS_MARKER_MODE_RATIO                               2
#define RSRFSIGGEN_VAL_GNSS_MARKER_MODE_PULSE_PER_SECOND                    3
#define RSRFSIGGEN_VAL_GNSS_MARKER_MODE_PULSE_PER_2_SECONDS                 4
#define RSRFSIGGEN_VAL_GNSS_MARKER_MODE_PULSE_10_PER_SECOND                 5

// RsRFSigGen_rngHUMSProtocolSNMP
#define RSRFSIGGEN_VAL_HUMS_PROTOCOL_SNMP_OFF                               0
#define RSRFSIGGEN_VAL_HUMS_PROTOCOL_SNMP_V12                               1
#define RSRFSIGGEN_VAL_HUMS_PROTOCOL_SNMP_V123                              2
#define RSRFSIGGEN_VAL_HUMS_PROTOCOL_SNMP_V3                                3

// RsRFSigGen_rng5GNRLinkDirection
#define RSRFSIGGEN_VAL_5G_NR5_G_LINK_DIRECTION_DOWN                         0
#define RSRFSIGGEN_VAL_5G_NR5_G_LINK_DIRECTION_SIDE                         1
#define RSRFSIGGEN_VAL_5G_NR5_G_LINK_DIRECTION_UP                           2

// RsRFSigGen_rng5GNRNodeNewSource
#define RSRFSIGGEN_VAL_5G_NR_NODE_NEW_SOURCE_CARRIER                        0
#define RSRFSIGGEN_VAL_5G_NR_NODE_NEW_SOURCE_LOAD                           1

// RsRFSigGen_rng5GNRFilterTestCase
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_ALL                           0
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC323110                      1
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC323112                      2
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC323114                      3
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32311                       4
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32312                       5
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32314                       6
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32316                       7
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32318                       8
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32511                       9
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32512                       10
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32513                       11
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32514                       12
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32515                       13
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32516                       14
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32517                       15
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32518                       16
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32611                       17
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32612                       18
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32613                       19
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32614                       20
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32615                       21
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32313                       22
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32315                       23
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32317                       24
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32319                       25
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32381                       26
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC323111                      27
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC323113                      28
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC323115                      29
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC323117                      30
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC323121                      31
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32332                       32
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32532                       33
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32333                       34
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32334                       35
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32335                       36
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32336                       37
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32337                       38
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32338                       39
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32339                       40
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC323310                      41
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC323311                      42
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32533                       43
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32534                       44
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32535                       45
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32536                       46
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32537                       47
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32538                       48
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC32539                       49
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC325310                      50
#define RSRFSIGGEN_VAL_5G_NR_FILTER_TEST_CASE_TC325311                      51

// RsRFSigGen_rng5GNRTestCaseWizardRFPorts
#define RSRFSIGGEN_VAL_5G_NR_TEST_CASE_WIZARD_RF_PORTS_1                    0
#define RSRFSIGGEN_VAL_5G_NR_TEST_CASE_WIZARD_RF_PORTS_2                    1

// RsRFSigGen_rng5GNRTestCaseWizardOutputMode
#define RSRFSIGGEN_VAL_NR5_G_TEST_CASE_WIZARD_OUTPUT_MODE_ALL               0
#define RSRFSIGGEN_VAL_NR5_G_TEST_CASE_WIZARD_OUTPUT_MODE_HSAL              1

// RsRFSigGen_rng5GNRTestCaseWizardFeedbackConnector
#define RSRFSIGGEN_VAL_5G_NR_TEST_CASE_WIZARD_FEEDBACK_CONNECTOR_LOCAL      0

// RsRFSigGen_rng5GNRTestCaseWizardWSRestrictedSet
#define RSRFSIGGEN_VAL_5G_NR_TEST_CASE_WIZARD_WS_RESTRICTED_SET_ARES        0
#define RSRFSIGGEN_VAL_5G_NR_TEST_CASE_WIZARD_WS_RESTRICTED_SET_BRES        1

// RsRFSigGen_rng5GNRTestCaseWizardWSTestRequirement
#define RSRFSIGGEN_VAL_5G_NR_TEST_CASE_WIZARD_WS_TEST_REQUIREMENT_NORM      0
#define RSRFSIGGEN_VAL_5G_NR_TEST_CASE_WIZARD_WS_TEST_REQUIREMENT_HST       1

// RsRFSigGen_rng5GNRMarkerConfigurationMode
#define RSRFSIGGEN_VAL_5G_NR_MARKER_CONFIGURATION_MODE_ULDL                 0

// RsRFSigGen_rng5GNRNodeSSPBCHSLBlocks
#define RSRFSIGGEN_VAL_5G_NR_NODE_SSPBCH_SL_BLOCKS_1                        0
#define RSRFSIGGEN_VAL_5G_NR_NODE_SSPBCH_SL_BLOCKS_2                        1
#define RSRFSIGGEN_VAL_5G_NR_NODE_SSPBCH_SL_BLOCKS_4                        2
#define RSRFSIGGEN_VAL_5G_NR_NODE_SSPBCH_SL_BLOCKS_8                        3
#define RSRFSIGGEN_VAL_5G_NR_NODE_SSPBCH_SL_BLOCKS_16                       4
#define RSRFSIGGEN_VAL_5G_NR_NODE_SSPBCH_SL_BLOCKS_32                       5
#define RSRFSIGGEN_VAL_5G_NR_NODE_SSPBCH_SL_BLOCKS_64                       6

// RsRFSigGen_rng5GNRSchedulingAllocationPDSCHTxSchemeCSIRSAntennaPorts
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TX_SCHEME_CSIRS_ANTENNA_PORTS_N1 0
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TX_SCHEME_CSIRS_ANTENNA_PORTS_N2 1
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TX_SCHEME_CSIRS_ANTENNA_PORTS_N4 2

// RsRFSigGen_rng5GNRSchedulingAllocationPDSCHTxSchemeCodebookMode
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TX_SCHEME_CODEBOOK_MODE_N1 0
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TX_SCHEME_CODEBOOK_MODE_N2 1

// RsRFSigGen_rng5GNRSchedulingAllocationPDSCHTxSchemeCodebookType
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TX_SCHEME_CODEBOOK_TYPE_T1SP 0

// RsRFSigGen_rng5GNRSchedulingAllocationPDSCHTxScheme
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TX_SCHEME_N1       0
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TX_SCHEME_N2       1
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TX_SCHEME_N3       2
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TX_SCHEME_N4       3
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TX_SCHEME_N6       4
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TX_SCHEME_N8       5
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TX_SCHEME_N12      6
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PDSCH_TX_SCHEME_N16      7

// RsRFSigGen_rng5GNRSchedulingAllocationPSCCHResourceBlocks
#define RSRFSIGGEN_VAL_NR5_G_SCHEDULING_ALLOCATION_PSCCH_RESOURCE_BLOCKS_RB10 0
#define RSRFSIGGEN_VAL_NR5_G_SCHEDULING_ALLOCATION_PSCCH_RESOURCE_BLOCKS_RB12 1
#define RSRFSIGGEN_VAL_NR5_G_SCHEDULING_ALLOCATION_PSCCH_RESOURCE_BLOCKS_RB15 2
#define RSRFSIGGEN_VAL_NR5_G_SCHEDULING_ALLOCATION_PSCCH_RESOURCE_BLOCKS_RB20 3
#define RSRFSIGGEN_VAL_NR5_G_SCHEDULING_ALLOCATION_PSCCH_RESOURCE_BLOCKS_RB25 4

// RsRFSigGen_rng5GNRSchedulingAllocationPSSCHDMRSAntennaPort
#define RSRFSIGGEN_VAL_NR5_G_SCHEDULING_ALLOCATION_PSSCHDMRS_ANTENNA_PORT_P1000 0
#define RSRFSIGGEN_VAL_NR5_G_SCHEDULING_ALLOCATION_PSSCHDMRS_ANTENNA_PORT_P1001 1
#define RSRFSIGGEN_VAL_NR5_G_SCHEDULING_ALLOCATION_PSSCHDMRS_ANTENNA_PORT_PBOTH 2

// RsRFSigGen_rng5GNRSchedulingAllocationPSSCHModulation
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PSSCH_MODULATION_QPSK    0
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PSSCH_MODULATION_QAM16   1
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PSSCH_MODULATION_QAM64   2
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PSSCH_MODULATION_QAM256  3

// RsRFSigGen_rng5GNRDLBWPPDSCHPrecodingMethod
#define RSRFSIGGEN_VAL_5G_NR_DL_BWP_PDSCH_PRECODING_METHOD_CB               0
#define RSRFSIGGEN_VAL_5G_NR_DL_BWP_PDSCH_PRECODING_METHOD_RDM              1

// RsRFSigGen_rng5GNRDLBWPPDSCHxOverhead
#define RSRFSIGGEN_VAL_5G_NR_DL_BWP_PDSCH_X_OVERHEAD_N0                     0
#define RSRFSIGGEN_VAL_5G_NR_DL_BWP_PDSCH_X_OVERHEAD_N6                     1
#define RSRFSIGGEN_VAL_5G_NR_DL_BWP_PDSCH_X_OVERHEAD_N12                    2
#define RSRFSIGGEN_VAL_5G_NR_DL_BWP_PDSCH_X_OVERHEAD_N18                    3

// RsRFSigGen_rng5GNRSLBWPResourcePoolsMCSTable
#define RSRFSIGGEN_VAL_5G_NR_SL_BWP_MCS_TABLE_QAM64                         0
#define RSRFSIGGEN_VAL_5G_NR_SL_BWP_MCS_TABLE_QAM256                        1
#define RSRFSIGGEN_VAL_5G_NR_SL_BWP_MCS_TABLE_QAM64LSE                      2

// RsRFSigGen_rng5GNRSLBWPScalingFactor
#define RSRFSIGGEN_VAL_5G_NR_SL_BWP_SCALING_FACTOR_FP5                      0
#define RSRFSIGGEN_VAL_5G_NR_SL_BWP_SCALING_FACTOR_FP8                      1
#define RSRFSIGGEN_VAL_5G_NR_SL_BWP_SCALING_FACTOR_FP65                     2
#define RSRFSIGGEN_VAL_5G_NR_SL_BWP_SCALING_FACTOR_FP1                      3

// RsRFSigGen_rng5GNRSLBWPSubchannelSize
#define RSRFSIGGEN_VAL_5G_NRSL_BWP_SUBCHANNEL_SIZE_R10                      0
#define RSRFSIGGEN_VAL_5G_NRSL_BWP_SUBCHANNEL_SIZE_R12                      1
#define RSRFSIGGEN_VAL_5G_NRSL_BWP_SUBCHANNEL_SIZE_R15                      2
#define RSRFSIGGEN_VAL_5G_NRSL_BWP_SUBCHANNEL_SIZE_R20                      3
#define RSRFSIGGEN_VAL_5G_NRSL_BWP_SUBCHANNEL_SIZE_R25                      4
#define RSRFSIGGEN_VAL_5G_NRSL_BWP_SUBCHANNEL_SIZE_R50                      5
#define RSRFSIGGEN_VAL_5G_NRSL_BWP_SUBCHANNEL_SIZE_R75                      6

// RsRFSigGen_rng5GNRSLBWPSCSpacing
#define RSRFSIGGEN_VAL_5G_NR_SL_BWP_SC_SPACING_15KHZ                        0
#define RSRFSIGGEN_VAL_5G_NR_SL_BWP_SC_SPACING_30KHZ                        1
#define RSRFSIGGEN_VAL_5G_NR_SL_BWP_SC_SPACING_60KHZ                        2
#define RSRFSIGGEN_VAL_5G_NR_SL_BWP_SC_SPACING_60KHZ_EXTENDED               3
#define RSRFSIGGEN_VAL_5G_NR_SL_BWP_SC_SPACING_120KHZ                       4

// RsRFSigGen_rng5GNRULBWPFRCBandwidth
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW5                       0
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW10                      1
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW15                      2
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW20                      3
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW25                      4
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW30                      5
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW35                      6
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW40                      7
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW45                      8
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW50                      9
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW60                      10
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW70                      11
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW80                      12
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW90                      13
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW100                     14
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW200                     15
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW400                     16
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW800                     17
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW1600                    18
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_FRC_BANDWIDTH_BW2000                    19

// RsRFSigGen_rng5GNRULBWPPUSCHxOverhead
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_PUSCH_XOVERHEAD_N0                      0
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_PUSCH_XOVERHEAD_N6                      1
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_PUSCH_XOVERHEAD_N12                     2
#define RSRFSIGGEN_VAL_5G_NR_UL_BWP_PUSCH_XOVERHEAD_N18                     3

// RsRFSigGen_rng5GNRSchedulingAllocationPRACHSequenceLength
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PRACH_SEQUENCE_LENGTH_L139 0
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PRACH_SEQUENCE_LENGTH_L571 1
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PRACH_SEQUENCE_LENGTH_L839 2
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PRACH_SEQUENCE_LENGTH_L1151 3

// RsRFSigGen_rng5GNRSchedulingAllocationResultingMappingType
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_RESULTING_MAPPING_TYPE_A 0
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_RESULTING_MAPPING_TYPE_B 1

// RsRFSigGen_rng5GNRSchedulingAllocationPUCCHOCCLengths
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PUCCH_OCC_LENGTHS_L1     0
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PUCCH_OCC_LENGTHS_L2     1
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PUCCH_OCC_LENGTHS_LL4    2

// RsRFSigGen_rng5GNRSchedulingAllocationPUSCHAggregationFactor
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PUSCH_AGGREGATION_FACTOR_F2 0
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PUSCH_AGGREGATION_FACTOR_F4 1
#define RSRFSIGGEN_VAL_5G_NR_SCHEDULING_ALLOCATION_PUSCH_AGGREGATION_FACTOR_F8 2

// RsRFSigGen_rng5GNRSchedulingAllocationTBSScalingFactor
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_TBS_SCALING_FACTOR_S1    0
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_TBS_SCALING_FACTOR_S5    1
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_TBS_SCALING_FACTOR_S25   2

// RsRFSigGen_rngDVBRCS2SectionMode
#define RSRFSIGGEN_VAL_DVBRCS2_SECTION_MODE_PRED                            0
#define RSRFSIGGEN_VAL_DVBRCS2_SECTION_MODE_USERD                           1

// RsRFSigGen_rngDVBRCS2WaveformId
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM1                              0
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM2                              1
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM3                              2
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM4                              3
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM5                              4
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM6                              5
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM7                              6
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM8                              7
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM9                              8
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM10                             9
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM11                             10
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM12                             11
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM13                             12
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM14                             13
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM15                             14
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM16                             15
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM17                             16
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM18                             17
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM19                             18
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM20                             19
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM21                             20
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM22                             21
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM32                             22
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM33                             23
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM34                             24
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM35                             25
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM36                             26
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM37                             27
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM38                             28
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM39                             29
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM40                             30
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM41                             31
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM42                             32
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM43                             33
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM44                             34
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM45                             35
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM46                             36
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM47                             37
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM48                             38
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_LM49                             39
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM1                            40
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM2                            41
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM3                            42
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM4                            43
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM5                            44
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM6                            45
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM7                            46
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM8                            47
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM9                            48
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM10                           49
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM11                           50
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM12                           51
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM13                           52
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM14                           53
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM15                           54
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM16                           55
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM17                           56
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM18                           57
#define RSRFSIGGEN_VAL_DVBRCS2_WAVEFORM_ID_SSLM19                           58

// RsRFSigGen_rngDVBRCS2Modulation
#define RSRFSIGGEN_VAL_DVBRCS2_MODULATION_BPSK                              0
#define RSRFSIGGEN_VAL_DVBRCS2_MODULATION_QPSK                              1
#define RSRFSIGGEN_VAL_DVBRCS2_MODULATION_PSK8                              2
#define RSRFSIGGEN_VAL_DVBRCS2_MODULATION_QAM16                             3

// RsRFSigGen_rngDVBRCS2SpreadingFactor
#define RSRFSIGGEN_VAL_DVBRCS2_SPREADING_FACTOR_SF2                         0
#define RSRFSIGGEN_VAL_DVBRCS2_SPREADING_FACTOR_SF4                         1
#define RSRFSIGGEN_VAL_DVBRCS2_SPREADING_FACTOR_SF8                         2
#define RSRFSIGGEN_VAL_DVBRCS2_SPREADING_FACTOR_SF16                        3

// RsRFSigGen_rngDVBRCS2PayloadContentType
#define RSRFSIGGEN_VAL_DVBRCS2_PAYLOAD_CONTENT_TYPE_LOGON                   0
#define RSRFSIGGEN_VAL_DVBRCS2_PAYLOAD_CONTENT_TYPE_CONTROL                 1
#define RSRFSIGGEN_VAL_DVBRCS2_PAYLOAD_CONTENT_TYPE_TRAFFIC_CONTROL         2
#define RSRFSIGGEN_VAL_DVBRCS2_PAYLOAD_CONTENT_TYPE_TRAFFIC                 3

// RsRFSigGen_rngDVBRCS2TXFormat
#define RSRFSIGGEN_VAL_DVBRCS2_TX_FORMAT_LM                                 0
#define RSRFSIGGEN_VAL_DVBRCS2_TX_FORMAT_SSLM                               1

// RsRFSigGen_rngDVBS2SFConfigSFFI
#define RSRFSIGGEN_VAL_DVBS2_SF_CONFIG_SFFI_SFFI4                           0
#define RSRFSIGGEN_VAL_DVBS2_SF_CONFIG_SFFI_SFFI5                           1
#define RSRFSIGGEN_VAL_DVBS2_SF_CONFIG_SFFI_SFFI6                           2
#define RSRFSIGGEN_VAL_DVBS2_SF_CONFIG_SFFI_SFFI7                           3

// RsRFSigGen_rngDVBS2SFConfigPLI
#define RSRFSIGGEN_VAL_DVBS2_SF_CONFIG_PLI_STANDARD                         0
#define RSRFSIGGEN_VAL_DVBS2_SF_CONFIG_PLI_ROBUST                           1
#define RSRFSIGGEN_VAL_DVBS2_SF_CONFIG_PLI_VERY_ROBUST                      2
#define RSRFSIGGEN_VAL_DVBS2_SF_CONFIG_PLI_HIGH_EFFICIENCY                  3

// RsRFSigGen_rngDVBS2MODCODUnique
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU1                             1
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU2                             2
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU3                             3
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU4                             4
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU5                             5
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU6                             6
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU7                             7
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU8                             8
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU9                             9
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU10                            10
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU11                            11
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU12                            12
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU13                            13
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU14                            14
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU15                            15
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU16                            16
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU17                            17
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU18                            18
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU19                            19
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU20                            20
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU21                            21
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU22                            22
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU23                            23
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU24                            24
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU25                            25
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU26                            26
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU27                            27
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU28                            28
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU29                            29
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU30                            30
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU31                            31
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU32                            32
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU33                            33
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU34                            34
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU35                            35
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU36                            36
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU37                            37
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU38                            38
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU39                            39
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU40                            40
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU41                            41
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU42                            42
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU43                            43
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU44                            44
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU45                            45
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU46                            46
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU47                            47
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU48                            48
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU49                            49
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU50                            50
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU51                            51
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU52                            52
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU53                            53
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU54                            54
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU55                            55
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU56                            56
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU57                            57
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU58                            58
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU59                            59
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU60                            60
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU61                            61
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU62                            62
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU63                            63
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU64                            64
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU65                            65
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU66                            66
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU67                            67
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU68                            68
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU69                            69
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU70                            70
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU71                            71
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU72                            72
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU73                            73
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU74                            74
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU75                            75
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU76                            76
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU77                            77
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU78                            78
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU79                            79
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU80                            80
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU81                            81
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU82                            82
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU83                            83
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU84                            84
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU85                            85
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU86                            86
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU87                            87
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU88                            88
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU89                            89
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU90                            90
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU91                            91
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU92                            92
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU93                            93
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU94                            94
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU95                            95
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU96                            96
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU97                            97
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU98                            98
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU99                            99
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU100                           100
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU101                           101
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU102                           102
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU103                           103
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU104                           104
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU105                           105
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU106                           106
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU107                           107
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU108                           108
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU109                           109
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU110                           110
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU111                           111
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU112                           112
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU113                           113
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU114                           114
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU115                           115
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU116                           116
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU117                           117
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU118                           118
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU119                           119
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU120                           120
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU121                           121
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU122                           122
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU123                           123
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU124                           124
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU125                           125
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU126                           126
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU127                           127
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU128                           128
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU129                           129
#define RSRFSIGGEN_VAL_DVBS2_MODCOD_UNIQUE_MCU130                           130

// RsRFSigGen_rngSatNavGNSSSBASSystem
#define RSRFSIGGEN_VAL_SAT_NAV_GNSSSBAS_SYSTEM_EGNOS                        0
#define RSRFSIGGEN_VAL_SAT_NAV_GNSSSBAS_SYSTEM_WAAS                         1
#define RSRFSIGGEN_VAL_SAT_NAV_GNSSSBAS_SYSTEM_MSAS                         2
#define RSRFSIGGEN_VAL_SAT_NAV_GNSSSBAS_SYSTEM_GAGAN                        3
#define RSRFSIGGEN_VAL_SAT_NAV_GNSSSBAS_SYSTEM_NONE                         4

// RsRFSigGen_rngARBEthernetUploadMode
#define RSRFSIGGEN_VAL_ARB_ETHERNET_UPLOAD_MODE_M10G                        0
#define RSRFSIGGEN_VAL_ARB_ETHERNET_UPLOAD_MODE_M40G                        1

// RsRFSigGen_rngARBMode
#define RSRFSIGGEN_VAL_ARB_MODE_STAN                                        0
#define RSRFSIGGEN_VAL_ARB_MODE_EUPL                                        1

// RsRFSigGen_rngSystemNetworkQSFPIPAddressMode
#define RSRFSIGGEN_VAL_SYSTEM_NETWORK_QSFP_IP_ADDRESS_MODE_STATIC           0

// RsRFSigGen_rngSystemNetworkQSFPProtocol
#define RSRFSIGGEN_VAL_SYSTEM_NETWORK_QSFP_PROTOCOL_UDP                     0

// RsRFSigGen_rngFrontendMode
#define RSRFSIGGEN_VAL_FRONTEND_MODE_AUTO                                   0
#define RSRFSIGGEN_VAL_FRONTEND_MODE_MANUAL                                 1

// RsRFSigGen_rngHRPUWBFrameMaxDataLength
#define RSRFSIGGEN_VAL_HRPUWB_FRAME_MAX_DATA_LENGTH_MDL1023                 0
#define RSRFSIGGEN_VAL_HRPUWB_FRAME_MAX_DATA_LENGTH_MDL2047                 1
#define RSRFSIGGEN_VAL_HRPUWB_FRAME_MAX_DATA_LENGTH_MDL4095                 2

// RsRFSigGen_rngHRPUWBFrameMaxFCSLength
#define RSRFSIGGEN_VAL_HRPUWB_FRAME_MAX_FCS_LENGTH_MFL2                     0
#define RSRFSIGGEN_VAL_HRPUWB_FRAME_MAX_FCS_LENGTH_MFL4                     1

// RsRFSigGen_rngWLANNEHTSIGMCS
#define RSRFSIGGEN_VAL_WLANNEHTSIGMCS_MCS0                                  0
#define RSRFSIGGEN_VAL_WLANNEHTSIGMCS_MCS1                                  1
#define RSRFSIGGEN_VAL_WLANNEHTSIGMCS_MCS3                                  2
#define RSRFSIGGEN_VAL_WLANNEHTSIGMCS_MCS15                                 3

// RsRFSigGen_rngWLANNMPDUTriggerProcessTime
#define RSRFSIGGEN_VAL_WLANNMPDU_TRIGGER_PROCESS_TIME_TPT0                  0
#define RSRFSIGGEN_VAL_WLANNMPDU_TRIGGER_PROCESS_TIME_TPT8                  1
#define RSRFSIGGEN_VAL_WLANNMPDU_TRIGGER_PROCESS_TIME_TPT16                 2

// RsRFSigGen_rngWLANNRUAllocation
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU0                               0
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU1                               1
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU2                               2
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU3                               3
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU4                               4
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU5                               5
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU6                               6
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU7                               7
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU8                               8
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU9                               9
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU10                              10
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU11                              11
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU12                              12
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU13                              13
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU14                              14
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU15                              15
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU16                              16
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU17                              17
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU18                              18
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU19                              19
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU20                              20
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU21                              21
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU22                              22
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU23                              23
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU24                              24
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU25                              25
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU26                              26
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU27                              27
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU28                              28
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU29                              29
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU30                              30
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU31                              31
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU32                              32
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU33                              33
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU34                              34
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU35                              35
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU36                              36
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU37                              37
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU38                              38
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU39                              39
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU40                              40
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU41                              41
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU42                              42
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU43                              43
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU44                              44
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU45                              45
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU46                              46
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU47                              47
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU48                              48
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU49                              49
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU50                              50
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU51                              51
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU52                              52
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU53                              53
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU54                              54
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU55                              55
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU56                              56
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU57                              57
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU58                              58
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU59                              59
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU60                              60
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU61                              61
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU62                              62
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU63                              63
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU64                              64
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU65                              65
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU66                              66
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU67                              67
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU68                              68
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU69                              69
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU70                              70
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU71                              71
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU72                              72
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU73                              73
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU74                              74
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU75                              75
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU76                              76
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU77                              77
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU78                              78
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU79                              79
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU80                              80
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU81                              81
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU82                              82
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU83                              83
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU84                              84
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU85                              85
#define RSRFSIGGEN_VAL_WLANNRU_ALLOCATION_RU86                              86

// RsRFSigGen_rngExtSeqAgileSequencingOperationMode
#define RSRFSIGGEN_VAL_EXT_SEQ_AGILE_SEQUENCING_OPERATION_MODE_INST         0
#define RSRFSIGGEN_VAL_EXT_SEQ_AGILE_SEQUENCING_OPERATION_MODE_DET          1

// RsRFSigGen_rngExtSeqDesiredARBSampleRate
#define RSRFSIGGEN_VAL_EXT_SEQ_DESIRED_ARB_SAMPLE_RATE_SR37M5               0
#define RSRFSIGGEN_VAL_EXT_SEQ_DESIRED_ARB_SAMPLE_RATE_SR75M                1
#define RSRFSIGGEN_VAL_EXT_SEQ_DESIRED_ARB_SAMPLE_RATE_SR300M               2
#define RSRFSIGGEN_VAL_EXT_SEQ_DESIRED_ARB_SAMPLE_RATE_SR2G4                3

// RsRFSigGen_rngEUTRAARBMode
#define RSRFSIGGEN_VAL_EUTRA_ARB_MODE_OFF                                   0
#define RSRFSIGGEN_VAL_EUTRA_ARB_MODE_BEFORE                                1
#define RSRFSIGGEN_VAL_EUTRA_ARB_MODE_AFTER                                 2

// RsRFSigGen_rngSatNavGNSSRTKProtocol
#define RSRFSIGGEN_VAL_SAT_NAV_GNSSRTK_PROTOCOL_RTCM                        0

// RsRFSigGen_rng5GNRSchedulingAllocationCORESETDCIMultiplexingTable
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_CORESETDCI_MULTIPLEXING_TABLE_TABA 0
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_CORESETDCI_MULTIPLEXING_TABLE_TABB 1
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_CORESETDCI_MULTIPLEXING_TABLE_TABC 2

// RsRFSigGen_rng5GNRSchedulingAllocationCORESETDMRSReferencePoint
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_CORESETDMRS_REFERENCE_POINT_CS 0
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_CORESETDMRS_REFERENCE_POINT_POINT 1

// RsRFSigGen_rng5GNRSchedulingAllocationResultsDensity
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_DENSITY_EVEN5    0
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_DENSITY_ODD5     1
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_DENSITY_DEN1     2
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_DENSITY_DEN3     3

// RsRFSigGen_rng5GNRSchedulingAllocationResultsSRSPorts
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_PORTS_AP1    0
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_PORTS_AP2    1
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_PORTS_AP4    2

// RsRFSigGen_rng5GNRSchedulingAllocationPDSCHFrequencyDensity
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_PDSCH_FREQUENCY_DENSITY_FD2 0
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_PDSCH_FREQUENCY_DENSITY_FD4 1

// RsRFSigGen_rng5GNRSchedulingAllocationResultsSRSRepetitionFactor
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_REPETITION_FACTOR_REP1 0
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_REPETITION_FACTOR_REP2 1
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_REPETITION_FACTOR_REP4 2
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_REPETITION_FACTOR_REP5 3
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_REPETITION_FACTOR_REP6 4
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_REPETITION_FACTOR_REP7 5
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_REPETITION_FACTOR_REP8 6
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_REPETITION_FACTOR_REP10 7
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_REPETITION_FACTOR_REP12 8
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_REPETITION_FACTOR_REP14 9

// RsRFSigGen_rng5GNRSchedulingAllocationResultsSRSResourceType
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_RESOURCE_TYPE_APER 0
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_RESOURCE_TYPE_PER 1
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_RESOURCE_TYPE_SP 2

// RsRFSigGen_rng5GNRSchedulingAllocationResultsSRSSequenceHopping
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_SEQUENCE_HOPPING_GRP 0
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_SEQUENCE_HOPPING_N 1
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_SEQUENCE_HOPPING_SEQ 2

// RsRFSigGen_rng5GNRSchedulingAllocationResultsSRSTransmissionComb
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_TRANSMISSION_COMB_TC2 0
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_TRANSMISSION_COMB_TC4 1
#define RSRFSIGGEN_VAL_NR_5G_SCHEDULING_ALLOCATION_RESULTS_SRS_TRANSMISSION_COMB_TC8 2

// RsRFSigGen_rng5GNRTestCaseWizardGeneratedSignal
#define RSRFSIGGEN_VAL_NR_5G_TEST_CASE_WIZARD_GENERATED_SIGNAL_ALL          0
#define RSRFSIGGEN_VAL_NR_5G_TEST_CASE_WIZARD_GENERATED_SIGNAL_IF           1
#define RSRFSIGGEN_VAL_NR_5G_TEST_CASE_WIZARD_GENERATED_SIGNAL_WS           2

// RsRFSigGen_rng5GNRDLBWPDCIMaxLTESubchannels
#define RSRFSIGGEN_VAL_NR_5G_DL_BWP_DCI_MAX_LTE_SUBCHANNELS_S1              0
#define RSRFSIGGEN_VAL_NR_5G_DL_BWP_DCI_MAX_LTE_SUBCHANNELS_S3              1
#define RSRFSIGGEN_VAL_NR_5G_DL_BWP_DCI_MAX_LTE_SUBCHANNELS_S5              2
#define RSRFSIGGEN_VAL_NR_5G_DL_BWP_DCI_MAX_LTE_SUBCHANNELS_S8              3
#define RSRFSIGGEN_VAL_NR_5G_DL_BWP_DCI_MAX_LTE_SUBCHANNELS_S10             4
#define RSRFSIGGEN_VAL_NR_5G_DL_BWP_DCI_MAX_LTE_SUBCHANNELS_S15             5
#define RSRFSIGGEN_VAL_NR_5G_DL_BWP_DCI_MAX_LTE_SUBCHANNELS_S20             6

// RsRFSigGen_rng5GNRDLBWPDCINumberPerPei
#define RSRFSIGGEN_VAL_NR_5G_DL_BWP_DCI_NUMBER_PER_PEI_N1                   0
#define RSRFSIGGEN_VAL_NR_5G_DL_BWP_DCI_NUMBER_PER_PEI_N2                   1
#define RSRFSIGGEN_VAL_NR_5G_DL_BWP_DCI_NUMBER_PER_PEI_N4                   2
#define RSRFSIGGEN_VAL_NR_5G_DL_BWP_DCI_NUMBER_PER_PEI_N8                   3

// RsRFSigGen_rng5GNRUserORANTestCase
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_1                   0
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_2                   1
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_3                   2
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_4                   3
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_5                   4
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_6                   5
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_7                   6
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_8                   7
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_9                   8
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_10                  9
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_11                  10
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_12                  11
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_13                  12
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_14                  13
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_15                  14
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_16                  15
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3231_17                  16
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3251_1                   17
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3251_2                   18
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3251_3                   19
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3251_4                   20
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3251_5                   21
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3251_6                   22
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3251_7                   23
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3251_8DL                 24
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3251_8UL                 25
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3261_1FR1                26
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3261_2FR1                27
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3261_3FR1                28
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3261_4FR1                29
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3261_5FR1                30
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3251_3DL                 31
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3251_3UL                 32
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3251_4DL                 33
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3251_4UL                 34
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3261_1DL                 35
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3261_1UL                 36
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3261_3DL                 37
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3261_3UL                 38
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3261_5DL                 39
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3261_5UL                 40
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3261_6DL                 41
#define RSRFSIGGEN_VAL_NR_5G_USER_ORAN_TEST_CASE_TC3261_6UL                 42

// RsRFSigGen_rngWLANNFrame320MHzTypeBW
#define RSRFSIGGEN_VAL_WLANN_FRAME_320_M_HZ_TYPE_BW_T1                      0
#define RSRFSIGGEN_VAL_WLANN_FRAME_320_M_HZ_TYPE_BW_T2                      1

// RsRFSigGen_rngFrontendExternalDeviceType
#define RSRFSIGGEN_VAL_FRONTEND_EXTERNAL_DEVICE_TYPE_FILTER                 0
#define RSRFSIGGEN_VAL_FRONTEND_EXTERNAL_DEVICE_TYPE_AMPLIFIER              1
#define RSRFSIGGEN_VAL_FRONTEND_EXTERNAL_DEVICE_TYPE_ATTENUATOR             2
#define RSRFSIGGEN_VAL_FRONTEND_EXTERNAL_DEVICE_TYPE_NONE                   3

// RsRFSigGen_rngBandwidthExtensionAlignStatus
#define RSRFSIGGEN_VAL_BANDWIDTH_EXTENSION_ALIGN_STATUS_NAL                 0
#define RSRFSIGGEN_VAL_BANDWIDTH_EXTENSION_ALIGN_STATUS_ALIG                1

// RsRFSigGen_rngFrontendLocalOscillatorMode
#define RSRFSIGGEN_VAL_FRONTEND_LO_MODE_INT                                 0
#define RSRFSIGGEN_VAL_FRONTEND_LO_MODE_EXT                                 1

// RsRFSigGen_rngOFDMDCMode
#define RSRFSIGGEN_VAL_OFDM_DC_MODE_UTIL                                    0
#define RSRFSIGGEN_VAL_OFDM_DC_MODE_PUNC                                    1
#define RSRFSIGGEN_VAL_OFDM_DC_MODE_SKIP                                    2

// RsRFSigGen_rngPowerSPCMode
#define RSRFSIGGEN_VAL_SPC_MODE_AUTO                                        0
#define RSRFSIGGEN_VAL_SPC_MODE_SING                                        1

// RsRFSigGen_rngHUMSSNMPAccessRights
#define RSRFSIGGEN_VAL_HUMS_SNMP_ACCESS_RIGHTS_RO                           0
#define RSRFSIGGEN_VAL_HUMS_SNMP_ACCESS_RIGHTS_RW                           1

// RsRFSigGen_rngHUMSSNMPSecurityLevel
#define RSRFSIGGEN_VAL_HUMS_SNMP_SECURITY_LEVEL_NOA                         0
#define RSRFSIGGEN_VAL_HUMS_SNMP_SECURITY_LEVEL_AUTH                        1
#define RSRFSIGGEN_VAL_HUMS_SNMP_SECURITY_LEVEL_PRIV                        2

// RsRFSigGen_rngTestPixelColor
#define RSRFSIGGEN_VAL_TEST_PIXEL_COLOR_RED                                 0
#define RSRFSIGGEN_VAL_TEST_PIXEL_COLOR_BLUE                                1
#define RSRFSIGGEN_VAL_TEST_PIXEL_COLOR_WHITE                               2
#define RSRFSIGGEN_VAL_TEST_PIXEL_COLOR_GREEN                               3
#define RSRFSIGGEN_VAL_TEST_PIXEL_COLOR_AUTO                                4
#define RSRFSIGGEN_VAL_TEST_PIXEL_COLOR_GR25                                5
#define RSRFSIGGEN_VAL_TEST_PIXEL_COLOR_GR50                                6
#define RSRFSIGGEN_VAL_TEST_PIXEL_COLOR_GR75                                7
#define RSRFSIGGEN_VAL_TEST_PIXEL_COLOR_BLACK                               8

// RsRFSigGen_rngSystemTimeProtocol
#define RSRFSIGGEN_VAL_SYSTEM_TIME_PROTOCOL_OFF                             0
#define RSRFSIGGEN_VAL_SYSTEM_TIME_PROTOCOL_ON                              1
#define RSRFSIGGEN_VAL_SYSTEM_TIME_PROTOCOL_NONE                            2
#define RSRFSIGGEN_VAL_SYSTEM_TIME_PROTOCOL_NTP                             3

// RsRFSigGen_rngLANServices
#define RSRFSIGGEN_VAL_LAN_SERVICES_AVAHI                                   0
#define RSRFSIGGEN_VAL_LAN_SERVICES_FTP                                     1
#define RSRFSIGGEN_VAL_LAN_SERVICES_HTTP                                    2
#define RSRFSIGGEN_VAL_LAN_SERVICES_RAW                                     3
#define RSRFSIGGEN_VAL_LAN_SERVICES_REMS                                    4
#define RSRFSIGGEN_VAL_LAN_SERVICES_RPC                                     5
#define RSRFSIGGEN_VAL_LAN_SERVICES_SMB                                     6
#define RSRFSIGGEN_VAL_LAN_SERVICES_SOE                                     7
#define RSRFSIGGEN_VAL_LAN_SERVICES_SSH                                     8
#define RSRFSIGGEN_VAL_LAN_SERVICES_SWUP                                    9
#define RSRFSIGGEN_VAL_LAN_SERVICES_VNC                                     10

// RsRFSigGen_rngWLANAYTRNAggregation
#define RSRFSIGGEN_VAL_WLANAYTRN_AGGREGATION_WB                             0
#define RSRFSIGGEN_VAL_WLANAYTRN_AGGREGATION_ATRN                           1

// RsRFSigGen_rngWLANAYGIType
#define RSRFSIGGEN_VAL_WLANAYGI_TYPE_SHORT                                  0
#define RSRFSIGGEN_VAL_WLANAYGI_TYPE_NORMAL                                 1
#define RSRFSIGGEN_VAL_WLANAYGI_TYPE_LONG                                   2

// RsRFSigGen_rngWLANAYBandwidth
#define RSRFSIGGEN_VAL_WLANAY_BANDWIDTH_BW216                               0
#define RSRFSIGGEN_VAL_WLANAY_BANDWIDTH_BW432                               1

// RsRFSigGen_rngWLANAYTrainingSequenceLength
#define RSRFSIGGEN_VAL_WLANAY_TRAINING_SEQUENCE_LENGTH_NORMAL               0
#define RSRFSIGGEN_VAL_WLANAY_TRAINING_SEQUENCE_LENGTH_LONG                 1
#define RSRFSIGGEN_VAL_WLANAY_TRAINING_SEQUENCE_LENGTH_SHORT                2

// RsRFSigGen_rng5GNRNodeSystemInformationSsbTimeOffsetR17
#define RSRFSIGGEN_VAL_SSB_TIME_OFFSET_R17_S0                               0
#define RSRFSIGGEN_VAL_SSB_TIME_OFFSET_R17_S5                               1
#define RSRFSIGGEN_VAL_SSB_TIME_OFFSET_R17_S10                              2
#define RSRFSIGGEN_VAL_SSB_TIME_OFFSET_R17_S15                              3

// RsRFSigGen_rngSRSFrequencyScalingFactor
#define RSRFSIGGEN_VAL_SRS_FREQUENCY_SCALING_FACTOR_PF1                     1
#define RSRFSIGGEN_VAL_SRS_FREQUENCY_SCALING_FACTOR_PF2                     2
#define RSRFSIGGEN_VAL_SRS_FREQUENCY_SCALING_FACTOR_PF4                     4

// RsRFSigGen_rngNRDMRSConfigurationType
#define RSRFSIGGEN_VAL_NR_DMRS_CONFIGURATION_TYPE_T1                        0
#define RSRFSIGGEN_VAL_NR_DMRS_CONFIGURATION_TYPE_T2                        1

// RsRFSigGen_rngNRDMRSConfigMode
#define RSRFSIGGEN_VAL_NR_DMRS_CONFIG_MODE_AUTO                             0
#define RSRFSIGGEN_VAL_NR_DMRS_CONFIG_MODE_MAN                              1

// RsRFSigGen_rngNRNumberofSlotsTBoMS
#define RSRFSIGGEN_VAL_NR_NUMBEROF_SLOTS_TBOMS_N1                           1
#define RSRFSIGGEN_VAL_NR_NUMBEROF_SLOTS_TBOMS_N2                           2
#define RSRFSIGGEN_VAL_NR_NUMBEROF_SLOTS_TBOMS_N4                           4
#define RSRFSIGGEN_VAL_NR_NUMBEROF_SLOTS_TBOMS_N8                           8

// RsRFSigGen_rng5GNRMaxBits2ndDownlinkAssignmentIndex
#define RSRFSIGGEN_VAL_NR_MAX_BITS_2ND_DOWNLINK_ASSIGNMENT_INDEX_L0         0
#define RSRFSIGGEN_VAL_NR_MAX_BITS_2ND_DOWNLINK_ASSIGNMENT_INDEX_L2         2
#define RSRFSIGGEN_VAL_NR_MAX_BITS_2ND_DOWNLINK_ASSIGNMENT_INDEX_L4         4

// RsRFSigGen_rng5GNRSchedulingAllocationSRSConfig
#define RSRFSIGGEN_VAL_NR_SCHEDULING_ALLOCATION_SRS_CONFIG_IE               0
#define RSRFSIGGEN_VAL_NR_SCHEDULING_ALLOCATION_SRS_CONFIG_IER16            1
#define RSRFSIGGEN_VAL_NR_SCHEDULING_ALLOCATION_SRS_CONFIG_IENPR16          2
#define RSRFSIGGEN_VAL_NR_SCHEDULING_ALLOCATION_SRS_CONFIG_IER17            3

// RsRFSigGen_rng5GNRULBWPFRCDeployment
#define RSRFSIGGEN_VAL_NRULBWPFRC_DEPLOYMENT_FR1LT3                         0
#define RSRFSIGGEN_VAL_NRULBWPFRC_DEPLOYMENT_FR1GT3                         1
#define RSRFSIGGEN_VAL_NRULBWPFRC_DEPLOYMENT_FR2_1                          2
#define RSRFSIGGEN_VAL_NRULBWPFRC_DEPLOYMENT_                               3
#define RSRFSIGGEN_VAL_NRULBWPFRC_DEPLOYMENT_FR2                            4
#define RSRFSIGGEN_VAL_NRULBWPFRC_DEPLOYMENT_BT36                           5
#define RSRFSIGGEN_VAL_NRULBWPFRC_DEPLOYMENT_GT6                            6
#define RSRFSIGGEN_VAL_NRULBWPFRC_DEPLOYMENT_LT3                            7
#define RSRFSIGGEN_VAL_NRULBWPFRC_DEPLOYMENT_BT37125                        8
#define RSRFSIGGEN_VAL_NRULBWPFRC_DEPLOYMENT_GT7125                         9

// RsRFSigGen_rng5GNRULBWPFRCWizardModulation
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_BPSK                        0
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_BPSK2                       1
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_QPSK                        2
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_QAM16                       3
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_QAM64                       4
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_QAM256                      5
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_QAM1024                     6
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_NSQAM2048                   7
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_NSQAM4096                   8
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_PSK8                        9
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_NSAPSK16_23                 10
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_NSAPSK16_34                 11
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_NSAPSK16_45                 12
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_NSAPSK16_56                 13
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_NSAPSK16_89                 14
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_NSAPSK16_910                15
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_NSAPSK32_34                 16
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_NSAPSK32_45                 17
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_NSAPSK32_56                 18
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_NSAPSK32_89                 19
#define RSRFSIGGEN_VAL_NR_FRC_WIZARD_MODULATION_NSAPSK32_910                20

//repcap Path
#define RSRFSIGGEN_REPCAP_PATH_A                                            1
#define RSRFSIGGEN_REPCAP_PATH_B                                            2
#define RSRFSIGGEN_REPCAP_PATH_C                                            3
#define RSRFSIGGEN_REPCAP_PATH_D                                            4

//repcap ExternalTrigger
#define RSRFSIGGEN_REPCAP_EXTERNALTRIGGER_EXT1                              1
#define RSRFSIGGEN_REPCAP_EXTERNALTRIGGER_EXT2                              2

//repcap Marker
#define RSRFSIGGEN_REPCAP_MARKER_M1                                         1
#define RSRFSIGGEN_REPCAP_MARKER_M2                                         2
#define RSRFSIGGEN_REPCAP_MARKER_M3                                         3
#define RSRFSIGGEN_REPCAP_MARKER_M4                                         4

//repcap TransportBlock
#define RSRFSIGGEN_REPCAP_TRANSPORTBLOCK_TB1                                1
#define RSRFSIGGEN_REPCAP_TRANSPORTBLOCK_TB2                                2

//repcap Subframe
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF0                                      0
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF1                                      1
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF2                                      2
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF3                                      3
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF4                                      4
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF5                                      5
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF6                                      6
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF7                                      7
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF8                                      8
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF9                                      9
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF10                                     10
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF11                                     11
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF12                                     12
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF13                                     13
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF14                                     14
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF15                                     15
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF16                                     16
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF17                                     17
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF18                                     18
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF19                                     19
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF20                                     20
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF21                                     21
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF22                                     22
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF23                                     23
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF24                                     24
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF25                                     25
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF26                                     26
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF27                                     27
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF28                                     28
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF29                                     29
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF30                                     30
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF31                                     31
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF32                                     32
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF33                                     33
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF34                                     34
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF35                                     35
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF36                                     36
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF37                                     37
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF38                                     38
#define RSRFSIGGEN_REPCAP_SUBFRAME_SF39                                     39

//repcap AllocationDL
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL0                                 0
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL1                                 1
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL2                                 2
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL3                                 3
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL4                                 4
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL5                                 5
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL6                                 6
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL7                                 7
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL8                                 8
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL9                                 9
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL10                                10
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL11                                11
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL12                                12
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL13                                13
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL14                                14
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL15                                15
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL16                                16
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL17                                17
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL18                                18
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL19                                19
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL20                                20
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL21                                21
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL22                                22
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL23                                23
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL24                                24
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL25                                25
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL26                                26
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL27                                27
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL28                                28
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL29                                29
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL30                                30
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL31                                31
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL32                                32
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL33                                33
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL34                                34
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL35                                35
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL36                                36
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL37                                37
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL38                                38
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL39                                39
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL40                                40
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL41                                41
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL42                                42
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL43                                43
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL44                                44
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL45                                45
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL46                                46
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL47                                47
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL48                                48
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL49                                49
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL50                                50
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL51                                51
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL52                                52
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL53                                53
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL54                                54
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL55                                55
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL56                                56
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL57                                57
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL58                                58
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL59                                59
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL60                                60
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL61                                61
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL62                                62
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL63                                63
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL64                                64
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL65                                65
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL66                                66
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL67                                67
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL68                                68
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL69                                69
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL70                                70
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL71                                71
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL72                                72
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL73                                73
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL74                                74
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL75                                75
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL76                                76
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL77                                77
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL78                                78
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL79                                79
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL80                                80
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL81                                81
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL82                                82
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL83                                83
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL84                                84
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL85                                85
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL86                                86
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL87                                87
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL88                                88
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL89                                89
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL90                                90
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL91                                91
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL92                                92
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL93                                93
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL94                                94
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL95                                95
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL96                                96
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL97                                97
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL98                                98
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL99                                99
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL100                               100
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL101                               101
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL102                               102
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL103                               103
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL104                               104
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL105                               105
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL106                               106
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL107                               107
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL108                               108
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL109                               109
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL110                               110
#define RSRFSIGGEN_REPCAP_ALLOCATIONDL_ALL111                               111

//repcap Slot
#define RSRFSIGGEN_REPCAP_SLOT_S0                                           0
#define RSRFSIGGEN_REPCAP_SLOT_S1                                           1
#define RSRFSIGGEN_REPCAP_SLOT_S2                                           2
#define RSRFSIGGEN_REPCAP_SLOT_S3                                           3
#define RSRFSIGGEN_REPCAP_SLOT_S4                                           4
#define RSRFSIGGEN_REPCAP_SLOT_S5                                           5
#define RSRFSIGGEN_REPCAP_SLOT_S6                                           6
#define RSRFSIGGEN_REPCAP_SLOT_S7                                           7

//repcap DCI
#define RSRFSIGGEN_REPCAP_DCI_DCI0                                          0
#define RSRFSIGGEN_REPCAP_DCI_DCI1                                          1
#define RSRFSIGGEN_REPCAP_DCI_DCI2                                          2
#define RSRFSIGGEN_REPCAP_DCI_DCI3                                          3
#define RSRFSIGGEN_REPCAP_DCI_DCI4                                          4
#define RSRFSIGGEN_REPCAP_DCI_DCI5                                          5
#define RSRFSIGGEN_REPCAP_DCI_DCI6                                          6
#define RSRFSIGGEN_REPCAP_DCI_DCI7                                          7
#define RSRFSIGGEN_REPCAP_DCI_DCI8                                          8
#define RSRFSIGGEN_REPCAP_DCI_DCI9                                          9
#define RSRFSIGGEN_REPCAP_DCI_DCI10                                         10
#define RSRFSIGGEN_REPCAP_DCI_DCI11                                         11
#define RSRFSIGGEN_REPCAP_DCI_DCI12                                         12
#define RSRFSIGGEN_REPCAP_DCI_DCI13                                         13
#define RSRFSIGGEN_REPCAP_DCI_DCI14                                         14
#define RSRFSIGGEN_REPCAP_DCI_DCI15                                         15
#define RSRFSIGGEN_REPCAP_DCI_DCI16                                         16
#define RSRFSIGGEN_REPCAP_DCI_DCI17                                         17
#define RSRFSIGGEN_REPCAP_DCI_DCI18                                         18
#define RSRFSIGGEN_REPCAP_DCI_DCI19                                         19

//repcap User
#define RSRFSIGGEN_REPCAP_USER_USER1                                        1
#define RSRFSIGGEN_REPCAP_USER_USER2                                        2
#define RSRFSIGGEN_REPCAP_USER_USER3                                        3
#define RSRFSIGGEN_REPCAP_USER_USER4                                        4

//repcap UserEquipment
#define RSRFSIGGEN_REPCAP_USEREQUIPMENT_UE1                                 1
#define RSRFSIGGEN_REPCAP_USEREQUIPMENT_UE2                                 2
#define RSRFSIGGEN_REPCAP_USEREQUIPMENT_UE3                                 3
#define RSRFSIGGEN_REPCAP_USEREQUIPMENT_UE4                                 4

//repcap PMCH
#define RSRFSIGGEN_REPCAP_PMCH_PMCH1                                        1
#define RSRFSIGGEN_REPCAP_PMCH_PMCH2                                        2

//repcap Apm
#define RSRFSIGGEN_REPCAP_APM_APM4                                          0
#define RSRFSIGGEN_REPCAP_APM_APM5                                          1
#define RSRFSIGGEN_REPCAP_APM_APM6                                          2
#define RSRFSIGGEN_REPCAP_APM_APM7                                          3
#define RSRFSIGGEN_REPCAP_APM_APM8                                          4

//repcap CodeWord
#define RSRFSIGGEN_REPCAP_CODEWORD_CW1                                      1
#define RSRFSIGGEN_REPCAP_CODEWORD_CW2                                      2

//repcap LoggingPoint
#define RSRFSIGGEN_REPCAP_LOGGINGPOINT_LP0                                  0
#define RSRFSIGGEN_REPCAP_LOGGINGPOINT_LP1                                  1
#define RSRFSIGGEN_REPCAP_LOGGINGPOINT_LP2                                  2
#define RSRFSIGGEN_REPCAP_LOGGINGPOINT_LP3                                  3
#define RSRFSIGGEN_REPCAP_LOGGINGPOINT_LP4                                  4
#define RSRFSIGGEN_REPCAP_LOGGINGPOINT_LP5                                  5
#define RSRFSIGGEN_REPCAP_LOGGINGPOINT_LP6                                  6
#define RSRFSIGGEN_REPCAP_LOGGINGPOINT_LP7                                  7
#define RSRFSIGGEN_REPCAP_LOGGINGPOINT_LP8                                  8
#define RSRFSIGGEN_REPCAP_LOGGINGPOINT_LP9                                  9
#define RSRFSIGGEN_REPCAP_LOGGINGPOINT_LP10                                 10
#define RSRFSIGGEN_REPCAP_LOGGINGPOINT_LP11                                 11
#define RSRFSIGGEN_REPCAP_LOGGINGPOINT_LP12                                 12

//repcap Group
#define RSRFSIGGEN_REPCAP_GROUP_G0                                          0
#define RSRFSIGGEN_REPCAP_GROUP_G1                                          1
#define RSRFSIGGEN_REPCAP_GROUP_G2                                          2
#define RSRFSIGGEN_REPCAP_GROUP_G3                                          3
#define RSRFSIGGEN_REPCAP_GROUP_G4                                          4
#define RSRFSIGGEN_REPCAP_GROUP_G5                                          5
#define RSRFSIGGEN_REPCAP_GROUP_G6                                          6
#define RSRFSIGGEN_REPCAP_GROUP_G7                                          7
#define RSRFSIGGEN_REPCAP_GROUP_G8                                          8
#define RSRFSIGGEN_REPCAP_GROUP_G9                                          9
#define RSRFSIGGEN_REPCAP_GROUP_G10                                         10
#define RSRFSIGGEN_REPCAP_GROUP_G11                                         11
#define RSRFSIGGEN_REPCAP_GROUP_G12                                         12
#define RSRFSIGGEN_REPCAP_GROUP_G13                                         13
#define RSRFSIGGEN_REPCAP_GROUP_G14                                         14
#define RSRFSIGGEN_REPCAP_GROUP_G15                                         15

//repcap PHICH
#define RSRFSIGGEN_REPCAP_PHICH_PHICH0                                      0
#define RSRFSIGGEN_REPCAP_PHICH_PHICH1                                      1
#define RSRFSIGGEN_REPCAP_PHICH_PHICH2                                      2
#define RSRFSIGGEN_REPCAP_PHICH_PHICH3                                      3
#define RSRFSIGGEN_REPCAP_PHICH_PHICH4                                      4
#define RSRFSIGGEN_REPCAP_PHICH_PHICH5                                      5
#define RSRFSIGGEN_REPCAP_PHICH_PHICH6                                      6
#define RSRFSIGGEN_REPCAP_PHICH_PHICH7                                      7

//repcap PowerRampChannel
#define RSRFSIGGEN_REPCAP_POWERRAMPCHANNEL_PRCH1                            1
#define RSRFSIGGEN_REPCAP_POWERRAMPCHANNEL_PRCH2                            2
#define RSRFSIGGEN_REPCAP_POWERRAMPCHANNEL_PRCH3                            3
#define RSRFSIGGEN_REPCAP_POWERRAMPCHANNEL_PRCH4                            4

//repcap TETRAFrame
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF1                                    1
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF2                                    2
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF3                                    3
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF4                                    4
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF5                                    5
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF6                                    6
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF7                                    7
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF8                                    8
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF9                                    9
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF10                                   10
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF11                                   11
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF12                                   12
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF13                                   13
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF14                                   14
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF15                                   15
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF16                                   16
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF17                                   17
#define RSRFSIGGEN_REPCAP_TETRAFRAME_TF18                                   18

//repcap TETRASlot
#define RSRFSIGGEN_REPCAP_TETRASLOT_TETRASLOT1                              1
#define RSRFSIGGEN_REPCAP_TETRASLOT_TETRASLOT2                              2
#define RSRFSIGGEN_REPCAP_TETRASLOT_TETRASLOT3                              3
#define RSRFSIGGEN_REPCAP_TETRASLOT_TETRASLOT4                              4
#define RSRFSIGGEN_REPCAP_TETRASLOT_TETRASLOT5                              5
#define RSRFSIGGEN_REPCAP_TETRASLOT_TETRASLOT6                              6
#define RSRFSIGGEN_REPCAP_TETRASLOT_TETRASLOT7                              7
#define RSRFSIGGEN_REPCAP_TETRASLOT_TETRASLOT8                              8

//repcap TETRALdir
#define RSRFSIGGEN_REPCAP_TETRALDIR_LD1                                     1
#define RSRFSIGGEN_REPCAP_TETRALDIR_LD2                                     2

//repcap BTShortTable
#define RSRFSIGGEN_REPCAP_BTSHORTTABLE_BTSHORTTABLE1                        1
#define RSRFSIGGEN_REPCAP_BTSHORTTABLE_BTSHORTTABLE2                        2
#define RSRFSIGGEN_REPCAP_BTSHORTTABLE_BTSHORTTABLE3                        3

//repcap BTLongTable
#define RSRFSIGGEN_REPCAP_BTLONGTABLE_BTLONG1                               1
#define RSRFSIGGEN_REPCAP_BTLONGTABLE_BTLONG2                               2
#define RSRFSIGGEN_REPCAP_BTLONGTABLE_BTLONG3                               3
#define RSRFSIGGEN_REPCAP_BTLONGTABLE_BTLONG4                               4
#define RSRFSIGGEN_REPCAP_BTLONGTABLE_BTLONG5                               5
#define RSRFSIGGEN_REPCAP_BTLONGTABLE_BTLONG6                               6
#define RSRFSIGGEN_REPCAP_BTLONGTABLE_BTLONG7                               7
#define RSRFSIGGEN_REPCAP_BTLONGTABLE_BTLONG8                               8
#define RSRFSIGGEN_REPCAP_BTLONGTABLE_BTLONG9                               9
#define RSRFSIGGEN_REPCAP_BTLONGTABLE_BTLONG10                              10

//repcap GPSSat
#define RSRFSIGGEN_REPCAP_GPSSAT_GPSSAT1                                    1
#define RSRFSIGGEN_REPCAP_GPSSAT_GPSSAT2                                    2
#define RSRFSIGGEN_REPCAP_GPSSAT_GPSSAT3                                    3
#define RSRFSIGGEN_REPCAP_GPSSAT_GPSSAT4                                    4

//repcap GPSSVID
#define RSRFSIGGEN_REPCAP_GPSSVID_SV1                                       1
#define RSRFSIGGEN_REPCAP_GPSSVID_SV2                                       2
#define RSRFSIGGEN_REPCAP_GPSSVID_SV3                                       3
#define RSRFSIGGEN_REPCAP_GPSSVID_SV4                                       4
#define RSRFSIGGEN_REPCAP_GPSSVID_SV5                                       5
#define RSRFSIGGEN_REPCAP_GPSSVID_SV6                                       6
#define RSRFSIGGEN_REPCAP_GPSSVID_SV7                                       7
#define RSRFSIGGEN_REPCAP_GPSSVID_SV8                                       8
#define RSRFSIGGEN_REPCAP_GPSSVID_SV9                                       9
#define RSRFSIGGEN_REPCAP_GPSSVID_SV10                                      10
#define RSRFSIGGEN_REPCAP_GPSSVID_SV11                                      11
#define RSRFSIGGEN_REPCAP_GPSSVID_SV12                                      12
#define RSRFSIGGEN_REPCAP_GPSSVID_SV13                                      13
#define RSRFSIGGEN_REPCAP_GPSSVID_SV14                                      14
#define RSRFSIGGEN_REPCAP_GPSSVID_SV15                                      15
#define RSRFSIGGEN_REPCAP_GPSSVID_SV16                                      16
#define RSRFSIGGEN_REPCAP_GPSSVID_SV17                                      17
#define RSRFSIGGEN_REPCAP_GPSSVID_SV18                                      18
#define RSRFSIGGEN_REPCAP_GPSSVID_SV19                                      19
#define RSRFSIGGEN_REPCAP_GPSSVID_SV20                                      20
#define RSRFSIGGEN_REPCAP_GPSSVID_SV21                                      21
#define RSRFSIGGEN_REPCAP_GPSSVID_SV22                                      22
#define RSRFSIGGEN_REPCAP_GPSSVID_SV23                                      23
#define RSRFSIGGEN_REPCAP_GPSSVID_SV24                                      24
#define RSRFSIGGEN_REPCAP_GPSSVID_SV25                                      25
#define RSRFSIGGEN_REPCAP_GPSSVID_SV26                                      26
#define RSRFSIGGEN_REPCAP_GPSSVID_SV27                                      27
#define RSRFSIGGEN_REPCAP_GPSSVID_SV28                                      28
#define RSRFSIGGEN_REPCAP_GPSSVID_SV29                                      29
#define RSRFSIGGEN_REPCAP_GPSSVID_SV30                                      30
#define RSRFSIGGEN_REPCAP_GPSSVID_SV31                                      31
#define RSRFSIGGEN_REPCAP_GPSSVID_SV32                                      32
#define RSRFSIGGEN_REPCAP_GPSSVID_SV33                                      33
#define RSRFSIGGEN_REPCAP_GPSSVID_SV34                                      34
#define RSRFSIGGEN_REPCAP_GPSSVID_SV35                                      35
#define RSRFSIGGEN_REPCAP_GPSSVID_SV36                                      36
#define RSRFSIGGEN_REPCAP_GPSSVID_SV37                                      37

//repcap GPSIon
#define RSRFSIGGEN_REPCAP_GPSION_ION0                                       0
#define RSRFSIGGEN_REPCAP_GPSION_ION1                                       1
#define RSRFSIGGEN_REPCAP_GPSION_ION2                                       2
#define RSRFSIGGEN_REPCAP_GPSION_ION3                                       3

//repcap GSMFrame
#define RSRFSIGGEN_REPCAP_GSMFRAME_F1                                       1
#define RSRFSIGGEN_REPCAP_GSMFRAME_F2                                       2

//repcap GSMSubchannel
#define RSRFSIGGEN_REPCAP_GSMSUBCHANNEL_SCH1                                1
#define RSRFSIGGEN_REPCAP_GSMSUBCHANNEL_SCH2                                2

//repcap GSMAtt
#define RSRFSIGGEN_REPCAP_GSMATT_ATT1                                       1
#define RSRFSIGGEN_REPCAP_GSMATT_ATT2                                       2
#define RSRFSIGGEN_REPCAP_GSMATT_ATT3                                       3
#define RSRFSIGGEN_REPCAP_GSMATT_ATT4                                       4
#define RSRFSIGGEN_REPCAP_GSMATT_ATT5                                       5
#define RSRFSIGGEN_REPCAP_GSMATT_ATT6                                       6
#define RSRFSIGGEN_REPCAP_GSMATT_ATT7                                       7

//repcap GSMQPSKAngle
#define RSRFSIGGEN_REPCAP_GSMQPSKANGLE_ANGLE0                               0
#define RSRFSIGGEN_REPCAP_GSMQPSKANGLE_ANGLE1                               1
#define RSRFSIGGEN_REPCAP_GSMQPSKANGLE_ANGLE2                               2
#define RSRFSIGGEN_REPCAP_GSMQPSKANGLE_ANGLE3                               3
#define RSRFSIGGEN_REPCAP_GSMQPSKANGLE_ANGLE4                               4
#define RSRFSIGGEN_REPCAP_GSMQPSKANGLE_ANGLE5                               5
#define RSRFSIGGEN_REPCAP_GSMQPSKANGLE_ANGLE6                               6
#define RSRFSIGGEN_REPCAP_GSMQPSKANGLE_ANGLE7                               7

//repcap GPPBS
#define RSRFSIGGEN_REPCAP_GPPBS_BS1                                         1
#define RSRFSIGGEN_REPCAP_GPPBS_BS2                                         2
#define RSRFSIGGEN_REPCAP_GPPBS_BS3                                         3
#define RSRFSIGGEN_REPCAP_GPPBS_BS4                                         4

//repcap GPPCH
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH0                                      0
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH1                                      1
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH2                                      2
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH3                                      3
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH4                                      4
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH5                                      5
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH6                                      6
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH7                                      7
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH8                                      8
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH9                                      9
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH10                                     10
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH11                                     11
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH12                                     12
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH13                                     13
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH14                                     14
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH15                                     15
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH16                                     16
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH17                                     17
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH18                                     18
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH19                                     19
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH20                                     20
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH21                                     21
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH22                                     22
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH23                                     23
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH24                                     24
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH25                                     25
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH26                                     26
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH27                                     27
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH28                                     28
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH29                                     29
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH30                                     30
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH31                                     31
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH32                                     32
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH33                                     33
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH34                                     34
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH35                                     35
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH36                                     36
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH37                                     37
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH38                                     38
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH39                                     39
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH40                                     40
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH41                                     41
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH42                                     42
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH43                                     43
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH44                                     44
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH45                                     45
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH46                                     46
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH47                                     47
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH48                                     48
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH49                                     49
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH50                                     50
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH51                                     51
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH52                                     52
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH53                                     53
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH54                                     54
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH55                                     55
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH56                                     56
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH57                                     57
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH58                                     58
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH59                                     59
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH60                                     60
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH61                                     61
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH62                                     62
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH63                                     63
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH64                                     64
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH65                                     65
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH66                                     66
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH67                                     67
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH68                                     68
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH69                                     69
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH70                                     70
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH71                                     71
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH72                                     72
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH73                                     73
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH74                                     74
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH75                                     75
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH76                                     76
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH77                                     77
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH78                                     78
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH79                                     79
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH80                                     80
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH81                                     81
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH82                                     82
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH83                                     83
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH84                                     84
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH85                                     85
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH86                                     86
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH87                                     87
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH88                                     88
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH89                                     89
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH90                                     90
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH91                                     91
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH92                                     92
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH93                                     93
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH94                                     94
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH95                                     95
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH96                                     96
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH97                                     97
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH98                                     98
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH99                                     99
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH100                                    100
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH101                                    101
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH102                                    102
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH103                                    103
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH104                                    104
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH105                                    105
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH106                                    106
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH107                                    107
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH108                                    108
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH109                                    109
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH110                                    110
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH111                                    111
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH112                                    112
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH113                                    113
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH114                                    114
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH115                                    115
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH116                                    116
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH117                                    117
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH118                                    118
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH119                                    119
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH120                                    120
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH121                                    121
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH122                                    122
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH123                                    123
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH124                                    124
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH125                                    125
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH126                                    126
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH127                                    127
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH128                                    128
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH129                                    129
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH130                                    130
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH131                                    131
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH132                                    132
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH133                                    133
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH134                                    134
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH135                                    135
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH136                                    136
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH137                                    137
#define RSRFSIGGEN_REPCAP_GPPCH_GPPCH138                                    138

//repcap GPPTTI
#define RSRFSIGGEN_REPCAP_GPPTTI_TTI0                                       0
#define RSRFSIGGEN_REPCAP_GPPTTI_TTI1                                       1
#define RSRFSIGGEN_REPCAP_GPPTTI_TTI2                                       2
#define RSRFSIGGEN_REPCAP_GPPTTI_TTI3                                       3
#define RSRFSIGGEN_REPCAP_GPPTTI_TTI4                                       4
#define RSRFSIGGEN_REPCAP_GPPTTI_TTI5                                       5
#define RSRFSIGGEN_REPCAP_GPPTTI_TTI6                                       6
#define RSRFSIGGEN_REPCAP_GPPTTI_TTI7                                       7
#define RSRFSIGGEN_REPCAP_GPPTTI_TTI8                                       8
#define RSRFSIGGEN_REPCAP_GPPTTI_TTI9                                       9

//repcap GPPStream
#define RSRFSIGGEN_REPCAP_GPPSTREAM_ST1                                     1
#define RSRFSIGGEN_REPCAP_GPPSTREAM_ST2                                     2

//repcap GPPTG
#define RSRFSIGGEN_REPCAP_GPPTG_TG1                                         1
#define RSRFSIGGEN_REPCAP_GPPTG_TG2                                         2

//repcap GPPDCH
#define RSRFSIGGEN_REPCAP_GPPDCH_DCH1                                       1
#define RSRFSIGGEN_REPCAP_GPPDCH_DCH2                                       2
#define RSRFSIGGEN_REPCAP_GPPDCH_DCH3                                       3
#define RSRFSIGGEN_REPCAP_GPPDCH_DCH4                                       4
#define RSRFSIGGEN_REPCAP_GPPDCH_DCH5                                       5
#define RSRFSIGGEN_REPCAP_GPPDCH_DCH6                                       6

//repcap GPPTC
#define RSRFSIGGEN_REPCAP_GPPTC_TC0                                         0
#define RSRFSIGGEN_REPCAP_GPPTC_TC1                                         1
#define RSRFSIGGEN_REPCAP_GPPTC_TC2                                         2
#define RSRFSIGGEN_REPCAP_GPPTC_TC3                                         3
#define RSRFSIGGEN_REPCAP_GPPTC_TC4                                         4
#define RSRFSIGGEN_REPCAP_GPPTC_TC5                                         5
#define RSRFSIGGEN_REPCAP_GPPTC_TC6                                         6

//repcap C2KBS
#define RSRFSIGGEN_REPCAP_C2KBS_C2KBS1                                      1
#define RSRFSIGGEN_REPCAP_C2KBS_C2KBS2                                      2
#define RSRFSIGGEN_REPCAP_C2KBS_C2KBS3                                      3
#define RSRFSIGGEN_REPCAP_C2KBS_C2KBS4                                      4

//repcap C2KCH
#define RSRFSIGGEN_REPCAP_C2KCH_CH1                                         1
#define RSRFSIGGEN_REPCAP_C2KCH_CH2                                         2
#define RSRFSIGGEN_REPCAP_C2KCH_CH3                                         3
#define RSRFSIGGEN_REPCAP_C2KCH_CH4                                         4
#define RSRFSIGGEN_REPCAP_C2KCH_CH5                                         5
#define RSRFSIGGEN_REPCAP_C2KCH_CH6                                         6
#define RSRFSIGGEN_REPCAP_C2KCH_CH7                                         7
#define RSRFSIGGEN_REPCAP_C2KCH_CH8                                         8
#define RSRFSIGGEN_REPCAP_C2KCH_CH9                                         9
#define RSRFSIGGEN_REPCAP_C2KCH_CH10                                        10
#define RSRFSIGGEN_REPCAP_C2KCH_CH11                                        11
#define RSRFSIGGEN_REPCAP_C2KCH_CH12                                        12
#define RSRFSIGGEN_REPCAP_C2KCH_CH13                                        13
#define RSRFSIGGEN_REPCAP_C2KCH_CH14                                        14

//repcap C2KCHG
#define RSRFSIGGEN_REPCAP_C2KCHG_CHG0                                       0
#define RSRFSIGGEN_REPCAP_C2KCHG_CHG1                                       1
#define RSRFSIGGEN_REPCAP_C2KCHG_CHG2                                       2
#define RSRFSIGGEN_REPCAP_C2KCHG_CHG3                                       3
#define RSRFSIGGEN_REPCAP_C2KCHG_CHG4                                       4
#define RSRFSIGGEN_REPCAP_C2KCHG_CHG5                                       5
#define RSRFSIGGEN_REPCAP_C2KCHG_CHG6                                       6
#define RSRFSIGGEN_REPCAP_C2KCHG_CHG7                                       7
#define RSRFSIGGEN_REPCAP_C2KCHG_CHG8                                       8

//repcap C2KMS
#define RSRFSIGGEN_REPCAP_C2KMS_MS1                                         1
#define RSRFSIGGEN_REPCAP_C2KMS_MS2                                         2
#define RSRFSIGGEN_REPCAP_C2KMS_MS3                                         3
#define RSRFSIGGEN_REPCAP_C2KMS_MS4                                         4

//repcap EVDOTU
#define RSRFSIGGEN_REPCAP_EVDOTU_TU1                                        1
#define RSRFSIGGEN_REPCAP_EVDOTU_TU2                                        2
#define RSRFSIGGEN_REPCAP_EVDOTU_TU3                                        3
#define RSRFSIGGEN_REPCAP_EVDOTU_TU4                                        4

//repcap EVDOZone
#define RSRFSIGGEN_REPCAP_EVDOZONE_EZONE0                                   0
#define RSRFSIGGEN_REPCAP_EVDOZONE_EZONE1                                   1
#define RSRFSIGGEN_REPCAP_EVDOZONE_EZONE2                                   2
#define RSRFSIGGEN_REPCAP_EVDOZONE_EZONE3                                   3

//repcap EVDOAT
#define RSRFSIGGEN_REPCAP_EVDOAT_AT1                                        1
#define RSRFSIGGEN_REPCAP_EVDOAT_AT2                                        2
#define RSRFSIGGEN_REPCAP_EVDOAT_AT3                                        3
#define RSRFSIGGEN_REPCAP_EVDOAT_AT4                                        4

//repcap EVDOPacket
#define RSRFSIGGEN_REPCAP_EVDOPACKET_PACKET1                                1
#define RSRFSIGGEN_REPCAP_EVDOPACKET_PACKET2                                2
#define RSRFSIGGEN_REPCAP_EVDOPACKET_PACKET3                                3

//repcap WLANNOutput
#define RSRFSIGGEN_REPCAP_WLANNOUTPUT_O1                                    1
#define RSRFSIGGEN_REPCAP_WLANNOUTPUT_O2                                    2
#define RSRFSIGGEN_REPCAP_WLANNOUTPUT_O3                                    3
#define RSRFSIGGEN_REPCAP_WLANNOUTPUT_O4                                    4
#define RSRFSIGGEN_REPCAP_WLANNOUTPUT_O5                                    5
#define RSRFSIGGEN_REPCAP_WLANNOUTPUT_O6                                    6
#define RSRFSIGGEN_REPCAP_WLANNOUTPUT_O7                                    7
#define RSRFSIGGEN_REPCAP_WLANNOUTPUT_O8                                    8

//repcap WLANNTx
#define RSRFSIGGEN_REPCAP_WLANNTX_TX1                                       1
#define RSRFSIGGEN_REPCAP_WLANNTX_TX2                                       2
#define RSRFSIGGEN_REPCAP_WLANNTX_TX3                                       3
#define RSRFSIGGEN_REPCAP_WLANNTX_TX4                                       4
#define RSRFSIGGEN_REPCAP_WLANNTX_TX5                                       5
#define RSRFSIGGEN_REPCAP_WLANNTX_TX6                                       6
#define RSRFSIGGEN_REPCAP_WLANNTX_TX7                                       7
#define RSRFSIGGEN_REPCAP_WLANNTX_TX8                                       8

//repcap WLANNFrameBlock
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB1                               1
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB2                               2
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB3                               3
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB4                               4
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB5                               5
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB6                               6
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB7                               7
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB8                               8
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB9                               9
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB10                              10
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB11                              11
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB12                              12
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB13                              13
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB14                              14
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB15                              15
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB16                              16
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB17                              17
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB18                              18
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB19                              19
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB20                              20
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB21                              21
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB22                              22
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB23                              23
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB24                              24
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB25                              25
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB26                              26
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB27                              27
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB28                              28
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB29                              29
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB30                              30
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB31                              31
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB32                              32
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB33                              33
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB34                              34
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB35                              35
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB36                              36
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB37                              37
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB38                              38
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB39                              39
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB40                              40
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB41                              41
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB42                              42
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB43                              43
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB44                              44
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB45                              45
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB46                              46
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB47                              47
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB48                              48
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB49                              49
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB50                              50
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB51                              51
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB52                              52
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB53                              53
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB54                              54
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB55                              55
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB56                              56
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB57                              57
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB58                              58
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB59                              59
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB60                              60
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB61                              61
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB62                              62
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB63                              63
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB64                              64
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB65                              65
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB66                              66
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB67                              67
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB68                              68
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB69                              69
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB70                              70
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB71                              71
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB72                              72
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB73                              73
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB74                              74
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB75                              75
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB76                              76
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB77                              77
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB78                              78
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB79                              79
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB80                              80
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB81                              81
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB82                              82
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB83                              83
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB84                              84
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB85                              85
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB86                              86
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB87                              87
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB88                              88
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB89                              89
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB90                              90
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB91                              91
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB92                              92
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB93                              93
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB94                              94
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB95                              95
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB96                              96
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB97                              97
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB98                              98
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB99                              99
#define RSRFSIGGEN_REPCAP_WLANNFRAMEBLOCK_FB100                             100

//repcap WiMAXBurst
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST0                                 0
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST1                                 1
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST2                                 2
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST3                                 3
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST4                                 4
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST5                                 5
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST6                                 6
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST7                                 7
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST8                                 8
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST9                                 9
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST10                                10
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST11                                11
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST12                                12
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST13                                13
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST14                                14
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST15                                15
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST16                                16
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST17                                17
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST18                                18
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST19                                19
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST20                                20
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST21                                21
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST22                                22
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST23                                23
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST24                                24
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST25                                25
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST26                                26
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST27                                27
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST28                                28
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST29                                29
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST30                                30
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST31                                31
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST32                                32
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST33                                33
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST34                                34
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST35                                35
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST36                                36
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST37                                37
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST38                                38
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST39                                39
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST40                                40
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST41                                41
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST42                                42
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST43                                43
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST44                                44
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST45                                45
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST46                                46
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST47                                47
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST48                                48
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST49                                49
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST50                                50
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST51                                51
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST52                                52
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST53                                53
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST54                                54
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST55                                55
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST56                                56
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST57                                57
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST58                                58
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST59                                59
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST60                                60
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST61                                61
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST62                                62
#define RSRFSIGGEN_REPCAP_WIMAXBURST_BURST63                                63

//repcap WiMAXZone
#define RSRFSIGGEN_REPCAP_WIMAXZONE_ZONE0                                   0
#define RSRFSIGGEN_REPCAP_WIMAXZONE_ZONE1                                   1
#define RSRFSIGGEN_REPCAP_WIMAXZONE_ZONE2                                   2
#define RSRFSIGGEN_REPCAP_WIMAXZONE_ZONE3                                   3
#define RSRFSIGGEN_REPCAP_WIMAXZONE_ZONE4                                   4
#define RSRFSIGGEN_REPCAP_WIMAXZONE_ZONE5                                   5
#define RSRFSIGGEN_REPCAP_WIMAXZONE_ZONE6                                   6
#define RSRFSIGGEN_REPCAP_WIMAXZONE_ZONE7                                   7

//repcap HARQ
#define RSRFSIGGEN_REPCAP_HARQ_HARQ0                                        0
#define RSRFSIGGEN_REPCAP_HARQ_HARQ1                                        1
#define RSRFSIGGEN_REPCAP_HARQ_HARQ2                                        2
#define RSRFSIGGEN_REPCAP_HARQ_HARQ3                                        3
#define RSRFSIGGEN_REPCAP_HARQ_HARQ4                                        4
#define RSRFSIGGEN_REPCAP_HARQ_HARQ5                                        5
#define RSRFSIGGEN_REPCAP_HARQ_HARQ6                                        6
#define RSRFSIGGEN_REPCAP_HARQ_HARQ7                                        7
#define RSRFSIGGEN_REPCAP_HARQ_HARQ8                                        8
#define RSRFSIGGEN_REPCAP_HARQ_HARQ9                                        9
#define RSRFSIGGEN_REPCAP_HARQ_HARQ10                                       10
#define RSRFSIGGEN_REPCAP_HARQ_HARQ11                                       11
#define RSRFSIGGEN_REPCAP_HARQ_HARQ12                                       12
#define RSRFSIGGEN_REPCAP_HARQ_HARQ13                                       13
#define RSRFSIGGEN_REPCAP_HARQ_HARQ14                                       14

//repcap WiMAXCh
#define RSRFSIGGEN_REPCAP_WIMAXCH_CH0                                       0
#define RSRFSIGGEN_REPCAP_WIMAXCH_CH1                                       1
#define RSRFSIGGEN_REPCAP_WIMAXCH_CH2                                       2
#define RSRFSIGGEN_REPCAP_WIMAXCH_CH3                                       3
#define RSRFSIGGEN_REPCAP_WIMAXCH_CH4                                       4
#define RSRFSIGGEN_REPCAP_WIMAXCH_CH5                                       5

//repcap WiMAXPDU
#define RSRFSIGGEN_REPCAP_WIMAXPDU_PDU1                                     1
#define RSRFSIGGEN_REPCAP_WIMAXPDU_PDU2                                     2
#define RSRFSIGGEN_REPCAP_WIMAXPDU_PDU3                                     3
#define RSRFSIGGEN_REPCAP_WIMAXPDU_PDU4                                     4
#define RSRFSIGGEN_REPCAP_WIMAXPDU_PDU5                                     5
#define RSRFSIGGEN_REPCAP_WIMAXPDU_PDU6                                     6
#define RSRFSIGGEN_REPCAP_WIMAXPDU_PDU7                                     7
#define RSRFSIGGEN_REPCAP_WIMAXPDU_PDU8                                     8
#define RSRFSIGGEN_REPCAP_WIMAXPDU_PDU9                                     9
#define RSRFSIGGEN_REPCAP_WIMAXPDU_PDU10                                    10
#define RSRFSIGGEN_REPCAP_WIMAXPDU_PDU11                                    11
#define RSRFSIGGEN_REPCAP_WIMAXPDU_PDU12                                    12
#define RSRFSIGGEN_REPCAP_WIMAXPDU_PDU13                                    13
#define RSRFSIGGEN_REPCAP_WIMAXPDU_PDU14                                    14
#define RSRFSIGGEN_REPCAP_WIMAXPDU_PDU15                                    15
#define RSRFSIGGEN_REPCAP_WIMAXPDU_PDU16                                    16

//repcap WiMAXCID
#define RSRFSIGGEN_REPCAP_WIMAXCID_CID0                                     0
#define RSRFSIGGEN_REPCAP_WIMAXCID_CID1                                     1
#define RSRFSIGGEN_REPCAP_WIMAXCID_CID2                                     2
#define RSRFSIGGEN_REPCAP_WIMAXCID_CID3                                     3
#define RSRFSIGGEN_REPCAP_WIMAXCID_CID4                                     4
#define RSRFSIGGEN_REPCAP_WIMAXCID_CID5                                     5
#define RSRFSIGGEN_REPCAP_WIMAXCID_CID6                                     6
#define RSRFSIGGEN_REPCAP_WIMAXCID_CID7                                     7
#define RSRFSIGGEN_REPCAP_WIMAXCID_CID8                                     8
#define RSRFSIGGEN_REPCAP_WIMAXCID_CID9                                     9
#define RSRFSIGGEN_REPCAP_WIMAXCID_CID10                                    10
#define RSRFSIGGEN_REPCAP_WIMAXCID_CID11                                    11
#define RSRFSIGGEN_REPCAP_WIMAXCID_CID12                                    12
#define RSRFSIGGEN_REPCAP_WIMAXCID_CID13                                    13
#define RSRFSIGGEN_REPCAP_WIMAXCID_CID14                                    14
#define RSRFSIGGEN_REPCAP_WIMAXCID_CID15                                    15

//repcap WiMAXUIUC
#define RSRFSIGGEN_REPCAP_WIMAXUIUC_UIUC1                                   1
#define RSRFSIGGEN_REPCAP_WIMAXUIUC_UIUC2                                   2
#define RSRFSIGGEN_REPCAP_WIMAXUIUC_UIUC3                                   3
#define RSRFSIGGEN_REPCAP_WIMAXUIUC_UIUC4                                   4
#define RSRFSIGGEN_REPCAP_WIMAXUIUC_UIUC5                                   5
#define RSRFSIGGEN_REPCAP_WIMAXUIUC_UIUC6                                   6
#define RSRFSIGGEN_REPCAP_WIMAXUIUC_UIUC7                                   7
#define RSRFSIGGEN_REPCAP_WIMAXUIUC_UIUC8                                   8
#define RSRFSIGGEN_REPCAP_WIMAXUIUC_UIUC9                                   9
#define RSRFSIGGEN_REPCAP_WIMAXUIUC_UIUC10                                  10

//repcap WiMAXDUIC
#define RSRFSIGGEN_REPCAP_WIMAXDUIC_DUIC0                                   0
#define RSRFSIGGEN_REPCAP_WIMAXDUIC_DUIC1                                   1
#define RSRFSIGGEN_REPCAP_WIMAXDUIC_DUIC2                                   2
#define RSRFSIGGEN_REPCAP_WIMAXDUIC_DUIC3                                   3
#define RSRFSIGGEN_REPCAP_WIMAXDUIC_DUIC4                                   4
#define RSRFSIGGEN_REPCAP_WIMAXDUIC_DUIC5                                   5
#define RSRFSIGGEN_REPCAP_WIMAXDUIC_DUIC6                                   6
#define RSRFSIGGEN_REPCAP_WIMAXDUIC_DUIC7                                   7
#define RSRFSIGGEN_REPCAP_WIMAXDUIC_DUIC8                                   8
#define RSRFSIGGEN_REPCAP_WIMAXDUIC_DUIC9                                   9
#define RSRFSIGGEN_REPCAP_WIMAXDUIC_DUIC10                                  10
#define RSRFSIGGEN_REPCAP_WIMAXDUIC_DUIC11                                  11
#define RSRFSIGGEN_REPCAP_WIMAXDUIC_DUIC12                                  12

//repcap WiMAXCSTD
#define RSRFSIGGEN_REPCAP_WIMAXCSTD_CSTD0                                   0
#define RSRFSIGGEN_REPCAP_WIMAXCSTD_CSTD1                                   1

//repcap WiMAXTap
#define RSRFSIGGEN_REPCAP_WIMAXTAP_WIMAXTAP0                                0
#define RSRFSIGGEN_REPCAP_WIMAXTAP_WIMAXTAP1                                1
#define RSRFSIGGEN_REPCAP_WIMAXTAP_WIMAXTAP2                                2
#define RSRFSIGGEN_REPCAP_WIMAXTAP_WIMAXTAP3                                3
#define RSRFSIGGEN_REPCAP_WIMAXTAP_WIMAXTAP4                                4

//repcap DMSymbol
#define RSRFSIGGEN_REPCAP_DMSYMBOL_SYMBOL0                                  0
#define RSRFSIGGEN_REPCAP_DMSYMBOL_SYMBOL1                                  1
#define RSRFSIGGEN_REPCAP_DMSYMBOL_SYMBOL2                                  2
#define RSRFSIGGEN_REPCAP_DMSYMBOL_SYMBOL3                                  3
#define RSRFSIGGEN_REPCAP_DMSYMBOL_SYMBOL4                                  4
#define RSRFSIGGEN_REPCAP_DMSYMBOL_SYMBOL5                                  5
#define RSRFSIGGEN_REPCAP_DMSYMBOL_SYMBOL6                                  6
#define RSRFSIGGEN_REPCAP_DMSYMBOL_SYMBOL7                                  7
#define RSRFSIGGEN_REPCAP_DMSYMBOL_SYMBOL8                                  8
#define RSRFSIGGEN_REPCAP_DMSYMBOL_SYMBOL9                                  9
#define RSRFSIGGEN_REPCAP_DMSYMBOL_SYMBOL10                                 10
#define RSRFSIGGEN_REPCAP_DMSYMBOL_SYMBOL11                                 11
#define RSRFSIGGEN_REPCAP_DMSYMBOL_SYMBOL12                                 12
#define RSRFSIGGEN_REPCAP_DMSYMBOL_SYMBOL13                                 13
#define RSRFSIGGEN_REPCAP_DMSYMBOL_SYMBOL14                                 14
#define RSRFSIGGEN_REPCAP_DMSYMBOL_SYMBOL15                                 15

//repcap ARBCarrier
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER0                               0
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER1                               1
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER2                               2
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER3                               3
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER4                               4
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER5                               5
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER6                               6
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER7                               7
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER8                               8
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER9                               9
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER10                              10
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER11                              11
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER12                              12
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER13                              13
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER14                              14
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER15                              15
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER16                              16
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER17                              17
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER18                              18
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER19                              19
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER20                              20
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER21                              21
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER22                              22
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER23                              23
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER24                              24
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER25                              25
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER26                              26
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER27                              27
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER28                              28
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER29                              29
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER30                              30
#define RSRFSIGGEN_REPCAP_ARBCARRIER_CARRIER31                              31

//repcap GPPGap
#define RSRFSIGGEN_REPCAP_GPPGAP_GAP1                                       1
#define RSRFSIGGEN_REPCAP_GPPGAP_GAP2                                       2

//repcap WLANNTimeShift
#define RSRFSIGGEN_REPCAP_WLANNTIMESHIFT_WLANNTS1                           1
#define RSRFSIGGEN_REPCAP_WLANNTIMESHIFT_WLANNTS2                           2
#define RSRFSIGGEN_REPCAP_WLANNTIMESHIFT_WLANNTS3                           3
#define RSRFSIGGEN_REPCAP_WLANNTIMESHIFT_WLANNTS4                           4
#define RSRFSIGGEN_REPCAP_WLANNTIMESHIFT_WLANNTS5                           5
#define RSRFSIGGEN_REPCAP_WLANNTIMESHIFT_WLANNTS6                           6
#define RSRFSIGGEN_REPCAP_WLANNTIMESHIFT_WLANNTS7                           7
#define RSRFSIGGEN_REPCAP_WLANNTIMESHIFT_WLANNTS8                           8

//repcap WLANNColumn
#define RSRFSIGGEN_REPCAP_WLANNCOLUMN_COL1                                  1
#define RSRFSIGGEN_REPCAP_WLANNCOLUMN_COL2                                  2
#define RSRFSIGGEN_REPCAP_WLANNCOLUMN_COL3                                  3
#define RSRFSIGGEN_REPCAP_WLANNCOLUMN_COL4                                  4
#define RSRFSIGGEN_REPCAP_WLANNCOLUMN_COL5                                  5
#define RSRFSIGGEN_REPCAP_WLANNCOLUMN_COL6                                  6
#define RSRFSIGGEN_REPCAP_WLANNCOLUMN_COL7                                  7
#define RSRFSIGGEN_REPCAP_WLANNCOLUMN_COL8                                  8

//repcap GPSReserved
#define RSRFSIGGEN_REPCAP_GPSRESERVED_RESERVED1                             1
#define RSRFSIGGEN_REPCAP_GPSRESERVED_RESERVED2                             2
#define RSRFSIGGEN_REPCAP_GPSRESERVED_RESERVED3                             3
#define RSRFSIGGEN_REPCAP_GPSRESERVED_RESERVED4                             4

//repcap C2KSub
#define RSRFSIGGEN_REPCAP_C2KSUB_SUB1                                       1
#define RSRFSIGGEN_REPCAP_C2KSUB_SUB2                                       2
#define RSRFSIGGEN_REPCAP_C2KSUB_SUB3                                       3
#define RSRFSIGGEN_REPCAP_C2KSUB_SUB4                                       4
#define RSRFSIGGEN_REPCAP_C2KSUB_SUB5                                       5
#define RSRFSIGGEN_REPCAP_C2KSUB_SUB6                                       6
#define RSRFSIGGEN_REPCAP_C2KSUB_SUB7                                       7
#define RSRFSIGGEN_REPCAP_C2KSUB_SUB8                                       8

//repcap SatNavRegion
#define RSRFSIGGEN_REPCAP_SATNAVREGION_REGION1                              1
#define RSRFSIGGEN_REPCAP_SATNAVREGION_REGION2                              2
#define RSRFSIGGEN_REPCAP_SATNAVREGION_REGION3                              3
#define RSRFSIGGEN_REPCAP_SATNAVREGION_REGION4                              4
#define RSRFSIGGEN_REPCAP_SATNAVREGION_REGION5                              5

//repcap SatNavSat
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT1                                    1
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT2                                    2
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT3                                    3
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT4                                    4
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT5                                    5
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT6                                    6
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT7                                    7
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT8                                    8
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT9                                    9
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT10                                   10
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT11                                   11
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT12                                   12
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT13                                   13
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT14                                   14
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT15                                   15
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT16                                   16
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT17                                   17
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT18                                   18
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT19                                   19
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT20                                   20
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT21                                   21
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT22                                   22
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT23                                   23
#define RSRFSIGGEN_REPCAP_SATNAVSAT_SAT24                                   24

//repcap SatNavSVID
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID1                                  1
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID2                                  2
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID3                                  3
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID4                                  4
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID5                                  5
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID6                                  6
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID7                                  7
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID8                                  8
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID9                                  9
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID10                                 10
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID11                                 11
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID12                                 12
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID13                                 13
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID14                                 14
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID15                                 15
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID16                                 16
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID17                                 17
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID18                                 18
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID19                                 19
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID20                                 20
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID21                                 21
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID22                                 22
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID23                                 23
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID24                                 24
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID25                                 25
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID26                                 26
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID27                                 27
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID28                                 28
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID29                                 29
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID30                                 30
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID31                                 31
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID32                                 32
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID33                                 33
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID34                                 34
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID35                                 35
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID36                                 36
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID37                                 37
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID38                                 38
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID39                                 39
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID40                                 40
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID41                                 41
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID42                                 42
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID43                                 43
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID44                                 44
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID45                                 45
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID46                                 46
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID47                                 47
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID48                                 48
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID49                                 49
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID50                                 50
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID193                                51
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID194                                52
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID195                                53
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID196                                54
#define RSRFSIGGEN_REPCAP_SATNAVSVID_SVID197                                55

//repcap SatNavTap
#define RSRFSIGGEN_REPCAP_SATNAVTAP_TAP1                                    1
#define RSRFSIGGEN_REPCAP_SATNAVTAP_TAP2                                    2
#define RSRFSIGGEN_REPCAP_SATNAVTAP_TAP3                                    3
#define RSRFSIGGEN_REPCAP_SATNAVTAP_TAP4                                    4
#define RSRFSIGGEN_REPCAP_SATNAVTAP_TAP5                                    5
#define RSRFSIGGEN_REPCAP_SATNAVTAP_TAP6                                    6
#define RSRFSIGGEN_REPCAP_SATNAVTAP_TAP7                                    7
#define RSRFSIGGEN_REPCAP_SATNAVTAP_TAP8                                    8
#define RSRFSIGGEN_REPCAP_SATNAVTAP_TAP9                                    9
#define RSRFSIGGEN_REPCAP_SATNAVTAP_TAP10                                   10

//repcap Sense
#define RSRFSIGGEN_REPCAP_SENSE_SENSE1                                      1
#define RSRFSIGGEN_REPCAP_SENSE_SENSE2                                      2
#define RSRFSIGGEN_REPCAP_SENSE_SENSE3                                      3
#define RSRFSIGGEN_REPCAP_SENSE_SENSE4                                      4

//repcap Connector
#define RSRFSIGGEN_REPCAP_CONNECTOR_C1                                      1
#define RSRFSIGGEN_REPCAP_CONNECTOR_C2                                      2
#define RSRFSIGGEN_REPCAP_CONNECTOR_C3                                      3
#define RSRFSIGGEN_REPCAP_CONNECTOR_C4                                      4
#define RSRFSIGGEN_REPCAP_CONNECTOR_C5                                      5
#define RSRFSIGGEN_REPCAP_CONNECTOR_C6                                      6

//repcap TDSCDMASlotNumber
#define RSRFSIGGEN_REPCAP_TDSCDMASLOTNUMBER_SN0                             0
#define RSRFSIGGEN_REPCAP_TDSCDMASLOTNUMBER_SN1                             1
#define RSRFSIGGEN_REPCAP_TDSCDMASLOTNUMBER_SN2                             2
#define RSRFSIGGEN_REPCAP_TDSCDMASLOTNUMBER_SN3                             3
#define RSRFSIGGEN_REPCAP_TDSCDMASLOTNUMBER_SN4                             4
#define RSRFSIGGEN_REPCAP_TDSCDMASLOTNUMBER_SN5                             5
#define RSRFSIGGEN_REPCAP_TDSCDMASLOTNUMBER_SN6                             6

//repcap TDSCDMAChannel
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC1                               1
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC2                               2
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC3                               3
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC4                               4
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC5                               5
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC6                               6
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC7                               7
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC8                               8
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC9                               9
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC10                              10
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC11                              11
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC12                              12
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC13                              13
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC14                              14
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC15                              15
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC16                              16
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC17                              17
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC18                              18
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC19                              19
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC20                              20
#define RSRFSIGGEN_REPCAP_TDSCDMACHANNEL_TDC21                              21

//repcap StereoDSGroup
#define RSRFSIGGEN_REPCAP_STEREODSGROUP_DSG0                                0
#define RSRFSIGGEN_REPCAP_STEREODSGROUP_DSG1                                1
#define RSRFSIGGEN_REPCAP_STEREODSGROUP_DSG2                                2
#define RSRFSIGGEN_REPCAP_STEREODSGROUP_DSG3                                3
#define RSRFSIGGEN_REPCAP_STEREODSGROUP_DSG4                                4
#define RSRFSIGGEN_REPCAP_STEREODSGROUP_DSG5                                5
#define RSRFSIGGEN_REPCAP_STEREODSGROUP_DSG6                                6
#define RSRFSIGGEN_REPCAP_STEREODSGROUP_DSG7                                7
#define RSRFSIGGEN_REPCAP_STEREODSGROUP_DSG8                                8
#define RSRFSIGGEN_REPCAP_STEREODSGROUP_DSG9                                9
#define RSRFSIGGEN_REPCAP_STEREODSGROUP_DSG10                               10
#define RSRFSIGGEN_REPCAP_STEREODSGROUP_DSG11                               11
#define RSRFSIGGEN_REPCAP_STEREODSGROUP_DSG12                               12
#define RSRFSIGGEN_REPCAP_STEREODSGROUP_DSG13                               13
#define RSRFSIGGEN_REPCAP_STEREODSGROUP_DSG14                               14
#define RSRFSIGGEN_REPCAP_STEREODSGROUP_DSG15                               15

//repcap StereoAF
#define RSRFSIGGEN_REPCAP_STEREOAF_AF0                                      0
#define RSRFSIGGEN_REPCAP_STEREOAF_AF1                                      1
#define RSRFSIGGEN_REPCAP_STEREOAF_AF2                                      2
#define RSRFSIGGEN_REPCAP_STEREOAF_AF3                                      3
#define RSRFSIGGEN_REPCAP_STEREOAF_AF4                                      4
#define RSRFSIGGEN_REPCAP_STEREOAF_AF5                                      5
#define RSRFSIGGEN_REPCAP_STEREOAF_AF6                                      6
#define RSRFSIGGEN_REPCAP_STEREOAF_AF7                                      7
#define RSRFSIGGEN_REPCAP_STEREOAF_AF8                                      8
#define RSRFSIGGEN_REPCAP_STEREOAF_AF9                                      9
#define RSRFSIGGEN_REPCAP_STEREOAF_AF10                                     10
#define RSRFSIGGEN_REPCAP_STEREOAF_AF11                                     11
#define RSRFSIGGEN_REPCAP_STEREOAF_AF12                                     12
#define RSRFSIGGEN_REPCAP_STEREOAF_AF13                                     13
#define RSRFSIGGEN_REPCAP_STEREOAF_AF14                                     14
#define RSRFSIGGEN_REPCAP_STEREOAF_AF15                                     15
#define RSRFSIGGEN_REPCAP_STEREOAF_AF16                                     16
#define RSRFSIGGEN_REPCAP_STEREOAF_AF17                                     17
#define RSRFSIGGEN_REPCAP_STEREOAF_AF18                                     18
#define RSRFSIGGEN_REPCAP_STEREOAF_AF19                                     19
#define RSRFSIGGEN_REPCAP_STEREOAF_AF20                                     20
#define RSRFSIGGEN_REPCAP_STEREOAF_AF21                                     21
#define RSRFSIGGEN_REPCAP_STEREOAF_AF22                                     22
#define RSRFSIGGEN_REPCAP_STEREOAF_AF23                                     23
#define RSRFSIGGEN_REPCAP_STEREOAF_AF24                                     24

//repcap StereoMF
#define RSRFSIGGEN_REPCAP_STEREOMF_MF0                                      0
#define RSRFSIGGEN_REPCAP_STEREOMF_MF1                                      1
#define RSRFSIGGEN_REPCAP_STEREOMF_MF2                                      2
#define RSRFSIGGEN_REPCAP_STEREOMF_MF3                                      3
#define RSRFSIGGEN_REPCAP_STEREOMF_MF4                                      4

//repcap StereoHexTabRow
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG0                               0
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG1                               1
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG2                               2
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG3                               3
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG4                               4
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG5                               5
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG6                               6
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG7                               7
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG8                               8
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG9                               9
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG10                              10
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG11                              11
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG12                              12
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG13                              13
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG14                              14
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG15                              15
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG16                              16
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG17                              17
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG18                              18
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG19                              19
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG20                              20
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG21                              21
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG22                              22
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG23                              23
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG24                              24
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG25                              25
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG26                              26
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG27                              27
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG28                              28
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG29                              29
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG30                              30
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG31                              31
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG32                              32
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG33                              33
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG34                              34
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG35                              35
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG36                              36
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG37                              37
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG38                              38
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG39                              39
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG40                              40
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG41                              41
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG42                              42
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG43                              43
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG44                              44
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG45                              45
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG46                              46
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG47                              47
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG48                              48
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG49                              49
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG50                              50
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG51                              51
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG52                              52
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG53                              53
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG54                              54
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG55                              55
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG56                              56
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG57                              57
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG58                              58
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG59                              59
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG60                              60
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG61                              61
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG62                              62
#define RSRFSIGGEN_REPCAP_STEREOHEXTABROW_HG63                              63

//repcap StereoHexTabBlock
#define RSRFSIGGEN_REPCAP_STEREOHEXTABBLOCK_B1                              1
#define RSRFSIGGEN_REPCAP_STEREOHEXTABBLOCK_B2                              2
#define RSRFSIGGEN_REPCAP_STEREOHEXTABBLOCK_B3                              3
#define RSRFSIGGEN_REPCAP_STEREOHEXTABBLOCK_B4                              4

//repcap StereoUMTabRow
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM0                                0
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM1                                1
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM2                                2
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM3                                3
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM4                                4
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM5                                5
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM6                                6
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM7                                7
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM8                                8
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM9                                9
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM10                               10
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM11                               11
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM12                               12
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM13                               13
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM14                               14
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM15                               15
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM16                               16
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM17                               17
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM18                               18
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM19                               19
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM20                               20
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM21                               21
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM22                               22
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM23                               23
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM24                               24
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM25                               25
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM26                               26
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM27                               27
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM28                               28
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM29                               29
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM30                               30
#define RSRFSIGGEN_REPCAP_STEREOUMTABROW_UM31                               31

//repcap StereoUMTabBlock
#define RSRFSIGGEN_REPCAP_STEREOUMTABBLOCK_UMB2                             0
#define RSRFSIGGEN_REPCAP_STEREOUMTABBLOCK_UMB3                             1
#define RSRFSIGGEN_REPCAP_STEREOUMTABBLOCK_UMB4                             2

//repcap FSIMPath
#define RSRFSIGGEN_REPCAP_FSIMPATH_P1                                       1
#define RSRFSIGGEN_REPCAP_FSIMPATH_P2                                       2
#define RSRFSIGGEN_REPCAP_FSIMPATH_P3                                       3
#define RSRFSIGGEN_REPCAP_FSIMPATH_P4                                       4
#define RSRFSIGGEN_REPCAP_FSIMPATH_P5                                       5
#define RSRFSIGGEN_REPCAP_FSIMPATH_P6                                       6
#define RSRFSIGGEN_REPCAP_FSIMPATH_P7                                       7
#define RSRFSIGGEN_REPCAP_FSIMPATH_P8                                       8
#define RSRFSIGGEN_REPCAP_FSIMPATH_P9                                       9
#define RSRFSIGGEN_REPCAP_FSIMPATH_P10                                      10
#define RSRFSIGGEN_REPCAP_FSIMPATH_P11                                      11
#define RSRFSIGGEN_REPCAP_FSIMPATH_P12                                      12

//repcap FSIMTab
#define RSRFSIGGEN_REPCAP_FSIMTAB_T1                                        1
#define RSRFSIGGEN_REPCAP_FSIMTAB_T2                                        2
#define RSRFSIGGEN_REPCAP_FSIMTAB_T3                                        3
#define RSRFSIGGEN_REPCAP_FSIMTAB_T4                                        4
#define RSRFSIGGEN_REPCAP_FSIMTAB_T5                                        5
#define RSRFSIGGEN_REPCAP_FSIMTAB_T6                                        6
#define RSRFSIGGEN_REPCAP_FSIMTAB_T7                                        7
#define RSRFSIGGEN_REPCAP_FSIMTAB_T8                                        8
#define RSRFSIGGEN_REPCAP_FSIMTAB_T9                                        9
#define RSRFSIGGEN_REPCAP_FSIMTAB_T10                                       10

//repcap FSIMRow
#define RSRFSIGGEN_REPCAP_FSIMROW_R1                                        1
#define RSRFSIGGEN_REPCAP_FSIMROW_R2                                        2
#define RSRFSIGGEN_REPCAP_FSIMROW_R3                                        3
#define RSRFSIGGEN_REPCAP_FSIMROW_R4                                        4

//repcap FSIMCol
#define RSRFSIGGEN_REPCAP_FSIMCOL_FSIMC1                                    1
#define RSRFSIGGEN_REPCAP_FSIMCOL_FSIMC2                                    2
#define RSRFSIGGEN_REPCAP_FSIMCOL_FSIMC3                                    3
#define RSRFSIGGEN_REPCAP_FSIMCOL_FSIMC4                                    4

//repcap FSIMPathDel
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD1                                1
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD2                                2
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD3                                3
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD4                                4
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD5                                5
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD6                                6
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD7                                7
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD8                                8
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD9                                9
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD10                               10
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD11                               11
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD12                               12
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD13                               13
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD14                               14
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD15                               15
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD16                               16
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD17                               17
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD18                               18
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD19                               19
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD20                               20
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD21                               21
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD22                               22
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD23                               23
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD24                               24
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD25                               25
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD26                               26
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD27                               27
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD28                               28
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD29                               29
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD30                               30
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD31                               31
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD32                               32
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD33                               33
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD34                               34
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD35                               35
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD36                               36
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD37                               37
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD38                               38
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD39                               39
#define RSRFSIGGEN_REPCAP_FSIMPATHDEL_PATHD40                               40

//repcap AllocationUL
#define RSRFSIGGEN_REPCAP_ALLOCATIONUL_ALLOCATIONUL1                        0
#define RSRFSIGGEN_REPCAP_ALLOCATIONUL_ALLOCATIONUL2                        1
#define RSRFSIGGEN_REPCAP_ALLOCATIONUL_ALLOCATIONUL3                        2
#define RSRFSIGGEN_REPCAP_ALLOCATIONUL_ALLOCATIONUL4                        3

//repcap Set
#define RSRFSIGGEN_REPCAP_SET_SET1                                          1
#define RSRFSIGGEN_REPCAP_SET_SET2                                          2

//repcap GPPPostamble
#define RSRFSIGGEN_REPCAP_GPPPOSTAMBLE_POST1                                1
#define RSRFSIGGEN_REPCAP_GPPPOSTAMBLE_POST2                                2

//repcap GPPDPCH
#define RSRFSIGGEN_REPCAP_GPPDPCH_DPCH11                                    0
#define RSRFSIGGEN_REPCAP_GPPDPCH_DPCH12                                    1
#define RSRFSIGGEN_REPCAP_GPPDPCH_DPCH13                                    2

//repcap EUTRACell
#define RSRFSIGGEN_REPCAP_EUTRACELL_PCELL0                                  0
#define RSRFSIGGEN_REPCAP_EUTRACELL_SCELL1                                  1
#define RSRFSIGGEN_REPCAP_EUTRACELL_SCELL2                                  2
#define RSRFSIGGEN_REPCAP_EUTRACELL_SCELL3                                  3
#define RSRFSIGGEN_REPCAP_EUTRACELL_SCELL4                                  4

//repcap EVDOCarrier
#define RSRFSIGGEN_REPCAP_EVDOCARRIER_EC1                                   1
#define RSRFSIGGEN_REPCAP_EVDOCARRIER_EC2                                   2
#define RSRFSIGGEN_REPCAP_EVDOCARRIER_EC3                                   3
#define RSRFSIGGEN_REPCAP_EVDOCARRIER_EC4                                   4
#define RSRFSIGGEN_REPCAP_EVDOCARRIER_EC5                                   5
#define RSRFSIGGEN_REPCAP_EVDOCARRIER_EC6                                   6
#define RSRFSIGGEN_REPCAP_EVDOCARRIER_EC7                                   7
#define RSRFSIGGEN_REPCAP_EVDOCARRIER_EC8                                   8
#define RSRFSIGGEN_REPCAP_EVDOCARRIER_EC9                                   9
#define RSRFSIGGEN_REPCAP_EVDOCARRIER_EC10                                  10
#define RSRFSIGGEN_REPCAP_EVDOCARRIER_EC11                                  11
#define RSRFSIGGEN_REPCAP_EVDOCARRIER_EC12                                  12
#define RSRFSIGGEN_REPCAP_EVDOCARRIER_EC13                                  13
#define RSRFSIGGEN_REPCAP_EVDOCARRIER_EC14                                  14
#define RSRFSIGGEN_REPCAP_EVDOCARRIER_EC15                                  15
#define RSRFSIGGEN_REPCAP_EVDOCARRIER_EC16                                  16

//repcap LF
#define RSRFSIGGEN_REPCAP_LF_LF1                                            1
#define RSRFSIGGEN_REPCAP_LF_LF2                                            2

//repcap UserSMW
#define RSRFSIGGEN_REPCAP_USERSMW_US1                                       1
#define RSRFSIGGEN_REPCAP_USERSMW_US2                                       2
#define RSRFSIGGEN_REPCAP_USERSMW_US3                                       3
#define RSRFSIGGEN_REPCAP_USERSMW_US4                                       4
#define RSRFSIGGEN_REPCAP_USERSMW_US5                                       5
#define RSRFSIGGEN_REPCAP_USERSMW_US6                                       6

//repcap Area
#define RSRFSIGGEN_REPCAP_AREA_A0                                           0
#define RSRFSIGGEN_REPCAP_AREA_A1                                           1
#define RSRFSIGGEN_REPCAP_AREA_A2                                           2
#define RSRFSIGGEN_REPCAP_AREA_A3                                           3
#define RSRFSIGGEN_REPCAP_AREA_A4                                           4
#define RSRFSIGGEN_REPCAP_AREA_A5                                           5
#define RSRFSIGGEN_REPCAP_AREA_A6                                           6
#define RSRFSIGGEN_REPCAP_AREA_A7                                           7
#define RSRFSIGGEN_REPCAP_AREA_A8                                           8
#define RSRFSIGGEN_REPCAP_AREA_A9                                           9
#define RSRFSIGGEN_REPCAP_AREA_A10                                          10
#define RSRFSIGGEN_REPCAP_AREA_A11                                          11
#define RSRFSIGGEN_REPCAP_AREA_A12                                          12
#define RSRFSIGGEN_REPCAP_AREA_A13                                          13
#define RSRFSIGGEN_REPCAP_AREA_A14                                          14
#define RSRFSIGGEN_REPCAP_AREA_A15                                          15
#define RSRFSIGGEN_REPCAP_AREA_A16                                          16
#define RSRFSIGGEN_REPCAP_AREA_A17                                          17
#define RSRFSIGGEN_REPCAP_AREA_A18                                          18
#define RSRFSIGGEN_REPCAP_AREA_A19                                          19
#define RSRFSIGGEN_REPCAP_AREA_A20                                          20
#define RSRFSIGGEN_REPCAP_AREA_A21                                          21
#define RSRFSIGGEN_REPCAP_AREA_A22                                          22
#define RSRFSIGGEN_REPCAP_AREA_A23                                          23
#define RSRFSIGGEN_REPCAP_AREA_A24                                          24
#define RSRFSIGGEN_REPCAP_AREA_A25                                          25
#define RSRFSIGGEN_REPCAP_AREA_A26                                          26
#define RSRFSIGGEN_REPCAP_AREA_A27                                          27
#define RSRFSIGGEN_REPCAP_AREA_A28                                          28
#define RSRFSIGGEN_REPCAP_AREA_A29                                          29
#define RSRFSIGGEN_REPCAP_AREA_A30                                          30
#define RSRFSIGGEN_REPCAP_AREA_A31                                          31
#define RSRFSIGGEN_REPCAP_AREA_A32                                          32
#define RSRFSIGGEN_REPCAP_AREA_A33                                          33
#define RSRFSIGGEN_REPCAP_AREA_A34                                          34
#define RSRFSIGGEN_REPCAP_AREA_A35                                          35
#define RSRFSIGGEN_REPCAP_AREA_A36                                          36
#define RSRFSIGGEN_REPCAP_AREA_A37                                          37
#define RSRFSIGGEN_REPCAP_AREA_A38                                          38
#define RSRFSIGGEN_REPCAP_AREA_A39                                          39
#define RSRFSIGGEN_REPCAP_AREA_A40                                          40
#define RSRFSIGGEN_REPCAP_AREA_A41                                          41
#define RSRFSIGGEN_REPCAP_AREA_A42                                          42
#define RSRFSIGGEN_REPCAP_AREA_A43                                          43
#define RSRFSIGGEN_REPCAP_AREA_A44                                          44
#define RSRFSIGGEN_REPCAP_AREA_A45                                          45
#define RSRFSIGGEN_REPCAP_AREA_A46                                          46
#define RSRFSIGGEN_REPCAP_AREA_A47                                          47
#define RSRFSIGGEN_REPCAP_AREA_A48                                          48
#define RSRFSIGGEN_REPCAP_AREA_A49                                          49
#define RSRFSIGGEN_REPCAP_AREA_A50                                          50

//repcap SatNavAlpha
#define RSRFSIGGEN_REPCAP_SATNAVALPHA_SNA0                                  0
#define RSRFSIGGEN_REPCAP_SATNAVALPHA_SNA1                                  1
#define RSRFSIGGEN_REPCAP_SATNAVALPHA_SNA2                                  2
#define RSRFSIGGEN_REPCAP_SATNAVALPHA_SNA3                                  3

//repcap NFCSeq
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC1                                       1
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC2                                       2
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC3                                       3
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC4                                       4
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC5                                       5
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC6                                       6
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC7                                       7
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC8                                       8
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC9                                       9
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC10                                      10
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC11                                      11
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC12                                      12
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC13                                      13
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC14                                      14
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC15                                      15
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC16                                      16
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC17                                      17
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC18                                      18
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC19                                      19
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC20                                      20
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC21                                      21
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC22                                      22
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC23                                      23
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC24                                      24
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC25                                      25
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC26                                      26
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC27                                      27
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC28                                      28
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC29                                      29
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC30                                      30
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC31                                      31
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC32                                      32
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC33                                      33
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC34                                      34
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC35                                      35
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC36                                      36
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC37                                      37
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC38                                      38
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC39                                      39
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC40                                      40
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC41                                      41
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC42                                      42
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC43                                      43
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC44                                      44
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC45                                      45
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC46                                      46
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC47                                      47
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC48                                      48
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC49                                      49
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC50                                      50
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC51                                      51
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC52                                      52
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC53                                      53
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC54                                      54
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC55                                      55
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC56                                      56
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC57                                      57
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC58                                      58
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC59                                      59
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC60                                      60
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC61                                      61
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC62                                      62
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC63                                      63
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC64                                      64
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC65                                      65
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC66                                      66
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC67                                      67
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC68                                      68
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC69                                      69
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC70                                      70
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC71                                      71
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC72                                      72
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC73                                      73
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC74                                      74
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC75                                      75
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC76                                      76
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC77                                      77
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC78                                      78
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC79                                      79
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC80                                      80
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC81                                      81
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC82                                      82
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC83                                      83
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC84                                      84
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC85                                      85
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC86                                      86
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC87                                      87
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC88                                      88
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC89                                      89
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC90                                      90
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC91                                      91
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC92                                      92
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC93                                      93
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC94                                      94
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC95                                      95
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC96                                      96
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC97                                      97
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC98                                      98
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC99                                      99
#define RSRFSIGGEN_REPCAP_NFCSEQ_NFC100                                     100

//repcap NFCService
#define RSRFSIGGEN_REPCAP_NFCSERVICE_NFCS1                                  1
#define RSRFSIGGEN_REPCAP_NFCSERVICE_NFCS2                                  2
#define RSRFSIGGEN_REPCAP_NFCSERVICE_NFCS3                                  3
#define RSRFSIGGEN_REPCAP_NFCSERVICE_NFCS4                                  4
#define RSRFSIGGEN_REPCAP_NFCSERVICE_NFCS5                                  5
#define RSRFSIGGEN_REPCAP_NFCSERVICE_NFCS6                                  6
#define RSRFSIGGEN_REPCAP_NFCSERVICE_NFCS7                                  7
#define RSRFSIGGEN_REPCAP_NFCSERVICE_NFCS8                                  8
#define RSRFSIGGEN_REPCAP_NFCSERVICE_NFCS9                                  9
#define RSRFSIGGEN_REPCAP_NFCSERVICE_NFCS10                                 10
#define RSRFSIGGEN_REPCAP_NFCSERVICE_NFCS11                                 11
#define RSRFSIGGEN_REPCAP_NFCSERVICE_NFCS12                                 12
#define RSRFSIGGEN_REPCAP_NFCSERVICE_NFCS13                                 13
#define RSRFSIGGEN_REPCAP_NFCSERVICE_NFCS14                                 14
#define RSRFSIGGEN_REPCAP_NFCSERVICE_NFCS15                                 15
#define RSRFSIGGEN_REPCAP_NFCSERVICE_NFCS16                                 16

//repcap NFCBlock
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB0                                    0
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB1                                    1
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB2                                    2
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB3                                    3
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB4                                    4
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB5                                    5
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB6                                    6
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB7                                    7
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB8                                    8
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB9                                    9
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB10                                   10
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB11                                   11
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB12                                   12
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB13                                   13
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB14                                   14
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB15                                   15
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB16                                   16
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB17                                   17
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB18                                   18
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB19                                   19
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB20                                   20
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB21                                   21
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB22                                   22
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB23                                   23
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB24                                   24
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB25                                   25
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB26                                   26
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB27                                   27
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB28                                   28
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB29                                   29
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB30                                   30
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB31                                   31
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB32                                   32
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB33                                   33
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB34                                   34
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB35                                   35
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB36                                   36
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB37                                   37
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB38                                   38
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB39                                   39
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB40                                   40
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB41                                   41
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB42                                   42
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB43                                   43
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB44                                   44
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB45                                   45
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB46                                   46
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB47                                   47
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB48                                   48
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB49                                   49
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB50                                   50
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB51                                   51
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB52                                   52
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB53                                   53
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB54                                   54
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB55                                   55
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB56                                   56
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB57                                   57
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB58                                   58
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB59                                   59
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB60                                   60
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB61                                   61
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB62                                   62
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB63                                   63
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB64                                   64
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB65                                   65
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB66                                   66
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB67                                   67
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB68                                   68
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB69                                   69
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB70                                   70
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB71                                   71
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB72                                   72
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB73                                   73
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB74                                   74
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB75                                   75
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB76                                   76
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB77                                   77
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB78                                   78
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB79                                   79
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB80                                   80
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB81                                   81
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB82                                   82
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB83                                   83
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB84                                   84
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB85                                   85
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB86                                   86
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB87                                   87
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB88                                   88
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB89                                   89
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB90                                   90
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB91                                   91
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB92                                   92
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB93                                   93
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB94                                   94
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB95                                   95
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB96                                   96
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB97                                   97
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB98                                   98
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB99                                   99
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB100                                  100
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB101                                  101
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB102                                  102
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB103                                  103
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB104                                  104
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB105                                  105
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB106                                  106
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB107                                  107
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB108                                  108
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB109                                  109
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB110                                  110
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB111                                  111
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB112                                  112
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB113                                  113
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB114                                  114
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB115                                  115
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB116                                  116
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB117                                  117
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB118                                  118
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB119                                  119
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB120                                  120
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB121                                  121
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB122                                  122
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB123                                  123
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB124                                  124
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB125                                  125
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB126                                  126
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB127                                  127
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB128                                  128
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB129                                  129
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB130                                  130
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB131                                  131
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB132                                  132
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB133                                  133
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB134                                  134
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB135                                  135
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB136                                  136
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB137                                  137
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB138                                  138
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB139                                  139
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB140                                  140
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB141                                  141
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB142                                  142
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB143                                  143
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB144                                  144
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB145                                  145
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB146                                  146
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB147                                  147
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB148                                  148
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB149                                  149
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB150                                  150
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB151                                  151
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB152                                  152
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB153                                  153
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB154                                  154
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB155                                  155
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB156                                  156
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB157                                  157
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB158                                  158
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB159                                  159
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB160                                  160
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB161                                  161
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB162                                  162
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB163                                  163
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB164                                  164
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB165                                  165
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB166                                  166
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB167                                  167
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB168                                  168
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB169                                  169
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB170                                  170
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB171                                  171
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB172                                  172
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB173                                  173
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB174                                  174
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB175                                  175
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB176                                  176
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB177                                  177
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB178                                  178
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB179                                  179
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB180                                  180
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB181                                  181
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB182                                  182
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB183                                  183
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB184                                  184
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB185                                  185
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB186                                  186
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB187                                  187
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB188                                  188
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB189                                  189
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB190                                  190
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB191                                  191
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB192                                  192
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB193                                  193
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB194                                  194
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB195                                  195
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB196                                  196
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB197                                  197
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB198                                  198
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB199                                  199
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB200                                  200
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB201                                  201
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB202                                  202
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB203                                  203
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB204                                  204
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB205                                  205
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB206                                  206
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB207                                  207
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB208                                  208
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB209                                  209
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB210                                  210
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB211                                  211
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB212                                  212
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB213                                  213
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB214                                  214
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB215                                  215
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB216                                  216
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB217                                  217
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB218                                  218
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB219                                  219
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB220                                  220
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB221                                  221
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB222                                  222
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB223                                  223
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB224                                  224
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB225                                  225
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB226                                  226
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB227                                  227
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB228                                  228
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB229                                  229
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB230                                  230
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB231                                  231
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB232                                  232
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB233                                  233
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB234                                  234
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB235                                  235
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB236                                  236
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB237                                  237
#define RSRFSIGGEN_REPCAP_NFCBLOCK_NFCB238                                  238

//repcap VDBChannel
#define RSRFSIGGEN_REPCAP_VDBCHANNEL_VDBC1                                  1
#define RSRFSIGGEN_REPCAP_VDBCHANNEL_VDBC2                                  2
#define RSRFSIGGEN_REPCAP_VDBCHANNEL_VDBC3                                  3
#define RSRFSIGGEN_REPCAP_VDBCHANNEL_VDBC4                                  4
#define RSRFSIGGEN_REPCAP_VDBCHANNEL_VDBC5                                  5
#define RSRFSIGGEN_REPCAP_VDBCHANNEL_VDBC6                                  6
#define RSRFSIGGEN_REPCAP_VDBCHANNEL_VDBC7                                  7
#define RSRFSIGGEN_REPCAP_VDBCHANNEL_VDBC8                                  8

//repcap TimeSlot
#define RSRFSIGGEN_REPCAP_TIMESLOT_TS1                                      1
#define RSRFSIGGEN_REPCAP_TIMESLOT_TS2                                      2
#define RSRFSIGGEN_REPCAP_TIMESLOT_TS3                                      3
#define RSRFSIGGEN_REPCAP_TIMESLOT_TS4                                      4
#define RSRFSIGGEN_REPCAP_TIMESLOT_TS5                                      5
#define RSRFSIGGEN_REPCAP_TIMESLOT_TS6                                      6
#define RSRFSIGGEN_REPCAP_TIMESLOT_TS7                                      7
#define RSRFSIGGEN_REPCAP_TIMESLOT_TS8                                      8

//repcap MPDU
#define RSRFSIGGEN_REPCAP_MPDU_MPDU1                                        1
#define RSRFSIGGEN_REPCAP_MPDU_MPDU2                                        2
#define RSRFSIGGEN_REPCAP_MPDU_MPDU3                                        3
#define RSRFSIGGEN_REPCAP_MPDU_MPDU4                                        4
#define RSRFSIGGEN_REPCAP_MPDU_MPDU5                                        5
#define RSRFSIGGEN_REPCAP_MPDU_MPDU6                                        6
#define RSRFSIGGEN_REPCAP_MPDU_MPDU7                                        7
#define RSRFSIGGEN_REPCAP_MPDU_MPDU8                                        8
#define RSRFSIGGEN_REPCAP_MPDU_MPDU9                                        9
#define RSRFSIGGEN_REPCAP_MPDU_MPDU10                                       10
#define RSRFSIGGEN_REPCAP_MPDU_MPDU11                                       11
#define RSRFSIGGEN_REPCAP_MPDU_MPDU12                                       12
#define RSRFSIGGEN_REPCAP_MPDU_MPDU13                                       13
#define RSRFSIGGEN_REPCAP_MPDU_MPDU14                                       14
#define RSRFSIGGEN_REPCAP_MPDU_MPDU15                                       15
#define RSRFSIGGEN_REPCAP_MPDU_MPDU16                                       16
#define RSRFSIGGEN_REPCAP_MPDU_MPDU17                                       17
#define RSRFSIGGEN_REPCAP_MPDU_MPDU18                                       18
#define RSRFSIGGEN_REPCAP_MPDU_MPDU19                                       19
#define RSRFSIGGEN_REPCAP_MPDU_MPDU20                                       20
#define RSRFSIGGEN_REPCAP_MPDU_MPDU21                                       21
#define RSRFSIGGEN_REPCAP_MPDU_MPDU22                                       22
#define RSRFSIGGEN_REPCAP_MPDU_MPDU23                                       23
#define RSRFSIGGEN_REPCAP_MPDU_MPDU24                                       24
#define RSRFSIGGEN_REPCAP_MPDU_MPDU25                                       25
#define RSRFSIGGEN_REPCAP_MPDU_MPDU26                                       26
#define RSRFSIGGEN_REPCAP_MPDU_MPDU27                                       27
#define RSRFSIGGEN_REPCAP_MPDU_MPDU28                                       28
#define RSRFSIGGEN_REPCAP_MPDU_MPDU29                                       29
#define RSRFSIGGEN_REPCAP_MPDU_MPDU30                                       30
#define RSRFSIGGEN_REPCAP_MPDU_MPDU31                                       31
#define RSRFSIGGEN_REPCAP_MPDU_MPDU32                                       32
#define RSRFSIGGEN_REPCAP_MPDU_MPDU33                                       33
#define RSRFSIGGEN_REPCAP_MPDU_MPDU34                                       34
#define RSRFSIGGEN_REPCAP_MPDU_MPDU35                                       35
#define RSRFSIGGEN_REPCAP_MPDU_MPDU36                                       36
#define RSRFSIGGEN_REPCAP_MPDU_MPDU37                                       37
#define RSRFSIGGEN_REPCAP_MPDU_MPDU38                                       38
#define RSRFSIGGEN_REPCAP_MPDU_MPDU39                                       39
#define RSRFSIGGEN_REPCAP_MPDU_MPDU40                                       40
#define RSRFSIGGEN_REPCAP_MPDU_MPDU41                                       41
#define RSRFSIGGEN_REPCAP_MPDU_MPDU42                                       42
#define RSRFSIGGEN_REPCAP_MPDU_MPDU43                                       43
#define RSRFSIGGEN_REPCAP_MPDU_MPDU44                                       44
#define RSRFSIGGEN_REPCAP_MPDU_MPDU45                                       45
#define RSRFSIGGEN_REPCAP_MPDU_MPDU46                                       46
#define RSRFSIGGEN_REPCAP_MPDU_MPDU47                                       47
#define RSRFSIGGEN_REPCAP_MPDU_MPDU48                                       48
#define RSRFSIGGEN_REPCAP_MPDU_MPDU49                                       49
#define RSRFSIGGEN_REPCAP_MPDU_MPDU50                                       50
#define RSRFSIGGEN_REPCAP_MPDU_MPDU51                                       51
#define RSRFSIGGEN_REPCAP_MPDU_MPDU52                                       52
#define RSRFSIGGEN_REPCAP_MPDU_MPDU53                                       53
#define RSRFSIGGEN_REPCAP_MPDU_MPDU54                                       54
#define RSRFSIGGEN_REPCAP_MPDU_MPDU55                                       55
#define RSRFSIGGEN_REPCAP_MPDU_MPDU56                                       56
#define RSRFSIGGEN_REPCAP_MPDU_MPDU57                                       57
#define RSRFSIGGEN_REPCAP_MPDU_MPDU58                                       58
#define RSRFSIGGEN_REPCAP_MPDU_MPDU59                                       59
#define RSRFSIGGEN_REPCAP_MPDU_MPDU60                                       60
#define RSRFSIGGEN_REPCAP_MPDU_MPDU61                                       61
#define RSRFSIGGEN_REPCAP_MPDU_MPDU62                                       62
#define RSRFSIGGEN_REPCAP_MPDU_MPDU63                                       63
#define RSRFSIGGEN_REPCAP_MPDU_MPDU64                                       64

//repcap GPPRowNumber
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW0                              0
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW1                              1
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW2                              2
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW3                              3
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW4                              4
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW5                              5
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW6                              6
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW7                              7
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW8                              8
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW9                              9
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW10                             10
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW11                             11
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW12                             12
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW13                             13
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW14                             14
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW15                             15
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW16                             16
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW17                             17
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW18                             18
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW19                             19
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW20                             20
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW21                             21
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW22                             22
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW23                             23
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW24                             24
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW25                             25
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW26                             26
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW27                             27
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW28                             28
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW29                             29
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW30                             30
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW31                             31
#define RSRFSIGGEN_REPCAP_GPPROWNUMBER_GPPROW32                             32

//repcap GPPHARQACK
#define RSRFSIGGEN_REPCAP_GPPHARQACK_ACK1                                   1
#define RSRFSIGGEN_REPCAP_GPPHARQACK_ACK2                                   2
#define RSRFSIGGEN_REPCAP_GPPHARQACK_ACK3                                   3
#define RSRFSIGGEN_REPCAP_GPPHARQACK_ACK4                                   4

//repcap GPPPCQINumber
#define RSRFSIGGEN_REPCAP_GPPPCQINUMBER_PCQI1                               1
#define RSRFSIGGEN_REPCAP_GPPPCQINUMBER_PCQI2                               2
#define RSRFSIGGEN_REPCAP_GPPPCQINUMBER_PCQI3                               3
#define RSRFSIGGEN_REPCAP_GPPPCQINUMBER_PCQI4                               4

//repcap GPPCQI
#define RSRFSIGGEN_REPCAP_GPPCQI_CQI1                                       1
#define RSRFSIGGEN_REPCAP_GPPCQI_CQI2                                       2

//repcap EUTRAAntPort
#define RSRFSIGGEN_REPCAP_EUTRAANTPORT_ANTPORT1                             1
#define RSRFSIGGEN_REPCAP_EUTRAANTPORT_ANTPORT2                             2

//repcap EutraPhysAnt
#define RSRFSIGGEN_REPCAP_EUTRAPHYSANT_PA1                                  1
#define RSRFSIGGEN_REPCAP_EUTRAPHYSANT_PA2                                  2
#define RSRFSIGGEN_REPCAP_EUTRAPHYSANT_PA3                                  3
#define RSRFSIGGEN_REPCAP_EUTRAPHYSANT_PA4                                  4
#define RSRFSIGGEN_REPCAP_EUTRAPHYSANT_PA5                                  5
#define RSRFSIGGEN_REPCAP_EUTRAPHYSANT_PA6                                  6
#define RSRFSIGGEN_REPCAP_EUTRAPHYSANT_PA7                                  7

//repcap Stream
#define RSRFSIGGEN_REPCAP_STREAM_STREAM1                                    1
#define RSRFSIGGEN_REPCAP_STREAM_STREAM2                                    2
#define RSRFSIGGEN_REPCAP_STREAM_STREAM3                                    3
#define RSRFSIGGEN_REPCAP_STREAM_STREAM4                                    4
#define RSRFSIGGEN_REPCAP_STREAM_STREAM5                                    5
#define RSRFSIGGEN_REPCAP_STREAM_STREAM6                                    6
#define RSRFSIGGEN_REPCAP_STREAM_STREAM7                                    7
#define RSRFSIGGEN_REPCAP_STREAM_STREAM8                                    8

//repcap Row
#define RSRFSIGGEN_REPCAP_ROW_ROW0                                          0
#define RSRFSIGGEN_REPCAP_ROW_ROW1                                          1
#define RSRFSIGGEN_REPCAP_ROW_ROW2                                          2
#define RSRFSIGGEN_REPCAP_ROW_ROW3                                          3
#define RSRFSIGGEN_REPCAP_ROW_ROW4                                          4
#define RSRFSIGGEN_REPCAP_ROW_ROW5                                          5
#define RSRFSIGGEN_REPCAP_ROW_ROW6                                          6
#define RSRFSIGGEN_REPCAP_ROW_ROW7                                          7
#define RSRFSIGGEN_REPCAP_ROW_ROW8                                          8
#define RSRFSIGGEN_REPCAP_ROW_ROW9                                          9
#define RSRFSIGGEN_REPCAP_ROW_ROW10                                         10
#define RSRFSIGGEN_REPCAP_ROW_ROW11                                         11
#define RSRFSIGGEN_REPCAP_ROW_ROW12                                         12
#define RSRFSIGGEN_REPCAP_ROW_ROW13                                         13
#define RSRFSIGGEN_REPCAP_ROW_ROW14                                         14
#define RSRFSIGGEN_REPCAP_ROW_ROW15                                         15
#define RSRFSIGGEN_REPCAP_ROW_ROW16                                         16
#define RSRFSIGGEN_REPCAP_ROW_ROW17                                         17
#define RSRFSIGGEN_REPCAP_ROW_ROW18                                         18
#define RSRFSIGGEN_REPCAP_ROW_ROW19                                         19
#define RSRFSIGGEN_REPCAP_ROW_ROW20                                         20
#define RSRFSIGGEN_REPCAP_ROW_ROW21                                         21
#define RSRFSIGGEN_REPCAP_ROW_ROW22                                         22

//repcap Baseband
#define RSRFSIGGEN_REPCAP_BASEBAND_BB1                                      1
#define RSRFSIGGEN_REPCAP_BASEBAND_BB2                                      2
#define RSRFSIGGEN_REPCAP_BASEBAND_BB3                                      3
#define RSRFSIGGEN_REPCAP_BASEBAND_BB4                                      4
#define RSRFSIGGEN_REPCAP_BASEBAND_BB5                                      5
#define RSRFSIGGEN_REPCAP_BASEBAND_BB6                                      6
#define RSRFSIGGEN_REPCAP_BASEBAND_BB7                                      7
#define RSRFSIGGEN_REPCAP_BASEBAND_BB8                                      8

//repcap EUTRALayer
#define RSRFSIGGEN_REPCAP_EUTRALAYER_LA0                                    0
#define RSRFSIGGEN_REPCAP_EUTRALAYER_LA1                                    1
#define RSRFSIGGEN_REPCAP_EUTRALAYER_LA2                                    2
#define RSRFSIGGEN_REPCAP_EUTRALAYER_LA3                                    3

//repcap FSIMCluster
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL1                                   1
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL2                                   2
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL3                                   3
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL4                                   4
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL5                                   5
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL6                                   6
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL7                                   7
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL8                                   8
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL9                                   9
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL10                                  10
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL11                                  11
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL12                                  12
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL13                                  13
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL14                                  14
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL15                                  15
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL16                                  16
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL17                                  17
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL18                                  18
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL19                                  19
#define RSRFSIGGEN_REPCAP_FSIMCLUSTER_CL20                                  20

//repcap FSIMSubCluster
#define RSRFSIGGEN_REPCAP_FSIMSUBCLUSTER_SCL1                               1
#define RSRFSIGGEN_REPCAP_FSIMSUBCLUSTER_SCL2                               2
#define RSRFSIGGEN_REPCAP_FSIMSUBCLUSTER_SCL3                               3

//repcap FSIMArraySize
#define RSRFSIGGEN_REPCAP_FSIMARRAYSIZE_SIZE1                               1
#define RSRFSIGGEN_REPCAP_FSIMARRAYSIZE_SIZE2                               2
#define RSRFSIGGEN_REPCAP_FSIMARRAYSIZE_SIZE3                               3
#define RSRFSIGGEN_REPCAP_FSIMARRAYSIZE_SIZE4                               4
#define RSRFSIGGEN_REPCAP_FSIMARRAYSIZE_SIZE5                               5
#define RSRFSIGGEN_REPCAP_FSIMARRAYSIZE_SIZE6                               6
#define RSRFSIGGEN_REPCAP_FSIMARRAYSIZE_SIZE7                               7
#define RSRFSIGGEN_REPCAP_FSIMARRAYSIZE_SIZE8                               8

//repcap PRN
#define RSRFSIGGEN_REPCAP_PRN_PRN1                                          1

//repcap EUTRATransmission
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION1              1
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION2              2
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION3              3
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION4              4
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION5              5
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION6              6
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION7              7
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION8              8
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION9              9
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION10             10
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION11             11
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION12             12
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION13             13
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION14             14
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION15             15
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION16             16
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION17             17
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION18             18
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION19             19
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION20             20
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION21             21
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION22             22
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION23             23
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION24             24
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION25             25
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION26             26
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION27             27
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION28             28
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION29             29
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION30             30
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION31             31
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION32             32
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION33             33
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION34             34
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION35             35
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION36             36
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION37             37
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION38             38
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION39             39
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION40             40
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION41             41
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION42             42
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION43             43
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION44             44
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION45             45
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION46             46
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION47             47
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION48             48
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION49             49
#define RSRFSIGGEN_REPCAP_EUTRATRANSMISSION_EUTRATRANSMISSION50             50

//repcap EUTRASRSSet
#define RSRFSIGGEN_REPCAP_EUTRASRSSET_EUTRASRS1                             1
#define RSRFSIGGEN_REPCAP_EUTRASRSSET_EUTRASRS2                             2
#define RSRFSIGGEN_REPCAP_EUTRASRSSET_EUTRASRS3                             3
#define RSRFSIGGEN_REPCAP_EUTRASRSSET_EUTRASRS4                             4
#define RSRFSIGGEN_REPCAP_EUTRASRSSET_EUTRASRS5                             5
#define RSRFSIGGEN_REPCAP_EUTRASRSSET_EUTRASRS6                             6

//repcap EUTRAIndex
#define RSRFSIGGEN_REPCAP_EUTRAINDEX_EUTRAINDEX1                            1
#define RSRFSIGGEN_REPCAP_EUTRAINDEX_EUTRAINDEX2                            2

//repcap EUTRAAntenna
#define RSRFSIGGEN_REPCAP_EUTRAANTENNA_EUTRAANTENNA0                        0
#define RSRFSIGGEN_REPCAP_EUTRAANTENNA_EUTRAANTENNA1                        1

//repcap Allocation
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC0                                 0
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC1                                 1
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC2                                 2
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC3                                 3
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC4                                 4
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC5                                 5
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC6                                 6
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC7                                 7
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC8                                 8
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC9                                 9
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC10                                10
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC11                                11
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC12                                12
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC13                                13
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC14                                14
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC15                                15
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC16                                16
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC17                                17
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC18                                18
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC19                                19
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC20                                20
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC21                                21
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC22                                22
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC23                                23
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC24                                24
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC25                                25
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC26                                26
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC27                                27
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC28                                28
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC29                                29
#define RSRFSIGGEN_REPCAP_ALLOCATION_ALLOC30                                30

//repcap Layer
#define RSRFSIGGEN_REPCAP_LAYER_L0                                          0
#define RSRFSIGGEN_REPCAP_LAYER_L1                                          1
#define RSRFSIGGEN_REPCAP_LAYER_L2                                          2
#define RSRFSIGGEN_REPCAP_LAYER_L3                                          3
#define RSRFSIGGEN_REPCAP_LAYER_L4                                          4
#define RSRFSIGGEN_REPCAP_LAYER_L5                                          5

//repcap UserChannel
#define RSRFSIGGEN_REPCAP_USERCHANNEL_UCH0                                  0
#define RSRFSIGGEN_REPCAP_USERCHANNEL_UCH1                                  1
#define RSRFSIGGEN_REPCAP_USERCHANNEL_UCH2                                  2
#define RSRFSIGGEN_REPCAP_USERCHANNEL_UCH3                                  3
#define RSRFSIGGEN_REPCAP_USERCHANNEL_UCH4                                  4
#define RSRFSIGGEN_REPCAP_USERCHANNEL_UCH5                                  5

//repcap FSIMSCMRay
#define RSRFSIGGEN_REPCAP_FSIMSCMRAY_FSCMR1                                 1
#define RSRFSIGGEN_REPCAP_FSIMSCMRAY_FSCMR2                                 2
#define RSRFSIGGEN_REPCAP_FSIMSCMRAY_FSCMR3                                 3
#define RSRFSIGGEN_REPCAP_FSIMSCMRAY_FSCMR4                                 4
#define RSRFSIGGEN_REPCAP_FSIMSCMRAY_FSCMR5                                 5
#define RSRFSIGGEN_REPCAP_FSIMSCMRAY_FSCMR6                                 6

//repcap BTChannelIndex
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX0                         0
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX1                         1
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX2                         2
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX3                         3
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX4                         4
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX5                         5
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX6                         6
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX7                         7
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX8                         8
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX9                         9
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX10                        10
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX11                        11
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX12                        12
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX13                        13
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX14                        14
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX15                        15
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX16                        16
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX17                        17
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX18                        18
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX19                        19
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX20                        20
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX21                        21
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX22                        22
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX23                        23
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX24                        24
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX25                        25
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX26                        26
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX27                        27
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX28                        28
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX29                        29
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX30                        30
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX31                        31
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX32                        32
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX33                        33
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX34                        34
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX35                        35
#define RSRFSIGGEN_REPCAP_BTCHANNELINDEX_BRCHINDEX36                        36

//repcap TMC
#define RSRFSIGGEN_REPCAP_TMC_TMC1                                          1
#define RSRFSIGGEN_REPCAP_TMC_TMC2                                          2
#define RSRFSIGGEN_REPCAP_TMC_TMC3                                          3

//repcap Address
#define RSRFSIGGEN_REPCAP_ADDRESS_ADDRESS1                                  1
#define RSRFSIGGEN_REPCAP_ADDRESS_ADDRESS2                                  2
#define RSRFSIGGEN_REPCAP_ADDRESS_ADDRESS3                                  3
#define RSRFSIGGEN_REPCAP_ADDRESS_ADDRESS4                                  4

//repcap TAP
#define RSRFSIGGEN_REPCAP_TAP_TAP1                                          1
#define RSRFSIGGEN_REPCAP_TAP_TAP2                                          2
#define RSRFSIGGEN_REPCAP_TAP_TAP3                                          3
#define RSRFSIGGEN_REPCAP_TAP_TAP4                                          4
#define RSRFSIGGEN_REPCAP_TAP_TAP5                                          5
#define RSRFSIGGEN_REPCAP_TAP_TAP6                                          6
#define RSRFSIGGEN_REPCAP_TAP_TAP7                                          7
#define RSRFSIGGEN_REPCAP_TAP_TAP8                                          8
#define RSRFSIGGEN_REPCAP_TAP_TAP9                                          9
#define RSRFSIGGEN_REPCAP_TAP_TAP10                                         10

//repcap FSIMAnt
#define RSRFSIGGEN_REPCAP_FSIMANT_FANT1                                     1
#define RSRFSIGGEN_REPCAP_FSIMANT_FANT2                                     2
#define RSRFSIGGEN_REPCAP_FSIMANT_FANT3                                     3
#define RSRFSIGGEN_REPCAP_FSIMANT_FANT4                                     4
#define RSRFSIGGEN_REPCAP_FSIMANT_FANT5                                     5
#define RSRFSIGGEN_REPCAP_FSIMANT_FANT6                                     6
#define RSRFSIGGEN_REPCAP_FSIMANT_FANT7                                     7
#define RSRFSIGGEN_REPCAP_FSIMANT_FANT8                                     8

//repcap FSIMSubpath
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP1                                  1
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP2                                  2
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP3                                  3
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP4                                  4
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP5                                  5
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP6                                  6
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP7                                  7
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP8                                  8
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP9                                  9
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP10                                 10
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP11                                 11
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP12                                 12
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP13                                 13
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP14                                 14
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP15                                 15
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP16                                 16
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP17                                 17
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP18                                 18
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP19                                 19
#define RSRFSIGGEN_REPCAP_FSIMSUBPATH_FSP20                                 20

//repcap EUTRAEPDCCH
#define RSRFSIGGEN_REPCAP_EUTRAEPDCCH_EE1                                   1
#define RSRFSIGGEN_REPCAP_EUTRAEPDCCH_EE2                                   2

//repcap Object
#define RSRFSIGGEN_REPCAP_OBJECT_OBJ1                                       1
#define RSRFSIGGEN_REPCAP_OBJECT_OBJ2                                       2
#define RSRFSIGGEN_REPCAP_OBJECT_OBJ3                                       3
#define RSRFSIGGEN_REPCAP_OBJECT_OBJ4                                       4
#define RSRFSIGGEN_REPCAP_OBJECT_OBJ5                                       5
#define RSRFSIGGEN_REPCAP_OBJECT_OBJ6                                       6
#define RSRFSIGGEN_REPCAP_OBJECT_OBJ7                                       7
#define RSRFSIGGEN_REPCAP_OBJECT_OBJ8                                       8
#define RSRFSIGGEN_REPCAP_OBJECT_OBJ9                                       9
#define RSRFSIGGEN_REPCAP_OBJECT_OBJ10                                      10
#define RSRFSIGGEN_REPCAP_OBJECT_OBJ11                                      11
#define RSRFSIGGEN_REPCAP_OBJECT_OBJ12                                      12

//repcap Cell
#define RSRFSIGGEN_REPCAP_CELL_CELL1                                        1
#define RSRFSIGGEN_REPCAP_CELL_CELL2                                        2
#define RSRFSIGGEN_REPCAP_CELL_CELL3                                        3
#define RSRFSIGGEN_REPCAP_CELL_CELL4                                        4

//repcap LAABurst
#define RSRFSIGGEN_REPCAP_LAABURST_LAABURST0                                0
#define RSRFSIGGEN_REPCAP_LAABURST_LAABURST1                                1
#define RSRFSIGGEN_REPCAP_LAABURST_LAABURST2                                2
#define RSRFSIGGEN_REPCAP_LAABURST_LAABURST3                                3
#define RSRFSIGGEN_REPCAP_LAABURST_LAABURST4                                4
#define RSRFSIGGEN_REPCAP_LAABURST_LAABURST5                                5
#define RSRFSIGGEN_REPCAP_LAABURST_LAABURST6                                6
#define RSRFSIGGEN_REPCAP_LAABURST_LAABURST7                                7
#define RSRFSIGGEN_REPCAP_LAABURST_LAABURST8                                8
#define RSRFSIGGEN_REPCAP_LAABURST_LAABURST9                                9
#define RSRFSIGGEN_REPCAP_LAABURST_LAABURST10                               10

//repcap CSIRS
#define RSRFSIGGEN_REPCAP_CSIRS_ZP1                                         1
#define RSRFSIGGEN_REPCAP_CSIRS_ZP2                                         2
#define RSRFSIGGEN_REPCAP_CSIRS_ZP3                                         3
#define RSRFSIGGEN_REPCAP_CSIRS_ZP4                                         4
#define RSRFSIGGEN_REPCAP_CSIRS_ZP5                                         5

//repcap NonCSIRS
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP1                                     1
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP2                                     2
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP3                                     3
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP4                                     4
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP5                                     5
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP6                                     6
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP7                                     7
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP8                                     8
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP9                                     9
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP10                                    10
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP11                                    11
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP12                                    12
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP13                                    13
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP14                                    14
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP15                                    15
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP16                                    16
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP17                                    17
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP18                                    18
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP19                                    19
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP20                                    20
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP21                                    21
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP22                                    22
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP23                                    23
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP24                                    24
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP25                                    25
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP26                                    26
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP27                                    27
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP28                                    28
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP29                                    29
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP30                                    30
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP31                                    31
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP32                                    32
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP33                                    33
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP34                                    34
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP35                                    35
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP36                                    36
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP37                                    37
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP38                                    38
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP39                                    39
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP40                                    40
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP41                                    41
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP42                                    42
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP43                                    43
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP44                                    44
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP45                                    45
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP46                                    46
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP47                                    47
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP48                                    48
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP49                                    49
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP50                                    50
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP51                                    51
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP52                                    52
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP53                                    53
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP54                                    54
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP55                                    55
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP56                                    56
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP57                                    57
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP58                                    58
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP59                                    59
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP60                                    60
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP61                                    61
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP62                                    62
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP63                                    63
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP64                                    64
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP65                                    65
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP66                                    66
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP67                                    67
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP68                                    68
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP69                                    69
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP70                                    70
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP71                                    71
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP72                                    72
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP73                                    73
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP74                                    74
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP75                                    75
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP76                                    76
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP77                                    77
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP78                                    78
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP79                                    79
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP80                                    80
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP81                                    81
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP82                                    82
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP83                                    83
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP84                                    84
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP85                                    85
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP86                                    86
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP87                                    87
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP88                                    88
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP89                                    89
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP90                                    90
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP91                                    91
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP92                                    92
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP93                                    93
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP94                                    94
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP95                                    95
#define RSRFSIGGEN_REPCAP_NONCSIRS_NZP96                                    96

//repcap SList
#define RSRFSIGGEN_REPCAP_SLIST_SL1                                         1
#define RSRFSIGGEN_REPCAP_SLIST_SL2                                         2
#define RSRFSIGGEN_REPCAP_SLIST_SL3                                         3
#define RSRFSIGGEN_REPCAP_SLIST_SL4                                         4
#define RSRFSIGGEN_REPCAP_SLIST_SL5                                         5
#define RSRFSIGGEN_REPCAP_SLIST_SL6                                         6
#define RSRFSIGGEN_REPCAP_SLIST_SL7                                         7
#define RSRFSIGGEN_REPCAP_SLIST_SL8                                         8
#define RSRFSIGGEN_REPCAP_SLIST_SL9                                         9
#define RSRFSIGGEN_REPCAP_SLIST_SL10                                        10

//repcap FList
#define RSRFSIGGEN_REPCAP_FLIST_FL1                                         1
#define RSRFSIGGEN_REPCAP_FLIST_FL2                                         2
#define RSRFSIGGEN_REPCAP_FLIST_FL3                                         3
#define RSRFSIGGEN_REPCAP_FLIST_FL4                                         4
#define RSRFSIGGEN_REPCAP_FLIST_FL5                                         5

//repcap ExtSeqAtt
#define RSRFSIGGEN_REPCAP_EXTSEQATT_ESATT1                                  1
#define RSRFSIGGEN_REPCAP_EXTSEQATT_ESATT2                                  2

//repcap WLANNStation
#define RSRFSIGGEN_REPCAP_WLANNSTATION_WLANNSTATION1                        1
#define RSRFSIGGEN_REPCAP_WLANNSTATION_WLANNSTATION2                        2

//repcap WLANNUser
#define RSRFSIGGEN_REPCAP_WLANNUSER_U1                                      1
#define RSRFSIGGEN_REPCAP_WLANNUSER_U2                                      2
#define RSRFSIGGEN_REPCAP_WLANNUSER_U3                                      3
#define RSRFSIGGEN_REPCAP_WLANNUSER_U4                                      4
#define RSRFSIGGEN_REPCAP_WLANNUSER_U5                                      5
#define RSRFSIGGEN_REPCAP_WLANNUSER_U6                                      6
#define RSRFSIGGEN_REPCAP_WLANNUSER_U7                                      7
#define RSRFSIGGEN_REPCAP_WLANNUSER_U8                                      8
#define RSRFSIGGEN_REPCAP_WLANNUSER_U9                                      9

//repcap EUTRACarrier
#define RSRFSIGGEN_REPCAP_EUTRACARRIER_EUTRACARR1                           1
#define RSRFSIGGEN_REPCAP_EUTRACARRIER_EUTRACARR2                           2
#define RSRFSIGGEN_REPCAP_EUTRACARRIER_EUTRACARR3                           3
#define RSRFSIGGEN_REPCAP_EUTRACARRIER_EUTRACARR4                           4

//repcap EUTRAZPCSIRS
#define RSRFSIGGEN_REPCAP_EUTRAZPCSIRS_EUTRAZP0                             0
#define RSRFSIGGEN_REPCAP_EUTRAZPCSIRS_EUTRAZP1                             1

//repcap EUTRAConf
#define RSRFSIGGEN_REPCAP_EUTRACONF_EUTRACONF1                              1
#define RSRFSIGGEN_REPCAP_EUTRACONF_EUTRACONF2                              2
#define RSRFSIGGEN_REPCAP_EUTRACONF_EUTRACONF3                              3

//repcap NPRACHConf
#define RSRFSIGGEN_REPCAP_NPRACHCONF_NPRACHCONF0                            0
#define RSRFSIGGEN_REPCAP_NPRACHCONF_NPRACHCONF1                            1
#define RSRFSIGGEN_REPCAP_NPRACHCONF_NPRACHCONF2                            2

//repcap EMTCTransmission
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC1                            1
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC2                            2
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC3                            3
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC4                            4
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC5                            5
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC6                            6
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC7                            7
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC8                            8
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC9                            9
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC10                           10
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC11                           11
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC12                           12
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC13                           13
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC14                           14
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC15                           15
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC16                           16
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC17                           17
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC18                           18
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC19                           19
#define RSRFSIGGEN_REPCAP_EMTCTRANSMISSION_EMTC20                           20

//repcap PRACHAttempt
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT1                             1
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT2                             2
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT3                             3
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT4                             4
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT5                             5
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT6                             6
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT7                             7
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT8                             8
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT9                             9
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT10                            10
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT11                            11
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT12                            12
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT13                            13
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT14                            14
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT15                            15
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT16                            16
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT17                            17
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT18                            18
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT19                            19
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT20                            20
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT21                            21
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT22                            22
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT23                            23
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT24                            24
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT25                            25
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT26                            26
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT27                            27
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT28                            28
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT29                            29
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT30                            30
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT31                            31
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT32                            32
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT33                            33
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT34                            34
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT35                            35
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT36                            36
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT37                            37
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT38                            38
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT39                            39
#define RSRFSIGGEN_REPCAP_PRACHATTEMPT_ATTEMPT40                            40

//repcap EutraCELevel
#define RSRFSIGGEN_REPCAP_EUTRACELEVEL_ECELEVEL0                            0
#define RSRFSIGGEN_REPCAP_EUTRACELEVEL_ECELEVEL1                            1
#define RSRFSIGGEN_REPCAP_EUTRACELEVEL_ECELEVEL2                            2
#define RSRFSIGGEN_REPCAP_EUTRACELEVEL_ECELEVEL3                            3

//repcap OneWebBB
#define RSRFSIGGEN_REPCAP_ONEWEBBB_OWBB0                                    0
#define RSRFSIGGEN_REPCAP_ONEWEBBB_OWBB1                                    1
#define RSRFSIGGEN_REPCAP_ONEWEBBB_OWBB2                                    2
#define RSRFSIGGEN_REPCAP_ONEWEBBB_OWBB3                                    3
#define RSRFSIGGEN_REPCAP_ONEWEBBB_OWBB4                                    4
#define RSRFSIGGEN_REPCAP_ONEWEBBB_OWBB5                                    5
#define RSRFSIGGEN_REPCAP_ONEWEBBB_OWBB6                                    6
#define RSRFSIGGEN_REPCAP_ONEWEBBB_OWBB7                                    7

//repcap OneWebAP
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP0                                    0
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP1                                    1
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP2                                    2
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP3                                    3
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP4                                    4
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP5                                    5
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP6                                    6
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP7                                    7
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP8                                    8
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP9                                    9
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP10                                   10
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP11                                   11
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP12                                   12
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP13                                   13
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP14                                   14
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP15                                   15
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP16                                   16
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP17                                   17
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP18                                   18
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP19                                   19
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP20                                   20
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP21                                   21
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP22                                   22
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP23                                   23
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP24                                   24
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP25                                   25
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP26                                   26
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP27                                   27
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP28                                   28
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP29                                   29
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP30                                   30
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP31                                   31
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP32                                   32
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP33                                   33
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP34                                   34
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP35                                   35
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP36                                   36
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP37                                   37
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP38                                   38
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP39                                   39
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP40                                   40
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP41                                   41
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP42                                   42
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP43                                   43
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP44                                   44
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP45                                   45
#define RSRFSIGGEN_REPCAP_ONEWEBAP_OWAP46                                   46

//repcap BBINChannel
#define RSRFSIGGEN_REPCAP_BBINCHANNEL_BCH0                                  0
#define RSRFSIGGEN_REPCAP_BBINCHANNEL_BCH1                                  1
#define RSRFSIGGEN_REPCAP_BBINCHANNEL_BCH2                                  2
#define RSRFSIGGEN_REPCAP_BBINCHANNEL_BCH3                                  3
#define RSRFSIGGEN_REPCAP_BBINCHANNEL_BCH4                                  4
#define RSRFSIGGEN_REPCAP_BBINCHANNEL_BCH5                                  5
#define RSRFSIGGEN_REPCAP_BBINCHANNEL_BCH6                                  6
#define RSRFSIGGEN_REPCAP_BBINCHANNEL_BCH7                                  7

//repcap OneWebCell
#define RSRFSIGGEN_REPCAP_ONEWEBCELL_OWC0                                   0
#define RSRFSIGGEN_REPCAP_ONEWEBCELL_OWC1                                   1
#define RSRFSIGGEN_REPCAP_ONEWEBCELL_OWC2                                   2
#define RSRFSIGGEN_REPCAP_ONEWEBCELL_OWC3                                   3
#define RSRFSIGGEN_REPCAP_ONEWEBCELL_OWC4                                   4

//repcap OneWebItem
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI0                                   0
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI1                                   1
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI2                                   2
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI3                                   3
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI4                                   4
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI5                                   5
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI6                                   6
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI7                                   7
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI8                                   8
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI9                                   9
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI10                                  10
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI11                                  11
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI12                                  12
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI13                                  13
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI14                                  14
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI15                                  15
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI16                                  16
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI17                                  17
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI18                                  18
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI19                                  19
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI20                                  20
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI21                                  21
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI22                                  22
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI23                                  23
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI24                                  24
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI25                                  25
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI26                                  26
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI27                                  27
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI28                                  28
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI29                                  29
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI30                                  30
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI31                                  31
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI32                                  32
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI33                                  33
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI34                                  34
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI35                                  35
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI36                                  36
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI37                                  37
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI38                                  38
#define RSRFSIGGEN_REPCAP_ONEWEBITEM_OWI39                                  39

//repcap OneWebSRSSet
#define RSRFSIGGEN_REPCAP_ONEWEBSRSSET_OWSRS1                               1
#define RSRFSIGGEN_REPCAP_ONEWEBSRSSET_OWSRS2                               2
#define RSRFSIGGEN_REPCAP_ONEWEBSRSSET_OWSRS3                               3
#define RSRFSIGGEN_REPCAP_ONEWEBSRSSET_OWSRS4                               4
#define RSRFSIGGEN_REPCAP_ONEWEBSRSSET_OWSRS5                               5
#define RSRFSIGGEN_REPCAP_ONEWEBSRSSET_OWSRS6                               6

//repcap OneWebTransmission
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS1                       1
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS2                       2
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS3                       3
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS4                       4
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS5                       5
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS6                       6
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS7                       7
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS8                       8
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS9                       9
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS10                      10
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS11                      11
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS12                      12
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS13                      13
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS14                      14
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS15                      15
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS16                      16
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS17                      17
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS18                      18
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS19                      19
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS20                      20
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS21                      21
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS22                      22
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS23                      23
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS24                      24
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS25                      25
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS26                      26
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS27                      27
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS28                      28
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS29                      29
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS30                      30
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS31                      31
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS32                      32
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS33                      33
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS34                      34
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS35                      35
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS36                      36
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS37                      37
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS38                      38
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS39                      39
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS40                      40
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS41                      41
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS42                      42
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS43                      43
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS44                      44
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS45                      45
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS46                      46
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS47                      47
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS48                      48
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS49                      49
#define RSRFSIGGEN_REPCAP_ONEWEBTRANSMISSION_OWTRANS50                      50

//repcap OneWebUser
#define RSRFSIGGEN_REPCAP_ONEWEBUSER_OWUSER1                                1
#define RSRFSIGGEN_REPCAP_ONEWEBUSER_OWUSER2                                2

//repcap OneWebAntennaPort
#define RSRFSIGGEN_REPCAP_ONEWEBANTENNAPORT_OWANTPORT0                      0
#define RSRFSIGGEN_REPCAP_ONEWEBANTENNAPORT_OWANTPORT1                      1

//repcap V5GBB
#define RSRFSIGGEN_REPCAP_V5GBB_V5GBB0                                      0
#define RSRFSIGGEN_REPCAP_V5GBB_V5GBB1                                      1
#define RSRFSIGGEN_REPCAP_V5GBB_V5GBB2                                      2
#define RSRFSIGGEN_REPCAP_V5GBB_V5GBB3                                      3
#define RSRFSIGGEN_REPCAP_V5GBB_V5GBB4                                      4
#define RSRFSIGGEN_REPCAP_V5GBB_V5GBB5                                      5
#define RSRFSIGGEN_REPCAP_V5GBB_V5GBB6                                      6
#define RSRFSIGGEN_REPCAP_V5GBB_V5GBB7                                      7

//repcap V5GLayer
#define RSRFSIGGEN_REPCAP_V5GLAYER_V5GLAYER0                                0
#define RSRFSIGGEN_REPCAP_V5GLAYER_V5GLAYER1                                1

//repcap V5GAllocations
#define RSRFSIGGEN_REPCAP_V5GALLOCATIONS_V5GAL0                             0
#define RSRFSIGGEN_REPCAP_V5GALLOCATIONS_V5GAL1                             1
#define RSRFSIGGEN_REPCAP_V5GALLOCATIONS_V5GAL2                             2
#define RSRFSIGGEN_REPCAP_V5GALLOCATIONS_V5GAL3                             3
#define RSRFSIGGEN_REPCAP_V5GALLOCATIONS_V5GAL4                             4
#define RSRFSIGGEN_REPCAP_V5GALLOCATIONS_V5GAL5                             5
#define RSRFSIGGEN_REPCAP_V5GALLOCATIONS_V5GAL6                             6
#define RSRFSIGGEN_REPCAP_V5GALLOCATIONS_V5GAL7                             7
#define RSRFSIGGEN_REPCAP_V5GALLOCATIONS_V5GAL8                             8
#define RSRFSIGGEN_REPCAP_V5GALLOCATIONS_V5GAL9                             9

//repcap V5GAPM
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM8                                    0
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM9                                    1
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM10                                   2
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM11                                   3
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM12                                   4
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM13                                   5
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM14                                   6
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM15                                   7
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM16                                   8
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM17                                   9
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM18                                   10
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM19                                   11
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM20                                   12
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM21                                   13
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM22                                   14
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM23                                   15
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM24                                   16
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM25                                   17
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM26                                   18
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM27                                   19
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM28                                   20
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM29                                   21
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM30                                   22
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM31                                   23
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM60                                   24
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM61                                   25
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM107                                  26
#define RSRFSIGGEN_REPCAP_V5GAPM_V5GAPM109                                  27

//repcap V5GItem
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM0                                  0
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM1                                  1
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM2                                  2
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM3                                  3
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM4                                  4
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM5                                  5
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM6                                  6
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM7                                  7
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM8                                  8
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM9                                  9
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM10                                 10
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM11                                 11
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM12                                 12
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM13                                 13
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM14                                 14
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM15                                 15
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM16                                 16
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM17                                 17
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM18                                 18
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM19                                 19
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM20                                 20
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM21                                 21
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM22                                 22
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM23                                 23
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM24                                 24
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM25                                 25
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM26                                 26
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM27                                 27
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM28                                 28
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM29                                 29
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM30                                 30
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM31                                 31
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM32                                 32
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM33                                 33
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM34                                 34
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM35                                 35
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM36                                 36
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM37                                 37
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM38                                 38
#define RSRFSIGGEN_REPCAP_V5GITEM_V5GITEM39                                 39

//repcap V5GSubframe
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME0                          0
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME1                          1
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME2                          2
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME3                          3
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME4                          4
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME5                          5
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME6                          6
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME7                          7
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME8                          8
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME9                          9
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME10                         10
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME11                         11
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME12                         12
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME13                         13
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME14                         14
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME15                         15
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME16                         16
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME17                         17
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME18                         18
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME19                         19
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME20                         20
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME21                         21
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME22                         22
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME23                         23
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME24                         24
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME25                         25
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME26                         26
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME27                         27
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME28                         28
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME29                         29
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME30                         30
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME31                         31
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME32                         32
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME33                         33
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME34                         34
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME35                         35
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME36                         36
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME37                         37
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME38                         38
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME39                         39
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME40                         40
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME41                         41
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME42                         42
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME43                         43
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME44                         44
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME45                         45
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME46                         46
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME47                         47
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME48                         48
#define RSRFSIGGEN_REPCAP_V5GSUBFRAME_V5GSUBFRAME49                         49

//repcap V5GCell
#define RSRFSIGGEN_REPCAP_V5GCELL_V5GCELL0                                  0
#define RSRFSIGGEN_REPCAP_V5GCELL_V5GCELL1                                  1
#define RSRFSIGGEN_REPCAP_V5GCELL_V5GCELL2                                  2
#define RSRFSIGGEN_REPCAP_V5GCELL_V5GCELL3                                  3

//repcap BTTableOffset
#define RSRFSIGGEN_REPCAP_BTTABLEOFFSET_BTOFFSET0                           0
#define RSRFSIGGEN_REPCAP_BTTABLEOFFSET_BTOFFSET1                           1
#define RSRFSIGGEN_REPCAP_BTTABLEOFFSET_BTOFFSET2                           2
#define RSRFSIGGEN_REPCAP_BTTABLEOFFSET_BTOFFSET3                           3
#define RSRFSIGGEN_REPCAP_BTTABLEOFFSET_BTOFFSET4                           4
#define RSRFSIGGEN_REPCAP_BTTABLEOFFSET_BTOFFSET5                           5

//repcap EUTRASCI
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI0                                     0
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI1                                     1
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI2                                     2
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI3                                     3
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI4                                     4
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI5                                     5
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI6                                     6
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI7                                     7
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI8                                     8
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI9                                     9
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI10                                    10
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI11                                    11
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI12                                    12
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI13                                    13
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI14                                    14
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI15                                    15
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI16                                    16
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI17                                    17
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI18                                    18
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI19                                    19
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI20                                    20
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI21                                    21
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI22                                    22
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI23                                    23
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI24                                    24
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI25                                    25
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI26                                    26
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI27                                    27
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI28                                    28
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI29                                    29
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI30                                    30
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI31                                    31
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI32                                    32
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI33                                    33
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI34                                    34
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI35                                    35
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI36                                    36
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI37                                    37
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI38                                    38
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI39                                    39
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI40                                    40
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI41                                    41
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI42                                    42
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI43                                    43
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI44                                    44
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI45                                    45
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI46                                    46
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI47                                    47
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI48                                    48
#define RSRFSIGGEN_REPCAP_EUTRASCI_SCI49                                    49

//repcap DVBMODCOD
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST1                                     1
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST2                                     2
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST3                                     3
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST4                                     4
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST5                                     5
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST6                                     6
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST7                                     7
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST8                                     8
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST9                                     9
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST10                                    10
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST11                                    11
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST12                                    12
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST13                                    13
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST14                                    14
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST15                                    15
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST16                                    16
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST17                                    17
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST18                                    18
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST19                                    19
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST20                                    20
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST21                                    21
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST22                                    22
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST23                                    23
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST24                                    24
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST25                                    25
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST26                                    26
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST27                                    27
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST28                                    28
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST29                                    29
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST30                                    30
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST31                                    31
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST32                                    32
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST33                                    33
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST34                                    34
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST35                                    35
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST36                                    36
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST37                                    37
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST38                                    38
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST39                                    39
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST40                                    40
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST41                                    41
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST42                                    42
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST43                                    43
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST44                                    44
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST45                                    45
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST46                                    46
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST47                                    47
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST48                                    48
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST49                                    49
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST50                                    50
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST51                                    51
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST52                                    52
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST53                                    53
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST54                                    54
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST55                                    55
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST56                                    56
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST57                                    57
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST58                                    58
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST59                                    59
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST60                                    60
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST61                                    61
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST62                                    62
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST63                                    63
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST64                                    64
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST65                                    65
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST66                                    66
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST67                                    67
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST68                                    68
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST69                                    69
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST70                                    70
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST71                                    71
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST72                                    72
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST73                                    73
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST74                                    74
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST75                                    75
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST76                                    76
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST77                                    77
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST78                                    78
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST79                                    79
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST80                                    80
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST81                                    81
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST82                                    82
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST83                                    83
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST84                                    84
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST85                                    85
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST86                                    86
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST87                                    87
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST88                                    88
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST89                                    89
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST90                                    90
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST91                                    91
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST92                                    92
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST93                                    93
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST94                                    94
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST95                                    95
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST96                                    96
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST97                                    97
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST98                                    98
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST99                                    99
#define RSRFSIGGEN_REPCAP_DVBMODCOD_ST100                                   100

//repcap EUTRAAntennaPort
#define RSRFSIGGEN_REPCAP_EUTRAANTENNAPORT_DIR5                             0
#define RSRFSIGGEN_REPCAP_EUTRAANTENNAPORT_DIR7                             1
#define RSRFSIGGEN_REPCAP_EUTRAANTENNAPORT_DIR8                             2
#define RSRFSIGGEN_REPCAP_EUTRAANTENNAPORT_DIR9                             3
#define RSRFSIGGEN_REPCAP_EUTRAANTENNAPORT_DIR10                            4
#define RSRFSIGGEN_REPCAP_EUTRAANTENNAPORT_DIR11                            5
#define RSRFSIGGEN_REPCAP_EUTRAANTENNAPORT_DIR12                            6
#define RSRFSIGGEN_REPCAP_EUTRAANTENNAPORT_DIR13                            7
#define RSRFSIGGEN_REPCAP_EUTRAANTENNAPORT_DIR14                            8

//repcap HSDigChannel
#define RSRFSIGGEN_REPCAP_HSDIGCHANNEL_HSCHAN0                              0
#define RSRFSIGGEN_REPCAP_HSDIGCHANNEL_HSCHAN1                              1
#define RSRFSIGGEN_REPCAP_HSDIGCHANNEL_HSCHAN2                              2
#define RSRFSIGGEN_REPCAP_HSDIGCHANNEL_HSCHAN3                              3
#define RSRFSIGGEN_REPCAP_HSDIGCHANNEL_HSCHAN4                              4
#define RSRFSIGGEN_REPCAP_HSDIGCHANNEL_HSCHAN5                              5
#define RSRFSIGGEN_REPCAP_HSDIGCHANNEL_HSCHAN6                              6
#define RSRFSIGGEN_REPCAP_HSDIGCHANNEL_HSCHAN7                              7

//repcap NotchNumber
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH1                                1
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH2                                2
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH3                                3
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH4                                4
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH5                                5
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH6                                6
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH7                                7
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH8                                8
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH9                                9
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH10                               10
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH11                               11
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH12                               12
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH13                               13
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH14                               14
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH15                               15
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH16                               16
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH17                               17
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH18                               18
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH19                               19
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH20                               20
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH21                               21
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH22                               22
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH23                               23
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH24                               24
#define RSRFSIGGEN_REPCAP_NOTCHNUMBER_NOTCH25                               25

//repcap NoisePoint
#define RSRFSIGGEN_REPCAP_NOISEPOINT_NOISEPOINT1                            1
#define RSRFSIGGEN_REPCAP_NOISEPOINT_NOISEPOINT2                            2
#define RSRFSIGGEN_REPCAP_NOISEPOINT_NOISEPOINT3                            3
#define RSRFSIGGEN_REPCAP_NOISEPOINT_NOISEPOINT4                            4
#define RSRFSIGGEN_REPCAP_NOISEPOINT_NOISEPOINT5                            5

//repcap NR5GCell
#define RSRFSIGGEN_REPCAP_NR5GCELL_NR5GCELL0                                0
#define RSRFSIGGEN_REPCAP_NR5GCELL_NR5GCELL1                                1
#define RSRFSIGGEN_REPCAP_NR5GCELL_NR5GCELL2                                2
#define RSRFSIGGEN_REPCAP_NR5GCELL_NR5GCELL3                                3
#define RSRFSIGGEN_REPCAP_NR5GCELL_NR5GCELL4                                4
#define RSRFSIGGEN_REPCAP_NR5GCELL_NR5GCELL5                                5
#define RSRFSIGGEN_REPCAP_NR5GCELL_NR5GCELL6                                6
#define RSRFSIGGEN_REPCAP_NR5GCELL_NR5GCELL7                                7

//repcap NR5GSSPBCH
#define RSRFSIGGEN_REPCAP_NR5GSSPBCH_NR5GSSPBCH0                            0
#define RSRFSIGGEN_REPCAP_NR5GSSPBCH_NR5GSSPBCH1                            1
#define RSRFSIGGEN_REPCAP_NR5GSSPBCH_NR5GSSPBCH2                            2
#define RSRFSIGGEN_REPCAP_NR5GSSPBCH_NR5GSSPBCH3                            3

//repcap NR5GBaseband
#define RSRFSIGGEN_REPCAP_NR5GBASEBAND_NR5GBB0                              0
#define RSRFSIGGEN_REPCAP_NR5GBASEBAND_NR5GBB1                              1
#define RSRFSIGGEN_REPCAP_NR5GBASEBAND_NR5GBB2                              2
#define RSRFSIGGEN_REPCAP_NR5GBASEBAND_NR5GBB3                              3
#define RSRFSIGGEN_REPCAP_NR5GBASEBAND_NR5GBB4                              4
#define RSRFSIGGEN_REPCAP_NR5GBASEBAND_NR5GBB5                              5
#define RSRFSIGGEN_REPCAP_NR5GBASEBAND_NR5GBB6                              6
#define RSRFSIGGEN_REPCAP_NR5GBASEBAND_NR5GBB7                              7

//repcap NR5GUsers
#define RSRFSIGGEN_REPCAP_NR5GUSERS_NR5GUSER0                               0
#define RSRFSIGGEN_REPCAP_NR5GUSERS_NR5GUSER1                               1
#define RSRFSIGGEN_REPCAP_NR5GUSERS_NR5GUSER2                               2
#define RSRFSIGGEN_REPCAP_NR5GUSERS_NR5GUSER3                               3
#define RSRFSIGGEN_REPCAP_NR5GUSERS_NR5GUSER4                               4
#define RSRFSIGGEN_REPCAP_NR5GUSERS_NR5GUSER5                               5
#define RSRFSIGGEN_REPCAP_NR5GUSERS_NR5GUSER6                               6
#define RSRFSIGGEN_REPCAP_NR5GUSERS_NR5GUSER7                               7
#define RSRFSIGGEN_REPCAP_NR5GUSERS_NR5GUSER8                               8
#define RSRFSIGGEN_REPCAP_NR5GUSERS_NR5GUSER9                               9

//repcap NR5GBWP
#define RSRFSIGGEN_REPCAP_NR5GBWP_NR5GBWP0                                  0
#define RSRFSIGGEN_REPCAP_NR5GBWP_NR5GBWP1                                  1
#define RSRFSIGGEN_REPCAP_NR5GBWP_NR5GBWP2                                  2
#define RSRFSIGGEN_REPCAP_NR5GBWP_NR5GBWP3                                  3

//repcap NR5GAllocations
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL0                           0
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL1                           1
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL2                           2
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL3                           3
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL4                           4
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL5                           5
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL6                           6
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL7                           7
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL8                           8
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL9                           9
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL10                          10
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL11                          11
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL12                          12
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL13                          13
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL14                          14
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL15                          15
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL16                          16
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL17                          17
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL18                          18
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL19                          19
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL20                          20
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL21                          21
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL22                          22
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL23                          23
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL24                          24
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL25                          25
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL26                          26
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL27                          27
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL28                          28
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL29                          29
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL30                          30
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL31                          31
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL32                          32
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL33                          33
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL34                          34
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL35                          35
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL36                          36
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL37                          37
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL38                          38
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL39                          39
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL40                          40
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL41                          41
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL42                          42
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL43                          43
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL44                          44
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL45                          45
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL46                          46
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL47                          47
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL48                          48
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL49                          49
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL50                          50
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL51                          51
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL52                          52
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL53                          53
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL54                          54
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL55                          55
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL56                          56
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL57                          57
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL58                          58
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL59                          59
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL60                          60
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL61                          61
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL62                          62
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL63                          63
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL64                          64
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL65                          65
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL66                          66
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL67                          67
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL68                          68
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL69                          69
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL70                          70
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL71                          71
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL72                          72
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL73                          73
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL74                          74
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL75                          75
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL76                          76
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL77                          77
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL78                          78
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL79                          79
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL80                          80
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL81                          81
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL82                          82
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL83                          83
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL84                          84
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL85                          85
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL86                          86
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL87                          87
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL88                          88
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL89                          89
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL90                          90
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL91                          91
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL92                          92
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL93                          93
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL94                          94
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL95                          95
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL96                          96
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL97                          97
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL98                          98
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL99                          99
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL100                         100
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL101                         101
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL102                         102
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL103                         103
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL104                         104
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL105                         105
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL106                         106
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL107                         107
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL108                         108
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL109                         109
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL110                         110
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL111                         111
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL112                         112
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL113                         113
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL114                         114
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL115                         115
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL116                         116
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL117                         117
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL118                         118
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL119                         119
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL120                         120
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL121                         121
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL122                         122
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL123                         123
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL124                         124
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL125                         125
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL126                         126
#define RSRFSIGGEN_REPCAP_NR5GALLOCATIONS_NR5GAL127                         127

//repcap NR5GSubframe
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME0                        0
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME1                        1
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME2                        2
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME3                        3
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME4                        4
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME5                        5
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME6                        6
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME7                        7
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME8                        8
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME9                        9
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME10                       10
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME11                       11
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME12                       12
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME13                       13
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME14                       14
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME15                       15
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME16                       16
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME17                       17
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME18                       18
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME19                       19
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME20                       20
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME21                       21
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME22                       22
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME23                       23
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME24                       24
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME25                       25
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME26                       26
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME27                       27
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME28                       28
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME29                       29
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME30                       30
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME31                       31
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME32                       32
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME33                       33
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME34                       34
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME35                       35
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME36                       36
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME37                       37
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME38                       38
#define RSRFSIGGEN_REPCAP_NR5GSUBFRAME_NR5GSUBFRAME39                       39

//repcap NR5GDCI
#define RSRFSIGGEN_REPCAP_NR5GDCI_NR5GDCI0                                  0
#define RSRFSIGGEN_REPCAP_NR5GDCI_NR5GDCI1                                  1
#define RSRFSIGGEN_REPCAP_NR5GDCI_NR5GDCI2                                  2
#define RSRFSIGGEN_REPCAP_NR5GDCI_NR5GDCI3                                  3

//repcap NR5GCodeword
#define RSRFSIGGEN_REPCAP_NR5GCODEWORD_NR5GCW0                              0
#define RSRFSIGGEN_REPCAP_NR5GCODEWORD_NR5GCW1                              1

//repcap BBMM
#define RSRFSIGGEN_REPCAP_BBMM_BBMM1                                        1
#define RSRFSIGGEN_REPCAP_BBMM_BBMM2                                        2

//repcap SatNavMonitor
#define RSRFSIGGEN_REPCAP_SATNAVMONITOR_SNM1                                1
#define RSRFSIGGEN_REPCAP_SATNAVMONITOR_SNM2                                2

//repcap SatNavAF
#define RSRFSIGGEN_REPCAP_SATNAVAF_SAF0                                     0
#define RSRFSIGGEN_REPCAP_SATNAVAF_SAF1                                     1
#define RSRFSIGGEN_REPCAP_SATNAVAF_SAF2                                     2

//repcap SatNavAnt
#define RSRFSIGGEN_REPCAP_SATNAVANT_SA1                                     1
#define RSRFSIGGEN_REPCAP_SATNAVANT_SA2                                     2
#define RSRFSIGGEN_REPCAP_SATNAVANT_SA3                                     3
#define RSRFSIGGEN_REPCAP_SATNAVANT_SA4                                     4

//repcap NR5GSet
#define RSRFSIGGEN_REPCAP_NR5GSET_NR5GSET0                                  0
#define RSRFSIGGEN_REPCAP_NR5GSET_NR5GSET1                                  1
#define RSRFSIGGEN_REPCAP_NR5GSET_NR5GSET2                                  2
#define RSRFSIGGEN_REPCAP_NR5GSET_NR5GSET3                                  3
#define RSRFSIGGEN_REPCAP_NR5GSET_NR5GSET4                                  4
#define RSRFSIGGEN_REPCAP_NR5GSET_NR5GSET5                                  5
#define RSRFSIGGEN_REPCAP_NR5GSET_NR5GSET6                                  6
#define RSRFSIGGEN_REPCAP_NR5GSET_NR5GSET7                                  7
#define RSRFSIGGEN_REPCAP_NR5GSET_NR5GSET8                                  8
#define RSRFSIGGEN_REPCAP_NR5GSET_NR5GSET9                                  9
#define RSRFSIGGEN_REPCAP_NR5GSET_NR5GSET10                                 10
#define RSRFSIGGEN_REPCAP_NR5GSET_NR5GSET11                                 11
#define RSRFSIGGEN_REPCAP_NR5GSET_NR5GSET12                                 12
#define RSRFSIGGEN_REPCAP_NR5GSET_NR5GSET13                                 13
#define RSRFSIGGEN_REPCAP_NR5GSET_NR5GSET14                                 14
#define RSRFSIGGEN_REPCAP_NR5GSET_NR5GSET15                                 15

//repcap NR5GRes
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES0                                  0
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES1                                  1
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES2                                  2
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES3                                  3
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES4                                  4
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES5                                  5
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES6                                  6
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES7                                  7
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES8                                  8
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES9                                  9
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES10                                 10
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES11                                 11
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES12                                 12
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES13                                 13
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES14                                 14
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES15                                 15
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES16                                 16
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES17                                 17
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES18                                 18
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES19                                 19
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES20                                 20
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES21                                 21
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES22                                 22
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES23                                 23
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES24                                 24
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES25                                 25
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES26                                 26
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES27                                 27
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES28                                 28
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES29                                 29
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES30                                 30
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES31                                 31
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES32                                 32
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES33                                 33
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES34                                 34
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES35                                 35
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES36                                 36
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES37                                 37
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES38                                 38
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES39                                 39
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES40                                 40
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES41                                 41
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES42                                 42
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES43                                 43
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES44                                 44
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES45                                 45
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES46                                 46
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES47                                 47
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES48                                 48
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES49                                 49
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES50                                 50
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES51                                 51
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES52                                 52
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES53                                 53
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES54                                 54
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES55                                 55
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES56                                 56
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES57                                 57
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES58                                 58
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES59                                 59
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES60                                 60
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES61                                 61
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES62                                 62
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES63                                 63
#define RSRFSIGGEN_REPCAP_NR5GRES_NR5GRES64                                 64

//repcap NR5GRow
#define RSRFSIGGEN_REPCAP_NR5GROW_NR5GROW0                                  0
#define RSRFSIGGEN_REPCAP_NR5GROW_NR5GROW1                                  1
#define RSRFSIGGEN_REPCAP_NR5GROW_NR5GROW2                                  2
#define RSRFSIGGEN_REPCAP_NR5GROW_NR5GROW3                                  3
#define RSRFSIGGEN_REPCAP_NR5GROW_NR5GROW4                                  4
#define RSRFSIGGEN_REPCAP_NR5GROW_NR5GROW5                                  5
#define RSRFSIGGEN_REPCAP_NR5GROW_NR5GROW6                                  6
#define RSRFSIGGEN_REPCAP_NR5GROW_NR5GROW7                                  7

//repcap NR5GAP
#define RSRFSIGGEN_REPCAP_NR5GAP_NR5GAP1000                                 0
#define RSRFSIGGEN_REPCAP_NR5GAP_NR5GAP1001                                 1
#define RSRFSIGGEN_REPCAP_NR5GAP_NR5GAP1002                                 2
#define RSRFSIGGEN_REPCAP_NR5GAP_NR5GAP1003                                 3

//repcap NR5GTDA
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA0                                  0
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA1                                  1
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA2                                  2
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA3                                  3
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA4                                  4
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA5                                  5
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA6                                  6
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA7                                  7
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA8                                  8
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA9                                  9
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA10                                 10
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA11                                 11
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA12                                 12
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA13                                 13
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA14                                 14
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA15                                 15
#define RSRFSIGGEN_REPCAP_NR5GTDA_NR5GTDA16                                 16

//repcap NR5GGroup
#define RSRFSIGGEN_REPCAP_NR5GGROUP_NR5GGROUP0                              0
#define RSRFSIGGEN_REPCAP_NR5GGROUP_NR5GGROUP1                              1
#define RSRFSIGGEN_REPCAP_NR5GGROUP_NR5GGROUP2                              2

//repcap NR5GCol
#define RSRFSIGGEN_REPCAP_NR5GCOL_NR5GCOL0                                  0
#define RSRFSIGGEN_REPCAP_NR5GCOL_NR5GCOL1                                  1
#define RSRFSIGGEN_REPCAP_NR5GCOL_NR5GCOL2                                  2
#define RSRFSIGGEN_REPCAP_NR5GCOL_NR5GCOL3                                  3
#define RSRFSIGGEN_REPCAP_NR5GCOL_NR5GCOL4                                  4
#define RSRFSIGGEN_REPCAP_NR5GCOL_NR5GCOL5                                  5
#define RSRFSIGGEN_REPCAP_NR5GCOL_NR5GCOL6                                  6
#define RSRFSIGGEN_REPCAP_NR5GCOL_NR5GCOL7                                  7

//repcap GBASFDB
#define RSRFSIGGEN_REPCAP_GBASFDB_GBASFDB1                                  1
#define RSRFSIGGEN_REPCAP_GBASFDB_GBASFDB2                                  2
#define RSRFSIGGEN_REPCAP_GBASFDB_GBASFDB3                                  3
#define RSRFSIGGEN_REPCAP_GBASFDB_GBASFDB4                                  4
#define RSRFSIGGEN_REPCAP_GBASFDB_GBASFDB5                                  5

//repcap EUTRASubframe
#define RSRFSIGGEN_REPCAP_EUTRASUBFRAME_ESF0                                0
#define RSRFSIGGEN_REPCAP_EUTRASUBFRAME_ESF1                                1
#define RSRFSIGGEN_REPCAP_EUTRASUBFRAME_ESF2                                2
#define RSRFSIGGEN_REPCAP_EUTRASUBFRAME_ESF3                                3
#define RSRFSIGGEN_REPCAP_EUTRASUBFRAME_ESF4                                4
#define RSRFSIGGEN_REPCAP_EUTRASUBFRAME_ESF5                                5
#define RSRFSIGGEN_REPCAP_EUTRASUBFRAME_ESF6                                6
#define RSRFSIGGEN_REPCAP_EUTRASUBFRAME_ESF7                                7
#define RSRFSIGGEN_REPCAP_EUTRASUBFRAME_ESF8                                8
#define RSRFSIGGEN_REPCAP_EUTRASUBFRAME_ESF9                                9

//repcap GNSSRLM
#define RSRFSIGGEN_REPCAP_GNSSRLM_GNSSRLM1                                  1
#define RSRFSIGGEN_REPCAP_GNSSRLM_GNSSRLM2                                  2
#define RSRFSIGGEN_REPCAP_GNSSRLM_GNSSRLM3                                  3
#define RSRFSIGGEN_REPCAP_GNSSRLM_GNSSRLM4                                  4
#define RSRFSIGGEN_REPCAP_GNSSRLM_GNSSRLM5                                  5
#define RSRFSIGGEN_REPCAP_GNSSRLM_GNSSRLM6                                  6
#define RSRFSIGGEN_REPCAP_GNSSRLM_GNSSRLM7                                  7
#define RSRFSIGGEN_REPCAP_GNSSRLM_GNSSRLM8                                  8

//repcap FrequencyBand
#define RSRFSIGGEN_REPCAP_FREQUENCYBAND_FREQBAND1                           1
#define RSRFSIGGEN_REPCAP_FREQUENCYBAND_FREQBAND2                           2

//repcap BTAntenna
#define RSRFSIGGEN_REPCAP_BTANTENNA_BTANTENNA0                              0
#define RSRFSIGGEN_REPCAP_BTANTENNA_BTANTENNA1                              1
#define RSRFSIGGEN_REPCAP_BTANTENNA_BTANTENNA2                              2
#define RSRFSIGGEN_REPCAP_BTANTENNA_BTANTENNA3                              3

//repcap NR5GPosIdx
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX0                            0
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX1                            1
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX2                            2
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX3                            3
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX4                            4
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX5                            5
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX6                            6
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX7                            7
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX8                            8
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX9                            9
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX10                           10
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX11                           11
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX12                           12
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX13                           13
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX14                           14
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX15                           15
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX16                           16
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX17                           17
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX18                           18
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX19                           19
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX20                           20
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX21                           21
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX22                           22
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX23                           23
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX24                           24
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX25                           25
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX26                           26
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX27                           27
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX28                           28
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX29                           29
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX30                           30
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX31                           31
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX32                           32
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX33                           33
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX34                           34
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX35                           35
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX36                           36
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX37                           37
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX38                           38
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX39                           39
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX40                           40
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX41                           41
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX42                           42
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX43                           43
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX44                           44
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX45                           45
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX46                           46
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX47                           47
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX48                           48
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX49                           49
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX50                           50
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX51                           51
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX52                           52
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX53                           53
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX54                           54
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX55                           55
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX56                           56
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX57                           57
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX58                           58
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX59                           59
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX60                           60
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX61                           61
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX62                           62
#define RSRFSIGGEN_REPCAP_NR5GPOSIDX_NR5GPOSIDX63                           63

//repcap NR5GFreqHopOff
#define RSRFSIGGEN_REPCAP_NR5GFREQHOPOFF_NRGFREQHOPOFF1                     0
#define RSRFSIGGEN_REPCAP_NR5GFREQHOPOFF_NRGFREQHOPOFF2                     1
#define RSRFSIGGEN_REPCAP_NR5GFREQHOPOFF_NRGFREQHOPOFF3                     2
#define RSRFSIGGEN_REPCAP_NR5GFREQHOPOFF_NRGFREQHOPOFF4                     3

//repcap NR5GLayer
#define RSRFSIGGEN_REPCAP_NR5GLAYER_NRGLAYER1                               1
#define RSRFSIGGEN_REPCAP_NR5GLAYER_NRGLAYER2                               2
#define RSRFSIGGEN_REPCAP_NR5GLAYER_NRGLAYER3                               3
#define RSRFSIGGEN_REPCAP_NR5GLAYER_NRGLAYER4                               4
#define RSRFSIGGEN_REPCAP_NR5GLAYER_NRGLAYER5                               5
#define RSRFSIGGEN_REPCAP_NR5GLAYER_NRGLAYER6                               6
#define RSRFSIGGEN_REPCAP_NR5GLAYER_NRGLAYER7                               7
#define RSRFSIGGEN_REPCAP_NR5GLAYER_NRGLAYER8                               8

//repcap NR5GCancInd
#define RSRFSIGGEN_REPCAP_NR5GCANCIND_NR5GCANCIND1                          1
#define RSRFSIGGEN_REPCAP_NR5GCANCIND_NR5GCANCIND2                          2
#define RSRFSIGGEN_REPCAP_NR5GCANCIND_NR5GCANCIND3                          3
#define RSRFSIGGEN_REPCAP_NR5GCANCIND_NR5GCANCIND4                          4
#define RSRFSIGGEN_REPCAP_NR5GCANCIND_NR5GCANCIND5                          5
#define RSRFSIGGEN_REPCAP_NR5GCANCIND_NR5GCANCIND6                          6
#define RSRFSIGGEN_REPCAP_NR5GCANCIND_NR5GCANCIND7                          7
#define RSRFSIGGEN_REPCAP_NR5GCANCIND_NR5GCANCIND8                          8
#define RSRFSIGGEN_REPCAP_NR5GCANCIND_NR5GCANCIND9                          9
#define RSRFSIGGEN_REPCAP_NR5GCANCIND_NR5GCANCIND10                         10
#define RSRFSIGGEN_REPCAP_NR5GCANCIND_NR5GCANCIND11                         11
#define RSRFSIGGEN_REPCAP_NR5GCANCIND_NR5GCANCIND12                         12
#define RSRFSIGGEN_REPCAP_NR5GCANCIND_NR5GCANCIND13                         13
#define RSRFSIGGEN_REPCAP_NR5GCANCIND_NR5GCANCIND14                         14
#define RSRFSIGGEN_REPCAP_NR5GCANCIND_NR5GCANCIND15                         15
#define RSRFSIGGEN_REPCAP_NR5GCANCIND_NR5GCANCIND16                         16

//repcap NR5GCLI
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI1                                   1
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI2                                   2
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI3                                   3
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI4                                   4
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI5                                   5
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI6                                   6
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI7                                   7
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI8                                   8
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI9                                   9
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI10                                  10
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI11                                  11
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI12                                  12
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI13                                  13
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI14                                  14
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI15                                  15
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI16                                  16
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI17                                  17
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI18                                  18
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI19                                  19
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI20                                  20
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI21                                  21
#define RSRFSIGGEN_REPCAP_NR5GCLI_NRGCLI22                                  22

//repcap NR5GTPC
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC1                                  1
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC2                                  2
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC3                                  3
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC4                                  4
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC5                                  5
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC6                                  6
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC7                                  7
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC8                                  8
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC9                                  9
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC10                                 10
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC11                                 11
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC12                                 12
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC13                                 13
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC14                                 14
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC15                                 15
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC16                                 16
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC17                                 17
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC18                                 18
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC19                                 19
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC20                                 20
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC21                                 21
#define RSRFSIGGEN_REPCAP_NR5GTPC_NR5GTPC22                                 22

//repcap NR5GPreEmpt
#define RSRFSIGGEN_REPCAP_NR5GPREEMPT_NR5GPREEMPT1                          1
#define RSRFSIGGEN_REPCAP_NR5GPREEMPT_NR5GPREEMPT2                          2
#define RSRFSIGGEN_REPCAP_NR5GPREEMPT_NR5GPREEMPT3                          3
#define RSRFSIGGEN_REPCAP_NR5GPREEMPT_NR5GPREEMPT4                          4
#define RSRFSIGGEN_REPCAP_NR5GPREEMPT_NR5GPREEMPT5                          5
#define RSRFSIGGEN_REPCAP_NR5GPREEMPT_NR5GPREEMPT6                          6
#define RSRFSIGGEN_REPCAP_NR5GPREEMPT_NR5GPREEMPT7                          7
#define RSRFSIGGEN_REPCAP_NR5GPREEMPT_NR5GPREEMPT8                          8
#define RSRFSIGGEN_REPCAP_NR5GPREEMPT_NR5GPREEMPT9                          9

//repcap NR5GSFI
#define RSRFSIGGEN_REPCAP_NR5GSFI_NR5GSFI1                                  1
#define RSRFSIGGEN_REPCAP_NR5GSFI_NR5GSFI2                                  2
#define RSRFSIGGEN_REPCAP_NR5GSFI_NR5GSFI3                                  3
#define RSRFSIGGEN_REPCAP_NR5GSFI_NR5GSFI4                                  4
#define RSRFSIGGEN_REPCAP_NR5GSFI_NR5GSFI5                                  5
#define RSRFSIGGEN_REPCAP_NR5GSFI_NR5GSFI6                                  6
#define RSRFSIGGEN_REPCAP_NR5GSFI_NR5GSFI7                                  7
#define RSRFSIGGEN_REPCAP_NR5GSFI_NR5GSFI8                                  8
#define RSRFSIGGEN_REPCAP_NR5GSFI_NR5GSFI9                                  9
#define RSRFSIGGEN_REPCAP_NR5GSFI_NR5GSFI10                                 10
#define RSRFSIGGEN_REPCAP_NR5GSFI_NR5GSFI11                                 11
#define RSRFSIGGEN_REPCAP_NR5GSFI_NR5GSFI12                                 12
#define RSRFSIGGEN_REPCAP_NR5GSFI_NR5GSFI13                                 13
#define RSRFSIGGEN_REPCAP_NR5GSFI_NR5GSFI14                                 14
#define RSRFSIGGEN_REPCAP_NR5GSFI_NR5GSFI15                                 15
#define RSRFSIGGEN_REPCAP_NR5GSFI_NR5GSFI16                                 16

//repcap NR5GSRS
#define RSRFSIGGEN_REPCAP_NR5GSRS_NRGSRS1                                   1
#define RSRFSIGGEN_REPCAP_NR5GSRS_NRGSRS2                                   2
#define RSRFSIGGEN_REPCAP_NR5GSRS_NRGSRS3                                   3
#define RSRFSIGGEN_REPCAP_NR5GSRS_NRGSRS4                                   4
#define RSRFSIGGEN_REPCAP_NR5GSRS_NRGSRS5                                   5
#define RSRFSIGGEN_REPCAP_NR5GSRS_NRGSRS6                                   6
#define RSRFSIGGEN_REPCAP_NR5GSRS_NRGSRS7                                   7
#define RSRFSIGGEN_REPCAP_NR5GSRS_NRGSRS8                                   8
#define RSRFSIGGEN_REPCAP_NR5GSRS_NRGSRS9                                   9
#define RSRFSIGGEN_REPCAP_NR5GSRS_NRGSRS10                                  10
#define RSRFSIGGEN_REPCAP_NR5GSRS_NRGSRS11                                  11

//repcap SatNavPseudorange
#define RSRFSIGGEN_REPCAP_SATNAVPSEUDORANGE_SNPSEUDO1                       1
#define RSRFSIGGEN_REPCAP_SATNAVPSEUDORANGE_SNPSEUDO2                       2
#define RSRFSIGGEN_REPCAP_SATNAVPSEUDORANGE_SNPSEUDO3                       3
#define RSRFSIGGEN_REPCAP_SATNAVPSEUDORANGE_SNPSEUDO4                       4
#define RSRFSIGGEN_REPCAP_SATNAVPSEUDORANGE_SNPSEUDO5                       5
#define RSRFSIGGEN_REPCAP_SATNAVPSEUDORANGE_SNPSEUDO6                       6
#define RSRFSIGGEN_REPCAP_SATNAVPSEUDORANGE_SNPSEUDO7                       7
#define RSRFSIGGEN_REPCAP_SATNAVPSEUDORANGE_SNPSEUDO8                       8
#define RSRFSIGGEN_REPCAP_SATNAVPSEUDORANGE_SNPSEUDO9                       9
#define RSRFSIGGEN_REPCAP_SATNAVPSEUDORANGE_SNPSEUDO10                      10

//repcap SatNavArea
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA1                                1
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA2                                2
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA3                                3
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA4                                4
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA5                                5
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA6                                6
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA7                                7
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA8                                8
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA9                                9
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA10                               10
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA11                               11
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA12                               12
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA13                               13
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA14                               14
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA15                               15
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA16                               16
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA17                               17
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA18                               18
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA19                               19
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA20                               20
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA21                               21
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA22                               22
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA23                               23
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA24                               24
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA25                               25
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA26                               26
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA27                               27
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA28                               28
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA29                               29
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA30                               30
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA31                               31
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA32                               32
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA33                               33
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA34                               34
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA35                               35
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA36                               36
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA37                               37
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA38                               38
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA39                               39
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA40                               40
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA41                               41
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA42                               42
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA43                               43
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA44                               44
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA45                               45
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA46                               46
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA47                               47
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA48                               48
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA49                               49
#define RSRFSIGGEN_REPCAP_SATNAVAREA_SNAREA50                               50

//repcap SatNavEcho
#define RSRFSIGGEN_REPCAP_SATNAVECHO_SNECHO0                                0
#define RSRFSIGGEN_REPCAP_SATNAVECHO_SNECHO1                                1
#define RSRFSIGGEN_REPCAP_SATNAVECHO_SNECHO2                                2
#define RSRFSIGGEN_REPCAP_SATNAVECHO_SNECHO3                                3
#define RSRFSIGGEN_REPCAP_SATNAVECHO_SNECHO4                                4
#define RSRFSIGGEN_REPCAP_SATNAVECHO_SNECHO5                                5
#define RSRFSIGGEN_REPCAP_SATNAVECHO_SNECHO6                                6
#define RSRFSIGGEN_REPCAP_SATNAVECHO_SNECHO7                                7
#define RSRFSIGGEN_REPCAP_SATNAVECHO_SNECHO8                                8
#define RSRFSIGGEN_REPCAP_SATNAVECHO_SNECHO9                                9

//repcap SatNavVehicles
#define RSRFSIGGEN_REPCAP_SATNAVVEHICLES_SNVEH1                             1
#define RSRFSIGGEN_REPCAP_SATNAVVEHICLES_SNVEH2                             2

//repcap NR5GAntPort
#define RSRFSIGGEN_REPCAP_NR5GANTPORT_NR5GANTPORT0                          0
#define RSRFSIGGEN_REPCAP_NR5GANTPORT_NR5GANTPORT1                          1
#define RSRFSIGGEN_REPCAP_NR5GANTPORT_NR5GANTPORT2                          2
#define RSRFSIGGEN_REPCAP_NR5GANTPORT_NR5GANTPORT3                          3
#define RSRFSIGGEN_REPCAP_NR5GANTPORT_NR5GANTPORT4                          4
#define RSRFSIGGEN_REPCAP_NR5GANTPORT_NR5GANTPORT5                          5
#define RSRFSIGGEN_REPCAP_NR5GANTPORT_NR5GANTPORT6                          6
#define RSRFSIGGEN_REPCAP_NR5GANTPORT_NR5GANTPORT7                          7
#define RSRFSIGGEN_REPCAP_NR5GANTPORT_NR5GANTPORT8                          8
#define RSRFSIGGEN_REPCAP_NR5GANTPORT_NR5GANTPORT9                          9
#define RSRFSIGGEN_REPCAP_NR5GANTPORT_NR5GANTPORT10                         10
#define RSRFSIGGEN_REPCAP_NR5GANTPORT_NR5GANTPORT11                         11
#define RSRFSIGGEN_REPCAP_NR5GANTPORT_NR5GANTPORT12                         12

//repcap NR5GLTEPatterns
#define RSRFSIGGEN_REPCAP_NR5GLTEPATTERNS_NR5GLTEPATTERN1                   1
#define RSRFSIGGEN_REPCAP_NR5GLTEPATTERNS_NR5GLTEPATTERN2                   2
#define RSRFSIGGEN_REPCAP_NR5GLTEPATTERNS_NR5GLTEPATTERN3                   3
#define RSRFSIGGEN_REPCAP_NR5GLTEPATTERNS_NR5GLTEPATTERN4                   4

//repcap NR5GAvailIndic
#define RSRFSIGGEN_REPCAP_NR5GAVAILINDIC_NR5GAVAILINDIC1                    1
#define RSRFSIGGEN_REPCAP_NR5GAVAILINDIC_NR5GAVAILINDIC2                    2
#define RSRFSIGGEN_REPCAP_NR5GAVAILINDIC_NR5GAVAILINDIC3                    3
#define RSRFSIGGEN_REPCAP_NR5GAVAILINDIC_NR5GAVAILINDIC4                    4
#define RSRFSIGGEN_REPCAP_NR5GAVAILINDIC_NR5GAVAILINDIC5                    5
#define RSRFSIGGEN_REPCAP_NR5GAVAILINDIC_NR5GAVAILINDIC6                    6
#define RSRFSIGGEN_REPCAP_NR5GAVAILINDIC_NR5GAVAILINDIC7                    7
#define RSRFSIGGEN_REPCAP_NR5GAVAILINDIC_NR5GAVAILINDIC8                    8
#define RSRFSIGGEN_REPCAP_NR5GAVAILINDIC_NR5GAVAILINDIC9                    9
#define RSRFSIGGEN_REPCAP_NR5GAVAILINDIC_NR5GAVAILINDIC10                   10
#define RSRFSIGGEN_REPCAP_NR5GAVAILINDIC_NR5GAVAILINDIC11                   11
#define RSRFSIGGEN_REPCAP_NR5GAVAILINDIC_NR5GAVAILINDIC12                   12
#define RSRFSIGGEN_REPCAP_NR5GAVAILINDIC_NR5GAVAILINDIC13                   13
#define RSRFSIGGEN_REPCAP_NR5GAVAILINDIC_NR5GAVAILINDIC14                   14
#define RSRFSIGGEN_REPCAP_NR5GAVAILINDIC_NR5GAVAILINDIC15                   15
#define RSRFSIGGEN_REPCAP_NR5GAVAILINDIC_NR5GAVAILINDIC16                   16

//repcap NR5GDormIndic
#define RSRFSIGGEN_REPCAP_NR5GDORMINDIC_NR5GDORMINDIC1                      1
#define RSRFSIGGEN_REPCAP_NR5GDORMINDIC_NR5GDORMINDIC2                      2
#define RSRFSIGGEN_REPCAP_NR5GDORMINDIC_NR5GDORMINDIC3                      3
#define RSRFSIGGEN_REPCAP_NR5GDORMINDIC_NR5GDORMINDIC4                      4
#define RSRFSIGGEN_REPCAP_NR5GDORMINDIC_NR5GDORMINDIC5                      5
#define RSRFSIGGEN_REPCAP_NR5GDORMINDIC_NR5GDORMINDIC6                      6
#define RSRFSIGGEN_REPCAP_NR5GDORMINDIC_NR5GDORMINDIC7                      7
#define RSRFSIGGEN_REPCAP_NR5GDORMINDIC_NR5GDORMINDIC8                      8
#define RSRFSIGGEN_REPCAP_NR5GDORMINDIC_NR5GDORMINDIC9                      9
#define RSRFSIGGEN_REPCAP_NR5GDORMINDIC_NR5GDORMINDIC10                     10

//repcap NR5GK0OffIndic
#define RSRFSIGGEN_REPCAP_NR5GK0OFFINDIC_NR5GK0OFFINDIC1                    0
#define RSRFSIGGEN_REPCAP_NR5GK0OFFINDIC_NR5GK0OFFINDIC2                    1
#define RSRFSIGGEN_REPCAP_NR5GK0OFFINDIC_NR5GK0OFFINDIC3                    2
#define RSRFSIGGEN_REPCAP_NR5GK0OFFINDIC_NR5GK0OFFINDIC4                    3
#define RSRFSIGGEN_REPCAP_NR5GK0OFFINDIC_NR5GK0OFFINDIC5                    4
#define RSRFSIGGEN_REPCAP_NR5GK0OFFINDIC_NR5GK0OFFINDIC6                    5
#define RSRFSIGGEN_REPCAP_NR5GK0OFFINDIC_NR5GK0OFFINDIC7                    6
#define RSRFSIGGEN_REPCAP_NR5GK0OFFINDIC_NR5GK0OFFINDIC8                    7
#define RSRFSIGGEN_REPCAP_NR5GK0OFFINDIC_NR5GK0OFFINDIC9                    8
#define RSRFSIGGEN_REPCAP_NR5GK0OFFINDIC_NR5GK0OFFINDIC10                   9
#define RSRFSIGGEN_REPCAP_NR5GK0OFFINDIC_NR5GK0OFFINDIC11                   10
#define RSRFSIGGEN_REPCAP_NR5GK0OFFINDIC_NR5GK0OFFINDIC12                   11
#define RSRFSIGGEN_REPCAP_NR5GK0OFFINDIC_NR5GK0OFFINDIC13                   12
#define RSRFSIGGEN_REPCAP_NR5GK0OFFINDIC_NR5GK0OFFINDIC14                   13
#define RSRFSIGGEN_REPCAP_NR5GK0OFFINDIC_NR5GK0OFFINDIC15                   14
#define RSRFSIGGEN_REPCAP_NR5GK0OFFINDIC_NR5GK0OFFINDIC16                   15

//repcap NR5GTCICodepoint
#define RSRFSIGGEN_REPCAP_NR5GTCICODEPOINT_NR5GTCICODEPOINT0                0
#define RSRFSIGGEN_REPCAP_NR5GTCICODEPOINT_NR5GTCICODEPOINT1                1
#define RSRFSIGGEN_REPCAP_NR5GTCICODEPOINT_NR5GTCICODEPOINT2                2
#define RSRFSIGGEN_REPCAP_NR5GTCICODEPOINT_NR5GTCICODEPOINT3                3
#define RSRFSIGGEN_REPCAP_NR5GTCICODEPOINT_NR5GTCICODEPOINT4                4
#define RSRFSIGGEN_REPCAP_NR5GTCICODEPOINT_NR5GTCICODEPOINT5                5
#define RSRFSIGGEN_REPCAP_NR5GTCICODEPOINT_NR5GTCICODEPOINT6                6
#define RSRFSIGGEN_REPCAP_NR5GTCICODEPOINT_NR5GTCICODEPOINT7                7
#define RSRFSIGGEN_REPCAP_NR5GTCICODEPOINT_NR5GTCICODEPOINT8                8

//repcap NR5GCPext
#define RSRFSIGGEN_REPCAP_NR5GCPEXT_NR5GCPEXT1                              0
#define RSRFSIGGEN_REPCAP_NR5GCPEXT_NR5GCPEXT2                              1
#define RSRFSIGGEN_REPCAP_NR5GCPEXT_NR5GCPEXT3                              2
#define RSRFSIGGEN_REPCAP_NR5GCPEXT_NR5GCPEXT4                              3
#define RSRFSIGGEN_REPCAP_NR5GCPEXT_NR5GCPEXT5                              4
#define RSRFSIGGEN_REPCAP_NR5GCPEXT_NR5GCPEXT6                              5
#define RSRFSIGGEN_REPCAP_NR5GCPEXT_NR5GCPEXT7                              6
#define RSRFSIGGEN_REPCAP_NR5GCPEXT_NR5GCPEXT8                              7
#define RSRFSIGGEN_REPCAP_NR5GCPEXT_NR5GCPEXT9                              8
#define RSRFSIGGEN_REPCAP_NR5GCPEXT_NR5GCPEXT10                             9
#define RSRFSIGGEN_REPCAP_NR5GCPEXT_NR5GCPEXT11                             10
#define RSRFSIGGEN_REPCAP_NR5GCPEXT_NR5GCPEXT12                             11
#define RSRFSIGGEN_REPCAP_NR5GCPEXT_NR5GCPEXT13                             12
#define RSRFSIGGEN_REPCAP_NR5GCPEXT_NR5GCPEXT14                             13
#define RSRFSIGGEN_REPCAP_NR5GCPEXT_NR5GCPEXT15                             14
#define RSRFSIGGEN_REPCAP_NR5GCPEXT_NR5GCPEXT16                             15

//repcap NR5GPRSResSet
#define RSRFSIGGEN_REPCAP_NR5GPRSRESSET_NR5GPRSRESSET1                      0
#define RSRFSIGGEN_REPCAP_NR5GPRSRESSET_NR5GPRSRESSET2                      1
#define RSRFSIGGEN_REPCAP_NR5GPRSRESSET_NR5GPRSRESSET3                      2
#define RSRFSIGGEN_REPCAP_NR5GPRSRESSET_NR5GPRSRESSET4                      3
#define RSRFSIGGEN_REPCAP_NR5GPRSRESSET_NR5GPRSRESSET5                      4
#define RSRFSIGGEN_REPCAP_NR5GPRSRESSET_NR5GPRSRESSET6                      5
#define RSRFSIGGEN_REPCAP_NR5GPRSRESSET_NR5GPRSRESSET7                      6
#define RSRFSIGGEN_REPCAP_NR5GPRSRESSET_NR5GPRSRESSET8                      7

//repcap ExtendedSequencer
#define RSRFSIGGEN_REPCAP_EXTENDEDSEQUENCER_EXTSEQ1                         1
#define RSRFSIGGEN_REPCAP_EXTENDEDSEQUENCER_EXTSEQ2                         2
#define RSRFSIGGEN_REPCAP_EXTENDEDSEQUENCER_EXTSEQ3                         3
#define RSRFSIGGEN_REPCAP_EXTENDEDSEQUENCER_EXTSEQ4                         4
#define RSRFSIGGEN_REPCAP_EXTENDEDSEQUENCER_EXTSEQ5                         5
#define RSRFSIGGEN_REPCAP_EXTENDEDSEQUENCER_EXTSEQ6                         6

//repcap ExtendedSequencerStream
#define RSRFSIGGEN_REPCAP_EXTENDEDSEQUENCERSTREAM_EXTSEQSTREAMA             1
#define RSRFSIGGEN_REPCAP_EXTENDEDSEQUENCERSTREAM_EXTSEQSTREAMB             2

//repcap SatNavGridFile
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE1                          0
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE2                          1
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE3                          2
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE4                          3
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE5                          4
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE6                          5
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE7                          6
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE8                          7
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE9                          8
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE10                         9
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE11                         10
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE12                         11
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE13                         12
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE14                         13
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE15                         14
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE16                         15
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE17                         16
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE18                         17
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE19                         18
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE20                         19
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE21                         20
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE22                         21
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE23                         22
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE24                         23
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE25                         24
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE26                         25
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE27                         26
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE28                         27
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE29                         28
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE30                         29
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE31                         30
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE32                         31
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE33                         32
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE34                         33
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE35                         34
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE36                         35
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE37                         36
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE38                         37
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE39                         38
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE40                         39
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE41                         40
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE42                         41
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE43                         42
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE44                         43
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE45                         44
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE46                         45
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE47                         46
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE48                         47
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE49                         48
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE50                         49
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE51                         50
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE52                         51
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE53                         52
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE54                         53
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE55                         54
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE56                         55
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE57                         56
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE58                         57
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE59                         58
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE60                         59
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE61                         60
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE62                         61
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE63                         62
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE64                         63
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE65                         64
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE66                         65
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE67                         66
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE68                         67
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE69                         68
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE70                         69
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE71                         70
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE72                         71
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE73                         72
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE74                         73
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE75                         74
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE76                         75
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE77                         76
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE78                         77
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE79                         78
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE80                         79
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE81                         80
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE82                         81
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE83                         82
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE84                         83
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE85                         84
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE86                         85
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE87                         86
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE88                         87
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE89                         88
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE90                         89
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE91                         90
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE92                         91
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE93                         92
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE94                         93
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE95                         94
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE96                         95
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE97                         96
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE98                         97
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE99                         98
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE100                        99
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE101                        100
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE102                        101
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE103                        102
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE104                        103
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE105                        104
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE106                        105
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE107                        106
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE108                        107
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE109                        108
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE110                        109
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE111                        110
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE112                        111
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE113                        112
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE114                        113
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE115                        114
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE116                        115
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE117                        116
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE118                        117
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE119                        118
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE120                        119
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE121                        120
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE122                        121
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE123                        122
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE124                        123
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE125                        124
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE126                        125
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE127                        126
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE128                        127
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE129                        128
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE130                        129
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE131                        130
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE132                        131
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE133                        132
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE134                        133
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE135                        134
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE136                        135
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE137                        136
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE138                        137
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE139                        138
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE140                        139
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE141                        140
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE142                        141
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE143                        142
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE144                        143
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE145                        144
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE146                        145
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE147                        146
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE148                        147
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE149                        148
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE150                        149
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE151                        150
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE152                        151
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE153                        152
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE154                        153
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE155                        154
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE156                        155
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE157                        156
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE158                        157
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE159                        158
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE160                        159
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE161                        160
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE162                        161
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE163                        162
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE164                        163
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE165                        164
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE166                        165
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE167                        166
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE168                        167
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE169                        168
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE170                        169
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE171                        170
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE172                        171
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE173                        172
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE174                        173
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE175                        174
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE176                        175
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE177                        176
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE178                        177
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE179                        178
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE180                        179
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE181                        180
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE182                        181
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE183                        182
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE184                        183
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE185                        184
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE186                        185
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE187                        186
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE188                        187
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE189                        188
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE190                        189
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE191                        190
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE192                        191
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE193                        192
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE194                        193
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE195                        194
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE196                        195
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE197                        196
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE198                        197
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE199                        198
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE200                        199
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE201                        200
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE202                        201
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE203                        202
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE204                        203
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE205                        204
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE206                        205
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE207                        206
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE208                        207
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE209                        208
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE210                        209
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE211                        210
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE212                        211
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE213                        212
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE214                        213
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE215                        214
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE216                        215
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE217                        216
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE218                        217
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE219                        218
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE220                        219
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE221                        220
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE222                        221
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE223                        222
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE224                        223
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE225                        224
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE226                        225
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE227                        226
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE228                        227
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE229                        228
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE230                        229
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE231                        230
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE232                        231
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE233                        232
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE234                        233
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE235                        234
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE236                        235
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE237                        236
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE238                        237
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE239                        238
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE240                        239
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE241                        240
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE242                        241
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE243                        242
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE244                        243
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE245                        244
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE246                        245
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE247                        246
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE248                        247
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE249                        248
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE250                        249
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE251                        250
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE252                        251
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE253                        252
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE254                        253
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE255                        254
#define RSRFSIGGEN_REPCAP_SATNAVGRIDFILE_GRIDFILE256                        255

//repcap NR5GResPool
#define RSRFSIGGEN_REPCAP_NR5GRESPOOL_NR5GRESPOOL1                          1
#define RSRFSIGGEN_REPCAP_NR5GRESPOOL_NR5GRESPOOL2                          2
#define RSRFSIGGEN_REPCAP_NR5GRESPOOL_NR5GRESPOOL3                          3
#define RSRFSIGGEN_REPCAP_NR5GRESPOOL_NR5GRESPOOL4                          4
#define RSRFSIGGEN_REPCAP_NR5GRESPOOL_NR5GRESPOOL5                          5
#define RSRFSIGGEN_REPCAP_NR5GRESPOOL_NR5GRESPOOL6                          6
#define RSRFSIGGEN_REPCAP_NR5GRESPOOL_NR5GRESPOOL7                          7
#define RSRFSIGGEN_REPCAP_NR5GRESPOOL_NR5GRESPOOL8                          8

//repcap NR5GCodebook
#define RSRFSIGGEN_REPCAP_NR5GCODEBOOK_NR5GCODEBOOK1                        1
#define RSRFSIGGEN_REPCAP_NR5GCODEBOOK_NR5GCODEBOOK2                        2

//repcap NR5GCarrier
#define RSRFSIGGEN_REPCAP_NR5GCARRIER_NR5GCARRIER1                          1
#define RSRFSIGGEN_REPCAP_NR5GCARRIER_NR5GCARRIER2                          2
#define RSRFSIGGEN_REPCAP_NR5GCARRIER_NR5GCARRIER3                          3
#define RSRFSIGGEN_REPCAP_NR5GCARRIER_NR5GCARRIER4                          4
#define RSRFSIGGEN_REPCAP_NR5GCARRIER_NR5GCARRIER5                          5
#define RSRFSIGGEN_REPCAP_NR5GCARRIER_NR5GCARRIER6                          6
#define RSRFSIGGEN_REPCAP_NR5GCARRIER_NR5GCARRIER7                          7
#define RSRFSIGGEN_REPCAP_NR5GCARRIER_NR5GCARRIER8                          8
#define RSRFSIGGEN_REPCAP_NR5GCARRIER_NR5GCARRIER9                          9
#define RSRFSIGGEN_REPCAP_NR5GCARRIER_NR5GCARRIER10                         10
#define RSRFSIGGEN_REPCAP_NR5GCARRIER_NR5GCARRIER11                         11
#define RSRFSIGGEN_REPCAP_NR5GCARRIER_NR5GCARRIER12                         12
#define RSRFSIGGEN_REPCAP_NR5GCARRIER_NR5GCARRIER13                         13
#define RSRFSIGGEN_REPCAP_NR5GCARRIER_NR5GCARRIER14                         14
#define RSRFSIGGEN_REPCAP_NR5GCARRIER_NR5GCARRIER15                         15
#define RSRFSIGGEN_REPCAP_NR5GCARRIER_NR5GCARRIER16                         16

//repcap NR5GInterlace
#define RSRFSIGGEN_REPCAP_NR5GINTERLACE_NR5GINTERLACE0                      0
#define RSRFSIGGEN_REPCAP_NR5GINTERLACE_NR5GINTERLACE1                      1
#define RSRFSIGGEN_REPCAP_NR5GINTERLACE_NR5GINTERLACE2                      2
#define RSRFSIGGEN_REPCAP_NR5GINTERLACE_NR5GINTERLACE3                      3
#define RSRFSIGGEN_REPCAP_NR5GINTERLACE_NR5GINTERLACE4                      4
#define RSRFSIGGEN_REPCAP_NR5GINTERLACE_NR5GINTERLACE5                      5
#define RSRFSIGGEN_REPCAP_NR5GINTERLACE_NR5GINTERLACE6                      6
#define RSRFSIGGEN_REPCAP_NR5GINTERLACE_NR5GINTERLACE7                      7
#define RSRFSIGGEN_REPCAP_NR5GINTERLACE_NR5GINTERLACE8                      8
#define RSRFSIGGEN_REPCAP_NR5GINTERLACE_NR5GINTERLACE9                      9

//repcap DVBSuperframe
#define RSRFSIGGEN_REPCAP_DVBSUPERFRAME_DVBSUPERFRAME1                      1
#define RSRFSIGGEN_REPCAP_DVBSUPERFRAME_DVBSUPERFRAME2                      2
#define RSRFSIGGEN_REPCAP_DVBSUPERFRAME_DVBSUPERFRAME3                      3
#define RSRFSIGGEN_REPCAP_DVBSUPERFRAME_DVBSUPERFRAME4                      4
#define RSRFSIGGEN_REPCAP_DVBSUPERFRAME_DVBSUPERFRAME5                      5
#define RSRFSIGGEN_REPCAP_DVBSUPERFRAME_DVBSUPERFRAME6                      6
#define RSRFSIGGEN_REPCAP_DVBSUPERFRAME_DVBSUPERFRAME7                      7
#define RSRFSIGGEN_REPCAP_DVBSUPERFRAME_DVBSUPERFRAME8                      8
#define RSRFSIGGEN_REPCAP_DVBSUPERFRAME_DVBSUPERFRAME9                      9
#define RSRFSIGGEN_REPCAP_DVBSUPERFRAME_DVBSUPERFRAME10                     10

//repcap DVBFrame
#define RSRFSIGGEN_REPCAP_DVBFRAME_DVBFRAME1                                1
#define RSRFSIGGEN_REPCAP_DVBFRAME_DVBFRAME2                                2
#define RSRFSIGGEN_REPCAP_DVBFRAME_DVBFRAME3                                3
#define RSRFSIGGEN_REPCAP_DVBFRAME_DVBFRAME4                                4
#define RSRFSIGGEN_REPCAP_DVBFRAME_DVBFRAME5                                5
#define RSRFSIGGEN_REPCAP_DVBFRAME_DVBFRAME6                                6
#define RSRFSIGGEN_REPCAP_DVBFRAME_DVBFRAME7                                7
#define RSRFSIGGEN_REPCAP_DVBFRAME_DVBFRAME8                                8
#define RSRFSIGGEN_REPCAP_DVBFRAME_DVBFRAME9                                9
#define RSRFSIGGEN_REPCAP_DVBFRAME_DVBFRAME10                               10

//repcap DVBGrid
#define RSRFSIGGEN_REPCAP_DVBGRID_DVBGRID1                                  1
#define RSRFSIGGEN_REPCAP_DVBGRID_DVBGRID2                                  2
#define RSRFSIGGEN_REPCAP_DVBGRID_DVBGRID3                                  3
#define RSRFSIGGEN_REPCAP_DVBGRID_DVBGRID4                                  4
#define RSRFSIGGEN_REPCAP_DVBGRID_DVBGRID5                                  5
#define RSRFSIGGEN_REPCAP_DVBGRID_DVBGRID6                                  6
#define RSRFSIGGEN_REPCAP_DVBGRID_DVBGRID7                                  7
#define RSRFSIGGEN_REPCAP_DVBGRID_DVBGRID8                                  8
#define RSRFSIGGEN_REPCAP_DVBGRID_DVBGRID9                                  9
#define RSRFSIGGEN_REPCAP_DVBGRID_DVBGRID10                                 10

//repcap DVBSection
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION0                            0
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION1                            1
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION2                            2
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION3                            3
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION4                            4
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION5                            5
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION6                            6
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION7                            7
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION8                            8
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION9                            9
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION10                           10
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION11                           11
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION12                           12
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION13                           13
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION14                           14
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION15                           15
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION16                           16
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION17                           17
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION18                           18
#define RSRFSIGGEN_REPCAP_DVBSECTION_DVBSECTION19                           19

//repcap DVBDT
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT1                                      1
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT2                                      2
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT3                                      3
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT4                                      4
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT5                                      5
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT6                                      6
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT7                                      7
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT8                                      8
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT9                                      9
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT10                                     10
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT11                                     11
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT12                                     12
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT13                                     13
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT14                                     14
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT15                                     15
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT16                                     16
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT17                                     17
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT18                                     18
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT19                                     19
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT20                                     20
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT21                                     21
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT22                                     22
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT23                                     23
#define RSRFSIGGEN_REPCAP_DVBDT_DVBDT24                                     24

//repcap Base
#define RSRFSIGGEN_REPCAP_BASE_BASE1                                        1
#define RSRFSIGGEN_REPCAP_BASE_BASE2                                        2
#define RSRFSIGGEN_REPCAP_BASE_BASE3                                        3
#define RSRFSIGGEN_REPCAP_BASE_BASE4                                        4
#define RSRFSIGGEN_REPCAP_BASE_BASE5                                        5
#define RSRFSIGGEN_REPCAP_BASE_BASE6                                        6
#define RSRFSIGGEN_REPCAP_BASE_BASE7                                        7
#define RSRFSIGGEN_REPCAP_BASE_BASE8                                        8
#define RSRFSIGGEN_REPCAP_BASE_BASE9                                        9
#define RSRFSIGGEN_REPCAP_BASE_BASE10                                       10
#define RSRFSIGGEN_REPCAP_BASE_BASE11                                       11
#define RSRFSIGGEN_REPCAP_BASE_BASE12                                       12
#define RSRFSIGGEN_REPCAP_BASE_BASE13                                       13
#define RSRFSIGGEN_REPCAP_BASE_BASE14                                       14
#define RSRFSIGGEN_REPCAP_BASE_BASE15                                       15
#define RSRFSIGGEN_REPCAP_BASE_BASE16                                       16
#define RSRFSIGGEN_REPCAP_BASE_BASE17                                       17
#define RSRFSIGGEN_REPCAP_BASE_BASE18                                       18
#define RSRFSIGGEN_REPCAP_BASE_BASE19                                       19
#define RSRFSIGGEN_REPCAP_BASE_BASE20                                       20
#define RSRFSIGGEN_REPCAP_BASE_BASE21                                       21
#define RSRFSIGGEN_REPCAP_BASE_BASE22                                       22
#define RSRFSIGGEN_REPCAP_BASE_BASE23                                       23
#define RSRFSIGGEN_REPCAP_BASE_BASE24                                       24
#define RSRFSIGGEN_REPCAP_BASE_BASE25                                       25
#define RSRFSIGGEN_REPCAP_BASE_BASE26                                       26
#define RSRFSIGGEN_REPCAP_BASE_BASE27                                       27
#define RSRFSIGGEN_REPCAP_BASE_BASE28                                       28
#define RSRFSIGGEN_REPCAP_BASE_BASE29                                       29
#define RSRFSIGGEN_REPCAP_BASE_BASE30                                       30
#define RSRFSIGGEN_REPCAP_BASE_BASE31                                       31
#define RSRFSIGGEN_REPCAP_BASE_BASE32                                       32
#define RSRFSIGGEN_REPCAP_BASE_BASE33                                       33
#define RSRFSIGGEN_REPCAP_BASE_BASE34                                       34
#define RSRFSIGGEN_REPCAP_BASE_BASE35                                       35
#define RSRFSIGGEN_REPCAP_BASE_BASE36                                       36
#define RSRFSIGGEN_REPCAP_BASE_BASE37                                       37
#define RSRFSIGGEN_REPCAP_BASE_BASE38                                       38
#define RSRFSIGGEN_REPCAP_BASE_BASE39                                       39
#define RSRFSIGGEN_REPCAP_BASE_BASE40                                       40
#define RSRFSIGGEN_REPCAP_BASE_BASE41                                       41
#define RSRFSIGGEN_REPCAP_BASE_BASE42                                       42
#define RSRFSIGGEN_REPCAP_BASE_BASE43                                       43
#define RSRFSIGGEN_REPCAP_BASE_BASE44                                       44
#define RSRFSIGGEN_REPCAP_BASE_BASE45                                       45
#define RSRFSIGGEN_REPCAP_BASE_BASE46                                       46
#define RSRFSIGGEN_REPCAP_BASE_BASE47                                       47
#define RSRFSIGGEN_REPCAP_BASE_BASE48                                       48
#define RSRFSIGGEN_REPCAP_BASE_BASE49                                       49
#define RSRFSIGGEN_REPCAP_BASE_BASE50                                       50
#define RSRFSIGGEN_REPCAP_BASE_BASE51                                       51
#define RSRFSIGGEN_REPCAP_BASE_BASE52                                       52
#define RSRFSIGGEN_REPCAP_BASE_BASE53                                       53
#define RSRFSIGGEN_REPCAP_BASE_BASE54                                       54
#define RSRFSIGGEN_REPCAP_BASE_BASE55                                       55
#define RSRFSIGGEN_REPCAP_BASE_BASE56                                       56
#define RSRFSIGGEN_REPCAP_BASE_BASE57                                       57
#define RSRFSIGGEN_REPCAP_BASE_BASE58                                       58
#define RSRFSIGGEN_REPCAP_BASE_BASE59                                       59
#define RSRFSIGGEN_REPCAP_BASE_BASE60                                       60
#define RSRFSIGGEN_REPCAP_BASE_BASE61                                       61
#define RSRFSIGGEN_REPCAP_BASE_BASE62                                       62
#define RSRFSIGGEN_REPCAP_BASE_BASE63                                       63
#define RSRFSIGGEN_REPCAP_BASE_BASE64                                       64
#define RSRFSIGGEN_REPCAP_BASE_BASE65                                       65
#define RSRFSIGGEN_REPCAP_BASE_BASE66                                       66
#define RSRFSIGGEN_REPCAP_BASE_BASE67                                       67
#define RSRFSIGGEN_REPCAP_BASE_BASE68                                       68
#define RSRFSIGGEN_REPCAP_BASE_BASE69                                       69
#define RSRFSIGGEN_REPCAP_BASE_BASE70                                       70
#define RSRFSIGGEN_REPCAP_BASE_BASE71                                       71
#define RSRFSIGGEN_REPCAP_BASE_BASE72                                       72
#define RSRFSIGGEN_REPCAP_BASE_BASE73                                       73
#define RSRFSIGGEN_REPCAP_BASE_BASE74                                       74
#define RSRFSIGGEN_REPCAP_BASE_BASE75                                       75
#define RSRFSIGGEN_REPCAP_BASE_BASE76                                       76
#define RSRFSIGGEN_REPCAP_BASE_BASE77                                       77
#define RSRFSIGGEN_REPCAP_BASE_BASE78                                       78
#define RSRFSIGGEN_REPCAP_BASE_BASE79                                       79
#define RSRFSIGGEN_REPCAP_BASE_BASE80                                       80
#define RSRFSIGGEN_REPCAP_BASE_BASE81                                       81
#define RSRFSIGGEN_REPCAP_BASE_BASE82                                       82
#define RSRFSIGGEN_REPCAP_BASE_BASE83                                       83
#define RSRFSIGGEN_REPCAP_BASE_BASE84                                       84
#define RSRFSIGGEN_REPCAP_BASE_BASE85                                       85
#define RSRFSIGGEN_REPCAP_BASE_BASE86                                       86
#define RSRFSIGGEN_REPCAP_BASE_BASE87                                       87
#define RSRFSIGGEN_REPCAP_BASE_BASE88                                       88
#define RSRFSIGGEN_REPCAP_BASE_BASE89                                       89
#define RSRFSIGGEN_REPCAP_BASE_BASE90                                       90
#define RSRFSIGGEN_REPCAP_BASE_BASE91                                       91
#define RSRFSIGGEN_REPCAP_BASE_BASE92                                       92
#define RSRFSIGGEN_REPCAP_BASE_BASE93                                       93
#define RSRFSIGGEN_REPCAP_BASE_BASE94                                       94
#define RSRFSIGGEN_REPCAP_BASE_BASE95                                       95
#define RSRFSIGGEN_REPCAP_BASE_BASE96                                       96
#define RSRFSIGGEN_REPCAP_BASE_BASE97                                       97
#define RSRFSIGGEN_REPCAP_BASE_BASE98                                       98
#define RSRFSIGGEN_REPCAP_BASE_BASE99                                       99
#define RSRFSIGGEN_REPCAP_BASE_BASE100                                      100

//repcap RTKAntenna
#define RSRFSIGGEN_REPCAP_RTKANTENNA_RTKA1                                  1
#define RSRFSIGGEN_REPCAP_RTKANTENNA_RTKA2                                  2
#define RSRFSIGGEN_REPCAP_RTKANTENNA_RTKA3                                  3
#define RSRFSIGGEN_REPCAP_RTKANTENNA_RTKA4                                  4

//repcap DCIInstance
#define RSRFSIGGEN_REPCAP_DCIINSTANCE_DCII1                                 1
#define RSRFSIGGEN_REPCAP_DCIINSTANCE_DCII2                                 2
#define RSRFSIGGEN_REPCAP_DCIINSTANCE_DCII3                                 3
#define RSRFSIGGEN_REPCAP_DCIINSTANCE_DCII4                                 4
#define RSRFSIGGEN_REPCAP_DCIINSTANCE_DCII5                                 5
#define RSRFSIGGEN_REPCAP_DCIINSTANCE_DCII6                                 6
#define RSRFSIGGEN_REPCAP_DCIINSTANCE_DCII7                                 7
#define RSRFSIGGEN_REPCAP_DCIINSTANCE_DCII8                                 8

//repcap ExternalDevice
#define RSRFSIGGEN_REPCAP_EXTERNALDEVICE_EXTDEV1                            1
#define RSRFSIGGEN_REPCAP_EXTERNALDEVICE_EXTDEV2                            2
#define RSRFSIGGEN_REPCAP_EXTERNALDEVICE_EXTDEV3                            3
#define RSRFSIGGEN_REPCAP_EXTERNALDEVICE_EXTDEV4                            4
#define RSRFSIGGEN_REPCAP_EXTERNALDEVICE_EXTDEV5                            5
#define RSRFSIGGEN_REPCAP_EXTERNALDEVICE_EXTDEV6                            6
#define RSRFSIGGEN_REPCAP_EXTERNALDEVICE_EXTDEV7                            7
#define RSRFSIGGEN_REPCAP_EXTERNALDEVICE_EXTDEV8                            8
#define RSRFSIGGEN_REPCAP_EXTERNALDEVICE_EXTDEV9                            9
#define RSRFSIGGEN_REPCAP_EXTERNALDEVICE_EXTDEV10                           10

//repcap FrontendPort
#define RSRFSIGGEN_REPCAP_FRONTENDPORT_FRONTPORT1                           1
#define RSRFSIGGEN_REPCAP_FRONTENDPORT_FRONTPORT2                           2
#define RSRFSIGGEN_REPCAP_FRONTENDPORT_FRONTPORT3                           3
#define RSRFSIGGEN_REPCAP_FRONTENDPORT_FRONTPORT4                           4
#define RSRFSIGGEN_REPCAP_FRONTENDPORT_FRONTPORT5                           5
#define RSRFSIGGEN_REPCAP_FRONTENDPORT_FRONTPORT6                           6
#define RSRFSIGGEN_REPCAP_FRONTENDPORT_FRONTPORT7                           7
#define RSRFSIGGEN_REPCAP_FRONTENDPORT_FRONTPORT8                           8
#define RSRFSIGGEN_REPCAP_FRONTENDPORT_FRONTPORT9                           9
#define RSRFSIGGEN_REPCAP_FRONTENDPORT_FRONTPORT10                          10

//repcap OFDMConPoint
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP0                              0
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1                              1
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2                              2
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3                              3
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4                              4
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP5                              5
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP6                              6
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP7                              7
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP8                              8
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP9                              9
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP10                             10
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP11                             11
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP12                             12
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP13                             13
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP14                             14
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP15                             15
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP16                             16
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP17                             17
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP18                             18
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP19                             19
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP20                             20
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP21                             21
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP22                             22
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP23                             23
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP24                             24
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP25                             25
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP26                             26
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP27                             27
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP28                             28
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP29                             29
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP30                             30
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP31                             31
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP32                             32
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP33                             33
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP34                             34
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP35                             35
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP36                             36
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP37                             37
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP38                             38
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP39                             39
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP40                             40
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP41                             41
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP42                             42
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP43                             43
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP44                             44
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP45                             45
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP46                             46
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP47                             47
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP48                             48
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP49                             49
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP50                             50
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP51                             51
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP52                             52
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP53                             53
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP54                             54
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP55                             55
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP56                             56
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP57                             57
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP58                             58
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP59                             59
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP60                             60
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP61                             61
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP62                             62
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP63                             63
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP64                             64
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP65                             65
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP66                             66
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP67                             67
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP68                             68
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP69                             69
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP70                             70
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP71                             71
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP72                             72
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP73                             73
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP74                             74
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP75                             75
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP76                             76
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP77                             77
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP78                             78
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP79                             79
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP80                             80
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP81                             81
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP82                             82
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP83                             83
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP84                             84
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP85                             85
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP86                             86
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP87                             87
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP88                             88
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP89                             89
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP90                             90
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP91                             91
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP92                             92
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP93                             93
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP94                             94
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP95                             95
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP96                             96
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP97                             97
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP98                             98
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP99                             99
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP100                            100
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP101                            101
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP102                            102
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP103                            103
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP104                            104
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP105                            105
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP106                            106
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP107                            107
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP108                            108
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP109                            109
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP110                            110
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP111                            111
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP112                            112
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP113                            113
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP114                            114
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP115                            115
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP116                            116
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP117                            117
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP118                            118
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP119                            119
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP120                            120
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP121                            121
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP122                            122
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP123                            123
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP124                            124
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP125                            125
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP126                            126
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP127                            127
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP128                            128
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP129                            129
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP130                            130
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP131                            131
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP132                            132
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP133                            133
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP134                            134
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP135                            135
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP136                            136
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP137                            137
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP138                            138
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP139                            139
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP140                            140
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP141                            141
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP142                            142
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP143                            143
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP144                            144
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP145                            145
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP146                            146
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP147                            147
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP148                            148
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP149                            149
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP150                            150
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP151                            151
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP152                            152
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP153                            153
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP154                            154
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP155                            155
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP156                            156
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP157                            157
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP158                            158
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP159                            159
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP160                            160
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP161                            161
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP162                            162
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP163                            163
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP164                            164
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP165                            165
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP166                            166
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP167                            167
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP168                            168
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP169                            169
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP170                            170
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP171                            171
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP172                            172
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP173                            173
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP174                            174
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP175                            175
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP176                            176
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP177                            177
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP178                            178
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP179                            179
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP180                            180
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP181                            181
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP182                            182
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP183                            183
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP184                            184
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP185                            185
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP186                            186
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP187                            187
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP188                            188
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP189                            189
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP190                            190
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP191                            191
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP192                            192
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP193                            193
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP194                            194
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP195                            195
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP196                            196
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP197                            197
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP198                            198
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP199                            199
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP200                            200
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP201                            201
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP202                            202
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP203                            203
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP204                            204
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP205                            205
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP206                            206
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP207                            207
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP208                            208
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP209                            209
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP210                            210
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP211                            211
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP212                            212
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP213                            213
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP214                            214
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP215                            215
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP216                            216
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP217                            217
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP218                            218
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP219                            219
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP220                            220
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP221                            221
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP222                            222
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP223                            223
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP224                            224
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP225                            225
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP226                            226
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP227                            227
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP228                            228
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP229                            229
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP230                            230
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP231                            231
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP232                            232
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP233                            233
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP234                            234
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP235                            235
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP236                            236
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP237                            237
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP238                            238
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP239                            239
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP240                            240
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP241                            241
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP242                            242
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP243                            243
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP244                            244
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP245                            245
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP246                            246
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP247                            247
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP248                            248
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP249                            249
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP250                            250
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP251                            251
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP252                            252
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP253                            253
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP254                            254
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP255                            255
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP256                            256
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP257                            257
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP258                            258
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP259                            259
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP260                            260
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP261                            261
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP262                            262
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP263                            263
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP264                            264
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP265                            265
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP266                            266
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP267                            267
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP268                            268
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP269                            269
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP270                            270
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP271                            271
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP272                            272
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP273                            273
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP274                            274
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP275                            275
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP276                            276
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP277                            277
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP278                            278
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP279                            279
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP280                            280
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP281                            281
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP282                            282
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP283                            283
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP284                            284
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP285                            285
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP286                            286
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP287                            287
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP288                            288
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP289                            289
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP290                            290
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP291                            291
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP292                            292
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP293                            293
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP294                            294
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP295                            295
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP296                            296
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP297                            297
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP298                            298
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP299                            299
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP300                            300
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP301                            301
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP302                            302
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP303                            303
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP304                            304
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP305                            305
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP306                            306
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP307                            307
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP308                            308
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP309                            309
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP310                            310
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP311                            311
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP312                            312
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP313                            313
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP314                            314
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP315                            315
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP316                            316
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP317                            317
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP318                            318
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP319                            319
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP320                            320
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP321                            321
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP322                            322
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP323                            323
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP324                            324
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP325                            325
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP326                            326
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP327                            327
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP328                            328
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP329                            329
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP330                            330
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP331                            331
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP332                            332
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP333                            333
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP334                            334
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP335                            335
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP336                            336
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP337                            337
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP338                            338
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP339                            339
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP340                            340
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP341                            341
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP342                            342
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP343                            343
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP344                            344
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP345                            345
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP346                            346
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP347                            347
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP348                            348
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP349                            349
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP350                            350
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP351                            351
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP352                            352
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP353                            353
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP354                            354
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP355                            355
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP356                            356
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP357                            357
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP358                            358
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP359                            359
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP360                            360
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP361                            361
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP362                            362
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP363                            363
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP364                            364
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP365                            365
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP366                            366
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP367                            367
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP368                            368
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP369                            369
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP370                            370
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP371                            371
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP372                            372
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP373                            373
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP374                            374
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP375                            375
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP376                            376
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP377                            377
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP378                            378
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP379                            379
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP380                            380
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP381                            381
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP382                            382
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP383                            383
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP384                            384
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP385                            385
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP386                            386
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP387                            387
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP388                            388
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP389                            389
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP390                            390
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP391                            391
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP392                            392
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP393                            393
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP394                            394
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP395                            395
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP396                            396
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP397                            397
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP398                            398
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP399                            399
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP400                            400
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP401                            401
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP402                            402
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP403                            403
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP404                            404
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP405                            405
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP406                            406
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP407                            407
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP408                            408
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP409                            409
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP410                            410
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP411                            411
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP412                            412
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP413                            413
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP414                            414
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP415                            415
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP416                            416
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP417                            417
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP418                            418
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP419                            419
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP420                            420
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP421                            421
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP422                            422
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP423                            423
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP424                            424
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP425                            425
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP426                            426
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP427                            427
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP428                            428
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP429                            429
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP430                            430
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP431                            431
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP432                            432
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP433                            433
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP434                            434
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP435                            435
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP436                            436
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP437                            437
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP438                            438
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP439                            439
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP440                            440
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP441                            441
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP442                            442
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP443                            443
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP444                            444
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP445                            445
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP446                            446
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP447                            447
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP448                            448
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP449                            449
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP450                            450
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP451                            451
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP452                            452
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP453                            453
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP454                            454
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP455                            455
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP456                            456
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP457                            457
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP458                            458
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP459                            459
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP460                            460
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP461                            461
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP462                            462
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP463                            463
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP464                            464
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP465                            465
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP466                            466
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP467                            467
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP468                            468
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP469                            469
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP470                            470
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP471                            471
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP472                            472
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP473                            473
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP474                            474
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP475                            475
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP476                            476
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP477                            477
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP478                            478
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP479                            479
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP480                            480
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP481                            481
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP482                            482
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP483                            483
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP484                            484
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP485                            485
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP486                            486
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP487                            487
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP488                            488
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP489                            489
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP490                            490
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP491                            491
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP492                            492
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP493                            493
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP494                            494
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP495                            495
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP496                            496
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP497                            497
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP498                            498
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP499                            499
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP500                            500
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP501                            501
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP502                            502
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP503                            503
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP504                            504
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP505                            505
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP506                            506
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP507                            507
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP508                            508
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP509                            509
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP510                            510
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP511                            511
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP512                            512
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP513                            513
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP514                            514
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP515                            515
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP516                            516
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP517                            517
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP518                            518
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP519                            519
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP520                            520
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP521                            521
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP522                            522
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP523                            523
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP524                            524
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP525                            525
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP526                            526
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP527                            527
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP528                            528
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP529                            529
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP530                            530
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP531                            531
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP532                            532
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP533                            533
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP534                            534
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP535                            535
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP536                            536
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP537                            537
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP538                            538
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP539                            539
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP540                            540
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP541                            541
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP542                            542
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP543                            543
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP544                            544
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP545                            545
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP546                            546
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP547                            547
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP548                            548
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP549                            549
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP550                            550
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP551                            551
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP552                            552
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP553                            553
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP554                            554
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP555                            555
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP556                            556
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP557                            557
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP558                            558
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP559                            559
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP560                            560
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP561                            561
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP562                            562
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP563                            563
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP564                            564
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP565                            565
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP566                            566
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP567                            567
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP568                            568
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP569                            569
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP570                            570
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP571                            571
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP572                            572
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP573                            573
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP574                            574
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP575                            575
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP576                            576
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP577                            577
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP578                            578
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP579                            579
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP580                            580
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP581                            581
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP582                            582
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP583                            583
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP584                            584
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP585                            585
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP586                            586
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP587                            587
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP588                            588
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP589                            589
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP590                            590
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP591                            591
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP592                            592
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP593                            593
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP594                            594
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP595                            595
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP596                            596
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP597                            597
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP598                            598
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP599                            599
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP600                            600
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP601                            601
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP602                            602
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP603                            603
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP604                            604
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP605                            605
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP606                            606
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP607                            607
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP608                            608
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP609                            609
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP610                            610
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP611                            611
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP612                            612
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP613                            613
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP614                            614
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP615                            615
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP616                            616
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP617                            617
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP618                            618
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP619                            619
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP620                            620
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP621                            621
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP622                            622
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP623                            623
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP624                            624
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP625                            625
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP626                            626
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP627                            627
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP628                            628
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP629                            629
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP630                            630
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP631                            631
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP632                            632
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP633                            633
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP634                            634
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP635                            635
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP636                            636
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP637                            637
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP638                            638
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP639                            639
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP640                            640
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP641                            641
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP642                            642
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP643                            643
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP644                            644
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP645                            645
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP646                            646
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP647                            647
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP648                            648
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP649                            649
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP650                            650
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP651                            651
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP652                            652
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP653                            653
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP654                            654
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP655                            655
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP656                            656
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP657                            657
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP658                            658
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP659                            659
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP660                            660
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP661                            661
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP662                            662
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP663                            663
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP664                            664
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP665                            665
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP666                            666
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP667                            667
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP668                            668
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP669                            669
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP670                            670
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP671                            671
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP672                            672
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP673                            673
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP674                            674
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP675                            675
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP676                            676
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP677                            677
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP678                            678
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP679                            679
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP680                            680
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP681                            681
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP682                            682
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP683                            683
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP684                            684
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP685                            685
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP686                            686
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP687                            687
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP688                            688
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP689                            689
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP690                            690
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP691                            691
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP692                            692
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP693                            693
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP694                            694
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP695                            695
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP696                            696
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP697                            697
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP698                            698
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP699                            699
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP700                            700
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP701                            701
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP702                            702
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP703                            703
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP704                            704
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP705                            705
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP706                            706
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP707                            707
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP708                            708
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP709                            709
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP710                            710
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP711                            711
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP712                            712
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP713                            713
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP714                            714
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP715                            715
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP716                            716
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP717                            717
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP718                            718
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP719                            719
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP720                            720
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP721                            721
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP722                            722
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP723                            723
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP724                            724
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP725                            725
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP726                            726
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP727                            727
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP728                            728
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP729                            729
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP730                            730
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP731                            731
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP732                            732
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP733                            733
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP734                            734
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP735                            735
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP736                            736
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP737                            737
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP738                            738
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP739                            739
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP740                            740
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP741                            741
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP742                            742
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP743                            743
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP744                            744
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP745                            745
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP746                            746
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP747                            747
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP748                            748
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP749                            749
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP750                            750
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP751                            751
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP752                            752
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP753                            753
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP754                            754
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP755                            755
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP756                            756
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP757                            757
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP758                            758
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP759                            759
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP760                            760
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP761                            761
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP762                            762
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP763                            763
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP764                            764
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP765                            765
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP766                            766
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP767                            767
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP768                            768
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP769                            769
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP770                            770
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP771                            771
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP772                            772
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP773                            773
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP774                            774
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP775                            775
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP776                            776
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP777                            777
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP778                            778
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP779                            779
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP780                            780
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP781                            781
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP782                            782
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP783                            783
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP784                            784
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP785                            785
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP786                            786
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP787                            787
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP788                            788
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP789                            789
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP790                            790
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP791                            791
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP792                            792
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP793                            793
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP794                            794
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP795                            795
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP796                            796
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP797                            797
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP798                            798
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP799                            799
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP800                            800
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP801                            801
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP802                            802
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP803                            803
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP804                            804
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP805                            805
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP806                            806
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP807                            807
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP808                            808
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP809                            809
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP810                            810
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP811                            811
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP812                            812
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP813                            813
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP814                            814
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP815                            815
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP816                            816
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP817                            817
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP818                            818
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP819                            819
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP820                            820
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP821                            821
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP822                            822
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP823                            823
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP824                            824
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP825                            825
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP826                            826
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP827                            827
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP828                            828
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP829                            829
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP830                            830
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP831                            831
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP832                            832
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP833                            833
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP834                            834
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP835                            835
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP836                            836
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP837                            837
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP838                            838
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP839                            839
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP840                            840
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP841                            841
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP842                            842
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP843                            843
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP844                            844
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP845                            845
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP846                            846
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP847                            847
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP848                            848
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP849                            849
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP850                            850
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP851                            851
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP852                            852
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP853                            853
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP854                            854
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP855                            855
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP856                            856
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP857                            857
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP858                            858
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP859                            859
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP860                            860
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP861                            861
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP862                            862
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP863                            863
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP864                            864
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP865                            865
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP866                            866
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP867                            867
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP868                            868
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP869                            869
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP870                            870
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP871                            871
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP872                            872
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP873                            873
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP874                            874
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP875                            875
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP876                            876
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP877                            877
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP878                            878
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP879                            879
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP880                            880
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP881                            881
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP882                            882
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP883                            883
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP884                            884
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP885                            885
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP886                            886
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP887                            887
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP888                            888
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP889                            889
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP890                            890
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP891                            891
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP892                            892
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP893                            893
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP894                            894
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP895                            895
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP896                            896
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP897                            897
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP898                            898
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP899                            899
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP900                            900
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP901                            901
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP902                            902
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP903                            903
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP904                            904
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP905                            905
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP906                            906
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP907                            907
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP908                            908
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP909                            909
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP910                            910
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP911                            911
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP912                            912
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP913                            913
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP914                            914
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP915                            915
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP916                            916
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP917                            917
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP918                            918
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP919                            919
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP920                            920
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP921                            921
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP922                            922
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP923                            923
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP924                            924
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP925                            925
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP926                            926
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP927                            927
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP928                            928
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP929                            929
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP930                            930
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP931                            931
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP932                            932
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP933                            933
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP934                            934
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP935                            935
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP936                            936
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP937                            937
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP938                            938
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP939                            939
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP940                            940
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP941                            941
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP942                            942
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP943                            943
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP944                            944
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP945                            945
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP946                            946
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP947                            947
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP948                            948
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP949                            949
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP950                            950
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP951                            951
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP952                            952
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP953                            953
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP954                            954
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP955                            955
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP956                            956
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP957                            957
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP958                            958
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP959                            959
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP960                            960
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP961                            961
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP962                            962
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP963                            963
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP964                            964
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP965                            965
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP966                            966
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP967                            967
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP968                            968
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP969                            969
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP970                            970
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP971                            971
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP972                            972
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP973                            973
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP974                            974
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP975                            975
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP976                            976
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP977                            977
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP978                            978
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP979                            979
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP980                            980
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP981                            981
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP982                            982
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP983                            983
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP984                            984
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP985                            985
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP986                            986
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP987                            987
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP988                            988
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP989                            989
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP990                            990
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP991                            991
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP992                            992
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP993                            993
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP994                            994
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP995                            995
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP996                            996
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP997                            997
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP998                            998
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP999                            999
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1000                           1000
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1001                           1001
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1002                           1002
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1003                           1003
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1004                           1004
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1005                           1005
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1006                           1006
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1007                           1007
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1008                           1008
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1009                           1009
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1010                           1010
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1011                           1011
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1012                           1012
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1013                           1013
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1014                           1014
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1015                           1015
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1016                           1016
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1017                           1017
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1018                           1018
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1019                           1019
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1020                           1020
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1021                           1021
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1022                           1022
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1023                           1023
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1024                           1024
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1025                           1025
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1026                           1026
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1027                           1027
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1028                           1028
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1029                           1029
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1030                           1030
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1031                           1031
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1032                           1032
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1033                           1033
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1034                           1034
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1035                           1035
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1036                           1036
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1037                           1037
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1038                           1038
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1039                           1039
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1040                           1040
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1041                           1041
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1042                           1042
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1043                           1043
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1044                           1044
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1045                           1045
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1046                           1046
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1047                           1047
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1048                           1048
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1049                           1049
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1050                           1050
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1051                           1051
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1052                           1052
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1053                           1053
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1054                           1054
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1055                           1055
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1056                           1056
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1057                           1057
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1058                           1058
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1059                           1059
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1060                           1060
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1061                           1061
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1062                           1062
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1063                           1063
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1064                           1064
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1065                           1065
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1066                           1066
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1067                           1067
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1068                           1068
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1069                           1069
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1070                           1070
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1071                           1071
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1072                           1072
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1073                           1073
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1074                           1074
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1075                           1075
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1076                           1076
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1077                           1077
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1078                           1078
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1079                           1079
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1080                           1080
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1081                           1081
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1082                           1082
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1083                           1083
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1084                           1084
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1085                           1085
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1086                           1086
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1087                           1087
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1088                           1088
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1089                           1089
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1090                           1090
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1091                           1091
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1092                           1092
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1093                           1093
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1094                           1094
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1095                           1095
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1096                           1096
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1097                           1097
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1098                           1098
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1099                           1099
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1100                           1100
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1101                           1101
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1102                           1102
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1103                           1103
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1104                           1104
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1105                           1105
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1106                           1106
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1107                           1107
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1108                           1108
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1109                           1109
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1110                           1110
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1111                           1111
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1112                           1112
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1113                           1113
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1114                           1114
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1115                           1115
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1116                           1116
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1117                           1117
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1118                           1118
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1119                           1119
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1120                           1120
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1121                           1121
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1122                           1122
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1123                           1123
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1124                           1124
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1125                           1125
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1126                           1126
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1127                           1127
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1128                           1128
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1129                           1129
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1130                           1130
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1131                           1131
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1132                           1132
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1133                           1133
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1134                           1134
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1135                           1135
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1136                           1136
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1137                           1137
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1138                           1138
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1139                           1139
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1140                           1140
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1141                           1141
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1142                           1142
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1143                           1143
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1144                           1144
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1145                           1145
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1146                           1146
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1147                           1147
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1148                           1148
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1149                           1149
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1150                           1150
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1151                           1151
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1152                           1152
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1153                           1153
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1154                           1154
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1155                           1155
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1156                           1156
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1157                           1157
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1158                           1158
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1159                           1159
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1160                           1160
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1161                           1161
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1162                           1162
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1163                           1163
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1164                           1164
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1165                           1165
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1166                           1166
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1167                           1167
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1168                           1168
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1169                           1169
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1170                           1170
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1171                           1171
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1172                           1172
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1173                           1173
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1174                           1174
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1175                           1175
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1176                           1176
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1177                           1177
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1178                           1178
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1179                           1179
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1180                           1180
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1181                           1181
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1182                           1182
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1183                           1183
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1184                           1184
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1185                           1185
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1186                           1186
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1187                           1187
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1188                           1188
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1189                           1189
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1190                           1190
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1191                           1191
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1192                           1192
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1193                           1193
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1194                           1194
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1195                           1195
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1196                           1196
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1197                           1197
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1198                           1198
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1199                           1199
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1200                           1200
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1201                           1201
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1202                           1202
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1203                           1203
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1204                           1204
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1205                           1205
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1206                           1206
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1207                           1207
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1208                           1208
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1209                           1209
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1210                           1210
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1211                           1211
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1212                           1212
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1213                           1213
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1214                           1214
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1215                           1215
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1216                           1216
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1217                           1217
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1218                           1218
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1219                           1219
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1220                           1220
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1221                           1221
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1222                           1222
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1223                           1223
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1224                           1224
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1225                           1225
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1226                           1226
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1227                           1227
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1228                           1228
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1229                           1229
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1230                           1230
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1231                           1231
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1232                           1232
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1233                           1233
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1234                           1234
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1235                           1235
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1236                           1236
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1237                           1237
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1238                           1238
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1239                           1239
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1240                           1240
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1241                           1241
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1242                           1242
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1243                           1243
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1244                           1244
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1245                           1245
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1246                           1246
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1247                           1247
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1248                           1248
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1249                           1249
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1250                           1250
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1251                           1251
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1252                           1252
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1253                           1253
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1254                           1254
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1255                           1255
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1256                           1256
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1257                           1257
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1258                           1258
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1259                           1259
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1260                           1260
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1261                           1261
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1262                           1262
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1263                           1263
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1264                           1264
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1265                           1265
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1266                           1266
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1267                           1267
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1268                           1268
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1269                           1269
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1270                           1270
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1271                           1271
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1272                           1272
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1273                           1273
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1274                           1274
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1275                           1275
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1276                           1276
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1277                           1277
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1278                           1278
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1279                           1279
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1280                           1280
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1281                           1281
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1282                           1282
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1283                           1283
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1284                           1284
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1285                           1285
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1286                           1286
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1287                           1287
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1288                           1288
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1289                           1289
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1290                           1290
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1291                           1291
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1292                           1292
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1293                           1293
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1294                           1294
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1295                           1295
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1296                           1296
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1297                           1297
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1298                           1298
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1299                           1299
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1300                           1300
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1301                           1301
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1302                           1302
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1303                           1303
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1304                           1304
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1305                           1305
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1306                           1306
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1307                           1307
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1308                           1308
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1309                           1309
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1310                           1310
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1311                           1311
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1312                           1312
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1313                           1313
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1314                           1314
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1315                           1315
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1316                           1316
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1317                           1317
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1318                           1318
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1319                           1319
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1320                           1320
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1321                           1321
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1322                           1322
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1323                           1323
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1324                           1324
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1325                           1325
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1326                           1326
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1327                           1327
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1328                           1328
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1329                           1329
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1330                           1330
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1331                           1331
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1332                           1332
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1333                           1333
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1334                           1334
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1335                           1335
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1336                           1336
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1337                           1337
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1338                           1338
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1339                           1339
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1340                           1340
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1341                           1341
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1342                           1342
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1343                           1343
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1344                           1344
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1345                           1345
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1346                           1346
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1347                           1347
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1348                           1348
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1349                           1349
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1350                           1350
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1351                           1351
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1352                           1352
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1353                           1353
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1354                           1354
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1355                           1355
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1356                           1356
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1357                           1357
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1358                           1358
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1359                           1359
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1360                           1360
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1361                           1361
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1362                           1362
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1363                           1363
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1364                           1364
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1365                           1365
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1366                           1366
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1367                           1367
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1368                           1368
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1369                           1369
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1370                           1370
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1371                           1371
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1372                           1372
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1373                           1373
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1374                           1374
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1375                           1375
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1376                           1376
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1377                           1377
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1378                           1378
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1379                           1379
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1380                           1380
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1381                           1381
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1382                           1382
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1383                           1383
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1384                           1384
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1385                           1385
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1386                           1386
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1387                           1387
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1388                           1388
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1389                           1389
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1390                           1390
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1391                           1391
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1392                           1392
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1393                           1393
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1394                           1394
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1395                           1395
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1396                           1396
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1397                           1397
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1398                           1398
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1399                           1399
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1400                           1400
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1401                           1401
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1402                           1402
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1403                           1403
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1404                           1404
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1405                           1405
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1406                           1406
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1407                           1407
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1408                           1408
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1409                           1409
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1410                           1410
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1411                           1411
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1412                           1412
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1413                           1413
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1414                           1414
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1415                           1415
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1416                           1416
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1417                           1417
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1418                           1418
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1419                           1419
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1420                           1420
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1421                           1421
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1422                           1422
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1423                           1423
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1424                           1424
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1425                           1425
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1426                           1426
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1427                           1427
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1428                           1428
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1429                           1429
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1430                           1430
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1431                           1431
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1432                           1432
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1433                           1433
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1434                           1434
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1435                           1435
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1436                           1436
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1437                           1437
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1438                           1438
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1439                           1439
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1440                           1440
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1441                           1441
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1442                           1442
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1443                           1443
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1444                           1444
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1445                           1445
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1446                           1446
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1447                           1447
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1448                           1448
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1449                           1449
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1450                           1450
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1451                           1451
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1452                           1452
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1453                           1453
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1454                           1454
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1455                           1455
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1456                           1456
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1457                           1457
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1458                           1458
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1459                           1459
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1460                           1460
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1461                           1461
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1462                           1462
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1463                           1463
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1464                           1464
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1465                           1465
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1466                           1466
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1467                           1467
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1468                           1468
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1469                           1469
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1470                           1470
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1471                           1471
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1472                           1472
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1473                           1473
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1474                           1474
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1475                           1475
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1476                           1476
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1477                           1477
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1478                           1478
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1479                           1479
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1480                           1480
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1481                           1481
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1482                           1482
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1483                           1483
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1484                           1484
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1485                           1485
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1486                           1486
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1487                           1487
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1488                           1488
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1489                           1489
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1490                           1490
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1491                           1491
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1492                           1492
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1493                           1493
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1494                           1494
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1495                           1495
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1496                           1496
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1497                           1497
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1498                           1498
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1499                           1499
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1500                           1500
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1501                           1501
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1502                           1502
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1503                           1503
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1504                           1504
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1505                           1505
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1506                           1506
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1507                           1507
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1508                           1508
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1509                           1509
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1510                           1510
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1511                           1511
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1512                           1512
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1513                           1513
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1514                           1514
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1515                           1515
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1516                           1516
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1517                           1517
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1518                           1518
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1519                           1519
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1520                           1520
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1521                           1521
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1522                           1522
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1523                           1523
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1524                           1524
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1525                           1525
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1526                           1526
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1527                           1527
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1528                           1528
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1529                           1529
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1530                           1530
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1531                           1531
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1532                           1532
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1533                           1533
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1534                           1534
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1535                           1535
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1536                           1536
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1537                           1537
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1538                           1538
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1539                           1539
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1540                           1540
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1541                           1541
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1542                           1542
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1543                           1543
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1544                           1544
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1545                           1545
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1546                           1546
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1547                           1547
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1548                           1548
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1549                           1549
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1550                           1550
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1551                           1551
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1552                           1552
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1553                           1553
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1554                           1554
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1555                           1555
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1556                           1556
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1557                           1557
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1558                           1558
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1559                           1559
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1560                           1560
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1561                           1561
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1562                           1562
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1563                           1563
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1564                           1564
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1565                           1565
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1566                           1566
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1567                           1567
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1568                           1568
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1569                           1569
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1570                           1570
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1571                           1571
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1572                           1572
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1573                           1573
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1574                           1574
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1575                           1575
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1576                           1576
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1577                           1577
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1578                           1578
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1579                           1579
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1580                           1580
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1581                           1581
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1582                           1582
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1583                           1583
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1584                           1584
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1585                           1585
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1586                           1586
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1587                           1587
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1588                           1588
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1589                           1589
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1590                           1590
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1591                           1591
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1592                           1592
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1593                           1593
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1594                           1594
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1595                           1595
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1596                           1596
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1597                           1597
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1598                           1598
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1599                           1599
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1600                           1600
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1601                           1601
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1602                           1602
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1603                           1603
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1604                           1604
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1605                           1605
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1606                           1606
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1607                           1607
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1608                           1608
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1609                           1609
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1610                           1610
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1611                           1611
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1612                           1612
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1613                           1613
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1614                           1614
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1615                           1615
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1616                           1616
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1617                           1617
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1618                           1618
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1619                           1619
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1620                           1620
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1621                           1621
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1622                           1622
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1623                           1623
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1624                           1624
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1625                           1625
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1626                           1626
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1627                           1627
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1628                           1628
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1629                           1629
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1630                           1630
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1631                           1631
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1632                           1632
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1633                           1633
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1634                           1634
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1635                           1635
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1636                           1636
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1637                           1637
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1638                           1638
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1639                           1639
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1640                           1640
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1641                           1641
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1642                           1642
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1643                           1643
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1644                           1644
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1645                           1645
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1646                           1646
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1647                           1647
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1648                           1648
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1649                           1649
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1650                           1650
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1651                           1651
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1652                           1652
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1653                           1653
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1654                           1654
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1655                           1655
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1656                           1656
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1657                           1657
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1658                           1658
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1659                           1659
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1660                           1660
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1661                           1661
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1662                           1662
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1663                           1663
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1664                           1664
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1665                           1665
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1666                           1666
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1667                           1667
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1668                           1668
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1669                           1669
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1670                           1670
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1671                           1671
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1672                           1672
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1673                           1673
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1674                           1674
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1675                           1675
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1676                           1676
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1677                           1677
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1678                           1678
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1679                           1679
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1680                           1680
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1681                           1681
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1682                           1682
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1683                           1683
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1684                           1684
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1685                           1685
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1686                           1686
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1687                           1687
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1688                           1688
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1689                           1689
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1690                           1690
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1691                           1691
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1692                           1692
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1693                           1693
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1694                           1694
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1695                           1695
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1696                           1696
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1697                           1697
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1698                           1698
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1699                           1699
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1700                           1700
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1701                           1701
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1702                           1702
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1703                           1703
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1704                           1704
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1705                           1705
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1706                           1706
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1707                           1707
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1708                           1708
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1709                           1709
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1710                           1710
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1711                           1711
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1712                           1712
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1713                           1713
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1714                           1714
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1715                           1715
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1716                           1716
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1717                           1717
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1718                           1718
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1719                           1719
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1720                           1720
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1721                           1721
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1722                           1722
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1723                           1723
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1724                           1724
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1725                           1725
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1726                           1726
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1727                           1727
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1728                           1728
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1729                           1729
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1730                           1730
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1731                           1731
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1732                           1732
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1733                           1733
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1734                           1734
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1735                           1735
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1736                           1736
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1737                           1737
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1738                           1738
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1739                           1739
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1740                           1740
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1741                           1741
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1742                           1742
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1743                           1743
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1744                           1744
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1745                           1745
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1746                           1746
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1747                           1747
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1748                           1748
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1749                           1749
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1750                           1750
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1751                           1751
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1752                           1752
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1753                           1753
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1754                           1754
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1755                           1755
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1756                           1756
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1757                           1757
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1758                           1758
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1759                           1759
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1760                           1760
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1761                           1761
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1762                           1762
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1763                           1763
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1764                           1764
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1765                           1765
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1766                           1766
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1767                           1767
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1768                           1768
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1769                           1769
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1770                           1770
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1771                           1771
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1772                           1772
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1773                           1773
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1774                           1774
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1775                           1775
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1776                           1776
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1777                           1777
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1778                           1778
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1779                           1779
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1780                           1780
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1781                           1781
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1782                           1782
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1783                           1783
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1784                           1784
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1785                           1785
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1786                           1786
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1787                           1787
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1788                           1788
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1789                           1789
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1790                           1790
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1791                           1791
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1792                           1792
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1793                           1793
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1794                           1794
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1795                           1795
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1796                           1796
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1797                           1797
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1798                           1798
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1799                           1799
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1800                           1800
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1801                           1801
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1802                           1802
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1803                           1803
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1804                           1804
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1805                           1805
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1806                           1806
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1807                           1807
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1808                           1808
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1809                           1809
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1810                           1810
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1811                           1811
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1812                           1812
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1813                           1813
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1814                           1814
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1815                           1815
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1816                           1816
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1817                           1817
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1818                           1818
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1819                           1819
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1820                           1820
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1821                           1821
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1822                           1822
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1823                           1823
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1824                           1824
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1825                           1825
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1826                           1826
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1827                           1827
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1828                           1828
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1829                           1829
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1830                           1830
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1831                           1831
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1832                           1832
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1833                           1833
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1834                           1834
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1835                           1835
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1836                           1836
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1837                           1837
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1838                           1838
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1839                           1839
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1840                           1840
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1841                           1841
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1842                           1842
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1843                           1843
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1844                           1844
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1845                           1845
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1846                           1846
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1847                           1847
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1848                           1848
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1849                           1849
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1850                           1850
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1851                           1851
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1852                           1852
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1853                           1853
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1854                           1854
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1855                           1855
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1856                           1856
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1857                           1857
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1858                           1858
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1859                           1859
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1860                           1860
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1861                           1861
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1862                           1862
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1863                           1863
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1864                           1864
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1865                           1865
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1866                           1866
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1867                           1867
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1868                           1868
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1869                           1869
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1870                           1870
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1871                           1871
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1872                           1872
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1873                           1873
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1874                           1874
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1875                           1875
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1876                           1876
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1877                           1877
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1878                           1878
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1879                           1879
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1880                           1880
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1881                           1881
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1882                           1882
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1883                           1883
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1884                           1884
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1885                           1885
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1886                           1886
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1887                           1887
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1888                           1888
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1889                           1889
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1890                           1890
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1891                           1891
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1892                           1892
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1893                           1893
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1894                           1894
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1895                           1895
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1896                           1896
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1897                           1897
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1898                           1898
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1899                           1899
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1900                           1900
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1901                           1901
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1902                           1902
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1903                           1903
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1904                           1904
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1905                           1905
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1906                           1906
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1907                           1907
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1908                           1908
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1909                           1909
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1910                           1910
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1911                           1911
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1912                           1912
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1913                           1913
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1914                           1914
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1915                           1915
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1916                           1916
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1917                           1917
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1918                           1918
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1919                           1919
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1920                           1920
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1921                           1921
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1922                           1922
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1923                           1923
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1924                           1924
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1925                           1925
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1926                           1926
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1927                           1927
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1928                           1928
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1929                           1929
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1930                           1930
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1931                           1931
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1932                           1932
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1933                           1933
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1934                           1934
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1935                           1935
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1936                           1936
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1937                           1937
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1938                           1938
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1939                           1939
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1940                           1940
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1941                           1941
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1942                           1942
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1943                           1943
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1944                           1944
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1945                           1945
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1946                           1946
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1947                           1947
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1948                           1948
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1949                           1949
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1950                           1950
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1951                           1951
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1952                           1952
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1953                           1953
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1954                           1954
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1955                           1955
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1956                           1956
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1957                           1957
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1958                           1958
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1959                           1959
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1960                           1960
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1961                           1961
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1962                           1962
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1963                           1963
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1964                           1964
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1965                           1965
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1966                           1966
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1967                           1967
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1968                           1968
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1969                           1969
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1970                           1970
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1971                           1971
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1972                           1972
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1973                           1973
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1974                           1974
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1975                           1975
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1976                           1976
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1977                           1977
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1978                           1978
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1979                           1979
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1980                           1980
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1981                           1981
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1982                           1982
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1983                           1983
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1984                           1984
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1985                           1985
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1986                           1986
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1987                           1987
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1988                           1988
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1989                           1989
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1990                           1990
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1991                           1991
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1992                           1992
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1993                           1993
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1994                           1994
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1995                           1995
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1996                           1996
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1997                           1997
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1998                           1998
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP1999                           1999
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2000                           2000
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2001                           2001
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2002                           2002
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2003                           2003
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2004                           2004
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2005                           2005
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2006                           2006
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2007                           2007
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2008                           2008
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2009                           2009
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2010                           2010
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2011                           2011
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2012                           2012
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2013                           2013
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2014                           2014
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2015                           2015
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2016                           2016
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2017                           2017
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2018                           2018
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2019                           2019
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2020                           2020
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2021                           2021
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2022                           2022
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2023                           2023
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2024                           2024
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2025                           2025
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2026                           2026
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2027                           2027
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2028                           2028
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2029                           2029
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2030                           2030
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2031                           2031
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2032                           2032
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2033                           2033
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2034                           2034
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2035                           2035
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2036                           2036
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2037                           2037
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2038                           2038
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2039                           2039
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2040                           2040
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2041                           2041
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2042                           2042
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2043                           2043
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2044                           2044
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2045                           2045
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2046                           2046
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2047                           2047
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2048                           2048
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2049                           2049
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2050                           2050
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2051                           2051
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2052                           2052
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2053                           2053
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2054                           2054
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2055                           2055
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2056                           2056
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2057                           2057
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2058                           2058
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2059                           2059
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2060                           2060
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2061                           2061
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2062                           2062
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2063                           2063
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2064                           2064
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2065                           2065
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2066                           2066
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2067                           2067
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2068                           2068
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2069                           2069
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2070                           2070
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2071                           2071
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2072                           2072
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2073                           2073
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2074                           2074
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2075                           2075
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2076                           2076
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2077                           2077
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2078                           2078
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2079                           2079
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2080                           2080
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2081                           2081
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2082                           2082
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2083                           2083
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2084                           2084
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2085                           2085
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2086                           2086
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2087                           2087
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2088                           2088
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2089                           2089
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2090                           2090
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2091                           2091
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2092                           2092
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2093                           2093
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2094                           2094
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2095                           2095
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2096                           2096
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2097                           2097
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2098                           2098
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2099                           2099
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2100                           2100
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2101                           2101
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2102                           2102
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2103                           2103
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2104                           2104
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2105                           2105
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2106                           2106
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2107                           2107
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2108                           2108
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2109                           2109
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2110                           2110
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2111                           2111
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2112                           2112
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2113                           2113
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2114                           2114
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2115                           2115
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2116                           2116
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2117                           2117
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2118                           2118
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2119                           2119
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2120                           2120
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2121                           2121
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2122                           2122
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2123                           2123
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2124                           2124
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2125                           2125
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2126                           2126
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2127                           2127
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2128                           2128
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2129                           2129
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2130                           2130
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2131                           2131
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2132                           2132
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2133                           2133
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2134                           2134
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2135                           2135
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2136                           2136
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2137                           2137
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2138                           2138
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2139                           2139
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2140                           2140
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2141                           2141
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2142                           2142
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2143                           2143
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2144                           2144
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2145                           2145
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2146                           2146
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2147                           2147
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2148                           2148
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2149                           2149
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2150                           2150
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2151                           2151
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2152                           2152
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2153                           2153
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2154                           2154
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2155                           2155
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2156                           2156
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2157                           2157
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2158                           2158
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2159                           2159
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2160                           2160
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2161                           2161
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2162                           2162
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2163                           2163
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2164                           2164
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2165                           2165
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2166                           2166
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2167                           2167
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2168                           2168
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2169                           2169
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2170                           2170
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2171                           2171
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2172                           2172
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2173                           2173
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2174                           2174
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2175                           2175
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2176                           2176
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2177                           2177
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2178                           2178
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2179                           2179
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2180                           2180
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2181                           2181
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2182                           2182
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2183                           2183
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2184                           2184
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2185                           2185
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2186                           2186
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2187                           2187
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2188                           2188
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2189                           2189
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2190                           2190
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2191                           2191
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2192                           2192
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2193                           2193
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2194                           2194
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2195                           2195
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2196                           2196
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2197                           2197
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2198                           2198
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2199                           2199
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2200                           2200
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2201                           2201
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2202                           2202
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2203                           2203
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2204                           2204
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2205                           2205
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2206                           2206
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2207                           2207
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2208                           2208
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2209                           2209
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2210                           2210
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2211                           2211
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2212                           2212
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2213                           2213
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2214                           2214
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2215                           2215
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2216                           2216
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2217                           2217
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2218                           2218
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2219                           2219
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2220                           2220
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2221                           2221
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2222                           2222
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2223                           2223
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2224                           2224
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2225                           2225
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2226                           2226
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2227                           2227
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2228                           2228
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2229                           2229
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2230                           2230
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2231                           2231
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2232                           2232
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2233                           2233
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2234                           2234
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2235                           2235
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2236                           2236
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2237                           2237
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2238                           2238
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2239                           2239
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2240                           2240
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2241                           2241
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2242                           2242
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2243                           2243
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2244                           2244
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2245                           2245
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2246                           2246
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2247                           2247
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2248                           2248
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2249                           2249
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2250                           2250
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2251                           2251
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2252                           2252
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2253                           2253
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2254                           2254
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2255                           2255
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2256                           2256
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2257                           2257
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2258                           2258
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2259                           2259
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2260                           2260
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2261                           2261
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2262                           2262
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2263                           2263
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2264                           2264
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2265                           2265
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2266                           2266
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2267                           2267
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2268                           2268
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2269                           2269
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2270                           2270
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2271                           2271
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2272                           2272
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2273                           2273
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2274                           2274
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2275                           2275
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2276                           2276
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2277                           2277
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2278                           2278
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2279                           2279
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2280                           2280
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2281                           2281
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2282                           2282
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2283                           2283
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2284                           2284
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2285                           2285
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2286                           2286
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2287                           2287
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2288                           2288
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2289                           2289
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2290                           2290
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2291                           2291
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2292                           2292
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2293                           2293
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2294                           2294
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2295                           2295
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2296                           2296
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2297                           2297
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2298                           2298
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2299                           2299
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2300                           2300
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2301                           2301
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2302                           2302
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2303                           2303
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2304                           2304
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2305                           2305
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2306                           2306
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2307                           2307
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2308                           2308
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2309                           2309
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2310                           2310
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2311                           2311
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2312                           2312
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2313                           2313
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2314                           2314
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2315                           2315
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2316                           2316
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2317                           2317
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2318                           2318
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2319                           2319
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2320                           2320
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2321                           2321
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2322                           2322
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2323                           2323
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2324                           2324
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2325                           2325
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2326                           2326
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2327                           2327
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2328                           2328
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2329                           2329
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2330                           2330
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2331                           2331
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2332                           2332
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2333                           2333
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2334                           2334
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2335                           2335
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2336                           2336
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2337                           2337
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2338                           2338
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2339                           2339
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2340                           2340
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2341                           2341
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2342                           2342
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2343                           2343
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2344                           2344
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2345                           2345
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2346                           2346
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2347                           2347
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2348                           2348
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2349                           2349
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2350                           2350
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2351                           2351
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2352                           2352
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2353                           2353
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2354                           2354
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2355                           2355
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2356                           2356
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2357                           2357
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2358                           2358
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2359                           2359
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2360                           2360
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2361                           2361
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2362                           2362
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2363                           2363
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2364                           2364
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2365                           2365
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2366                           2366
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2367                           2367
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2368                           2368
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2369                           2369
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2370                           2370
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2371                           2371
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2372                           2372
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2373                           2373
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2374                           2374
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2375                           2375
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2376                           2376
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2377                           2377
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2378                           2378
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2379                           2379
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2380                           2380
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2381                           2381
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2382                           2382
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2383                           2383
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2384                           2384
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2385                           2385
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2386                           2386
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2387                           2387
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2388                           2388
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2389                           2389
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2390                           2390
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2391                           2391
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2392                           2392
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2393                           2393
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2394                           2394
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2395                           2395
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2396                           2396
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2397                           2397
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2398                           2398
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2399                           2399
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2400                           2400
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2401                           2401
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2402                           2402
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2403                           2403
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2404                           2404
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2405                           2405
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2406                           2406
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2407                           2407
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2408                           2408
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2409                           2409
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2410                           2410
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2411                           2411
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2412                           2412
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2413                           2413
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2414                           2414
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2415                           2415
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2416                           2416
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2417                           2417
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2418                           2418
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2419                           2419
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2420                           2420
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2421                           2421
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2422                           2422
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2423                           2423
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2424                           2424
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2425                           2425
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2426                           2426
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2427                           2427
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2428                           2428
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2429                           2429
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2430                           2430
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2431                           2431
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2432                           2432
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2433                           2433
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2434                           2434
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2435                           2435
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2436                           2436
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2437                           2437
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2438                           2438
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2439                           2439
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2440                           2440
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2441                           2441
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2442                           2442
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2443                           2443
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2444                           2444
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2445                           2445
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2446                           2446
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2447                           2447
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2448                           2448
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2449                           2449
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2450                           2450
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2451                           2451
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2452                           2452
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2453                           2453
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2454                           2454
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2455                           2455
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2456                           2456
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2457                           2457
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2458                           2458
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2459                           2459
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2460                           2460
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2461                           2461
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2462                           2462
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2463                           2463
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2464                           2464
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2465                           2465
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2466                           2466
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2467                           2467
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2468                           2468
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2469                           2469
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2470                           2470
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2471                           2471
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2472                           2472
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2473                           2473
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2474                           2474
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2475                           2475
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2476                           2476
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2477                           2477
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2478                           2478
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2479                           2479
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2480                           2480
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2481                           2481
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2482                           2482
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2483                           2483
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2484                           2484
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2485                           2485
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2486                           2486
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2487                           2487
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2488                           2488
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2489                           2489
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2490                           2490
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2491                           2491
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2492                           2492
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2493                           2493
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2494                           2494
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2495                           2495
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2496                           2496
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2497                           2497
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2498                           2498
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2499                           2499
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2500                           2500
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2501                           2501
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2502                           2502
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2503                           2503
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2504                           2504
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2505                           2505
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2506                           2506
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2507                           2507
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2508                           2508
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2509                           2509
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2510                           2510
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2511                           2511
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2512                           2512
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2513                           2513
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2514                           2514
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2515                           2515
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2516                           2516
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2517                           2517
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2518                           2518
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2519                           2519
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2520                           2520
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2521                           2521
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2522                           2522
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2523                           2523
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2524                           2524
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2525                           2525
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2526                           2526
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2527                           2527
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2528                           2528
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2529                           2529
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2530                           2530
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2531                           2531
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2532                           2532
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2533                           2533
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2534                           2534
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2535                           2535
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2536                           2536
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2537                           2537
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2538                           2538
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2539                           2539
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2540                           2540
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2541                           2541
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2542                           2542
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2543                           2543
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2544                           2544
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2545                           2545
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2546                           2546
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2547                           2547
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2548                           2548
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2549                           2549
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2550                           2550
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2551                           2551
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2552                           2552
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2553                           2553
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2554                           2554
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2555                           2555
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2556                           2556
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2557                           2557
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2558                           2558
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2559                           2559
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2560                           2560
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2561                           2561
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2562                           2562
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2563                           2563
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2564                           2564
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2565                           2565
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2566                           2566
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2567                           2567
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2568                           2568
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2569                           2569
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2570                           2570
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2571                           2571
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2572                           2572
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2573                           2573
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2574                           2574
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2575                           2575
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2576                           2576
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2577                           2577
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2578                           2578
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2579                           2579
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2580                           2580
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2581                           2581
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2582                           2582
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2583                           2583
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2584                           2584
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2585                           2585
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2586                           2586
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2587                           2587
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2588                           2588
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2589                           2589
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2590                           2590
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2591                           2591
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2592                           2592
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2593                           2593
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2594                           2594
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2595                           2595
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2596                           2596
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2597                           2597
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2598                           2598
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2599                           2599
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2600                           2600
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2601                           2601
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2602                           2602
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2603                           2603
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2604                           2604
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2605                           2605
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2606                           2606
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2607                           2607
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2608                           2608
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2609                           2609
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2610                           2610
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2611                           2611
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2612                           2612
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2613                           2613
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2614                           2614
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2615                           2615
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2616                           2616
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2617                           2617
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2618                           2618
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2619                           2619
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2620                           2620
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2621                           2621
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2622                           2622
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2623                           2623
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2624                           2624
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2625                           2625
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2626                           2626
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2627                           2627
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2628                           2628
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2629                           2629
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2630                           2630
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2631                           2631
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2632                           2632
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2633                           2633
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2634                           2634
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2635                           2635
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2636                           2636
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2637                           2637
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2638                           2638
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2639                           2639
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2640                           2640
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2641                           2641
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2642                           2642
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2643                           2643
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2644                           2644
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2645                           2645
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2646                           2646
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2647                           2647
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2648                           2648
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2649                           2649
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2650                           2650
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2651                           2651
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2652                           2652
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2653                           2653
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2654                           2654
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2655                           2655
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2656                           2656
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2657                           2657
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2658                           2658
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2659                           2659
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2660                           2660
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2661                           2661
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2662                           2662
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2663                           2663
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2664                           2664
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2665                           2665
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2666                           2666
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2667                           2667
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2668                           2668
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2669                           2669
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2670                           2670
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2671                           2671
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2672                           2672
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2673                           2673
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2674                           2674
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2675                           2675
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2676                           2676
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2677                           2677
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2678                           2678
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2679                           2679
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2680                           2680
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2681                           2681
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2682                           2682
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2683                           2683
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2684                           2684
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2685                           2685
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2686                           2686
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2687                           2687
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2688                           2688
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2689                           2689
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2690                           2690
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2691                           2691
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2692                           2692
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2693                           2693
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2694                           2694
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2695                           2695
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2696                           2696
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2697                           2697
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2698                           2698
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2699                           2699
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2700                           2700
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2701                           2701
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2702                           2702
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2703                           2703
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2704                           2704
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2705                           2705
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2706                           2706
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2707                           2707
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2708                           2708
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2709                           2709
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2710                           2710
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2711                           2711
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2712                           2712
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2713                           2713
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2714                           2714
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2715                           2715
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2716                           2716
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2717                           2717
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2718                           2718
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2719                           2719
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2720                           2720
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2721                           2721
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2722                           2722
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2723                           2723
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2724                           2724
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2725                           2725
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2726                           2726
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2727                           2727
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2728                           2728
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2729                           2729
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2730                           2730
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2731                           2731
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2732                           2732
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2733                           2733
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2734                           2734
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2735                           2735
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2736                           2736
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2737                           2737
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2738                           2738
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2739                           2739
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2740                           2740
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2741                           2741
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2742                           2742
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2743                           2743
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2744                           2744
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2745                           2745
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2746                           2746
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2747                           2747
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2748                           2748
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2749                           2749
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2750                           2750
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2751                           2751
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2752                           2752
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2753                           2753
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2754                           2754
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2755                           2755
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2756                           2756
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2757                           2757
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2758                           2758
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2759                           2759
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2760                           2760
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2761                           2761
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2762                           2762
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2763                           2763
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2764                           2764
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2765                           2765
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2766                           2766
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2767                           2767
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2768                           2768
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2769                           2769
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2770                           2770
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2771                           2771
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2772                           2772
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2773                           2773
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2774                           2774
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2775                           2775
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2776                           2776
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2777                           2777
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2778                           2778
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2779                           2779
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2780                           2780
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2781                           2781
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2782                           2782
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2783                           2783
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2784                           2784
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2785                           2785
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2786                           2786
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2787                           2787
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2788                           2788
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2789                           2789
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2790                           2790
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2791                           2791
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2792                           2792
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2793                           2793
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2794                           2794
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2795                           2795
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2796                           2796
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2797                           2797
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2798                           2798
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2799                           2799
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2800                           2800
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2801                           2801
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2802                           2802
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2803                           2803
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2804                           2804
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2805                           2805
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2806                           2806
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2807                           2807
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2808                           2808
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2809                           2809
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2810                           2810
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2811                           2811
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2812                           2812
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2813                           2813
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2814                           2814
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2815                           2815
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2816                           2816
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2817                           2817
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2818                           2818
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2819                           2819
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2820                           2820
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2821                           2821
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2822                           2822
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2823                           2823
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2824                           2824
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2825                           2825
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2826                           2826
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2827                           2827
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2828                           2828
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2829                           2829
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2830                           2830
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2831                           2831
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2832                           2832
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2833                           2833
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2834                           2834
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2835                           2835
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2836                           2836
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2837                           2837
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2838                           2838
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2839                           2839
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2840                           2840
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2841                           2841
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2842                           2842
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2843                           2843
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2844                           2844
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2845                           2845
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2846                           2846
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2847                           2847
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2848                           2848
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2849                           2849
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2850                           2850
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2851                           2851
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2852                           2852
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2853                           2853
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2854                           2854
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2855                           2855
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2856                           2856
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2857                           2857
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2858                           2858
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2859                           2859
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2860                           2860
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2861                           2861
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2862                           2862
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2863                           2863
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2864                           2864
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2865                           2865
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2866                           2866
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2867                           2867
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2868                           2868
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2869                           2869
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2870                           2870
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2871                           2871
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2872                           2872
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2873                           2873
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2874                           2874
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2875                           2875
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2876                           2876
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2877                           2877
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2878                           2878
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2879                           2879
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2880                           2880
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2881                           2881
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2882                           2882
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2883                           2883
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2884                           2884
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2885                           2885
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2886                           2886
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2887                           2887
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2888                           2888
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2889                           2889
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2890                           2890
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2891                           2891
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2892                           2892
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2893                           2893
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2894                           2894
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2895                           2895
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2896                           2896
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2897                           2897
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2898                           2898
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2899                           2899
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2900                           2900
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2901                           2901
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2902                           2902
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2903                           2903
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2904                           2904
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2905                           2905
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2906                           2906
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2907                           2907
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2908                           2908
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2909                           2909
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2910                           2910
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2911                           2911
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2912                           2912
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2913                           2913
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2914                           2914
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2915                           2915
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2916                           2916
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2917                           2917
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2918                           2918
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2919                           2919
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2920                           2920
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2921                           2921
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2922                           2922
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2923                           2923
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2924                           2924
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2925                           2925
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2926                           2926
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2927                           2927
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2928                           2928
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2929                           2929
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2930                           2930
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2931                           2931
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2932                           2932
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2933                           2933
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2934                           2934
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2935                           2935
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2936                           2936
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2937                           2937
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2938                           2938
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2939                           2939
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2940                           2940
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2941                           2941
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2942                           2942
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2943                           2943
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2944                           2944
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2945                           2945
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2946                           2946
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2947                           2947
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2948                           2948
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2949                           2949
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2950                           2950
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2951                           2951
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2952                           2952
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2953                           2953
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2954                           2954
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2955                           2955
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2956                           2956
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2957                           2957
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2958                           2958
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2959                           2959
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2960                           2960
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2961                           2961
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2962                           2962
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2963                           2963
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2964                           2964
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2965                           2965
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2966                           2966
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2967                           2967
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2968                           2968
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2969                           2969
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2970                           2970
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2971                           2971
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2972                           2972
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2973                           2973
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2974                           2974
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2975                           2975
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2976                           2976
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2977                           2977
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2978                           2978
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2979                           2979
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2980                           2980
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2981                           2981
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2982                           2982
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2983                           2983
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2984                           2984
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2985                           2985
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2986                           2986
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2987                           2987
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2988                           2988
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2989                           2989
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2990                           2990
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2991                           2991
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2992                           2992
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2993                           2993
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2994                           2994
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2995                           2995
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2996                           2996
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2997                           2997
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2998                           2998
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP2999                           2999
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3000                           3000
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3001                           3001
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3002                           3002
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3003                           3003
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3004                           3004
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3005                           3005
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3006                           3006
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3007                           3007
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3008                           3008
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3009                           3009
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3010                           3010
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3011                           3011
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3012                           3012
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3013                           3013
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3014                           3014
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3015                           3015
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3016                           3016
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3017                           3017
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3018                           3018
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3019                           3019
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3020                           3020
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3021                           3021
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3022                           3022
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3023                           3023
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3024                           3024
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3025                           3025
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3026                           3026
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3027                           3027
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3028                           3028
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3029                           3029
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3030                           3030
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3031                           3031
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3032                           3032
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3033                           3033
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3034                           3034
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3035                           3035
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3036                           3036
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3037                           3037
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3038                           3038
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3039                           3039
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3040                           3040
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3041                           3041
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3042                           3042
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3043                           3043
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3044                           3044
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3045                           3045
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3046                           3046
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3047                           3047
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3048                           3048
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3049                           3049
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3050                           3050
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3051                           3051
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3052                           3052
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3053                           3053
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3054                           3054
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3055                           3055
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3056                           3056
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3057                           3057
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3058                           3058
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3059                           3059
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3060                           3060
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3061                           3061
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3062                           3062
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3063                           3063
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3064                           3064
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3065                           3065
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3066                           3066
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3067                           3067
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3068                           3068
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3069                           3069
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3070                           3070
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3071                           3071
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3072                           3072
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3073                           3073
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3074                           3074
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3075                           3075
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3076                           3076
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3077                           3077
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3078                           3078
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3079                           3079
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3080                           3080
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3081                           3081
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3082                           3082
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3083                           3083
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3084                           3084
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3085                           3085
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3086                           3086
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3087                           3087
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3088                           3088
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3089                           3089
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3090                           3090
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3091                           3091
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3092                           3092
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3093                           3093
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3094                           3094
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3095                           3095
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3096                           3096
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3097                           3097
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3098                           3098
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3099                           3099
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3100                           3100
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3101                           3101
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3102                           3102
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3103                           3103
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3104                           3104
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3105                           3105
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3106                           3106
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3107                           3107
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3108                           3108
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3109                           3109
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3110                           3110
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3111                           3111
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3112                           3112
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3113                           3113
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3114                           3114
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3115                           3115
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3116                           3116
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3117                           3117
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3118                           3118
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3119                           3119
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3120                           3120
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3121                           3121
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3122                           3122
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3123                           3123
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3124                           3124
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3125                           3125
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3126                           3126
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3127                           3127
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3128                           3128
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3129                           3129
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3130                           3130
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3131                           3131
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3132                           3132
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3133                           3133
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3134                           3134
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3135                           3135
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3136                           3136
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3137                           3137
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3138                           3138
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3139                           3139
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3140                           3140
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3141                           3141
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3142                           3142
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3143                           3143
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3144                           3144
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3145                           3145
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3146                           3146
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3147                           3147
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3148                           3148
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3149                           3149
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3150                           3150
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3151                           3151
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3152                           3152
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3153                           3153
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3154                           3154
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3155                           3155
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3156                           3156
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3157                           3157
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3158                           3158
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3159                           3159
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3160                           3160
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3161                           3161
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3162                           3162
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3163                           3163
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3164                           3164
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3165                           3165
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3166                           3166
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3167                           3167
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3168                           3168
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3169                           3169
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3170                           3170
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3171                           3171
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3172                           3172
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3173                           3173
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3174                           3174
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3175                           3175
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3176                           3176
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3177                           3177
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3178                           3178
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3179                           3179
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3180                           3180
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3181                           3181
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3182                           3182
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3183                           3183
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3184                           3184
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3185                           3185
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3186                           3186
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3187                           3187
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3188                           3188
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3189                           3189
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3190                           3190
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3191                           3191
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3192                           3192
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3193                           3193
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3194                           3194
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3195                           3195
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3196                           3196
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3197                           3197
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3198                           3198
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3199                           3199
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3200                           3200
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3201                           3201
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3202                           3202
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3203                           3203
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3204                           3204
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3205                           3205
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3206                           3206
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3207                           3207
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3208                           3208
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3209                           3209
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3210                           3210
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3211                           3211
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3212                           3212
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3213                           3213
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3214                           3214
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3215                           3215
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3216                           3216
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3217                           3217
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3218                           3218
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3219                           3219
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3220                           3220
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3221                           3221
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3222                           3222
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3223                           3223
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3224                           3224
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3225                           3225
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3226                           3226
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3227                           3227
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3228                           3228
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3229                           3229
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3230                           3230
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3231                           3231
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3232                           3232
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3233                           3233
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3234                           3234
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3235                           3235
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3236                           3236
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3237                           3237
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3238                           3238
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3239                           3239
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3240                           3240
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3241                           3241
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3242                           3242
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3243                           3243
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3244                           3244
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3245                           3245
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3246                           3246
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3247                           3247
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3248                           3248
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3249                           3249
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3250                           3250
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3251                           3251
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3252                           3252
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3253                           3253
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3254                           3254
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3255                           3255
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3256                           3256
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3257                           3257
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3258                           3258
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3259                           3259
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3260                           3260
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3261                           3261
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3262                           3262
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3263                           3263
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3264                           3264
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3265                           3265
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3266                           3266
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3267                           3267
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3268                           3268
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3269                           3269
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3270                           3270
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3271                           3271
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3272                           3272
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3273                           3273
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3274                           3274
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3275                           3275
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3276                           3276
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3277                           3277
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3278                           3278
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3279                           3279
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3280                           3280
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3281                           3281
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3282                           3282
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3283                           3283
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3284                           3284
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3285                           3285
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3286                           3286
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3287                           3287
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3288                           3288
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3289                           3289
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3290                           3290
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3291                           3291
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3292                           3292
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3293                           3293
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3294                           3294
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3295                           3295
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3296                           3296
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3297                           3297
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3298                           3298
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3299                           3299
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3300                           3300
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3301                           3301
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3302                           3302
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3303                           3303
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3304                           3304
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3305                           3305
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3306                           3306
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3307                           3307
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3308                           3308
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3309                           3309
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3310                           3310
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3311                           3311
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3312                           3312
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3313                           3313
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3314                           3314
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3315                           3315
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3316                           3316
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3317                           3317
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3318                           3318
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3319                           3319
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3320                           3320
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3321                           3321
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3322                           3322
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3323                           3323
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3324                           3324
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3325                           3325
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3326                           3326
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3327                           3327
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3328                           3328
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3329                           3329
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3330                           3330
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3331                           3331
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3332                           3332
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3333                           3333
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3334                           3334
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3335                           3335
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3336                           3336
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3337                           3337
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3338                           3338
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3339                           3339
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3340                           3340
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3341                           3341
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3342                           3342
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3343                           3343
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3344                           3344
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3345                           3345
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3346                           3346
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3347                           3347
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3348                           3348
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3349                           3349
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3350                           3350
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3351                           3351
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3352                           3352
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3353                           3353
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3354                           3354
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3355                           3355
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3356                           3356
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3357                           3357
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3358                           3358
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3359                           3359
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3360                           3360
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3361                           3361
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3362                           3362
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3363                           3363
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3364                           3364
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3365                           3365
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3366                           3366
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3367                           3367
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3368                           3368
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3369                           3369
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3370                           3370
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3371                           3371
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3372                           3372
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3373                           3373
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3374                           3374
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3375                           3375
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3376                           3376
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3377                           3377
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3378                           3378
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3379                           3379
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3380                           3380
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3381                           3381
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3382                           3382
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3383                           3383
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3384                           3384
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3385                           3385
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3386                           3386
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3387                           3387
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3388                           3388
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3389                           3389
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3390                           3390
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3391                           3391
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3392                           3392
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3393                           3393
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3394                           3394
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3395                           3395
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3396                           3396
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3397                           3397
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3398                           3398
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3399                           3399
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3400                           3400
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3401                           3401
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3402                           3402
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3403                           3403
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3404                           3404
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3405                           3405
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3406                           3406
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3407                           3407
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3408                           3408
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3409                           3409
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3410                           3410
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3411                           3411
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3412                           3412
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3413                           3413
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3414                           3414
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3415                           3415
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3416                           3416
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3417                           3417
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3418                           3418
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3419                           3419
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3420                           3420
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3421                           3421
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3422                           3422
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3423                           3423
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3424                           3424
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3425                           3425
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3426                           3426
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3427                           3427
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3428                           3428
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3429                           3429
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3430                           3430
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3431                           3431
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3432                           3432
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3433                           3433
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3434                           3434
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3435                           3435
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3436                           3436
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3437                           3437
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3438                           3438
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3439                           3439
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3440                           3440
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3441                           3441
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3442                           3442
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3443                           3443
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3444                           3444
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3445                           3445
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3446                           3446
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3447                           3447
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3448                           3448
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3449                           3449
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3450                           3450
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3451                           3451
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3452                           3452
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3453                           3453
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3454                           3454
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3455                           3455
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3456                           3456
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3457                           3457
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3458                           3458
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3459                           3459
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3460                           3460
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3461                           3461
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3462                           3462
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3463                           3463
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3464                           3464
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3465                           3465
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3466                           3466
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3467                           3467
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3468                           3468
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3469                           3469
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3470                           3470
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3471                           3471
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3472                           3472
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3473                           3473
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3474                           3474
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3475                           3475
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3476                           3476
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3477                           3477
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3478                           3478
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3479                           3479
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3480                           3480
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3481                           3481
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3482                           3482
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3483                           3483
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3484                           3484
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3485                           3485
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3486                           3486
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3487                           3487
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3488                           3488
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3489                           3489
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3490                           3490
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3491                           3491
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3492                           3492
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3493                           3493
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3494                           3494
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3495                           3495
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3496                           3496
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3497                           3497
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3498                           3498
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3499                           3499
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3500                           3500
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3501                           3501
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3502                           3502
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3503                           3503
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3504                           3504
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3505                           3505
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3506                           3506
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3507                           3507
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3508                           3508
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3509                           3509
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3510                           3510
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3511                           3511
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3512                           3512
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3513                           3513
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3514                           3514
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3515                           3515
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3516                           3516
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3517                           3517
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3518                           3518
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3519                           3519
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3520                           3520
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3521                           3521
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3522                           3522
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3523                           3523
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3524                           3524
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3525                           3525
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3526                           3526
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3527                           3527
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3528                           3528
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3529                           3529
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3530                           3530
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3531                           3531
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3532                           3532
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3533                           3533
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3534                           3534
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3535                           3535
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3536                           3536
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3537                           3537
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3538                           3538
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3539                           3539
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3540                           3540
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3541                           3541
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3542                           3542
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3543                           3543
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3544                           3544
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3545                           3545
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3546                           3546
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3547                           3547
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3548                           3548
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3549                           3549
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3550                           3550
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3551                           3551
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3552                           3552
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3553                           3553
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3554                           3554
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3555                           3555
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3556                           3556
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3557                           3557
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3558                           3558
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3559                           3559
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3560                           3560
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3561                           3561
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3562                           3562
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3563                           3563
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3564                           3564
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3565                           3565
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3566                           3566
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3567                           3567
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3568                           3568
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3569                           3569
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3570                           3570
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3571                           3571
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3572                           3572
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3573                           3573
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3574                           3574
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3575                           3575
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3576                           3576
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3577                           3577
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3578                           3578
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3579                           3579
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3580                           3580
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3581                           3581
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3582                           3582
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3583                           3583
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3584                           3584
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3585                           3585
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3586                           3586
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3587                           3587
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3588                           3588
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3589                           3589
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3590                           3590
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3591                           3591
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3592                           3592
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3593                           3593
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3594                           3594
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3595                           3595
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3596                           3596
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3597                           3597
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3598                           3598
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3599                           3599
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3600                           3600
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3601                           3601
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3602                           3602
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3603                           3603
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3604                           3604
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3605                           3605
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3606                           3606
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3607                           3607
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3608                           3608
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3609                           3609
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3610                           3610
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3611                           3611
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3612                           3612
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3613                           3613
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3614                           3614
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3615                           3615
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3616                           3616
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3617                           3617
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3618                           3618
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3619                           3619
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3620                           3620
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3621                           3621
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3622                           3622
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3623                           3623
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3624                           3624
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3625                           3625
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3626                           3626
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3627                           3627
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3628                           3628
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3629                           3629
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3630                           3630
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3631                           3631
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3632                           3632
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3633                           3633
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3634                           3634
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3635                           3635
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3636                           3636
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3637                           3637
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3638                           3638
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3639                           3639
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3640                           3640
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3641                           3641
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3642                           3642
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3643                           3643
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3644                           3644
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3645                           3645
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3646                           3646
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3647                           3647
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3648                           3648
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3649                           3649
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3650                           3650
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3651                           3651
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3652                           3652
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3653                           3653
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3654                           3654
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3655                           3655
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3656                           3656
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3657                           3657
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3658                           3658
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3659                           3659
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3660                           3660
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3661                           3661
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3662                           3662
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3663                           3663
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3664                           3664
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3665                           3665
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3666                           3666
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3667                           3667
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3668                           3668
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3669                           3669
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3670                           3670
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3671                           3671
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3672                           3672
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3673                           3673
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3674                           3674
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3675                           3675
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3676                           3676
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3677                           3677
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3678                           3678
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3679                           3679
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3680                           3680
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3681                           3681
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3682                           3682
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3683                           3683
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3684                           3684
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3685                           3685
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3686                           3686
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3687                           3687
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3688                           3688
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3689                           3689
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3690                           3690
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3691                           3691
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3692                           3692
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3693                           3693
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3694                           3694
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3695                           3695
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3696                           3696
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3697                           3697
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3698                           3698
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3699                           3699
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3700                           3700
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3701                           3701
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3702                           3702
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3703                           3703
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3704                           3704
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3705                           3705
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3706                           3706
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3707                           3707
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3708                           3708
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3709                           3709
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3710                           3710
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3711                           3711
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3712                           3712
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3713                           3713
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3714                           3714
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3715                           3715
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3716                           3716
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3717                           3717
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3718                           3718
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3719                           3719
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3720                           3720
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3721                           3721
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3722                           3722
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3723                           3723
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3724                           3724
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3725                           3725
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3726                           3726
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3727                           3727
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3728                           3728
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3729                           3729
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3730                           3730
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3731                           3731
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3732                           3732
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3733                           3733
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3734                           3734
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3735                           3735
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3736                           3736
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3737                           3737
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3738                           3738
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3739                           3739
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3740                           3740
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3741                           3741
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3742                           3742
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3743                           3743
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3744                           3744
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3745                           3745
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3746                           3746
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3747                           3747
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3748                           3748
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3749                           3749
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3750                           3750
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3751                           3751
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3752                           3752
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3753                           3753
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3754                           3754
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3755                           3755
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3756                           3756
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3757                           3757
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3758                           3758
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3759                           3759
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3760                           3760
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3761                           3761
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3762                           3762
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3763                           3763
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3764                           3764
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3765                           3765
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3766                           3766
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3767                           3767
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3768                           3768
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3769                           3769
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3770                           3770
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3771                           3771
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3772                           3772
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3773                           3773
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3774                           3774
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3775                           3775
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3776                           3776
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3777                           3777
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3778                           3778
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3779                           3779
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3780                           3780
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3781                           3781
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3782                           3782
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3783                           3783
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3784                           3784
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3785                           3785
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3786                           3786
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3787                           3787
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3788                           3788
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3789                           3789
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3790                           3790
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3791                           3791
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3792                           3792
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3793                           3793
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3794                           3794
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3795                           3795
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3796                           3796
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3797                           3797
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3798                           3798
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3799                           3799
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3800                           3800
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3801                           3801
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3802                           3802
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3803                           3803
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3804                           3804
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3805                           3805
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3806                           3806
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3807                           3807
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3808                           3808
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3809                           3809
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3810                           3810
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3811                           3811
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3812                           3812
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3813                           3813
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3814                           3814
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3815                           3815
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3816                           3816
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3817                           3817
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3818                           3818
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3819                           3819
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3820                           3820
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3821                           3821
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3822                           3822
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3823                           3823
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3824                           3824
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3825                           3825
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3826                           3826
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3827                           3827
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3828                           3828
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3829                           3829
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3830                           3830
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3831                           3831
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3832                           3832
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3833                           3833
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3834                           3834
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3835                           3835
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3836                           3836
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3837                           3837
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3838                           3838
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3839                           3839
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3840                           3840
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3841                           3841
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3842                           3842
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3843                           3843
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3844                           3844
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3845                           3845
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3846                           3846
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3847                           3847
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3848                           3848
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3849                           3849
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3850                           3850
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3851                           3851
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3852                           3852
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3853                           3853
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3854                           3854
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3855                           3855
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3856                           3856
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3857                           3857
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3858                           3858
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3859                           3859
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3860                           3860
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3861                           3861
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3862                           3862
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3863                           3863
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3864                           3864
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3865                           3865
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3866                           3866
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3867                           3867
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3868                           3868
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3869                           3869
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3870                           3870
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3871                           3871
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3872                           3872
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3873                           3873
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3874                           3874
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3875                           3875
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3876                           3876
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3877                           3877
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3878                           3878
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3879                           3879
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3880                           3880
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3881                           3881
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3882                           3882
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3883                           3883
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3884                           3884
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3885                           3885
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3886                           3886
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3887                           3887
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3888                           3888
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3889                           3889
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3890                           3890
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3891                           3891
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3892                           3892
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3893                           3893
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3894                           3894
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3895                           3895
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3896                           3896
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3897                           3897
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3898                           3898
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3899                           3899
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3900                           3900
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3901                           3901
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3902                           3902
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3903                           3903
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3904                           3904
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3905                           3905
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3906                           3906
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3907                           3907
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3908                           3908
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3909                           3909
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3910                           3910
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3911                           3911
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3912                           3912
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3913                           3913
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3914                           3914
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3915                           3915
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3916                           3916
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3917                           3917
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3918                           3918
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3919                           3919
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3920                           3920
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3921                           3921
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3922                           3922
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3923                           3923
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3924                           3924
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3925                           3925
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3926                           3926
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3927                           3927
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3928                           3928
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3929                           3929
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3930                           3930
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3931                           3931
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3932                           3932
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3933                           3933
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3934                           3934
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3935                           3935
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3936                           3936
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3937                           3937
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3938                           3938
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3939                           3939
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3940                           3940
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3941                           3941
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3942                           3942
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3943                           3943
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3944                           3944
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3945                           3945
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3946                           3946
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3947                           3947
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3948                           3948
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3949                           3949
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3950                           3950
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3951                           3951
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3952                           3952
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3953                           3953
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3954                           3954
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3955                           3955
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3956                           3956
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3957                           3957
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3958                           3958
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3959                           3959
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3960                           3960
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3961                           3961
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3962                           3962
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3963                           3963
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3964                           3964
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3965                           3965
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3966                           3966
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3967                           3967
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3968                           3968
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3969                           3969
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3970                           3970
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3971                           3971
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3972                           3972
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3973                           3973
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3974                           3974
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3975                           3975
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3976                           3976
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3977                           3977
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3978                           3978
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3979                           3979
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3980                           3980
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3981                           3981
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3982                           3982
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3983                           3983
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3984                           3984
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3985                           3985
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3986                           3986
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3987                           3987
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3988                           3988
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3989                           3989
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3990                           3990
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3991                           3991
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3992                           3992
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3993                           3993
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3994                           3994
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3995                           3995
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3996                           3996
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3997                           3997
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3998                           3998
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP3999                           3999
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4000                           4000
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4001                           4001
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4002                           4002
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4003                           4003
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4004                           4004
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4005                           4005
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4006                           4006
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4007                           4007
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4008                           4008
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4009                           4009
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4010                           4010
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4011                           4011
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4012                           4012
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4013                           4013
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4014                           4014
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4015                           4015
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4016                           4016
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4017                           4017
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4018                           4018
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4019                           4019
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4020                           4020
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4021                           4021
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4022                           4022
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4023                           4023
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4024                           4024
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4025                           4025
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4026                           4026
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4027                           4027
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4028                           4028
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4029                           4029
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4030                           4030
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4031                           4031
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4032                           4032
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4033                           4033
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4034                           4034
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4035                           4035
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4036                           4036
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4037                           4037
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4038                           4038
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4039                           4039
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4040                           4040
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4041                           4041
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4042                           4042
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4043                           4043
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4044                           4044
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4045                           4045
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4046                           4046
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4047                           4047
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4048                           4048
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4049                           4049
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4050                           4050
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4051                           4051
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4052                           4052
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4053                           4053
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4054                           4054
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4055                           4055
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4056                           4056
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4057                           4057
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4058                           4058
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4059                           4059
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4060                           4060
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4061                           4061
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4062                           4062
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4063                           4063
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4064                           4064
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4065                           4065
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4066                           4066
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4067                           4067
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4068                           4068
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4069                           4069
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4070                           4070
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4071                           4071
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4072                           4072
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4073                           4073
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4074                           4074
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4075                           4075
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4076                           4076
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4077                           4077
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4078                           4078
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4079                           4079
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4080                           4080
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4081                           4081
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4082                           4082
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4083                           4083
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4084                           4084
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4085                           4085
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4086                           4086
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4087                           4087
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4088                           4088
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4089                           4089
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4090                           4090
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4091                           4091
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4092                           4092
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4093                           4093
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4094                           4094
#define RSRFSIGGEN_REPCAP_OFDMCONPOINT_OFDMCP4095                           4095

//repcap WLANNUserInfo
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI0                                 0
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI1                                 1
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI2                                 2
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI3                                 3
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI4                                 4
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI5                                 5
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI6                                 6
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI7                                 7
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI8                                 8
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI9                                 9
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI10                                10
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI11                                11
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI12                                12
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI13                                13
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI14                                14
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI15                                15
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI16                                16
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI17                                17
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI18                                18
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI19                                19
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI20                                20
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI21                                21
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI22                                22
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI23                                23
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI24                                24
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI25                                25
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI26                                26
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI27                                27
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI28                                28
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI29                                29
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI30                                30
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI31                                31
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI32                                32
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI33                                33
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI34                                34
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI35                                35
#define RSRFSIGGEN_REPCAP_WLANNUSERINFO_UI36                                36

//repcap TransportBlockSlot
#define RSRFSIGGEN_REPCAP_TRANSPORTBLOCKSLOT_TBM0                           0
#define RSRFSIGGEN_REPCAP_TRANSPORTBLOCKSLOT_TBM1                           1
#define RSRFSIGGEN_REPCAP_TRANSPORTBLOCKSLOT_TBM2                           2
#define RSRFSIGGEN_REPCAP_TRANSPORTBLOCKSLOT_TBM3                           3
#define RSRFSIGGEN_REPCAP_TRANSPORTBLOCKSLOT_TBM4                           4
#define RSRFSIGGEN_REPCAP_TRANSPORTBLOCKSLOT_TBM5                           5
#define RSRFSIGGEN_REPCAP_TRANSPORTBLOCKSLOT_TBM6                           6
#define RSRFSIGGEN_REPCAP_TRANSPORTBLOCKSLOT_TBM7                           7

//repcap NR5GTDML
#define RSRFSIGGEN_REPCAP_NR5GTDML_NR5GTDML0                                0
#define RSRFSIGGEN_REPCAP_NR5GTDML_NR5GTDML1                                1
#define RSRFSIGGEN_REPCAP_NR5GTDML_NR5GTDML2                                2
#define RSRFSIGGEN_REPCAP_NR5GTDML_NR5GTDML3                                3
#define RSRFSIGGEN_REPCAP_NR5GTDML_NR5GTDML4                                4
#define RSRFSIGGEN_REPCAP_NR5GTDML_NR5GTDML5                                5
#define RSRFSIGGEN_REPCAP_NR5GTDML_NR5GTDML6                                6
#define RSRFSIGGEN_REPCAP_NR5GTDML_NR5GTDML7                                7
#define RSRFSIGGEN_REPCAP_NR5GTDML_NR5GTDML8                                8
#define RSRFSIGGEN_REPCAP_NR5GTDML_NR5GTDML9                                9
#define RSRFSIGGEN_REPCAP_NR5GTDML_NR5GTDML10                               10
#define RSRFSIGGEN_REPCAP_NR5GTDML_NR5GTDML11                               11
#define RSRFSIGGEN_REPCAP_NR5GTDML_NR5GTDML12                               12
#define RSRFSIGGEN_REPCAP_NR5GTDML_NR5GTDML13                               13
#define RSRFSIGGEN_REPCAP_NR5GTDML_NR5GTDML14                               14
#define RSRFSIGGEN_REPCAP_NR5GTDML_NR5GTDML15                               15

//repcap NR5GTD
#define RSRFSIGGEN_REPCAP_NR5GTD_NR5GTD0                                    0
#define RSRFSIGGEN_REPCAP_NR5GTD_NR5GTD1                                    1
#define RSRFSIGGEN_REPCAP_NR5GTD_NR5GTD2                                    2
#define RSRFSIGGEN_REPCAP_NR5GTD_NR5GTD3                                    3
#define RSRFSIGGEN_REPCAP_NR5GTD_NR5GTD4                                    4
#define RSRFSIGGEN_REPCAP_NR5GTD_NR5GTD5                                    5
#define RSRFSIGGEN_REPCAP_NR5GTD_NR5GTD6                                    6
#define RSRFSIGGEN_REPCAP_NR5GTD_NR5GTD7                                    7
/* END GENERATE */

/*****************************************************************************
 *- Hidden Attribute Declarations -------------------------------------------*
 *****************************************************************************/

#define RSRFSIGGEN_ATTR_OPC_TIMEOUT               (RS_ATTR_OPC_TIMEOUT)           /* ViInt32 */
#define RSRFSIGGEN_ATTR_IO_SESSION                (RS_ATTR_IO_SESSION)            /* ViSession */
#define RSRFSIGGEN_ATTR_OPC_CALLBACK              (RS_ATTR_OPC_CALLBACK)          /* ViAddr */
#define RSRFSIGGEN_ATTR_CHECK_STATUS_CALLBACK     (RS_ATTR_CHECK_STATUS_CALLBACK) /* ViAddr */

/****************************************************************************
 *---------------- Constant definition  ------------------------------------*
 ****************************************************************************/
// GG System
#define RSRFSIGGEN_VAL_SATNAV_SYSTEM_GPS                                    0
#define RSRFSIGGEN_VAL_SATNAV_SYSTEM_GAL                                    1
#define RSRFSIGGEN_VAL_SATNAV_SYSTEM_GLON                                   2
#define RSRFSIGGEN_VAL_SATNAV_SYSTEM_BEID                                   3

// Subsystem
#define RSRFSIGGEN_VAL_SUBSYSTEM_GSM                                        0
#define RSRFSIGGEN_VAL_SUBSYSTEM_BTO                                        1
#define RSRFSIGGEN_VAL_SUBSYSTEM_W3GPP                                      2
#define RSRFSIGGEN_VAL_SUBSYSTEM_C2K                                        3
#define RSRFSIGGEN_VAL_SUBSYSTEM_TDSCDMA                                    4
#define RSRFSIGGEN_VAL_SUBSYSTEM_WLAN                                       5
#define RSRFSIGGEN_VAL_SUBSYSTEM_WLANN                                      6
#define RSRFSIGGEN_VAL_SUBSYSTEM_WIMAX                                      7
#define RSRFSIGGEN_VAL_SUBSYSTEM_DVB                                        8
#define RSRFSIGGEN_VAL_SUBSYSTEM_DAB                                        9
#define RSRFSIGGEN_VAL_SUBSYSTEM_DM                                         10
#define RSRFSIGGEN_VAL_SUBSYSTEM_GPS                                        11
#define RSRFSIGGEN_VAL_SUBSYSTEM_STEREO                                     12
#define RSRFSIGGEN_VAL_SUBSYSTEM_XMR                                        13
#define RSRFSIGGEN_VAL_SUBSYSTEM_SIRIUS                                     14
#define RSRFSIGGEN_VAL_SUBSYSTEM_EUTRA                                      15
#define RSRFSIGGEN_VAL_SUBSYSTEM_TETRA                                      16
#define RSRFSIGGEN_VAL_SUBSYSTEM_FADING                                     17
#define RSRFSIGGEN_VAL_SUBSYSTEM_EVDO                                       18
#define RSRFSIGGEN_VAL_SUBSYSTEM_OFDM                                       19
#define RSRFSIGGEN_VAL_SUBSYSTEM_WLANAD                                     20
#define RSRFSIGGEN_VAL_SUBSYSTEM_EXTSEQ                                     21
#define RSRFSIGGEN_VAL_SUBSYSTEM_ONEWEB                                     22
#define RSRFSIGGEN_VAL_SUBSYSTEM_V5G                                        23
#define RSRFSIGGEN_VAL_SUBSYSTEM_5GNR                                       24
#define RSRFSIGGEN_VAL_SUBSYSTEM_LORA                                       25
#define RSRFSIGGEN_VAL_SUBSYSTEM_HRP_UWB                                    26

// File Action
#define RSRFSIGGEN_VAL_FILE_ACTION_DELETE                                   0
#define RSRFSIGGEN_VAL_FILE_ACTION_RECALL                                   1
#define RSRFSIGGEN_VAL_FILE_ACTION_SAVE                                     2

//Scaling
#define RSRFSIGGEN_VAL_LF_FREQUENCY_STEP_SCALING_LINEAR                     0
#define RSRFSIGGEN_VAL_LF_FREQUENCY_STEP_SCALING_LOGARITHMIC                1

//Sweep Mode
#define RSRFSIGGEN_VAL_SWEEP_MODE_FREQUENCY_SWEEP                           0
#define RSRFSIGGEN_VAL_SWEEP_MODE_POWER_SWEEP                               1

#define RSRFSIGGEN_VAL_FSIM_COOR_RX                                         0
#define RSRFSIGGEN_VAL_FSIM_COOR_TX                                         1

// SatNav Standard
#define RSRFSIGGEN_VAL_SATNAV_STANDARD_GPS                                  0
#define RSRFSIGGEN_VAL_SATNAV_STANDARD_GALILEO                              1
#define RSRFSIGGEN_VAL_SATNAV_STANDARD_GLONASS                              2
#define RSRFSIGGEN_VAL_SATNAV_STANDARD_BEIDOU                               3
#define RSRFSIGGEN_VAL_SATNAV_STANDARD_QZSS                                 4
#define RSRFSIGGEN_VAL_SATNAV_STANDARD_SBAS                                 5

#define RSRFSIGGEN_VAL_STAT_REG_PRESET                                      0
#define RSRFSIGGEN_VAL_STAT_REG_QUESTIONABLE                                1
#define RSRFSIGGEN_VAL_STAT_REG_OPERATION                                   2

#define RSRFSIGGEN_VAL_STAT_REG_MAIN                                        0

#define RSRFSIGGEN_VAL_STAT_REG_QUERY_COND                                  0
#define RSRFSIGGEN_VAL_STAT_REG_QUERY_EVENT                                 1

#define RSRFSIGGEN_VAL_SWEEP_MODE_SINGLE                                    1
#define RSRFSIGGEN_VAL_SWEEP_MODE_EXT_SINGLE                                3
#define RSRFSIGGEN_VAL_SWEEP_MODE_EXT_STEP                                  4

#define RSRFSIGGEN_VAL_LIST_TRIGGER_SOURCE_HOP                              3
#define RSRFSIGGEN_VAL_LIST_TRIGGER_SOURCE_DHOP                             4

#define RSRFSIGGEN_VAL_ON_WITHOUT_WAIT                                      2

#define RSRFSIGGEN_VAL_SYSTEM_LOCK_DISPLAY                                   0
#define RSRFSIGGEN_VAL_SYSTEM_LOCK_KEYBOARD                                  1

#define RSRFSIGGEN_VAL_EXTERNAL_CODER_DISCONNECT                             0
#define RSRFSIGGEN_VAL_EXTERNAL_CODER_CONNECT                                1

#define RSRFSIGGEN_VAL_PREDIST_DIAGRAM_AM_AM                                0
#define RSRFSIGGEN_VAL_PREDIST_DIAGRAM_AM_PM                                1

#define RSRFSIGGEN_VAL_PREDIST_UNIT_DBM                                     0
#define RSRFSIGGEN_VAL_PREDIST_UNIT_V                                       1

// RsRFSigGen_rngFrontendSettingsReferenceFrequency backwards compatibility
#define RSRFSIGGEN_VAL_FEREFFREQ_FCUR RSRFSIGGEN_VAL_FRONTEND_REF_FREQ_CURRENT
#define RSRFSIGGEN_VAL_FEREFFREQ_FG5 RSRFSIGGEN_VAL_FRONTEND_REF_FREQ_FG5
#define RSRFSIGGEN_VAL_FEREFFREQ_FG64 RSRFSIGGEN_VAL_FRONTEND_REF_FREQ_64MHZ
#define RSRFSIGGEN_VAL_FEREFFREQ_F1G RSRFSIGGEN_VAL_FRONTEND_REF_FREQ_1GHZ

// For backwards compatibility
#define RSRFSIGGEN_ATTR_5G_NR_OUTPUT_FMODE RSRFSIGGEN_ATTR_5G_NR_OUTPUT_FILTER_MODE

/****************************************************************************
 *---------------- Instrument Driver Function Declarations -----------------*
 ****************************************************************************/
ViStatus _VI_FUNC rsrfsiggen_init(ViRsrc     resourceName,
                                  ViBoolean  IDQuery,
                                  ViBoolean  resetDevice,
                                  ViSession* instrSession);

ViStatus _VI_FUNC rsrfsiggen_InitWithOptions(ViRsrc     resourceName,
                                             ViBoolean  IDQuery,
                                             ViBoolean  resetDevice,
                                             ViString   optionString,
                                             ViSession* instrSession);

ViStatus _VI_FUNC rsrfsiggen_ConfigureRF(ViSession instrSession,
                                         ViInt32   path,
                                         ViReal64  frequency,
                                         ViReal64  powerLevel);

ViStatus _VI_FUNC rsrfsiggen_ConfigureRFFrequency(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViReal64  frequency);

ViStatus _VI_FUNC rsrfsiggen_ConfigureRFAmplitude(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViReal64  powerLevel);

ViStatus _VI_FUNC rsrfsiggen_ConfigureRFLevel(ViSession instrSession,
                                              ViInt32   path,
                                              ViReal64  digitalAttenuation,
                                              ViInt32   mode,
                                              ViInt32   settingCharacteristics,
                                              ViReal64  limit,
                                              ViReal64  offset);

ViStatus _VI_FUNC rsrfsiggen_ConfigureRFLevelAttenuator(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   mode,
                                                        ViReal64  attenuation,
                                                        ViInt32   RFOFFMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigurePowerOnEMF(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViInt32   powerOnState,
                                                 ViBoolean displayLevelAsVoltageOfEMF);

ViStatus _VI_FUNC rsrfsiggen_ConfigureALCEnabled(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViInt32   ALCEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureALC(ViSession instrSession,
                                          ViInt32   path,
                                          ViInt32   detectorSensitivity,
                                          ViInt32   driverAmplifier,
                                          ViInt32   sampleLevel);

ViStatus _VI_FUNC rsrfsiggen_ConfigureUserCorrectionEnabled(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViBoolean userCorrectionEnabled);

ViStatus _VI_FUNC rsrfsiggen_FillUserCorrectionDataWithSensor(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   sensor);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOutputEnabled(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViBoolean outputEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFrequencyAndPowerMode(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   frequencyMode,
                                                            ViInt32   powerMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigurePowerSensorMapping(ViSession instrSession,
                                                         ViInt32   sensor,
                                                         ViInt32   mapping);

ViStatus _VI_FUNC rsrfsiggen_ConfigurePowerSensorMappingDirectly(
                            ViSession instrSession,
                            ViString  sensorID,
                            ViInt32   mapping);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFrontendNetwork(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViString  IPAddress,
                                                      ViString  subnetMask,
                                                      ViInt32   DHCP);

ViStatus _VI_FUNC rsrfsiggen_UserCorrectionDataLevelValues(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViInt32   arraySize,
                                                           ViReal64  power[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureCorrectionFrequencyLoad(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureCorrectionFrequencyStore(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QueryCorrectionFrequencyFRListCatalog(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   arraySize,
                            ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureCorrectionFrequencyFRListSelect(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   FRList,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QueryCorrectionFrequencySListCatalog(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   arraySize,
                            ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureCorrectionFrequencySListSelect(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   sList,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureAMEnabled(ViSession instrSession,
                                                ViInt32   path,
                                                ViBoolean AMEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureAMExternalCoupling(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   AMExternalCoupling);

ViStatus _VI_FUNC rsrfsiggen_ConfigureAM(ViSession instrSession,
                                         ViInt32   path,
                                         ViInt32   depthType,
                                         ViReal64  depth);

ViStatus _VI_FUNC rsrfsiggen_ConfigureAMSMW(ViSession instrSession,
                                            ViInt32   path,
                                            ViInt32   sourceModPath1,
                                            ViInt32   sourceModPath2,
                                            ViBoolean modPath1State,
                                            ViBoolean modPath2State,
                                            ViReal64  depth,
                                            ViReal64  ratioModPath21);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFMEnabled(ViSession instrSession,
                                                ViInt32   path,
                                                ViBoolean FMEnabled,
                                                ViInt32   FMMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFMExternalCoupling(ViSession instrSession,
                                                         ViInt32   FMExternalCoupling);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFM(ViSession instrSession,
                                         ViReal64  deviation);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFMSMW(ViSession instrSession,
                                            ViInt32   path,
                                            ViInt32   sourceModPath1,
                                            ViInt32   sourceModPath2,
                                            ViBoolean modPath1State,
                                            ViBoolean modPath2State,
                                            ViReal64  deviation,
                                            ViReal64  ratioModPath21,
                                            ViInt32   FMMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigurePMEnabled(ViSession instrSession,
                                                ViInt32   path,
                                                ViBoolean PMEnabled,
                                                ViInt32   PMMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigurePMExternalCoupling(ViSession instrSession,
                                                         ViInt32   PMExternalCoupling);

ViStatus _VI_FUNC rsrfsiggen_ConfigurePM(ViSession instrSession,
                                         ViReal64  deviation);

ViStatus _VI_FUNC rsrfsiggen_ConfigurePMSMW(ViSession instrSession,
                                            ViInt32   path,
                                            ViInt32   sourceModPath1,
                                            ViInt32   sourceModPath2,
                                            ViBoolean modPath1State,
                                            ViBoolean modPath2State,
                                            ViReal64  deviation,
                                            ViReal64  ratioModPath21);

ViStatus _VI_FUNC rsrfsiggen_ConfigurePulseModulationEnabled(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViBoolean pulseModulationEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigurePulseModulationSource(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigurePulseModulationExternalPolarity(
                            ViSession instrSession,
                            ViInt32   externalPolarity);

ViStatus _VI_FUNC rsrfsiggen_ConfigurePulseModulation(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViReal64  period,
                                                      ViReal64  width,
                                                      ViReal64  delay);

ViStatus _VI_FUNC rsrfsiggen_ConfigurePulseModulationInputandTriggerSettings(
                            ViSession instrSession,
                            ViInt32   externalImpedance,
                            ViInt32   triggerMode,
                            ViInt32   triggerInputSlope);

ViStatus _VI_FUNC rsrfsiggen_ConfigurePulseGeneratorEnabled(ViSession instrSession,
                                                            ViBoolean pulseGeneratorEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLFOutput(ViSession instrSession,
                                               ViInt32   path,
                                               ViInt32   output,
                                               ViReal64  frequency,
                                               ViInt32   shape);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLFGeneratorOutput(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   output,
                                                        ViReal64  amplitude,
                                                        ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLFSweepState(ViSession instrSession,
                                                   ViBoolean sweepState);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLFSweep(ViSession instrSession,
                                              ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLFFrequencySweepStartStop(
                            ViSession instrSession,
                            ViReal64  start,
                            ViReal64  stop);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLFFrequencyStepStartStop(
                            ViSession instrSession,
                            ViReal64  start,
                            ViReal64  stop,
                            ViInt32   scaling,
                            ViReal64  stepSize);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLFFrequencyStepDwell(ViSession instrSession,
                                                           ViReal64  dwell);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSweep(ViSession instrSession,
                                            ViInt32   path,
                                            ViInt32   type,
                                            ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFrequencySweepState(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViBoolean sweepState);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFrequencySweepStartStop(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64  start,
                            ViReal64  stop);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFrequencySweepCenterSpan(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64  center,
                            ViReal64  span);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFrequencyStep(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   scaling,
                                                    ViReal64  stepSize);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFrequencyStepDwell(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViReal64  dwell);

ViStatus _VI_FUNC rsrfsiggen_ConfigurePowerSweepState(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViBoolean sweepState);

ViStatus _VI_FUNC rsrfsiggen_ConfigurePowerSweepStartStop(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViReal64  start,
                                                          ViReal64  stop);

ViStatus _VI_FUNC rsrfsiggen_ConfigurePowerStepDwell(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViReal64  dwell);

ViStatus _VI_FUNC rsrfsiggen_ConfigureListState(ViSession instrSession,
                                                ViInt32   path,
                                                ViBoolean listState);

ViStatus _VI_FUNC rsrfsiggen_CreateFrequencyList(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViString  name,
                                                 ViReal64  frequencies[],
                                                 ViInt32   arraySize);

ViStatus _VI_FUNC rsrfsiggen_CreatePowerList(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  name,
                                             ViReal64  powers[],
                                             ViInt32   arraySize);

ViStatus _VI_FUNC rsrfsiggen_CreateDwellList(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  name,
                                             ViReal64  dwellTimes[],
                                             ViInt32   arraySize);

ViStatus _VI_FUNC rsrfsiggen_SelectList(ViSession instrSession,
                                        ViInt32   path,
                                        ViString  name);

ViStatus _VI_FUNC rsrfsiggen_ConfigureListDwell(ViSession instrSession,
                                                ViInt32   path,
                                                ViReal64  dwell);

ViStatus _VI_FUNC rsrfsiggen_ConfigureListDwellMode(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   mode,
                                                    ViInt32   dwellTimeMode);

ViStatus _VI_FUNC rsrfsiggen_ListCurrentState(ViSession  instrSession,
                                              ViInt32    path,
                                              ViBoolean* listState);

ViStatus _VI_FUNC rsrfsiggen_QueryPowerSParameterList(ViSession instrSession,
                                                      ViInt32   sensor,
                                                      ViInt32   arraySize,
                                                      ViChar    sParameterList[]);

ViStatus _VI_FUNC rsrfsiggen_PowerSParameterSelect(ViSession instrSession,
                                                   ViInt32   sensor,
                                                   ViInt32   sList);

ViStatus _VI_FUNC rsrfsiggen_ResetList(ViSession instrSession,
                                       ViInt32   path);

ViStatus _VI_FUNC rsrfsiggen_ConfigureListImportExport(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   mode,
                                                       ViString  name);

ViStatus _VI_FUNC rsrfsiggen_ConfigureListImportExportASCII(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViString  name,
                                                            ViInt32   extension,
                                                            ViInt32   columnSeparator,
                                                            ViInt32   decimalSeparator);

ViStatus _VI_FUNC rsrfsiggen_ExecuteListImportExport(ViSession instrSession,
                                                     ViInt32   path);

ViStatus _VI_FUNC rsrfsiggen_ConfigureListModeData(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViInt32   startListRange,
                                                   ViInt32   stopListRange,
                                                   ViInt32   runMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureReferenceOscillator(ViSession instrSession,
                                                          ViInt32   source,
                                                          ViInt32   frequency);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQEnabled(ViSession instrSession,
                                                ViInt32   path,
                                                ViBoolean IQEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQ(ViSession instrSession,
                                         ViInt32   path,
                                         ViInt32   source,
                                         ViBoolean swapEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQImpairmentEnabled(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViBoolean IQImpairmentEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQImpairment(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViReal64  iOffset,
                                                   ViReal64  qOffset,
                                                   ViReal64  gainImbalance,
                                                   ViReal64  quadratureOffset);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQAnalogWidebandInput(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   gain,
                                                            ViReal64  crestFactor);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQOutputOptimizeIQSignalsforRFOutputEnabled(
                            ViSession instrSession,
                            ViInt32   path,
                            ViBoolean IQSignalsForRFOutput);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQOutput(ViSession instrSession,
                                               ViInt32   path,
                                               ViInt32   IQOutputType,
                                               ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQOutputAnalogEnabled(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViBoolean IQAnalogEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQOutputAnalog(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViReal64  biasI,
                                                     ViReal64  offsetI,
                                                     ViReal64  biasQ,
                                                     ViReal64  offsetQ);

ViStatus _VI_FUNC rsrfsiggen_QueryIQEnvelopeVccForX(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViReal64  xValue,
                                                    ViInt32   xUnit,
                                                    ViInt32   xScale,
                                                    ViReal64* vcc);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQOutputEnvelopeTablesNew(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName,
                            ViInt32   arraySize,
                            ViReal64  data[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQOutputEnvelopeTablesData(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   arraySize,
                            ViReal64  data[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQOutputEnvelopeTablesAutoNew(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName,
                            ViInt32   arraySize,
                            ViReal64  data[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQOutputEnvelopeTablesAutoData(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   arraySize,
                            ViReal64  data[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQOutputEnvelopePolynomialCoefficients(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   arraySize,
                            ViReal64  coefficients[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQOutputDigitalEnabled(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViBoolean IQDigitalEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQDigitalPredistortionEnabled(
                            ViSession instrSession,
                            ViInt32   path,
                            ViBoolean digitalPredistortionEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQDigitalPredistortion(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   referenceLevel,
                                                             ViBoolean AMAMFirst,
                                                             ViReal64  maximumOutputLevelError,
                                                             ViInt32   maximumNumberOfIterations);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQDigitalPredistortionCorrection(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   shaping,
                            ViInt32   interpolation,
                            ViBoolean invertCorrectionValues);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQDigitalPredistortionInputPower(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64  minimumRange_PEPin,
                            ViReal64  maximumRange_PEPin);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQDigitalPredistortionDPDShapingTablesData(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   diagram,
                            ViInt32   arraySize,
                            ViReal64  data[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQDigitalPredistortionDPDShapingTablesNewFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   diagram,
                            ViString  fileName,
                            ViInt32   arraySize,
                            ViReal64  data[]);

ViStatus _VI_FUNC rsrfsiggen_QueryIQDigitalPredistortionDPDDeltaPhaseDeltaPowerForX(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   diagram,
                            ViReal64  xValue,
                            ViInt32   xUnit,
                            ViReal64* deltaPhase,
                            ViReal64* deltaPower);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQDigitalDPDShapingPolynomialCoefficients(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   arraySize,
                            ViReal64  coefficients[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQDigitalPredistortionNormalizedData(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64  pinMax,
                            ViReal64  vinVmax[],
                            ViReal64  deltaV[],
                            ViReal64  deltaPhase[],
                            ViInt32   arraySize);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQDigitalDohertyShapingTablesData(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   diagram,
                            ViInt32   arraySize,
                            ViReal64  data[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQDigitalDohertyShapingTablesNewFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   diagram,
                            ViString  fileName,
                            ViInt32   arraySize,
                            ViReal64  data[]);

ViStatus _VI_FUNC rsrfsiggen_QueryIQDigitalDohertyDeltaPhaseDeltaPowerForX(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   diagram,
                            ViReal64  xValue,
                            ViInt32   xUnit,
                            ViReal64* deltaPhase,
                            ViReal64* deltaPower);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQDigitalDohertyShapingPolynomialCoefficients(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   arraySize,
                            ViReal64  coefficients[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureIQDigitaDohertylPredistortionNormalizedData(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64  pinMax,
                            ViReal64  vinVmax[],
                            ViReal64  deltaV[],
                            ViReal64  deltaPhase[],
                            ViInt32   arraySize);

ViStatus _VI_FUNC rsrfsiggen_FileCatalog(ViSession instrSession,
                                         ViInt32   path,
                                         ViInt32   subsystem,
                                         ViInt32   arraySize,
                                         ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_FileSettings(ViSession instrSession,
                                          ViInt32   path,
                                          ViInt32   action,
                                          ViInt32   subsystem,
                                          ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_FileDirectory(ViSession instrSession,
                                           ViString  directory,
                                           ViInt32   bufferSize,
                                           ViChar    output[]);

ViStatus _VI_FUNC rsrfsiggen_FileCount(ViSession instrSession,
                                       ViString  directory,
                                       ViInt32*  numberOfFilesAndFolders);

ViStatus _VI_FUNC rsrfsiggen_FileSubDirectory(ViSession instrSession,
                                              ViString  directory,
                                              ViInt32   bufferSize,
                                              ViChar    output[]);

ViStatus _VI_FUNC rsrfsiggen_FileSubDirectoryCount(ViSession instrSession,
                                                   ViString  directory,
                                                   ViInt32*  numberOfFilesAndFolders);

ViStatus _VI_FUNC rsrfsiggen_MoveFile(ViSession instrSession,
                                      ViString  source,
                                      ViString  destination);

ViStatus _VI_FUNC rsrfsiggen_CopyFile(ViSession instrSession,
                                      ViString  source,
                                      ViString  destination);

ViStatus _VI_FUNC rsrfsiggen_FileDelete(ViSession instrSession,
                                        ViString  filename);

ViStatus _VI_FUNC rsrfsiggen_ChangeDirectory(ViSession instrSession,
                                             ViString  directory);

ViStatus _VI_FUNC rsrfsiggen_MakeDirectory(ViSession instrSession,
                                           ViString  directory);

ViStatus _VI_FUNC rsrfsiggen_DeleteDirectory(ViSession instrSession,
                                             ViString  directory);

ViStatus _VI_FUNC rsrfsiggen_GetUserPath(ViSession instrSession,
                                         ViInt32   arraySize,
                                         ViChar    userPath[]);

ViStatus _VI_FUNC rsrfsiggen_ChangeDrive(ViSession instrSession,
                                         ViString  drive);

ViStatus _VI_FUNC rsrfsiggen_LoadState(ViSession instrSession,
                                       ViInt32   number,
                                       ViString  filename);

ViStatus _VI_FUNC rsrfsiggen_StoreState(ViSession instrSession,
                                        ViInt32   number,
                                        ViString  filename);

ViStatus _VI_FUNC rsrfsiggen_GenerateWaveformFile(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViInt32   subsystem,
                                                  ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ReadToFileFromInstrument(ViSession instrSession,
                                                      ViString  source,
                                                      ViString  destination);

ViStatus _VI_FUNC rsrfsiggen_WriteFromFileToInstrument(ViSession instrSession,
                                                       ViString  source,
                                                       ViString  destination);

ViStatus _VI_FUNC rsrfsiggen_RecallInstrumentSettings(ViSession instrSession,
                                                      ViString  filename);

ViStatus _VI_FUNC rsrfsiggen_SaveInstrumentSettings(ViSession instrSession,
                                                    ViString  filename);

ViStatus _VI_FUNC rsrfsiggen_ConfigureArb(ViSession instrSession,
                                          ViInt32   path,
                                          ViString  waveform,
                                          ViReal64  clockFrequency,
                                          ViUInt16  ARBEnabled);

ViStatus _VI_FUNC rsrfsiggen_ARBMultisegmentAddBlankSegment(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViReal64  sampleCount,
                                                            ViReal64  frequency);

ViStatus _VI_FUNC rsrfsiggen_ARBMultisegmentAppendSegmentToPlayList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViBoolean state,
                            ViInt32   segment,
                            ViInt32   repetition,
                            ViInt32   next);

ViStatus _VI_FUNC rsrfsiggen_ClearAllArbWaveforms(ViSession instrSession,
                                                  ViInt32   path);

ViStatus _VI_FUNC rsrfsiggen_QueryARBEthernetUploadStatistics(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   statisticsAll[]);

ViStatus _VI_FUNC rsrfsiggen_QueryARBEthernetUploadWaveformTag(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  tagName,
                            ViInt32   bufferSize,
                            ViChar    tag[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsrfsiggen_WriteARBClockWaveformFile(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViString  fileName,
                                                       ViReal64  clock);

ViStatus _VI_FUNC rsrfsiggen_ConfigureARBClockSource(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureARBClockSourceLegacy(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ARBWaveformDataWrite(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViString  fileName,
                                                  ViInt32   arraySize,
                                                  ViUInt8   waveformData[]);

ViStatus _VI_FUNC rsrfsiggen_ARBWaveformDataRead(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViString  fileName,
                                                 ViString  waveformTag,
                                                 ViInt32   bufferSize,
                                                 ViChar    waveformData[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureARBTriggerDateTime(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   year,
                                                         ViInt32   month,
                                                         ViInt32   day,
                                                         ViInt32   hour,
                                                         ViInt32   minute,
                                                         ViInt32   second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMEnabled(ViSession instrSession,
                                                ViInt32   path,
                                                ViBoolean DMEnabled);

ViStatus _VI_FUNC rsrfsiggen_SelectDMStandard(ViSession instrSession,
                                              ViInt32   path,
                                              ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMDataSource(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMPRBSType(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViInt32   type);

ViStatus _VI_FUNC rsrfsiggen_DMGenerateWaveformFile(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMModulationType(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   modulation);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMPowerRampEnabled(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMPowerRampAttenuation(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViBoolean attenuation);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMPowerRamp(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViInt32   source,
                                                  ViInt32   function,
                                                  ViReal64  time,
                                                  ViReal64  riseDelay,
                                                  ViReal64  fallDelay,
                                                  ViReal64  attenuation);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMClockSource(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMClockSourceLegacy(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMTriggerDateTime(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   year,
                                                        ViInt32   month,
                                                        ViInt32   day,
                                                        ViInt32   hour,
                                                        ViInt32   minute,
                                                        ViInt32   second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureBBINDigitalInterface(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViInt32   digitalInterface);

ViStatus _VI_FUNC rsrfsiggen_ConfigureBBINChannelMapping(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   channel,
                                                         ViBoolean activateChannel,
                                                         ViInt32   BBChannel);

ViStatus _VI_FUNC rsrfsiggen_ConfigureBBINChannelPower(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   channel,
                                                       ViReal64  crestFactor,
                                                       ViReal64  peakLevel);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGSMEnabled(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean GSMEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGSM(ViSession instrSession,
                                          ViInt32   path,
                                          ViInt32   sequenceMode,
                                          ViInt32   symbolRateMode,
                                          ViInt32   simulationMode);

ViStatus _VI_FUNC rsrfsiggen_RecallGSMPredefinedFrame(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_RecallGSMUserFrame(ViSession instrSession,
                                                ViInt32   path,
                                                ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_SaveGSMUserFrame(ViSession instrSession,
                                              ViInt32   path,
                                              ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_DeleteGSMUserFrame(ViSession instrSession,
                                                ViInt32   path,
                                                ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_RecallGSMPredefinedSlot(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   frame,
                                                     ViInt32   slot,
                                                     ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_RecallGSMUserSlot(ViSession instrSession,
                                               ViInt32   path,
                                               ViInt32   frame,
                                               ViInt32   slot,
                                               ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_SaveGSMUserSlot(ViSession instrSession,
                                             ViInt32   path,
                                             ViInt32   frame,
                                             ViInt32   slot,
                                             ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_DeleteGSMUserSlot(ViSession instrSession,
                                               ViInt32   path,
                                               ViInt32   frame,
                                               ViInt32   slot,
                                               ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QueryGSMUserSlotMarkerDefinition(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   frame,
                            ViInt32   slot,
                            ViInt32   user,
                            ViString  tag,
                            ViInt32   arraySize,
                            ViChar    response[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGSMTriggerMode(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGSMTriggerSource(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGSMTriggerSourceLegacy(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGSMTrigger(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean sync,
                                                 ViReal64  delay,
                                                 ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGSMTriggerDateTime(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   year,
                                                         ViInt32   month,
                                                         ViInt32   day,
                                                         ViInt32   hour,
                                                         ViInt32   minute,
                                                         ViInt32   second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGSMMarkerMode(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   marker,
                                                    ViInt32   mode,
                                                    ViInt32   period);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGSMMarkerDelay(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   marker,
                                                     ViInt32   delay);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGSMClockSource(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGSMClockSourceLegacy(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureBTEnabled(ViSession instrSession,
                                                ViInt32   path,
                                                ViBoolean BTOEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureBTMode(ViSession instrSession,
                                             ViInt32   path,
                                             ViInt32   bluetoothMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureBTBasic(ViSession instrSession,
                                              ViInt32   path,
                                              ViInt32   transportMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureBTLowEnergy(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViInt32   channelType);

ViStatus _VI_FUNC rsrfsiggen_ConfigureBTLowEnergyFeatureSet(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   featureSet,
                                                            ViBoolean state);

ViStatus _VI_FUNC rsrfsiggen_ConfigureBTTriggerMode(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureBTTriggerSource(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureBTTriggerSourceLegacy(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureBTTrigger(ViSession instrSession,
                                                ViInt32   path,
                                                ViBoolean sync,
                                                ViReal64  delay,
                                                ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureBTTriggerDateTime(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   year,
                                                        ViInt32   month,
                                                        ViInt32   day,
                                                        ViInt32   hour,
                                                        ViInt32   minute,
                                                        ViInt32   second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureBTClockSource(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureBTClockSourceLegacy(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureW3GPPEnabled(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViBoolean w3GPPEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureW3GPPLinkDirection(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   linkDirection);

ViStatus _VI_FUNC rsrfsiggen_ConfigureW3GPPBasestationOCNS(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViBoolean OCNS,
                                                           ViInt32   OCNSMode);

ViStatus _VI_FUNC rsrfsiggen_DeleteW3GPPChannelCodingUserCoding(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_RecallW3GPPChannelCodingUserCoding(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_SaveW3GPPChannelCodingUserCoding(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_DeleteW3GPPGlobalEnhancedChannels(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_RecallW3GPPGlobalEnhancedChannels(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_SaveW3GPPGlobalEnhancedChannels(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureW3GPPTriggerMode(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureW3GPPTriggerSource(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureW3GPPTriggerSourceLegacy(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureW3GPPTrigger(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViBoolean sync,
                                                   ViReal64  delay,
                                                   ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureW3GPPClockSource(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureW3GPPClockSourceLegacy(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureC2kEnabled(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean c2KEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureC2kLinkDirection(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   linkDirection);

ViStatus _VI_FUNC rsrfsiggen_C2kCopyFromSource(ViSession instrSession,
                                               ViInt32   path,
                                               ViInt32   station);

ViStatus _VI_FUNC rsrfsiggen_C2kToDestination(ViSession instrSession,
                                              ViInt32   path,
                                              ViInt32   station);

ViStatus _VI_FUNC rsrfsiggen_ConfigureC2kTriggerMode(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureC2kTriggerSource(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureC2kTriggerSourceLegacy(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureC2kTrigger(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean sync,
                                                 ViReal64  delay,
                                                 ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureC2kClockSource(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureC2kClockSourceLegacy(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTDSCDMAEnabled(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViBoolean TDSCDMAEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTDSCDMALinkDirection(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViInt32   linkDirection);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTDSCDMATriggerMode(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTDSCDMATriggerSource(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTDSCDMATriggerSourceLegacy(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTDSCDMATrigger(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViBoolean sync,
                                                     ViReal64  delay,
                                                     ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTDSCDMAClockSource(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTDSCDMAClockSourceLegacy(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEVDOEnabled(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViBoolean EVDOEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEVDO(ViSession instrSession,
                                           ViInt32   path,
                                           ViInt32   linkDirection,
                                           ViInt32   PNOffset,
                                           ViReal64  systemTime);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEVDOTerminalPredefinedSettings(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   predefinedSettings);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEVDOTriggerMode(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEVDOTriggerSource(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEVDOTriggerSourceLegacy(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEVDOTrigger(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViBoolean sync,
                                                  ViReal64  delay,
                                                  ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEVDOClockSource(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEVDOClockSourceLegacy(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANEnabled(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViBoolean WLANEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLAN(ViSession instrSession,
                                           ViInt32   path,
                                           ViInt32   standard,
                                           ViInt32   physicalLayer,
                                           ViInt32   simulationMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANFrame(ViSession instrSession,
                                                ViInt32   path,
                                                ViInt32   predefinedFrame,
                                                ViInt32   sequenceLength,
                                                ViReal64  idleTime);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANTriggerMode(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANTriggerSource(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANTriggerSourceLegacy(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANTrigger(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViBoolean sync,
                                                  ViInt32   delay,
                                                  ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANClockSource(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANClockSourceLegacy(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANNEnabled(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViBoolean WLANEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANN(ViSession instrSession,
                                            ViInt32   path,
                                            ViInt32   standard,
                                            ViBoolean configureBasebandBFromA);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANNStandard(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   frame,
                                                    ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_SaveWLANAntennasChainMappingFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   txChain,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_WLANNPPDUSpatialMappingBeamformingFileSelection(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   frame,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANNTriggerDateTime(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViInt32   year,
                                                           ViInt32   month,
                                                           ViInt32   day,
                                                           ViInt32   hour,
                                                           ViInt32   minute,
                                                           ViInt32   second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANADEnabled(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANAD(ViSession instrSession,
                                             ViInt32   path,
                                             ViInt32   frameType,
                                             ViInt32   DMGPHYMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANADTriggerIn(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   mode,
                                                      ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANADTriggerDateTime(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   year,
                                                            ViInt32   month,
                                                            ViInt32   day,
                                                            ViInt32   hour,
                                                            ViInt32   minute,
                                                            ViInt32   second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANADMarker(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViInt32   marker,
                                                   ViInt32   mode,
                                                   ViReal64  delay);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWLANADFrame(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViInt32   sequenceLength,
                                                  ViReal64  idleTime);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWiMAXEnabled(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViBoolean wiMAXEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWiMAXPhysicalLayerMode(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   physicalLayerMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWiMAXVersion(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViInt32   version);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWiMAXOFDM(ViSession instrSession,
                                                ViInt32   path,
                                                ViInt32   duplexing,
                                                ViInt32   linkDirection,
                                                ViInt32   frameDuration,
                                                ViReal64  userFrameDuration,
                                                ViInt32   sequenceLength,
                                                ViInt32   predefinedFrames,
                                                ViInt32   levelReference);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWiMAXOFDMA(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViInt32   linkDirection,
                                                 ViBoolean basebandAB,
                                                 ViInt32   frameDuration,
                                                 ViReal64  userFrameDuration,
                                                 ViInt32   sequenceLength,
                                                 ViInt32   predefinedFrames,
                                                 ViInt32   levelReference);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWiMAXOFDMUlmapFile(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureWiMAXOFDMAUlmapFile(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   zone,
                                                          ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDVBEnabled(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean DVBEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDVB(ViSession instrSession,
                                          ViInt32   path,
                                          ViInt32   DVBStandard,
                                          ViInt32   numberOfSuperFrames);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDVBTriggerMode(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDVBTriggerSource(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDVBTriggerSourceLegacy(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDVBTrigger(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean sync,
                                                 ViReal64  delay,
                                                 ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDVBTriggerDateTime(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   year,
                                                         ViInt32   month,
                                                         ViInt32   day,
                                                         ViInt32   hour,
                                                         ViInt32   minute,
                                                         ViInt32   second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDVBClockSource(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDVBClockSourceLegacy(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDABEnabled(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean DABEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDAB(ViSession instrSession,
                                          ViInt32   path,
                                          ViInt32   dataSource,
                                          ViInt32   transportMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDABETI(ViSession instrSession,
                                             ViInt32   path,
                                             ViString  ETIFile,
                                             ViInt32   numberOfETIFrames);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDABTriggerMode(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDABTriggerSource(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDABTriggerSourceLegacy(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDABTrigger(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean sync,
                                                 ViInt32   delay,
                                                 ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDABClockSource(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDABClockSourceLegacy(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWCarrierSetup(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   noOfCarriers,
                                                       ViReal64  carrierSpacing,
                                                       ViInt32   optimizeCrestFactorMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWTableCarrier(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   carrierStart,
                                                       ViInt32   carrierStop);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWTablePhase(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViReal64  phaseStart,
                                                     ViReal64  phaseStep);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWTablePower(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViReal64  powerStart,
                                                     ViReal64  powerStep);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWCarrierEnabled(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   carrierIndex,
                                                         ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWCarrierPhase(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   carrierIndex,
                                                       ViReal64  phase);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWCarrierPower(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   carrierIndex,
                                                       ViReal64  power);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWMulticarrierCarrierEnabled(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   arraySize,
                            ViBoolean enabled[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWMulticarrierCarrierPhase(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   arraySize,
                            ViReal64  phase[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWMulticarrierCarrierPower(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   arraySize,
                            ViReal64  power[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWTriggerMode(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWTriggerSource(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWTriggerSourceLegacy(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWTrigger(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViBoolean sync,
                                                  ViReal64  delay,
                                                  ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWTriggerDateTime(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   year,
                                                          ViInt32   month,
                                                          ViInt32   day,
                                                          ViInt32   hour,
                                                          ViInt32   minute,
                                                          ViInt32   second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWClockSource(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMCCWClockSourceLegacy(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureStereoEnabled(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViBoolean stereoEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureStereoAudioSettings(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViReal64  deviation,
                                                          ViInt32   audioMode,
                                                          ViReal64  audioLevel,
                                                          ViInt32   preemphasis);

ViStatus _VI_FUNC rsrfsiggen_ConfigureStereoAudioSource(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureStereoPilotEnable(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureStereoPilotTone(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViReal64  deviation,
                                                      ViReal64  phase);

ViStatus _VI_FUNC rsrfsiggen_ConfigureXMREnabled(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean XMREnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureXMR(ViSession instrSession,
                                          ViInt32   path,
                                          ViInt32   physicalLayerMode,
                                          ViInt32   dataSource);

ViStatus _VI_FUNC rsrfsiggen_ConfigureXMRSatellite(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViReal64  delay);

ViStatus _VI_FUNC rsrfsiggen_ConfigureXMRTerrestrial(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViReal64  delay,
                                                     ViReal64  levelAMSS,
                                                     ViReal64  levelMCM);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSiriusEnabled(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViBoolean siriusEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSirius(ViSession instrSession,
                                             ViInt32   path,
                                             ViInt32   physicalLayer,
                                             ViInt32   physicalLayerTransmission,
                                             ViInt32   dataSource);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSiriusSatellite(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViReal64  delay,
                                                      ViInt32   modulation,
                                                      ViInt32   overlayAngularOffset);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSiriusTerrestrial(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViReal64  delay,
                                                        ViInt32   overlayAngularOffset);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEUTRAEnabled(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViBoolean EUTRAEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEUTRA(ViSession instrSession,
                                            ViInt32   path,
                                            ViInt32   duplexing,
                                            ViInt32   linkDirection,
                                            ViInt32   sequenceLength);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEUTRADLUserAPMCodebookIndex(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   user,
                            ViInt32   index,
                            ViInt32   codebookIndex);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEUTRATriggerMode(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEUTRATriggerSource(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEUTRATriggerSourceLegacy(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEUTRATrigger(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViBoolean sync,
                                                   ViReal64  delay,
                                                   ViInt64   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEUTRATriggerDateTime(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViInt32   year,
                                                           ViInt32   month,
                                                           ViInt32   day,
                                                           ViInt32   hour,
                                                           ViInt32   minute,
                                                           ViInt32   second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEUTRAClockSource(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureEUTRAClockSourceLegacy(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTETRAEnabled(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViBoolean TETRAEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTETRA(ViSession instrSession,
                                            ViInt32   path,
                                            ViInt32   testMode,
                                            ViInt32   linkDirection,
                                            ViInt32   sequenceLength);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTETRAChannelType(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   testMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTETRAModulationType(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   modulationType);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTETRADownlinkBurstType(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   burstType);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTETRATriggerMode(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTETRATriggerSource(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTETRATriggerSourceLegacy(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTETRATrigger(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViBoolean sync,
                                                   ViReal64  delay,
                                                   ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTETRAClockSource(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureTETRAClockSourceLegacy(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSEnabled(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViBoolean GPSEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPS(ViSession instrSession,
                                                ViInt32   path,
                                                ViInt32   RFBand,
                                                ViInt32   testScenario,
                                                ViInt32   simulationMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSGNSS(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViBoolean GALILEO,
                                                    ViBoolean GLONASS,
                                                    ViBoolean RFFrequency,
                                                    ViBoolean pCode,
                                                    ViBoolean beiDou);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSAlmanacFileGPS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSAlmanacFileGALILEO(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSAlmanacFileGLONASS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSRINEXFileGPS(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSRINEXFileGALILEO(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSRINEXFileGLONASS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSTriggerMode(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSTriggerSource(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSClockSource(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSUserEnvironmentVehicleLoad(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSLocWaypointFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSLocCoordinatesDecimal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64  longitude,
                            ViReal64  latitude,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSLocCoordinatesDMS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDir,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDir,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSAntennaLoad(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSAntennaUpdate(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViReal64  elapsedTime,
                                                             ViInt32   antennaID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSNavigationDate(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   year,
                            ViInt32   month,
                            ViInt32   day);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSNavigationTime(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   hour,
                            ViInt32   minute,
                            ViReal64  seconds);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSADGRefCoordinatesDecimal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   system,
                            ViReal64  longitude,
                            ViReal64  latitude,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSADGRefCoordinatesDMS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   system,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDir,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDir,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSADGGenerateAlmanacFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSADGGenerateNavigationFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSADGGenerateAcquisitionFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSADGGenerateIonosphericFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSADGGenerateUTCFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGPSSat(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViInt32   powerMode,
                                                   ViReal64  referencePower);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGPSRTAttitude(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   timeBasis,
                                                      ViInt32   year,
                                                      ViInt32   month,
                                                      ViInt32   day,
                                                      ViInt32   hour,
                                                      ViInt32   minutes,
                                                      ViReal64  seconds,
                                                      ViInt32   weekNumber,
                                                      ViReal64  timeOfWeek,
                                                      ViReal64* yaw,
                                                      ViReal64* pitch,
                                                      ViReal64* roll);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGPSRTDecimal(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   timeBasis,
                                                     ViInt32   year,
                                                     ViInt32   month,
                                                     ViInt32   day,
                                                     ViInt32   hour,
                                                     ViInt32   minutes,
                                                     ViReal64  seconds,
                                                     ViInt32   weekNumber,
                                                     ViReal64  timeOfWeek,
                                                     ViReal64* longitude,
                                                     ViReal64* latitude,
                                                     ViReal64* altitude);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGPSRTDMS(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViInt32   timeBasis,
                                                 ViInt32   year,
                                                 ViInt32   month,
                                                 ViInt32   day,
                                                 ViInt32   hour,
                                                 ViInt32   minutes,
                                                 ViReal64  seconds,
                                                 ViInt32   weekNumber,
                                                 ViReal64  timeOfWeek,
                                                 ViInt32*  longitudeDeg,
                                                 ViInt32*  longitudeMin,
                                                 ViReal64* longitudeSec,
                                                 ViChar    longitudeDir[],
                                                 ViInt32*  latitudeDeg,
                                                 ViInt32*  latitudeMin,
                                                 ViReal64* latitudeSec,
                                                 ViChar    latitudeDir[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGPSRTAzimuth(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   SVID,
                                                     ViInt32   system,
                                                     ViInt32   timeBasis,
                                                     ViInt32   year,
                                                     ViInt32   month,
                                                     ViInt32   day,
                                                     ViInt32   hour,
                                                     ViInt32   minutes,
                                                     ViReal64  seconds,
                                                     ViInt32   weekNumber,
                                                     ViReal64  timeOfWeek,
                                                     ViReal64* azimuth);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGPSRTElevation(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   SVID,
                                                       ViInt32   system,
                                                       ViInt32   timeBasis,
                                                       ViInt32   year,
                                                       ViInt32   month,
                                                       ViInt32   day,
                                                       ViInt32   hour,
                                                       ViInt32   minutes,
                                                       ViReal64  seconds,
                                                       ViInt32   weekNumber,
                                                       ViReal64  timeOfWeek,
                                                       ViReal64* elevation);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGPSRTPower(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViInt32   SVID,
                                                   ViInt32   system,
                                                   ViInt32   tap,
                                                   ViInt32   timeBasis,
                                                   ViInt32   year,
                                                   ViInt32   month,
                                                   ViInt32   day,
                                                   ViInt32   hour,
                                                   ViInt32   minutes,
                                                   ViReal64  seconds,
                                                   ViInt32   weekNumber,
                                                   ViReal64  timeOfWeek,
                                                   ViReal64* absolutePower);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALEnabled(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViBoolean GALEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGAL(ViSession instrSession,
                                                ViInt32   path,
                                                ViInt32   RFBand,
                                                ViInt32   testScenario,
                                                ViInt32   simulationMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALGNSS(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViBoolean GPS,
                                                    ViBoolean GLONASS,
                                                    ViBoolean beiDou,
                                                    ViBoolean RFFrequency,
                                                    ViBoolean pCode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALAlmanacFileGPS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALAlmanacFileGALILEO(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALAlmanacFileGLONASS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALRINEXFileGPS(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALRINEXFileGALILEO(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALRINEXFileGLONASS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALTriggerMode(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALTriggerSource(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALClockSource(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALUserEnvironmentVehicleLoad(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALLocWaypointFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALLocCoordinatesDecimal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64  longitude,
                            ViReal64  latitude,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALLocCoordinatesDMS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDir,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDir,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALAntennaLoad(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALAntennaUpdate(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViReal64  elapsedTime,
                                                             ViInt32   antennaID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALNavigationDate(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   year,
                            ViInt32   month,
                            ViInt32   day);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALNavigationTime(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   hour,
                            ViInt32   minute,
                            ViReal64  seconds);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALADGRefCoordinatesDecimal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   system,
                            ViReal64  longitude,
                            ViReal64  latitude,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALADGRefCoordinatesDMS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   system,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDir,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDir,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALADGGenerateAlmanacFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALADGGenerateNavigationFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALADGGenerateAcquisitionFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALADGGenerateIonosphericFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALADGGenerateUTCFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGALSat(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViInt32   powerMode,
                                                   ViReal64  referencePower);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGALRTAttitude(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   timeBasis,
                                                      ViInt32   year,
                                                      ViInt32   month,
                                                      ViInt32   day,
                                                      ViInt32   hour,
                                                      ViInt32   minutes,
                                                      ViReal64  seconds,
                                                      ViInt32   weekNumber,
                                                      ViReal64  timeOfWeek,
                                                      ViReal64* yaw,
                                                      ViReal64* pitch,
                                                      ViReal64* roll);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGALRTDecimal(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   timeBasis,
                                                     ViInt32   year,
                                                     ViInt32   month,
                                                     ViInt32   day,
                                                     ViInt32   hour,
                                                     ViInt32   minutes,
                                                     ViReal64  seconds,
                                                     ViInt32   weekNumber,
                                                     ViReal64  timeOfWeek,
                                                     ViReal64* longitude,
                                                     ViReal64* latitude,
                                                     ViReal64* altitude);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGALRTDMS(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViInt32   timeBasis,
                                                 ViInt32   year,
                                                 ViInt32   month,
                                                 ViInt32   day,
                                                 ViInt32   hour,
                                                 ViInt32   minutes,
                                                 ViReal64  seconds,
                                                 ViInt32   weekNumber,
                                                 ViReal64  timeOfWeek,
                                                 ViInt32*  longitudeDeg,
                                                 ViInt32*  longitudeMin,
                                                 ViReal64* longitudeSec,
                                                 ViChar    longitudeDir[],
                                                 ViInt32*  latitudeDeg,
                                                 ViInt32*  latitudeMin,
                                                 ViReal64* latitudeSec,
                                                 ViChar    latitudeDir[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGALRTAzimuth(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   SVID,
                                                     ViInt32   system,
                                                     ViInt32   timeBasis,
                                                     ViInt32   year,
                                                     ViInt32   month,
                                                     ViInt32   day,
                                                     ViInt32   hour,
                                                     ViInt32   minutes,
                                                     ViReal64  seconds,
                                                     ViInt32   weekNumber,
                                                     ViReal64  timeOfWeek,
                                                     ViReal64* azimuth);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGALRTElevation(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   SVID,
                                                       ViInt32   system,
                                                       ViInt32   timeBasis,
                                                       ViInt32   year,
                                                       ViInt32   month,
                                                       ViInt32   day,
                                                       ViInt32   hour,
                                                       ViInt32   minutes,
                                                       ViReal64  seconds,
                                                       ViInt32   weekNumber,
                                                       ViReal64  timeOfWeek,
                                                       ViReal64* elevation);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGALRTPower(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViInt32   SVID,
                                                   ViInt32   system,
                                                   ViInt32   tap,
                                                   ViInt32   timeBasis,
                                                   ViInt32   year,
                                                   ViInt32   month,
                                                   ViInt32   day,
                                                   ViInt32   hour,
                                                   ViInt32   minutes,
                                                   ViReal64  seconds,
                                                   ViInt32   weekNumber,
                                                   ViReal64  timeOfWeek,
                                                   ViReal64* absolutePower);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONEnabled(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViBoolean GLOEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLON(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViInt32   RFBand,
                                                 ViInt32   testScenario,
                                                 ViInt32   simulationMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONGNSS(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViBoolean GPS,
                                                     ViBoolean GALILEO,
                                                     ViBoolean beiDou,
                                                     ViBoolean RFFrequency,
                                                     ViBoolean pCode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONAlmanacFileGPS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONAlmanacFileGALILEO(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLOAlmanacFileGLONASS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONRINEXFileGPS(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONRINEXFileGALILEO(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLORINEXFileGLONASS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONTriggerMode(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONTriggerSource(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONClockSource(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONUserEnvironmentVehicleLoad(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONLocWaypointFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONLocCoordinatesDecimal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64  longitude,
                            ViReal64  latitude,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONLocCoordinatesDMS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDir,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDir,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONAntennaLoad(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONAntennaUpdate(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64  elapsedTime,
                            ViInt32   antennaID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONNavigationDate(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   year,
                            ViInt32   month,
                            ViInt32   day);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONNavigationTime(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   hour,
                            ViInt32   minute,
                            ViReal64  seconds);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONADGRefCoordinatesDecimal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   system,
                            ViReal64  longitude,
                            ViReal64  latitude,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONADGRefCoordinatesDMS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   system,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDir,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDir,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONADGGenerateAlmanacFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONADGGenerateNavigationFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONADGGenerateAcquisitionFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONADGGenerateIonosphericFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONADGGenerateUTCFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGLONSat(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   powerMode,
                                                    ViReal64  referencePower);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGLONRTAttitude(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   timeBasis,
                                                       ViInt32   year,
                                                       ViInt32   month,
                                                       ViInt32   day,
                                                       ViInt32   hour,
                                                       ViInt32   minutes,
                                                       ViReal64  seconds,
                                                       ViInt32   weekNumber,
                                                       ViReal64  timeOfWeek,
                                                       ViReal64* yaw,
                                                       ViReal64* pitch,
                                                       ViReal64* roll);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGLORTDecimal(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   timeBasis,
                                                     ViInt32   year,
                                                     ViInt32   month,
                                                     ViInt32   day,
                                                     ViInt32   hour,
                                                     ViInt32   minutes,
                                                     ViReal64  seconds,
                                                     ViInt32   weekNumber,
                                                     ViReal64  timeOfWeek,
                                                     ViReal64* longitude,
                                                     ViReal64* latitude,
                                                     ViReal64* altitude);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGLORTDMS(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViInt32   timeBasis,
                                                 ViInt32   year,
                                                 ViInt32   month,
                                                 ViInt32   day,
                                                 ViInt32   hour,
                                                 ViInt32   minutes,
                                                 ViReal64  seconds,
                                                 ViInt32   weekNumber,
                                                 ViReal64  timeOfWeek,
                                                 ViInt32*  longitudeDeg,
                                                 ViInt32*  longitudeMin,
                                                 ViReal64* longitudeSec,
                                                 ViChar    longitudeDir[],
                                                 ViInt32*  latitudeDeg,
                                                 ViInt32*  latitudeMin,
                                                 ViReal64* latitudeSec,
                                                 ViChar    latitudeDir[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGLONRTAzimuth(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   SVID,
                                                      ViInt32   system,
                                                      ViInt32   timeBasis,
                                                      ViInt32   year,
                                                      ViInt32   month,
                                                      ViInt32   day,
                                                      ViInt32   hour,
                                                      ViInt32   minutes,
                                                      ViReal64  seconds,
                                                      ViInt32   weekNumber,
                                                      ViReal64  timeOfWeek,
                                                      ViReal64* azimuth);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGLONRTElevation(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   SVID,
                                                        ViInt32   system,
                                                        ViInt32   timeBasis,
                                                        ViInt32   year,
                                                        ViInt32   month,
                                                        ViInt32   day,
                                                        ViInt32   hour,
                                                        ViInt32   minutes,
                                                        ViReal64  seconds,
                                                        ViInt32   weekNumber,
                                                        ViReal64  timeOfWeek,
                                                        ViReal64* elevation);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGLONRTPower(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   SVID,
                                                    ViInt32   system,
                                                    ViInt32   tap,
                                                    ViInt32   timeBasis,
                                                    ViInt32   year,
                                                    ViInt32   month,
                                                    ViInt32   day,
                                                    ViInt32   hour,
                                                    ViInt32   minutes,
                                                    ViReal64  seconds,
                                                    ViInt32   weekNumber,
                                                    ViReal64  timeOfWeek,
                                                    ViReal64* absolutePower);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouEnabled(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViBoolean beiDouEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDou(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViInt32   RFBand,
                                                   ViInt32   simulationMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouGNSS(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViBoolean GALILEO,
                                                       ViBoolean GLONASS,
                                                       ViBoolean RFFrequency,
                                                       ViBoolean pCode,
                                                       ViBoolean GPS);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouAlmanacFileBeiDou(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouAlmanacFileGPS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouAlmanacFileGALILEO(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouAlmanacFileGLONASS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouRINEXFileBeiDou(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouRINEXFileGPS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouRINEXFileGALILEO(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouRINEXFileGLONASS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouTriggerMode(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouTriggerSource(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouClockSource(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouUserEnvironmentVehicleLoad(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouLocWaypointFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouLocDecimal(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViReal64  longitude,
                                                             ViReal64  latitude,
                                                             ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouLocDMS(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   longitudeDeg,
                                                         ViInt32   longitudeMin,
                                                         ViReal64  longitudeSec,
                                                         ViInt32   longitudeDir,
                                                         ViInt32   latitudeDeg,
                                                         ViInt32   latitudeMin,
                                                         ViReal64  latitudeSec,
                                                         ViInt32   latitudeDir,
                                                         ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouAntennaLoad(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouAntennaUpdate(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64  elapsedTime,
                            ViInt32   antennaID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouNavigationDate(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   year,
                            ViInt32   month,
                            ViInt32   day);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouNavigationTime(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   hour,
                            ViInt32   minute,
                            ViReal64  seconds);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouADGRefDecimal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   system,
                            ViReal64  longitude,
                            ViReal64  latitude,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouADGRefDMS(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   system,
                                                            ViInt32   longitudeDeg,
                                                            ViInt32   longitudeMin,
                                                            ViReal64  longitudeSec,
                                                            ViInt32   longitudeDir,
                                                            ViInt32   latitudeDeg,
                                                            ViInt32   latitudeMin,
                                                            ViReal64  latitudeSec,
                                                            ViInt32   latitudeDir,
                                                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouADGAlmFile(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouADGNavFile(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouADGAcqFile(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouADGIonFile(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouADGUTCFile(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavBeiDouSat(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   powerMode,
                                                      ViReal64  referencePower);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavBeiDouRTAttitude(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   timeBasis,
                                                         ViInt32   year,
                                                         ViInt32   month,
                                                         ViInt32   day,
                                                         ViInt32   hour,
                                                         ViInt32   minutes,
                                                         ViReal64  seconds,
                                                         ViInt32   weekNumber,
                                                         ViReal64  timeOfWeek,
                                                         ViReal64* yaw,
                                                         ViReal64* pitch,
                                                         ViReal64* roll);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavBeiDouRTDecimal(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   timeBasis,
                                                        ViInt32   year,
                                                        ViInt32   month,
                                                        ViInt32   day,
                                                        ViInt32   hour,
                                                        ViInt32   minutes,
                                                        ViReal64  seconds,
                                                        ViInt32   weekNumber,
                                                        ViReal64  timeOfWeek,
                                                        ViReal64* longitude,
                                                        ViReal64* latitude,
                                                        ViReal64* altitude);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavBeiDouRTDMS(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   timeBasis,
                                                    ViInt32   year,
                                                    ViInt32   month,
                                                    ViInt32   day,
                                                    ViInt32   hour,
                                                    ViInt32   minutes,
                                                    ViReal64  seconds,
                                                    ViInt32   weekNumber,
                                                    ViReal64  timeOfWeek,
                                                    ViInt32*  longitudeDeg,
                                                    ViInt32*  longitudeMin,
                                                    ViReal64* longitudeSec,
                                                    ViChar    longitudeDir[],
                                                    ViInt32*  latitudeDeg,
                                                    ViInt32*  latitudeMin,
                                                    ViReal64* latitudeSec,
                                                    ViChar    latitudeDir[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavBeiDouRTAzimuth(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   SVID,
                                                        ViInt32   system,
                                                        ViInt32   timeBasis,
                                                        ViInt32   year,
                                                        ViInt32   month,
                                                        ViInt32   day,
                                                        ViInt32   hour,
                                                        ViInt32   minutes,
                                                        ViReal64  seconds,
                                                        ViInt32   weekNumber,
                                                        ViReal64  timeOfWeek,
                                                        ViReal64* azimuth);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavBeiDouRTElevation(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   SVID,
                                                          ViInt32   system,
                                                          ViInt32   timeBasis,
                                                          ViInt32   year,
                                                          ViInt32   month,
                                                          ViInt32   day,
                                                          ViInt32   hour,
                                                          ViInt32   minutes,
                                                          ViReal64  seconds,
                                                          ViInt32   weekNumber,
                                                          ViReal64  timeOfWeek,
                                                          ViReal64* elevation);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavBeiDouRTPower(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   SVID,
                                                      ViInt32   system,
                                                      ViInt32   tap,
                                                      ViInt32   timeBasis,
                                                      ViInt32   year,
                                                      ViInt32   month,
                                                      ViInt32   day,
                                                      ViInt32   hour,
                                                      ViInt32   minutes,
                                                      ViReal64  seconds,
                                                      ViInt32   weekNumber,
                                                      ViReal64  timeOfWeek,
                                                      ViReal64* absolutePower);

ViStatus _VI_FUNC rsrfsiggen_ConfigureNFCEnabled(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean NFCEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureNFC(ViSession instrSession,
                                          ViInt32   path,
                                          ViInt32   technology,
                                          ViInt32   transmissionMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureNFCModulation(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViBoolean slope,
                                                    ViReal64  tlow,
                                                    ViReal64  modulationDepth,
                                                    ViReal64  sampleRate);

ViStatus _VI_FUNC rsrfsiggen_ConfigureNFCPredefinedSequence(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   predefinedSequence,
                                                            ViBoolean configureMarker1);

ViStatus _VI_FUNC rsrfsiggen_ConfigureNFCPredefinedSequenceApply(
                            ViSession instrSession,
                            ViInt32   path);

ViStatus _VI_FUNC rsrfsiggen_ConfigureNFCSequence(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViInt32   sequence,
                                                  ViInt32   commandType,
                                                  ViInt32   repetition,
                                                  ViReal64  powerOffset);

ViStatus _VI_FUNC rsrfsiggen_ConfigureNFCTriggerMode(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureNFCTriggerSource(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureNFCClockSource(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSEnabled(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILS(ViSession instrSession,
                                          ViInt32   path,
                                          ViInt32   component);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSGlideSlopeSignal(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   DDMPolarity,
                                                          ViInt32   mode,
                                                          ViReal64  upDownPhase);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSGlideSlopeICAO(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   ICAOChannel);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSGlideSlopeUserCarrierFrequency(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64  carrierFrequency);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSGlideSlopeAmplitude(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViReal64  sumOfDepth,
                                                             ViInt32   fly,
                                                             ViInt32   DDMStep,
                                                             ViReal64  DDMDepth,
                                                             ViInt32   DDMSDMCoupling);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSLocalizerSignal(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   DDMPolarity,
                                                         ViInt32   mode,
                                                         ViReal64  leftRightPhase);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSLocalizerICAO(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   ICAOChannel);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSLocalizerUserCarrierFrequency(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64  carrierFrequency);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSLocalizerAmplitude(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViReal64  sumOfDepth,
                                                            ViInt32   fly,
                                                            ViInt32   DDMStep,
                                                            ViReal64  DDMDepth,
                                                            ViInt32   DDMSDMCoupling);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSLocalizerCOMID(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViBoolean state,
                                                        ViString  code,
                                                        ViReal64  frequency,
                                                        ViReal64  period,
                                                        ViReal64  depth,
                                                        ViInt32   timeSchema,
                                                        ViReal64  dotLength);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSLocalizerCOMIDUserTimeSchema(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64  dashLength,
                            ViReal64  symbolSpace,
                            ViReal64  letterSpace);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSMarkerBeaconsSignal(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   carrierFrequencyMode,
                                                             ViReal64  carrierFrequency,
                                                             ViReal64  markerFrequency,
                                                             ViReal64  markerDepth);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSMarkerBeaconsCOMID(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViBoolean state,
                                                            ViString  code,
                                                            ViReal64  frequency,
                                                            ViReal64  period,
                                                            ViReal64  depth,
                                                            ViInt32   timeSchema,
                                                            ViReal64  dotLength);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSMarkerBeaconsCOMIDUserTimeSchema(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64  dashLength,
                            ViReal64  symbolSpace,
                            ViReal64  letterSpace);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSTriggerMode(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSTriggerSource(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureILSClockSource(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureVOREnabled(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureVORSignal(ViSession instrSession,
                                                ViInt32   path,
                                                ViInt32   mode,
                                                ViReal64  VARREFFrequency,
                                                ViReal64  VARDepth,
                                                ViReal64  subcarrierFrequency,
                                                ViReal64  subcarrierDepth,
                                                ViReal64  REFDeviation);

ViStatus _VI_FUNC rsrfsiggen_ConfigureVORICAO(ViSession instrSession,
                                              ViInt32   path,
                                              ViInt32   ICAOChannel);

ViStatus _VI_FUNC rsrfsiggen_ConfigureVORUserCarrierFrequency(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64  carrierFrequency);

ViStatus _VI_FUNC rsrfsiggen_ConfigureVORPosition(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViReal64  bearingAngle,
                                                  ViInt32   direction);

ViStatus _VI_FUNC rsrfsiggen_ConfigureVORCOMID(ViSession instrSession,
                                               ViInt32   path,
                                               ViBoolean state,
                                               ViString  code,
                                               ViReal64  frequency,
                                               ViReal64  period,
                                               ViReal64  depth,
                                               ViInt32   timeSchema,
                                               ViReal64  dotLength);

ViStatus _VI_FUNC rsrfsiggen_ConfigureVORCOMIDUserTimeSchema(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViReal64  dashLength,
                                                             ViReal64  symbolSpace,
                                                             ViReal64  letterSpace);

ViStatus _VI_FUNC rsrfsiggen_ConfigureVORTriggerMode(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureVORTriggerSource(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureVORClockSource(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMEEnabled(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDME(ViSession instrSession,
                                          ViInt32   path,
                                          ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMEICAO(ViSession instrSession,
                                              ViInt32   path,
                                              ViInt32   ICAOChannel);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMEChannelFrequency(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   channel,
                                                          ViReal64  carrierFrequency);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMEPulse(ViSession instrSession,
                                               ViInt32   path,
                                               ViInt32   pulseShape,
                                               ViReal64  pulseRise,
                                               ViReal64  pulseWidth,
                                               ViReal64  pulseFall,
                                               ViReal64  pulseSpacing,
                                               ViBoolean singlePulse);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMEReceive(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViReal64  pulsePairSpacingTolerance);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMEInterrogationSignal(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViBoolean pulseSquitter,
                                                             ViInt32   pulseRepetitionRate);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMEAnalysis(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViBoolean state,
                                                  ViReal64  expectedReplayDelay,
                                                  ViReal64  gateLength,
                                                  ViReal64  measurementTime);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMEReplaySignal(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViBoolean pulseSquitter,
                                                      ViInt32   pulseRepetitionRate,
                                                      ViReal64  rangeDistance,
                                                      ViReal64  replyEfficiency);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMECOMID(ViSession instrSession,
                                               ViInt32   path,
                                               ViBoolean state,
                                               ViBoolean pairOfPulsePairs,
                                               ViReal64  pulsePairSpacing,
                                               ViString  code,
                                               ViReal64  rate,
                                               ViReal64  period,
                                               ViInt32   timeSchema,
                                               ViReal64  dotLength);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMECOMIDUserTimeSchema(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViReal64  dashLength,
                                                             ViReal64  symbolSpace,
                                                             ViReal64  letterSpace);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMETriggerMode(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMETriggerSource(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureDMEClockSource(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASEnabled(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBAS(ViSession instrSession,
                                           ViInt32   path,
                                           ViBoolean multipleFrequencyChannels);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDB(ViSession instrSession,
                                              ViInt32   path,
                                              ViInt32   channel,
                                              ViBoolean enabled,
                                              ViString  GBASID,
                                              ViInt32   SSID,
                                              ViInt32   frequencyNumber,
                                              ViInt32   data,
                                              ViInt32   numberOfFrames);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBAppend(ViSession instrSession,
                                                    ViInt32   path);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBInsert(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   channel);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBDelete(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   channel);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageType2ReferenceLocationConfigurationDecimal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViReal64  longitude,
                            ViReal64  latitude,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageType2ReferenceLocationConfigurationDMS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDir,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDir,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageType4FASLTPFTPLocationConfigurationDecimal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViReal64  longitude,
                            ViReal64  latitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageType4FASLTPFTPLocationConfigurationDMS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDir,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDir);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageType4FASDeltaFrapLocationConfigurationDecimal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViReal64  longitude,
                            ViReal64  latitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageType4FASDeltaFrapLocationConfigurationDMS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDir,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDir);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageType4LocationConfigurationDecimal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViReal64  longitude,
                            ViReal64  latitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageType4LocationConfigurationDMS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDir,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDir);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageType4FDBDERPLocationDecimal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViInt32   FDB,
                            ViReal64  longitude,
                            ViReal64  latitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageType4FDBDERPLocationDMS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViInt32   FDB,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDir,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDir);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageType4FDBDPLocationDecimal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViInt32   FDB,
                            ViReal64  longitude,
                            ViReal64  latitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageType4FDBDPLocationDMS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViInt32   FDB,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDir,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDir);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageType4TAPWaypointPredefinedFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageType4TAPWaypointUserDefinedFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageDifferentialGNSSPredefinedFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageDifferentialGNSSUserDefinedFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageDifferentialGNSSSPRFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASVDBMessageDifferentialGNSSSUSFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   channel,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASTriggerMode(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASTriggerSource(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureGBASClockSource(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOFDMEnabled(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOFDMModulationType(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   modulationType);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOFDMTriggerMode(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOFDMTriggerSource(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOFDMTrigger(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViBoolean sync,
                                                  ViReal64  delay,
                                                  ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOFDMTriggerDateTime(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   year,
                                                          ViInt32   month,
                                                          ViInt32   day,
                                                          ViInt32   hour,
                                                          ViInt32   minute,
                                                          ViInt32   second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOFDMClockSource(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureREGEnabled(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_QueryREGFileCatalog(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViInt32   arraySize,
                                                 ViChar    catalog[],
                                                 ViUInt32* bytesRead);

ViStatus _VI_FUNC rsrfsiggen_ConfigureREGLoad(ViSession instrSession,
                                              ViInt32   path,
                                              ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureREGStore(ViSession instrSession,
                                               ViInt32   path,
                                               ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QueryREGObjectFileCatalog(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   arraySize,
                                                       ViChar    catalog[],
                                                       ViUInt32* bytesRead);

ViStatus _VI_FUNC rsrfsiggen_ConfigureREGObjectLoad(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   object,
                                                    ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureREGObjectStore(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   object,
                                                     ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureExtSeqEnabled(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureExtSeqMode(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_QueryExtSeqArchiveFileCatalog(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViInt32   arraySize,
                                                           ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureExtSeqArchiveLoad(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureExtSeqArchiveStore(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QueryExtSeqPulseFileCatalog(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   arraySize,
                                                         ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureExtSeqPulseFileSelect(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   sequencer,
                                                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureExtSeqDirectionFindingFileSelect(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   sequencer,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QueryExtSeqRTCIFileCatalog(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   arraySize,
                                                        ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_QueryExtSeqRTCIWaveformFileCatalog(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   arraySize,
                            ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureExtSeqRTCIFile(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   sequencer,
                                                     ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureExtSeqRTCISave(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   sequencer,
                                                     ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QueryExtSeqUserFileCatalog(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   arraySize,
                                                        ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureExtSeqUserFileSelect(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QueryExtSeqUserHoppingFileCatalog(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   arraySize,
                            ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureExtSeqUserHoppingFileSelect(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QueryExtSeqUserAttenuationFileCatalog(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   arraySize,
                            ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureExtSeqUserAttenuationFileSelect(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   attenuation,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureExtSeqTriggerDateTime(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   year,
                                                            ViInt32   month,
                                                            ViInt32   day,
                                                            ViInt32   hour,
                                                            ViInt32   minute,
                                                            ViInt32   second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOneWebEnabled(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOneWebMode(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOneWebLinkDirection(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   linkDirection);

ViStatus _VI_FUNC rsrfsiggen_OneWebLoadReferenceSignals(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOneWebDLFrameUserDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   user,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOneWebDLSubframeAllocationUserDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   subframe,
                            ViInt32   allocation,
                            ViInt32   user,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOneWebULUEPUACHDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   userEquipment,
                            ViInt32   cell,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOneWebULUEPUSCHDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   userEquipment,
                            ViInt32   cell,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOneWebTriggerSource(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOneWebTrigger(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViBoolean sync,
                                                    ViReal64  delay,
                                                    ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureOneWebClockSource(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureV5GEnabled(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureV5GPredefinedConfiguration(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  predefinedConfiguration);

ViStatus _VI_FUNC rsrfsiggen_ConfigureV5GLinkDirection(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   linkDirection);

ViStatus _VI_FUNC rsrfsiggen_ConfigureV5GTriggerMode(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureV5GTriggerSource(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureV5GTrigger(ViSession instrSession,
                                                 ViInt32   path,
                                                 ViBoolean sync,
                                                 ViReal64  delay,
                                                 ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureV5GClockSource(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_Configure5GNREnabled(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_Export5GNRSettingsToAnalyzerFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_Configure5GNRLinkDirection(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   linkDirection);

ViStatus _VI_FUNC rsrfsiggen_Configure5GNRFilterLoad(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_Configure5GNRDLBWPRateMatchDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   user,
                            ViInt32   cell,
                            ViInt32   BWP,
                            ViInt32   group,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_Configure5GNRSchedulingCORESETDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   cell,
                            ViInt32   subframe,
                            ViInt32   user,
                            ViInt32   BWP,
                            ViInt32   allocation,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_Configure5GNRSchedulingCORESETDCIDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   cell,
                            ViInt32   subframe,
                            ViInt32   user,
                            ViInt32   BWP,
                            ViInt32   allocation,
                            ViInt32   DCI,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_Configure5GNRTriggerMode(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_Configure5GNRTriggerSource(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_Configure5GNRTrigger(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViBoolean sync,
                                                  ViReal64  delay,
                                                  ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_Configure5GNRTriggerDateTime(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   year,
                                                          ViInt32   month,
                                                          ViInt32   day,
                                                          ViInt32   hour,
                                                          ViInt32   minute,
                                                          ViInt32   second);

ViStatus _VI_FUNC rsrfsiggen_Configure5GNRClockSource(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLoRaEnabled(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLoRaGeneral(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViInt32   bandwidth,
                                                  ViReal64  idleInterval,
                                                  ViInt32   sequenceLength,
                                                  ViInt32   oversampling,
                                                  ViReal64  sampleRateVariation);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLoRaFrameGeneral(ViSession instrSession,
                                                       ViInt32   path,
                                                       ViBoolean payloadReducedCodingMode,
                                                       ViInt32   syncMode,
                                                       ViInt32   unmodulatedPreambleLength);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLoRaFrameModulationAndCodingConfiguration(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   codingRate,
                            ViBoolean encoderActive,
                            ViInt32   spreadingFactor,
                            ViBoolean interleaverActive);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLoRaFrameData(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   dataLength,
                                                    ViBoolean payloadCRC,
                                                    ViInt32   dataSource);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLoRaFrameDataHeaderConfiguration(
                            ViSession instrSession,
                            ViInt32   path,
                            ViBoolean headerActive,
                            ViBoolean burstMode,
                            ViBoolean compressedMode,
                            ViBoolean reversedBit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLoRaImpairments(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViBoolean impairments,
                                                      ViInt32   symbolTimingError,
                                                      ViReal64  frequencyError);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLoRaImpairmentsFrequencyDrift(
                            ViSession instrSession,
                            ViInt32   path,
                            ViBoolean enabled,
                            ViInt32   type,
                            ViReal64  deviation,
                            ViInt32   driftRate);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLoRaTriggerMode(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLoRaTriggerSource(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLoRaTrigger(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViBoolean sync,
                                                  ViReal64  delay,
                                                  ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureLoRaClockSource(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureHRPUWBEnabled(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureHRPUWBGeneral(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViInt32   mode,
                                                    ViInt32   channelNumber,
                                                    ViReal64  idleInterval,
                                                    ViInt32   sequenceLength);

ViStatus _VI_FUNC rsrfsiggen_QueryHRPUWBBandwidth(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViReal64* bandwidth);

ViStatus _VI_FUNC rsrfsiggen_ConfigureHRPUWBClipping(ViSession instrSession,
                                                     ViInt32   path,
                                                     ViBoolean enabled,
                                                     ViInt32   level,
                                                     ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureHRPUWBImpairments(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViBoolean enabled,
                                                        ViInt32   chipClockError,
                                                        ViReal64  frequencyOffset);

ViStatus _VI_FUNC rsrfsiggen_ConfigureHRPUWBTriggerMode(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureHRPUWBTriggerSource(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureHRPUWBTrigger(ViSession instrSession,
                                                    ViInt32   path,
                                                    ViBoolean sync,
                                                    ViReal64  delay,
                                                    ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureHRPUWBTriggerDateTime(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   year,
                                                            ViInt32   month,
                                                            ViInt32   day,
                                                            ViInt32   hour,
                                                            ViInt32   minute,
                                                            ViInt32   second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureHRPUWBClockSource(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMEnabled(ViSession instrSession,
                                                  ViInt32   path,
                                                  ViBoolean fadingEnabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMStandard(ViSession instrSession,
                                                   ViInt32   path,
                                                   ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIM(ViSession instrSession,
                                           ViInt32   path,
                                           ViInt32   configuration,
                                           ViInt32   signalDedicatedTo,
                                           ViReal64  virtualRF,
                                           ViBoolean ignoreRFChangesLt5PCT,
                                           ViInt32   hoppingMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMInsertionLoss(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   mode,
                                                        ViReal64  insertionLoss);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMInsertionLossClippedSamples(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   bufferSize,
                            ViChar    clippedSamples[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMCoupledParameters(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViBoolean speedSetting,
                                                            ViBoolean localConstant,
                                                            ViBoolean standardDeviation);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMGlobalFaderCoupling(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   startSeed);

ViStatus _VI_FUNC rsrfsiggen_FSIMScenarioLoad(ViSession instrSession,
                                              ViInt32   path,
                                              ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_FSIMScenarioSave(ViSession instrSession,
                                              ViInt32   path,
                                              ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMUserTrajectoryENU(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   rxTx,
                                                            ViReal64  x,
                                                            ViReal64  y,
                                                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMUserTrajectoryCoordinatesDegree(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   rxTx,
                            ViString  longitude,
                            ViString  longitudeDirection,
                            ViString  latitude,
                            ViString  latitudeDirection,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMUserTrajectoryCoordinatesDecimalDegree(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   rxTx,
                            ViReal64  longitude,
                            ViReal64  latitude,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMUserTrajectoryENUReferenceCoordinates(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   rxTx,
                            ViReal64  longitude,
                            ViReal64  latitude,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMShipToShipCoordinatesDegree(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   rxTx,
                            ViString  longitude,
                            ViString  longitudeDirection,
                            ViString  latitude,
                            ViString  latitudeDirection);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMShipToShipCoordinatesDecimalDegree(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   rxTx,
                            ViReal64  longitude,
                            ViReal64  latitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMCustomFadingProfile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   group,
                            ViInt32   delayPath,
                            ViReal64  bandwidth,
                            ViReal64  offsetFrequency,
                            ViReal64  lowerCutoffFrequency,
                            ViReal64  upperCutoffFrequency);

ViStatus _VI_FUNC rsrfsiggen_FSIMMIMOLoad(ViSession instrSession,
                                          ViInt32   path,
                                          ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_FSIMMIMOSave(ViSession instrSession,
                                          ViInt32   path,
                                          ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMMIMOKroneckerCorrelationPhase(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   tap,
                            ViInt32   rxTx,
                            ViInt32   matrixPath,
                            ViReal64  phase);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMMIMOKroneckerCorrelationRatio(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   tap,
                            ViInt32   rxTx,
                            ViInt32   matrixPath,
                            ViReal64  ratio);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMMIMOKroneckerCorrelationReal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   tap,
                            ViInt32   rxTx,
                            ViInt32   matrixPath,
                            ViReal64  real);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMMIMOKroneckerCorrelationImaginary(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   tap,
                            ViInt32   rxTx,
                            ViInt32   matrixPath,
                            ViReal64  imginary);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMMIMORelativeGainVectorMatrixGain(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   tap,
                            ViInt32   matrixPath,
                            ViReal64  gain);

ViStatus _VI_FUNC rsrfsiggen_ConfigureFSIMMIMORelativeGainVectorMatrixPhaseShift(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   tap,
                            ViInt32   matrixPath,
                            ViReal64  phaseShift);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavEnabled(ViSession instrSession,
                                                    ViInt32   standard,
                                                    ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavUpdateRFFrequency(
                            ViSession instrSession,
                            ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavRFBand(ViSession instrSession,
                                                   ViInt32   standard,
                                                   ViInt32   RFBand);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTestScenario(ViSession instrSession,
                                                         ViInt32   standard,
                                                         ViInt32   testScenario);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSimulationMode(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   simulationMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSetToDefault(ViSession instrSession,
                                                         ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSEnabledGPS(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSEnabledGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSEnabledGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSEnabledBeiDou(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSEnabledQZSS(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSUseCommonRFFrequency(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean useCommonRFFrequency);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSPCode(ViSession instrSession,
                                                      ViInt32   standard,
                                                      ViBoolean pCode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSAntiSpoofing(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViBoolean antiSpoofing);

ViStatus _VI_FUNC rsrfsiggen_SatNavGNSSValidSatellitesGPS(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViInt32   standard2,
                                                          ViInt32   SVID,
                                                          ViChar    validSatellites[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSVisibleInTheConstellation(
                            ViSession  instrSession,
                            ViInt32    path,
                            ViInt32    standard,
                            ViInt32    SVID,
                            ViBoolean* visible);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSSVIDHealthy(ViSession  instrSession,
                                                        ViInt32    path,
                                                        ViInt32    standard,
                                                        ViInt32    SVID,
                                                        ViBoolean* healthy);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSSVIDListAll(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   standard,
                                                        ViInt32   arraySize,
                                                        ViInt32   list[],
                                                        ViInt32*  returnedValues);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSSVIDListValid(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   standard,
                                                          ViInt32   arraySize,
                                                          ViInt32   list[],
                                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAlmanacFileGPS(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAlmanacFileGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAlmanacFileGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAlmanacFileBeiDou(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAlmanacFileQZSS(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavAlmanacWeekNumberGPS(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViReal64* weekNumber);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavAlmanacWeekNumberGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64* weekNumber);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavAlmanacWeekSpanBeginGPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViChar    begin[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavAlmanacWeekSpanBeginGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViChar    begin[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavAlmanacWeekSpanEndGPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViChar    end[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavAlmanacWeekSpanEndGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViChar    end[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavAlmanacTOAPWeekNumberGPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32*  weekNumber);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavAlmanacTOAPWeekNumberGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32*  weekNumber);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavAlmanacTOAPTimeOfWeekGPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViChar    timeOfWeek[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavAlmanacTOAPTimeOfWeekGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViChar    timeOfWeek[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavAlmanacTOAPDateGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViChar    date[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavAlmanacTOAPTimeGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViChar    time[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavRINEXFileGPS(ViSession instrSession,
                                                         ViInt32   standard,
                                                         ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavRINEXEnabledGPS(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavRINEXFileGALILEO(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavRINEXEnabledGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavRINEXFileGLONASS(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavRINEXEnabledGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavRINEXFileBeiDou(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavRINEXEnabledBeiDou(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavRINEXFileQZSS(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavRINEXEnabledQZSS(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavRINEXUTC(ViSession instrSession,
                                                     ViInt32   standard,
                                                     ViBoolean UTC);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavRINEXUpdateFrequencyGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean updateFrequency);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavRINEXImport(ViSession instrSession,
                                                        ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSMOPSFile(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSMOPSExport(ViSession instrSession,
                                                           ViInt32   path,
                                                           ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSMOPSImportAddEMS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSMOPSImportAddNSTB(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSMOPSImportAddGRID(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGSynchronize(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGReferenceFrame(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   referenceFrame);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGPositionFormat(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   positionFormat);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGCoordinatesDecimalPZ(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViReal64  longitude,
                            ViReal64  latitude,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGCoordinatesDecimal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViReal64  longitude,
                            ViReal64  latitude,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGCoordinatesDMSPZ(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDirection,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDirection,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGCoordinatesDMS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDirection,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDirection,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGUncertainlyRadius(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   uncertainlyRadius);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGTimeBasis(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   standard,
                                                             ViInt32   timeBasis);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGDate(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   standard,
                                                        ViInt32   year,
                                                        ViInt32   month,
                                                        ViInt32   day);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGTime(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   standard,
                                                        ViInt32   hour,
                                                        ViInt32   minute,
                                                        ViReal64  second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGDuration(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   standard,
                                                            ViReal64  duration);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGResolution(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViReal64  resolution);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGTimeofWeek(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViReal64  timeOfWeek);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGWeekNumber(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViReal64  weekNumber);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGCreateAcquisitionFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGCreateAlmanacFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGCreateUTCFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGCreateNavigationFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGCreateIonosphericFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSADGSVIDEnabled(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSOrbitGLONASST(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   SVID,
                                                          ViInt32*  hour,
                                                          ViInt32*  minute,
                                                          ViReal64* seconds);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSOrbitIODC(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   SVID,
                                                          ViInt32   standard,
                                                          ViInt32   IODC);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSAdditionalDataSVHealth(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   SVHealth);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSAdditionalDataURA(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   URA);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSAdditionalDataAsFlag(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   asFlag);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSAdditionalDataCodeOnL2Mode(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   codeOnL2Mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSAdditionalDataL2P(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean l2P);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSAdditionalDataFitInterval(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean fitInterval);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSAdditionalDataSubframe1(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   reservedValue,
                            ViInt32   subframeValue);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionStartDate(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   year,
                            ViInt32   month,
                            ViInt32   day);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionStartTime(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   hour,
                            ViInt32   minute,
                            ViReal64  second);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSTimeConversionStartUTCDate(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32*  year,
                            ViInt32*  month,
                            ViInt32*  day);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSTimeConversionStartUTCTime(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32*  hour,
                            ViInt32*  minute,
                            ViReal64* seconds);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSTimeConversionStartGLONASSDate(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32*  year,
                            ViInt32*  month,
                            ViInt32*  day);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSTimeConversionStartGLONASSTime(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32*  hour,
                            ViInt32*  minute,
                            ViReal64* seconds);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSTimeConversionStartUTCSDate(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32*  year,
                            ViInt32*  month,
                            ViInt32*  day);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionLeapDate(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   year,
                            ViInt32   month,
                            ViInt32   day);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSTimeConversionWeekNumber(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32*  weekNumber);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSTimeConversionTimeOfWeek(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32*  timeOfWeek);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSTimeConversionOffset(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   region,
                            ViReal64* offset);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionWNot(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   WNot);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionTot(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   tot);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionTotUnscaled(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   tot);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSTimeConversionIntegerOffset(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32*  integerOffset);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionA0(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   region,
                            ViReal64  a0);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionA0Unscaled(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   region,
                            ViReal64  a0);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionA1(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   region,
                            ViReal64  a1);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionA1Unscaled(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   region,
                            ViReal64  a1);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionSBASWNot(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   region,
                            ViInt32   WNot);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionSBASTot(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   region,
                            ViInt32   tot);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionSBASTotUnscaled(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   region,
                            ViInt32   tot);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionSBASA1(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   region,
                            ViInt32   a1);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionSBASA1Unscaled(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   region,
                            ViInt32   a1);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionSBASA0(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   region,
                            ViInt32   a0);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSTimeConversionSBASA0Unscaled(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   region,
                            ViInt32   a0);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalStandardEnabled(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   region,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalStandardSVEnabled(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalStandardPresentInConstellation(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalStandardPathLossEnabled(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSPowerStandardOffset(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  offset);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSPowerCopySVID(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   copySVID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSPowerCopySVIDExecute(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSModulationControlCopySVID(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   copySVID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSModulationControlCopyExecute(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalSBASL1BandCANavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalQZSSL1BandCANavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalQZSSL2BandL2CNavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalQZSSL5BandL5SNavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalNavICL5BandSPSNavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalGPSL1BandCANavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalGPSL1BandPNavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalGPSL2BandCANavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalGPSL2BandL2CNavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalGPSL2BandPNavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalGPSL5BandL5SNavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalGLONASSL1BandCANavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalGLONASSL2BandCANavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalGALILEOL1BandE1OSNavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalGALILEOL2BandE6SNavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalGALILEOL5BandE5ANavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalGALILEOL5BandE5BNavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalBeiDouL1BandB1CNavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalBeiDouL1BandB1INavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalBeiDouL2BandB3INavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalBeiDouL5BandB2ANavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalBeiDouL5BandB2INavMessageDataList(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSHILModeA(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   arraySize,
                                                         ViReal64  modeA[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSHILModeB(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   arraySize,
                                                         ViReal64  modeB[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSHILLatencyStatistics(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64* lastLatency,
                            ViReal64* maxLatency,
                            ViReal64* minLatency,
                            ViInt32*  noZeroValues,
                            ViInt32*  totalValues);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSReceiverLocationCoordinatesDecimalPZ(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64* longitude,
                            ViReal64* latitude,
                            ViReal64* altitude);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSReceiverLocationCoordinatesDecimal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViReal64* longitude,
                            ViReal64* latitude,
                            ViReal64* altitude);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSReceiverLocationCoordinatesDMSPZ(
                            ViSession instrSession,
                            ViInt32   arraySize,
                            ViInt32   path,
                            ViReal64  DMSResults[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSReceiverLocationCoordinatesDMS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   arraySize,
                            ViReal64  DMSResults[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSReceiverLocationWaypointsFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSReceiverLocationVehicleFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSReceiverEnvironmentVerticalLoadFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSReceiverEnvironmentRoadsideLoadFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSReceiverEnvironmentLandMobileLoadFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSReceiverEnvironmentStaticMultipathCopy(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   sourceStandard,
                            ViInt32   sourceSVID,
                            ViInt32   targetStandard,
                            ViInt32   targetSVID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSAntennaFile(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   antenna,
                                                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSBodyFile(ViSession instrSession,
                                                         ViInt32   path,
                                                         ViInt32   antenna,
                                                         ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSRTCoordinatesDecimal(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   timeBasis,
                            ViInt32   year,
                            ViInt32   month,
                            ViInt32   day,
                            ViInt32   hour,
                            ViInt32   minute,
                            ViReal64  second,
                            ViInt32   weekNumber,
                            ViReal64  timeOfWeek,
                            ViReal64* longitude,
                            ViReal64* latitude,
                            ViReal64* altitude);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSRTCoordinatesDMS(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   timeBasis,
                                                             ViInt32   year,
                                                             ViInt32   month,
                                                             ViInt32   day,
                                                             ViInt32   hour,
                                                             ViInt32   minute,
                                                             ViReal64  second,
                                                             ViInt32   weekNumber,
                                                             ViReal64  timeOfWeek,
                                                             ViReal64  longitude[],
                                                             ViInt32*  longitudeDirection,
                                                             ViReal64  latitude[],
                                                             ViInt32*  latitudeDirection,
                                                             ViReal64* altitude);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSRTReceiverVelocity(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   timeBasis,
                            ViInt32   year,
                            ViInt32   month,
                            ViInt32   day,
                            ViInt32   hour,
                            ViInt32   minute,
                            ViReal64  second,
                            ViInt32   weekNumber,
                            ViReal64  timeOfWeek,
                            ViReal64* velocity);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSRTReceiverAttitude(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   timeBasis,
                            ViInt32   year,
                            ViInt32   month,
                            ViInt32   day,
                            ViInt32   hour,
                            ViInt32   minutes,
                            ViReal64  seconds,
                            ViInt32   weekNumber,
                            ViReal64  timeOfWeek,
                            ViReal64* yaw,
                            ViReal64* pitch,
                            ViReal64* roll);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSRTReceiverPositionAndVelocity(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   timeBasis,
                            ViInt32   year,
                            ViInt32   month,
                            ViInt32   day,
                            ViInt32   hour,
                            ViInt32   minutes,
                            ViReal64  seconds,
                            ViInt32   weekNumber,
                            ViReal64  timeOfWeek,
                            ViReal64* longitude,
                            ViReal64* latitude,
                            ViReal64* altitude,
                            ViReal64* velocity);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSRTAzimuth(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   standard,
                                                      ViInt32   SVID,
                                                      ViInt32   timeBasis,
                                                      ViInt32   year,
                                                      ViInt32   month,
                                                      ViInt32   day,
                                                      ViInt32   hour,
                                                      ViInt32   minute,
                                                      ViReal64  second,
                                                      ViInt32   weekNumber,
                                                      ViReal64  timeOfWeek,
                                                      ViReal64* azimuth);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSRTElevation(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   standard,
                                                        ViInt32   SVID,
                                                        ViInt32   timeBasis,
                                                        ViInt32   year,
                                                        ViInt32   month,
                                                        ViInt32   day,
                                                        ViInt32   hour,
                                                        ViInt32   minute,
                                                        ViReal64  second,
                                                        ViInt32   weekNumber,
                                                        ViReal64  timeOfWeek,
                                                        ViReal64* elevation);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSRTKBaseLocationDecimalPZ(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   base,
                            ViReal64  longitude,
                            ViReal64  latitude,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSRTKBaseLocationDecimalWGS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   base,
                            ViReal64  longitude,
                            ViReal64  latitude,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSRTKBaseLocationDMSPZ(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   base,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDir,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDir,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSRTKBaseLocationDMSWGS(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   base,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDir,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDir,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ApplySatNavGNSSPseudorange(ViSession instrSession,
                                                        ViInt32   path,
                                                        ViInt32   standard,
                                                        ViInt32   SVID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSPseudorangeSVID(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   SVIDs);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSPseudorangeMode(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSPseudorangeValue(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  pseudorangeValue);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSPseudorangeErrorsFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViString  filename);

ViStatus _VI_FUNC rsrfsiggen_AppendSatNavGNSSPseudorangeProfileTableRow(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSPseudorangeProfileTableEntries(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32*  entries);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSPseudorangeProfileStartTimeOffset(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  offset);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSPseudorangeProfileDelete(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   pseudorange);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSPseudorangeProfileInsert(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   pseudorange);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSPseudorangeProfileReferenceTime(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   pseudorange,
                            ViReal64  time);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSPseudorangeProfileValue(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   pseudorange,
                            ViReal64  profileValue);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalDynamicsPredefinedConfiguration(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   configuration);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalDynamicsVelocityProfile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   profile);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalDynamicsInitialVelocity(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  velocity);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalDynamicsVelocity(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  velocity);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalDynamicsConstantAccelerationPeriod(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  acceleration);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalDynamicsConstantVelocityPeriod(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  velocity);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalDynamicsMaxAcceleration(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  maxAcceleration);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalDynamicsMaxJerk(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  maxJerk);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavGNSSSignalDynamicsRepetitionPeriod(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64* repetitionPeriod);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalDynamicsInitialCarrierPhase(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  carrierPhase);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalDynamicsInitialPseudorange(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  pseudorange);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSignalDynamicsTimeOffset(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  timeOffset);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitReferenceWeek(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   referenceWeek);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitReferenceTimeofWeek(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  referenceTimeOfWeek);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitSqrtA(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  sqrtA);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitEccentricity(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  eccentricity);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitInclinationAngle(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  i0);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitLongitudeOfAscendingNode(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  omega0);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitArgumentOfPerigee(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  omega);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitMeanAnomaly(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  m0);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitRateOfInclinationAngle(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  iDot);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitRateOfRightAscension(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  omegaDot);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitMeanMotionDifference(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  deltaN);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitGLONASSPZ90ReferenceDateTime(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViInt32   year,
                            ViInt32   month,
                            ViInt32   day,
                            ViInt32   hour,
                            ViInt32   minute,
                            ViReal64  second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitGLONASSPZ90Parameters(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViReal64  xn,
                            ViReal64  yn,
                            ViReal64  zn,
                            ViReal64  xnDot,
                            ViReal64  ynDot,
                            ViReal64  znDot,
                            ViReal64  xnDotDot,
                            ViReal64  ynDotDot,
                            ViReal64  znDotDot);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitCosineDifferenceOfLatitude(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  cuc);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitSineDifferenceOfLatitude(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  cus);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitCosineDifferenceOfOrbitalRadius(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  crc);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitSineDifferenceOfOrbitalRadius(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  crs);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitCosineDifferenceOfInclination(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  cic);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedOrbitSineDifferenceOfInclination(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  cis);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedClockReferenceWeek(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   referenceWeek);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedClockTimeOfClock(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  toc);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedClockGroupDelay(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  TGD);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedClockAF(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   AF,
                            ViReal64  AFValue);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSimulatedClockPZ90ReferenceDateTime(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViInt32   year,
                            ViInt32   month,
                            ViInt32   day,
                            ViInt32   hour,
                            ViInt32   minute,
                            ViReal64  second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSBASSimulatedOrbitReferenceDateTime(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViInt32   year,
                            ViInt32   month,
                            ViInt32   day,
                            ViInt32   hour,
                            ViInt32   minute,
                            ViReal64  second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSBASSimulatedClockReferenceDateTime(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViInt32   year,
                            ViInt32   month,
                            ViInt32   day,
                            ViInt32   hour,
                            ViInt32   minute,
                            ViReal64  second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavGNSSSBASSimulatedOrbitParameters(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   SVID,
                            ViReal64  XG,
                            ViReal64  YG,
                            ViReal64  ZG,
                            ViReal64  XGDot,
                            ViReal64  YGDot,
                            ViReal64  ZGDot,
                            ViReal64  XGDotDot,
                            ViReal64  YGDotDot,
                            ViReal64  ZGDotDot);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTriggerStatus(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViChar    triggerStatus[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTriggerArm(ViSession instrSession,
                                                       ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTriggerExecute(ViSession instrSession,
                                                           ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTriggerMode(ViSession instrSession,
                                                        ViInt32   standard,
                                                        ViInt32   triggerMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTriggerSource(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViInt32   triggerSource);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSynchronizationOutputtoExternalTrigger(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean output);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTriggerSignalDuration(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   signalDuration);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTriggerDateTime(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   year,
                                                            ViInt32   month,
                                                            ViInt32   day,
                                                            ViInt32   hour,
                                                            ViInt32   minute,
                                                            ViInt32   second);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavExternalTriggerDelay(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   externalTrigger,
                            ViInt32   delay);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavExternalTriggerInhibit(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   externalTrigger,
                            ViInt32   inhibit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMarkerMode(ViSession instrSession,
                                                       ViInt32   standard,
                                                       ViInt32   marker,
                                                       ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMarkerPulseDivider(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   marker,
                            ViInt32   pulseDivider);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavMarkerPulseFrequency(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViInt32   marker,
                                                             ViReal64* pulseFrequency);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMarkerOffTime(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViInt32   marker,
                                                          ViInt32   offTime);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMarkerOnTime(ViSession instrSession,
                                                         ViInt32   standard,
                                                         ViInt32   marker,
                                                         ViInt32   onTime);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMarkerPulseWidth(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViInt32   marker,
                                                             ViInt32   pulseWidth);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMarkerDelay(ViSession instrSession,
                                                        ViInt32   standard,
                                                        ViInt32   marker,
                                                        ViInt32   delay);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavFixMarkerDelayToCurrentRange(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   marker,
                            ViBoolean fixMarkerDelay);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavFixedMarkerDelayMaximum(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   marker,
                            ViInt32*  maximum);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavFixedMarkerDelayMinimum(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   marker,
                            ViInt32*  minimum);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavClockSynchronisationMode(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavClockSource(ViSession instrSession,
                                                        ViInt32   standard,
                                                        ViInt32   source);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavClockMode(ViSession instrSession,
                                                      ViInt32   standard,
                                                      ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavClockMultiplier(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViInt32   multiplier);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavUserEnvironmentVehicleType(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   vehicleType);

ViStatus _VI_FUNC rsrfsiggen_SatNavUserEnvironmentVehiclePredefinedCatalog(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   arraySize,
                            ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_SatNavUserEnvironmentVehicleUserCatalog(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   arraySize,
                            ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavUserEnvironmentVehicleLoad(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_SatNavLocCatalog(ViSession instrSession,
                                              ViInt32   standard,
                                              ViInt32   arraySize,
                                              ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLocWaypointFile(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavLocCoordinatesDecimal(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64* longitude,
                            ViReal64* latitude,
                            ViReal64* altitude);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavLocCoordinatesDMS(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViInt32   arraySize,
                                                          ViReal64  DMSResults[],
                                                          ViInt32*  returnedValues);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLocYaw(ViSession instrSession,
                                                   ViInt32   standard,
                                                   ViReal64  yaw);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLocFromMotionYaw(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViBoolean fromMotionYaw);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLocPitch(ViSession instrSession,
                                                     ViInt32   standard,
                                                     ViReal64  pitch);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLocFromMotionPitch(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean fromMotionPitch);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLocRoll(ViSession instrSession,
                                                    ViInt32   standard,
                                                    ViReal64  roll);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLocConstantRate(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViReal64  constantRate);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLocStartRollAngle(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  startRollAngle);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLocSmoothMovement(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean smoothMovement);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLocDelay(ViSession instrSession,
                                                     ViInt32   standard,
                                                     ViReal64  delay);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLocFileToBeRead(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViInt32   ROMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavObscurationType(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViInt32   type);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavObscurationNearEnvironment(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   nearEnvironment);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavObscurationPhysicalModel(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   physicalModel);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavObscurationReceiverOffsetX(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  receiverOffsetX);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavObscurationReceiverOffsetY(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  receiverOffsetY);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavObscurationReceiverHeightOffset(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  heightOffset);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavObscurationMapOrientation(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  mapOrientation);

ViStatus _VI_FUNC rsrfsiggen_SatNavObscurationObstaclesPredefinedCatalog(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   arraySize,
                            ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_SatNavObscurationRoadsidePredefinedCatalog(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   arraySize,
                            ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_SatNavObscurationObstaclesUserCatalog(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   arraySize,
                            ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_SatNavObscurationRoadsideUserCatalog(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   arraySize,
                            ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_SatNavObscurationAreaInsert(ViSession instrSession,
                                                         ViInt32   standard,
                                                         ViInt32   area);

ViStatus _VI_FUNC rsrfsiggen_SatNavObscurationAreaDelete(ViSession instrSession,
                                                         ViInt32   standard,
                                                         ViInt32   area);

ViStatus _VI_FUNC rsrfsiggen_SatNavObscurationAreaReference(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViInt32   area,
                                                            ViReal64  reference);

ViStatus _VI_FUNC rsrfsiggen_SatNavObscurationAreaLength(ViSession instrSession,
                                                         ViInt32   standard,
                                                         ViInt32   area,
                                                         ViReal64  length);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathEnabledGPS(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViInt32   SVID,
                                                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathEnabledGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathEnabledGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathEnabledBeiDou(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathTapGPS(ViSession instrSession,
                                                        ViInt32   standard,
                                                        ViInt32   SVID,
                                                        ViInt32   tap);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathTapGALILEO(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViInt32   SVID,
                                                            ViInt32   tap);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathTapGLONASS(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViInt32   SVID,
                                                            ViInt32   tap);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathTapBeiDou(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   SVID,
                                                           ViInt32   tap);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathCarrierPhaseGPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   tap,
                            ViReal64  phase);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathCarrierPhaseGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   tap,
                            ViReal64  phase);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathCarrierPhaseGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   tap,
                            ViReal64  phase);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathCarrierPhaseBeiDou(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   tap,
                            ViReal64  phase);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathCarrierPhaseQZSS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   tap,
                            ViReal64  phase);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathDopplerShiftGPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   tap,
                            ViReal64  dopplerShift);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathDopplerShiftGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   tap,
                            ViReal64  dopplerShift);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathDopplerShiftGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   tap,
                            ViReal64  dopplerShift);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathDopplerShiftBeiDou(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   tap,
                            ViReal64  dopplerShift);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathDopplerShiftQZSS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   tap,
                            ViReal64  dopplerShift);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathPowerGPS(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViInt32   SVID,
                                                          ViInt32   tap,
                                                          ViReal64  power);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathPowerGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   tap,
                            ViReal64  power);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathPowerGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   tap,
                            ViReal64  power);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathPowerBeiDou(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViInt32   SVID,
                                                             ViInt32   tap,
                                                             ViReal64  power);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathPowerQZSS(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   SVID,
                                                           ViInt32   tap,
                                                           ViReal64  power);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathDelayGPS(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViInt32   SVID,
                                                          ViInt32   tap,
                                                          ViReal64  delay);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathDelayGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   tap,
                            ViReal64  delay);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathDelayGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   tap,
                            ViReal64  delay);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathDelayBeiDou(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViInt32   SVID,
                                                             ViInt32   tap,
                                                             ViReal64  delay);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathDelayQZSS(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   SVID,
                                                           ViInt32   tap,
                                                           ViReal64  delay);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathLOSEnabled(ViSession instrSession,
                                                            ViInt32   path,
                                                            ViInt32   standard,
                                                            ViInt32   SVID,
                                                            ViInt32   vehicle,
                                                            ViInt32   antenna,
                                                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathLOSEchoesNumber(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   vehicle,
                            ViInt32   antenna,
                            ViInt32   echoesNumber);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavMpathLOSAngleOfArrivalAzimuth(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   vehicle,
                            ViInt32   antenna,
                            ViReal64* angleOfArrivalAzimuth);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavMpathLOSAngleOfArrivalElevation(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   vehicle,
                            ViInt32   antenna,
                            ViReal64* angleOfArrivalElevation);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavMpathLOSCodePhaseDrift(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   vehicle,
                            ViInt32   antenna,
                            ViReal64* codePhaseDrift);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavMpathLOSCarrierPhase(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   standard,
                                                             ViInt32   SVID,
                                                             ViInt32   vehicle,
                                                             ViInt32   antenna,
                                                             ViReal64* carrierPhase);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavMpathLOSDopplerShift(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   standard,
                                                             ViInt32   SVID,
                                                             ViInt32   vehicle,
                                                             ViInt32   antenna,
                                                             ViReal64* dopplerShift);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavMpathLOSInitialCodePhase(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   vehicle,
                            ViInt32   antenna,
                            ViReal64* initialCodePhase);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavMpathLOSPower(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   standard,
                                                      ViInt32   SVID,
                                                      ViInt32   vehicle,
                                                      ViInt32   antenna,
                                                      ViReal64* power);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathLOSAngleOfArrivalAzimuth(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   vehicle,
                            ViInt32   antenna,
                            ViInt32   echo,
                            ViReal64  angleOfArrivalAzimuth);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathLOSAngleOfArrivalElevation(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   vehicle,
                            ViInt32   antenna,
                            ViInt32   echo,
                            ViReal64  angleOfArrivalElevation);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathLOSCodePhaseDrift(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   vehicle,
                            ViInt32   antenna,
                            ViInt32   echo,
                            ViReal64  codePhaseDrift);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathLOSCarrierPhase(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   vehicle,
                            ViInt32   antenna,
                            ViInt32   echo,
                            ViReal64  carrierPhase);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathLOSDopplerShift(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   vehicle,
                            ViInt32   antenna,
                            ViInt32   echo,
                            ViReal64  dopplerShift);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathLOSInitialCodePhase(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   vehicle,
                            ViInt32   antenna,
                            ViInt32   echo,
                            ViReal64  initialCodePhase);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavMpathLOSPower(ViSession instrSession,
                                                          ViInt32   path,
                                                          ViInt32   standard,
                                                          ViInt32   SVID,
                                                          ViInt32   vehicle,
                                                          ViInt32   antenna,
                                                          ViInt32   echo,
                                                          ViReal64  power);

ViStatus _VI_FUNC rsrfsiggen_SatNavAntennaPredefinedCatalog(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViInt32   arraySize,
                                                            ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_SatNavAntennaUserCatalog(ViSession instrSession,
                                                      ViInt32   standard,
                                                      ViInt32   arraySize,
                                                      ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_SatNavAntennaLoad(ViSession instrSession,
                                               ViInt32   standard,
                                               ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_SatNavAntennaList(ViSession instrSession,
                                               ViInt32   standard,
                                               ViInt32   arraySize,
                                               ViChar    catalog[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAntennaID(ViSession instrSession,
                                                      ViInt32   standard,
                                                      ViInt32   ID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAntennaUpdate(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViReal64  elapsedTime,
                                                          ViInt32   antennaID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavNavigationDataSource(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   dataSource);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavNavigationDataList(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavNavigationSystemTime(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   systemTime);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavNavigationWeekNumber(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   weekNumber);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavNavigationTimeOfWeek(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  timeOfWeek);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavNavigationDate(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   year,
                                                           ViInt32   month,
                                                           ViInt32   day);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavNavigationTime(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   hour,
                                                           ViInt32   minute,
                                                           ViReal64  seconds);

ViStatus _VI_FUNC rsrfsiggen_SatNavTCONLeapSecondSynchronize(ViSession instrSession,
                                                             ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTCONLeapSecondCurrent(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   leapSecondCurrent);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTCONLeapSecondSimulateTransition(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean leapSecondSimulateTransition);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavTCONUTCReferenceDate(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViChar    referenceDate[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTCONUTCA0(ViSession instrSession,
                                                      ViInt32   standard,
                                                      ViReal64  UTCA0);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTCONUTCA1(ViSession instrSession,
                                                      ViInt32   standard,
                                                      ViReal64  UTCA1);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTCONParametersA0GPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   a0);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTCONParametersA0GALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   a0);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTCONParametersA0GLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   a0);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTCONParametersA1GPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  a1);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTCONParametersA1GALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  a1);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTCONParametersA1GLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  a1);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTCONParametersTotGPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   tOt);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTCONParametersTotGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   tOt);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTCONParametersTotGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   tOt);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTCONParametersWNotGPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   WNOt);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTCONParametersWNotGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   WNOt);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavTCONParametersWNotGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   WNOt);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatPowerMode(ViSession instrSession,
                                                         ViInt32   standard,
                                                         ViInt32   powerMode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatReferencePower(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  referencePower);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatReferenceSatellite(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   referenceSatellite);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSatTotalPower(ViSession instrSession,
                                                      ViInt32   standard,
                                                      ViReal64* totalPower);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatReferenceStandard(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   referenceStandard);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSatReferenceSignal(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViReal64* referenceSignal);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSatReferenceDistance(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViReal64* referenceDistance);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatElevationMask(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViReal64  elevationMask);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSatHDOP(ViSession instrSession,
                                                ViInt32   standard,
                                                ViReal64* HDOP);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSatPDOP(ViSession instrSession,
                                                ViInt32   standard,
                                                ViReal64* PDOP);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatOptimalConstellation(
                            ViSession instrSession,
                            ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatLatencyStatistics(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64* lastLatency,
                            ViReal64* maxLatency,
                            ViReal64* minLatency,
                            ViInt32*  noZeroValues,
                            ViInt32*  totalValues);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatTuningIntraZero(
                            ViSession instrSession,
                            ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatTuningIntraSetToStandard(
                            ViSession instrSession,
                            ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatTuningIntraCAP(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  intraCAP);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatTuningInterZero(
                            ViSession instrSession,
                            ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatTuningInterSetToStandard(
                            ViSession instrSession,
                            ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatTuningInterCAE1Def(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  CAE1Def);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatTuningInterCARCA(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  CARCA);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatTuningInterCATOGEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  CATOGEO);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatTuningInterCATOQZSSCA(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  CATOQZSSCA);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAtmosphericTroposphericModel(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   troposhphericModel);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAtmosphericIonosphericModel(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   ionoshphericModel);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAtmosphericIonosphericSolarFlux(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  solarFlux);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAtmosphericIonosphericSunspotNumber(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  sunspotNumber);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAtmosphericIonosphericMeasuredSunspot(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean measuredSunspot);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAtmosphericIonosphericGridFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAtmosphericGPSAlpha(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   alpha,
                            ViReal64  alphaParameter);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAtmosphericQZSSAlpha(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   alpha,
                            ViReal64  alphaParameter);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAtmosphericKlobucharAlpha(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   alpha,
                            ViReal64  klobucharAlpha);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAtmosphericGPSBeta(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   alpha,
                            ViReal64  beta);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAtmosphericBeiDouBeta(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   alpha,
                            ViReal64  beta);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAtmosphericQZSSBeta(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   alpha,
                            ViReal64  beta);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAtmosphericKlobucharBeta(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   alpha,
                            ViReal64  klobucharBeta);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAtmosphericGALILEOAlpha(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   alpha,
                            ViReal64  alphaParameter);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavAtmosphericGALILEOSF(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   SF);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatConfigurationEphemerisProjection(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean ephemerisProjection);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatConfigurationNumberOfSatellites(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   numberOfSatellites);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatEnabled(ViSession instrSession,
                                                       ViInt32   standard,
                                                       ViInt32   satellite,
                                                       ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatStandard(ViSession instrSession,
                                                        ViInt32   standard,
                                                        ViInt32   satellite,
                                                        ViInt32   satStandard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatSignals(ViSession instrSession,
                                                       ViInt32   standard,
                                                       ViInt32   satellite,
                                                       ViInt32   signals);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatSpaceVehicleID(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViInt32   spaceVehicleID);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSatPower(ViSession instrSession,
                                                 ViInt32   standard,
                                                 ViInt32   satellite,
                                                 ViReal64* power);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSatStandardChipRate(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViInt32   satellite,
                                                            ViReal64* standardChipRate);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSatModulation(ViSession instrSession,
                                                      ViInt32   standard,
                                                      ViInt32   satellite,
                                                      ViChar    modulation[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSatDuration(ViSession instrSession,
                                                    ViInt32   standard,
                                                    ViInt32   satellite,
                                                    ViReal64* duration);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatPseudorange(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   satellite,
                                                           ViReal64  pseudorange);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatPseudorangeBIAS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViReal64  pseudorangeBIAS);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatTimeShift(ViSession instrSession,
                                                         ViInt32   standard,
                                                         ViInt32   satellite,
                                                         ViReal64  timeShift);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatInitialCarrierPhase(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViReal64  initialCarrierPhase);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSatResultingStartFrequency(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViReal64* resultingStartFrequency);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSatResultingStartChipRate(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViReal64* resultingStartChipRate);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageNavigationPages(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   navigationPages);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageRealTimeProjection(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean realTimeProjection);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageTGDCorrectionGPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  TGDCorrection);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageTGDCorrectionBeiDou(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  TGDCorrection);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageTGDCorrectionQZSS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  TGDCorrection);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageSetToAlmanac(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageProjectNavigationMessage(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageCodeOnL2(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   codeOnL2);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageL2PDataFlag(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean l2PDataFlag);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageFitIntervalFlag(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean fitIntervalFlag);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageURAIndex(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   URAIndex);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageSVHealth(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   SVHealth);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageIODC(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   SVID,
                                                           ViInt32   IODC);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageIODE(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   SVID,
                                                           ViInt32   IODE);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageTOE(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViInt32   SVID,
                                                          ViInt32   TOE);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageM0(ViSession instrSession,
                                                         ViInt32   standard,
                                                         ViInt32   SVID,
                                                         ViInt32   m0);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageNDelta(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViInt32   SVID,
                                                             ViReal64  nDelta);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageEccentricity(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  eccentricity);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageSQRTA(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViInt32   SVID,
                                                            ViReal64  SQRT);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageOmega0(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViInt32   SVID,
                                                             ViInt32   omega0);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessagei0(ViSession instrSession,
                                                         ViInt32   standard,
                                                         ViInt32   SVID,
                                                         ViInt32   i0);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageOmega(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViInt32   SVID,
                                                            ViInt32   omega);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageOmegaDOT(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  omegaDOT);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageIDOT(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   SVID,
                                                           ViReal64  IDOT);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageCuc(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViInt32   SVID,
                                                          ViReal64  cuc);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageCus(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViInt32   SVID,
                                                          ViReal64  cus);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageCrc(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViInt32   SVID,
                                                          ViReal64  crc);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageCrs(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViInt32   SVID,
                                                          ViReal64  crs);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageCic(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViInt32   SVID,
                                                          ViReal64  cic);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageCis(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViInt32   SVID,
                                                          ViReal64  cis);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageSF1Reserved1(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   SF1Reserved1);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageSF1Reserved2(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   SF1Reserved2);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageSF1Reserved3(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   SF1Reserved3);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageSF1Reserved4(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   SF1Reserved4);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageAODO(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   SVID,
                                                           ViInt32   AODO);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageIODAGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   IODA);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessagePresetGPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessagePresetGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessagePresetGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessagePresetBeiDou(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessagePresetQZSS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatMessageSignalInSpaceAccuracy(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   SISA);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatClockTGD(ViSession instrSession,
                                                        ViInt32   standard,
                                                        ViInt32   SVID,
                                                        ViReal64  TGD);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatClocktOC(ViSession instrSession,
                                                        ViInt32   standard,
                                                        ViInt32   SVID,
                                                        ViInt32   tOC);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatClockaf0(ViSession instrSession,
                                                        ViInt32   standard,
                                                        ViInt32   SVID,
                                                        ViReal64  af0);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatClockaf1(ViSession instrSession,
                                                        ViInt32   standard,
                                                        ViInt32   SVID,
                                                        ViReal64  af1);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatClockaf2(ViSession instrSession,
                                                        ViInt32   standard,
                                                        ViInt32   SVID,
                                                        ViReal64  af2);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavRTAttitude(ViSession instrSession,
                                                   ViInt32   standard,
                                                   ViInt32   timeBasis,
                                                   ViInt32   year,
                                                   ViInt32   month,
                                                   ViInt32   day,
                                                   ViInt32   hour,
                                                   ViInt32   minutes,
                                                   ViReal64  seconds,
                                                   ViInt32   weekNumber,
                                                   ViReal64  timeOfWeek,
                                                   ViReal64* yaw,
                                                   ViReal64* pitch,
                                                   ViReal64* roll);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavRTDecimal(ViSession instrSession,
                                                  ViInt32   standard,
                                                  ViInt32   timeBasis,
                                                  ViInt32   year,
                                                  ViInt32   month,
                                                  ViInt32   day,
                                                  ViInt32   hour,
                                                  ViInt32   minutes,
                                                  ViReal64  seconds,
                                                  ViInt32   weekNumber,
                                                  ViReal64  timeOfWeek,
                                                  ViReal64* longitude,
                                                  ViReal64* latitude,
                                                  ViReal64* altitude);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavRTDMS(ViSession instrSession,
                                              ViInt32   standard,
                                              ViInt32   timeBasis,
                                              ViInt32   year,
                                              ViInt32   month,
                                              ViInt32   day,
                                              ViInt32   hour,
                                              ViInt32   minutes,
                                              ViReal64  seconds,
                                              ViInt32   weekNumber,
                                              ViReal64  timeOfWeek,
                                              ViInt32*  longitudeDeg,
                                              ViInt32*  longitudeMin,
                                              ViReal64* longitudeSec,
                                              ViChar    longitudeDir[],
                                              ViInt32*  latitudeDeg,
                                              ViInt32*  latitudeMin,
                                              ViReal64* latitudeSec,
                                              ViChar    latitudeDir[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavRTDisplayType(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViInt32   displayType);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavRTMapDeviation(ViSession instrSession,
                                                       ViInt32   standard,
                                                       ViInt32*  mapDeviation);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavRTAzimuth(ViSession instrSession,
                                                  ViInt32   standard,
                                                  ViInt32   SVID,
                                                  ViInt32   system,
                                                  ViInt32   timeBasis,
                                                  ViInt32   year,
                                                  ViInt32   month,
                                                  ViInt32   day,
                                                  ViInt32   hour,
                                                  ViInt32   minutes,
                                                  ViReal64  seconds,
                                                  ViInt32   weekNumber,
                                                  ViReal64  timeOfWeek,
                                                  ViReal64* azimuth);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavRTElevation(ViSession instrSession,
                                                    ViInt32   standard,
                                                    ViInt32   SVID,
                                                    ViInt32   system,
                                                    ViInt32   timeBasis,
                                                    ViInt32   year,
                                                    ViInt32   month,
                                                    ViInt32   day,
                                                    ViInt32   hour,
                                                    ViInt32   minutes,
                                                    ViReal64  seconds,
                                                    ViInt32   weekNumber,
                                                    ViReal64  timeOfWeek,
                                                    ViReal64* elevation);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavRTPower(ViSession instrSession,
                                                ViInt32   standard,
                                                ViInt32   SVID,
                                                ViInt32   system,
                                                ViInt32   tap,
                                                ViInt32   timeBasis,
                                                ViInt32   year,
                                                ViInt32   month,
                                                ViInt32   day,
                                                ViInt32   hour,
                                                ViInt32   minutes,
                                                ViReal64  seconds,
                                                ViInt32   weekNumber,
                                                ViReal64  timeOfWeek,
                                                ViReal64* absolutePower);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGMode(ViSession instrSession,
                                                    ViInt32   standard,
                                                    ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGSynchronizeAll(
                            ViSession instrSession,
                            ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGSynchronizeSVIDGPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   standard2);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGRefSynchronizeLocation(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   system);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGRefCoordinatesDecimal(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   system,
                            ViReal64  longitude,
                            ViReal64  latitude,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGRefCoordinatesDMS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   system,
                            ViInt32   longitudeDeg,
                            ViInt32   longitudeMin,
                            ViReal64  longitudeSec,
                            ViInt32   longitudeDir,
                            ViInt32   latitudeDeg,
                            ViInt32   latitudeMin,
                            ViReal64  latitudeSec,
                            ViInt32   latitudeDir,
                            ViReal64  altitude);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGRefUncertainlyRadius(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   system,
                            ViReal64  uncertainlyRadius);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGTOASynchronize(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   system);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGTOATimeBasis(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViInt32   system,
                                                            ViInt32   timeBasis);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavADGTOAWeekNumber(ViSession instrSession,
                                                         ViInt32   standard,
                                                         ViInt32   system,
                                                         ViInt32*  weekNumber);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGTOATimeOfWeek(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViInt32   system,
                                                             ViReal64  timeOfWeek);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGTOADuration(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   system,
                                                           ViReal64  duration);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGTOAResolutionGPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  resolution);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGTOAResolutionGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  resolution);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGTOADate(ViSession instrSession,
                                                       ViInt32   standard,
                                                       ViInt32   system,
                                                       ViInt32   year,
                                                       ViInt32   month,
                                                       ViInt32   day);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGTOATime(ViSession instrSession,
                                                       ViInt32   standard,
                                                       ViInt32   system,
                                                       ViInt32   hour,
                                                       ViInt32   minute,
                                                       ViReal64  seconds);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGSVIDEnabledGPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGSVIDEnabledGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGSVIDEnabledGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGSVIDEnabledBeiDou(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavADGSVIDAcquisitionBlockGPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  timeOffset,
                            ViChar    block[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavADGSVIDAcquisitionBlockBeiDou(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  timeOffset,
                            ViChar    block[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavADGSVIDSensitivityMessageGPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  timeOffset,
                            ViInt32   numberOfSymbols,
                            ViChar    block[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavADGSVIDSensitivityMessageGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  timeOffset,
                            ViInt32   numberOfSymbols,
                            ViChar    block[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavADGSVIDSensitivityMessageGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  timeOffset,
                            ViInt32   numberOfSymbols,
                            ViChar    block[]);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavADGSVIDSensitivityMessageBeiDou(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViReal64  timeOffset,
                            ViInt32   numberOfSymbols,
                            ViChar    block[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGGenerateAlmanacFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGGenerateNavigationFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGGenerateAcquisitionFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGGenerateIonosphericFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavADGGenerateUTCFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatGlobalSignalCoupling(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean coupling);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatGlobalSignalGPS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   signal);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatGlobalSignalGALILEO(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   signal);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatGlobalSignalGLONASS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   signal);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatGlobalSignalBeiDou(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViInt32   signal);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatGlobalPower(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   system,
                                                           ViInt32   SVID,
                                                           ViReal64  power);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSignalDynamicsConfig(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViInt32   config);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSignalDynamicsMaxAcceleration(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViReal64  maxAcceleration);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSignalDynamicsConstantAccelerationPeriod(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViReal64  accelerationPeriod);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSignalDynamicsConstantVelocityPeriod(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViReal64  velocityPeriod);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSignalDynamicsDopplerShift(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViReal64  dopplerShift);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSignalDynamicsDopplerShiftUnit(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViInt32   dopplerShiftUnit);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSignalDynamicsInitDopplerShift(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViReal64  initDopplerShift);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSignalDynamicsMaximumJerk(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViReal64  maximumJerk);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSignalDynamicsProfile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViInt32   profile);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSignalDynamicsDopplerPeriod(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViReal64* dopplerPeriod);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSignalDynamicsStartTimeOffset(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViReal64  startTimeOffset);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavModulationControlDataRate(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViInt32   dataRate);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavModulationControlMeanderingGLONASS(
                            ViSession instrSession,
                            ViInt32   satellite,
                            ViBoolean meandering);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavModulationControlTimeSequenceGLONASS(
                            ViSession instrSession,
                            ViInt32   satellite,
                            ViBoolean timeSequence);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavModulationControlSecondaryCode(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViInt32   SVID,
                            ViBoolean secondaryCode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavModulationControlSpreading(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   satellite,
                            ViInt32   SVID,
                            ViBoolean spreading);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatConstellationImportDedicatedFilesEnabled(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatConstellationImportNavigationFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatConstellationImportConstellationFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatConstellationImportExecute(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSatConstellationImportUseForAllSystems(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogMode(ViSession instrSession,
                                                    ViInt32   standard,
                                                    ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavLogDestination(ViSession instrSession,
                                                       ViInt32   standard,
                                                       ViChar    destination[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogDestinationFileDirectory(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  fileDirectory);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogDestinationFilePrefix(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViString  prefix);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogDestinationFileTimeStamp(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean timeStamp);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavLogSatelliteFormat(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32*  format);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogSatelliteEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavLogSatelliteFile(ViSession instrSession,
                                                         ViInt32   standard,
                                                         ViChar    file[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogSatelliteStep(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViInt32   step);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavLogUMotionFormat(ViSession instrSession,
                                                         ViInt32   standard,
                                                         ViInt32*  format);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogUMotionEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavLogUMotionFile(ViSession instrSession,
                                                       ViInt32   standard,
                                                       ViChar    file[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogUMotionStep(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   step);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogUMotionEnableAllSVID(
                            ViSession instrSession,
                            ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogUMotionDisableAllSVID(
                            ViSession instrSession,
                            ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogSatelliteEnableAllSVID(
                            ViSession instrSession,
                            ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogSatelliteDisableAllSVID(
                            ViSession instrSession,
                            ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogBeiDouEnabled(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViInt32   SVID,
                                                             ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogGALILEOEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogGLONASSEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   SVID,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogQZSSEnabled(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   SVID,
                                                           ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogSBASEnabled(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   SVID,
                                                           ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogGPSEnabled(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViInt32   SVID,
                                                          ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogOfflineAbort(ViSession instrSession,
                                                            ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogOfflineGenerate(
                            ViSession instrSession,
                            ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogOfflineSynchronize(
                            ViSession instrSession,
                            ViInt32   standard);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogOfflineTimeBasis(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   systemTime);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogOfflineDate(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   year,
                                                           ViInt32   month,
                                                           ViInt32   day);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogOfflineTime(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32   hour,
                                                           ViInt32   minute,
                                                           ViReal64  seconds);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogOfflineWeekNumber(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   weekNumber);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogOfflineTimeOfWeek(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  timeOfWeek);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogOfflineDuration(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViReal64  duration);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavLogOfflineProgress(ViSession instrSession,
                                                           ViInt32   standard,
                                                           ViInt32*  progress);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogRTEnabled(ViSession instrSession,
                                                         ViInt32   standard,
                                                         ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatAccelerationECEF(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatPositionECEF(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatVelocityECEF(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatAzimuth(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatCBLAS(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatCPhase(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatDShift(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatElevation(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatIDelay(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatPRange(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatPRangeBIAS(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatPRangeBIASRate(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatPRangeRate(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatRange(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatRangeRate(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatRRate(ViSession instrSession,
                                                             ViInt32   standard,
                                                             ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatSLevel(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamSatTDelay(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionAccelerationECEF(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionJerkECEF(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionPositionECEF(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionVelocityECEF(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionVelocityLNED(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionAttitude(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionAttitudeAcceleration(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionAttitudeJerk(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionAttitudeRate(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionGDOP(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionGSpeed(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionHDOP(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionPDOP(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionPositionENU(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionPositionLLA(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionTDOP(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavLogParamUMotionVDOP(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASNavigationDataMode(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   mode);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionAlmanacEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionAlmanacFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSBASRegionAlmanacSpan(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViChar    file[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionAlmanacPeriod(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   period);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionRinexEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionRinexFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSBASRegionRinexSpan(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViInt32   region,
                                                            ViChar    file[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionRinexPeriod(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   period);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSBASRegionUTCOffset(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViInt32   region,
                                                            ViChar    state[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionUTCOffsetPeriod(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   period);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionIGridEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionIGridFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSBASRegionIGridSpan(ViSession instrSession,
                                                            ViInt32   standard,
                                                            ViInt32   region,
                                                            ViChar    file[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionIGridPeriod(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   period);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionPRNMaskEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionPRNMaskFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSBASRegionPRNMaskSpan(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViChar    file[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionPRNMaskPeriod(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   period);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionFCorrectionEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionFCorrectionFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSBASRegionFCorrectionSpan(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViChar    file[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionFCorrectionPeriod(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   period);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionLTCorrectionEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionLTCorrectionFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSBASRegionLTCorrectionSpan(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViChar    file[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionLTCorrectionPeriod(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   period);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionCECovarianceEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionCECovarianceFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSBASRegionCECovarianceSpan(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViChar    file[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionCECovariancePeriod(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   period);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionFCDegradationEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionFCDegradationFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSBASRegionFCDegradationSpan(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViChar    file[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionFCDegradationPeriod(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   period);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionDFactorEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionDFactorFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSBASRegionDFactorSpan(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViChar    file[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionDFactorPeriod(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   period);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionServiceEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionServiceFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSBASRegionServiceSpan(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViChar    file[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionServicePeriod(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   period);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionIODEEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionPRNEnabled(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   PRN,
                            ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSBASRegionPRNDuration(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   PRN,
                            ViInt32*  duration);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionPRNFile(
                            ViSession instrSession,
                            ViInt32   standard,
                            ViInt32   region,
                            ViInt32   PRN,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSBASRegionPRNSpan(ViSession instrSession,
                                                          ViInt32   standard,
                                                          ViInt32   region,
                                                          ViInt32   PRN,
                                                          ViChar    span[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionImportAddDirectory(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   region,
                            ViString  directory);

ViStatus _VI_FUNC rsrfsiggen_ConfigureSatNavSBASRegionImportAddFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   region,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QuerySatNavSBASRegionImportFileCatalog(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   region,
                            ViInt32   arraySize,
                            ViChar    catalog[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsrfsiggen_LoadSatNavSBASRegionImportFiles(ViSession instrSession,
                                                             ViInt32   path,
                                                             ViInt32   region);

ViStatus _VI_FUNC rsrfsiggen_RemoveSatNavSBASRegionImportAllFiles(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   region);

ViStatus _VI_FUNC rsrfsiggen_RemoveSatNavSBASRegionImportFile(
                            ViSession instrSession,
                            ViInt32   path,
                            ViInt32   region,
                            ViInt32   position);

ViStatus _VI_FUNC rsrfsiggen_BERTestGenState(ViSession instrSession,
                                             ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_BERTestGenConfig(ViSession instrSession,
                                              ViInt32   measurementMode,
                                              ViInt32   clockFrequency,
                                              ViReal64  errorRate,
                                              ViInt32   trigger,
                                              ViInt64   dataEnableOnTime,
                                              ViInt64   dataEnableOffTime,
                                              ViInt64   restartDelay);

ViStatus _VI_FUNC rsrfsiggen_GetBLERResult(ViSession instrSession,
                                           ViInt32*  dataBits,
                                           ViInt32*  errors,
                                           ViReal64* bitErrorRate,
                                           ViInt32*  measurementStatus,
                                           ViInt32*  clockLineStatus,
                                           ViInt32*  dataLineStatus,
                                           ViInt32*  synchronizationStatus);

ViStatus _VI_FUNC rsrfsiggen_GetBERResult(ViSession instrSession,
                                          ViInt32*  dataBits,
                                          ViInt32*  errors,
                                          ViReal64* bitErrorRate,
                                          ViInt32*  measurementStatus,
                                          ViInt32*  clockLineStatus,
                                          ViInt32*  dataLineStatus,
                                          ViInt32*  synchronizationStatus);

ViStatus _VI_FUNC rsrfsiggen_QueryCoderRemoteConnection(ViSession  instrSession,
                                                        ViInt32    path,
                                                        ViBoolean* remoteConnectionState);

ViStatus _VI_FUNC rsrfsiggen_QueryBBMMRemoteConnection(ViSession  instrSession,
                                                       ViInt32    path,
                                                       ViBoolean* IQConnectionState);

ViStatus _VI_FUNC rsrfsiggen_ConfigureBBMMSelectedConnectorTriggerConnection(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  instrumentName,
                            ViString  RFPath);

ViStatus _VI_FUNC rsrfsiggen_ConfigureExternalCoderSelectedConnectorTriggerConnection(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  instrumentName,
                            ViString  RFPath);

ViStatus _VI_FUNC rsrfsiggen_ConfigureExternalFaderSelectedConnectorTriggerConnection(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  instrumentName,
                            ViString  RFPath);

ViStatus _VI_FUNC rsrfsiggen_ConfigureExternalIQSelectedConnectorTriggerConnection(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  instrumentName,
                            ViString  RFPath);

ViStatus _VI_FUNC rsrfsiggen_ConfigureExternalRFSelectedConnectorTriggerConnection(
                            ViSession instrSession,
                            ViInt32   path,
                            ViString  instrumentName,
                            ViString  RFPath);

ViStatus _VI_FUNC rsrfsiggen_ConfigureCoderConnection(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32   remoteConnection);

ViStatus _VI_FUNC rsrfsiggen_CheckConnectionsSettings(ViSession instrSession,
                                                      ViInt32   path,
                                                      ViInt32*  RFConnStatus,
                                                      ViInt32*  iOUTConnStatus,
                                                      ViInt32*  iBAROUTConnStatus,
                                                      ViInt32*  qOUTConnStatus,
                                                      ViInt32*  qBAROUTConnStatus,
                                                      ViInt32*  triggerConnStatus);

ViStatus _VI_FUNC rsrfsiggen_SystemConfigurationExternalAdd(ViSession instrSession,
                                                            ViString  instrumentName,
                                                            ViString  hardwareChannel,
                                                            ViString  address,
                                                            ViString  RFPath);

ViStatus _VI_FUNC rsrfsiggen_SystemConfigurationExternalRename(
                            ViSession instrSession,
                            ViString  currentName,
                            ViString  newName);

ViStatus _VI_FUNC rsrfsiggen_LoadRFPortsAlignmentPredefinedFile(
                            ViSession instrSession,
                            ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_LoadRFPortsAlignmentSetupFile(ViSession instrSession,
                                                           ViString  fileName);

ViStatus _VI_FUNC rsrfsiggen_QueryRFPortsAlignmentCalibrationFrequencyList(
                            ViSession instrSession,
                            ViInt32   arraySize,
                            ViReal64  frequencyList[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsrfsiggen_QueryRFPortsAlignmentCalibrationPEPList(
                            ViSession instrSession,
                            ViInt32   arraySize,
                            ViReal64  PEPList[],
                            ViInt32*  returnedValues);

ViStatus _VI_FUNC rsrfsiggen_ConfigureHUMSTagValue(ViSession instrSession,
                                                   ViInt32   ID,
                                                   ViString  key,
                                                   ViString  tagValue);

ViStatus _VI_FUNC rsrfsiggen_QueryHUMSTagValue(ViSession instrSession,
                                               ViInt32   ID,
                                               ViInt32   arraySize,
                                               ViChar    tagsValues[]);

ViStatus _VI_FUNC rsrfsiggen_AddHUMSSNMPUser(ViSession instrSession,
                                             ViString  name,
                                             ViInt32   access,
                                             ViInt32   level,
                                             ViString  authenticationPassword,
                                             ViString  privacyPassword);

ViStatus _VI_FUNC rsrfsiggen_QueryHUMSSNMPUsers(ViSession instrSession,
                                                ViInt32   bufferSize,
                                                ViInt32*  count,
                                                ViChar    users[],
                                                ViInt32*  returnedValues);

ViStatus _VI_FUNC rsrfsiggen_ConfigureScreenColor(ViSession instrSession,
                                                  ViInt32   redChannel,
                                                  ViInt32   greenChannel,
                                                  ViInt32   blueChannel,
                                                  ViInt32   alphaChannel);

ViStatus _VI_FUNC rsrfsiggen_SendSoftwareTrigger(ViSession instrSession);

ViStatus _VI_FUNC rsrfsiggen_readToFile(ViSession instrSession,
                                        ViString  source,
                                        ViString  destination);

ViStatus _VI_FUNC rsrfsiggen_writeFromFile(ViSession instrSession,
                                           ViString  source,
                                           ViString  destination);

ViStatus _VI_FUNC rsrfsiggen_reset(ViSession instrSession);

ViStatus _VI_FUNC rsrfsiggen_Preset(ViSession instrSession);

ViStatus _VI_FUNC rsrfsiggen_self_test(ViSession instrSession,
                                       ViInt16*  selfTestResult,
                                       ViChar    selfTestMessage[]);

ViStatus _VI_FUNC rsrfsiggen_revision_query(ViSession instrSession,
                                            ViChar    instrumentDriverRevision[],
                                            ViChar    firmwareRevision[]);

ViStatus _VI_FUNC rsrfsiggen_error_query(ViSession instrSession,
                                         ViInt32*  errorCode,
                                         ViChar    errorMessage[]);

ViStatus _VI_FUNC rsrfsiggen_SystemStaticError(ViSession instrSession,
                                               ViInt32   bufferSize,
                                               ViChar    buffer[]);

ViStatus _VI_FUNC rsrfsiggen_error_message(ViSession instrSession,
                                           ViStatus  errorCode,
                                           ViChar    errorMessage[]);

ViStatus _VI_FUNC rsrfsiggen_ConfigureErrorChecking(ViSession instrSession,
                                                    ViBoolean optionChecking,
                                                    ViBoolean rangeChecking,
                                                    ViBoolean statusChecking);

ViStatus _VI_FUNC rsrfsiggen_ClearStatus(ViSession instrSession);

ViStatus _VI_FUNC rsrfsiggen_IDQueryResponse(ViSession instrSession,
                                             ViChar    IDQueryResponse[]);

ViStatus _VI_FUNC rsrfsiggen_ProcessAllPreviousCommands(ViSession instrSession);

ViStatus _VI_FUNC rsrfsiggen_QueryOPC(ViSession instrSession,
                                      ViInt32*  OPC);

ViStatus _VI_FUNC rsrfsiggen_SetTimeout(ViSession instrSession,
                                        ViUInt32  OPCTimeout);

ViStatus _VI_FUNC rsrfsiggen_GetTimeout(ViSession instrSession,
                                        ViUInt32* timeout);

ViStatus _VI_FUNC rsrfsiggen_SetVISATimeout(ViSession instrSession,
                                            ViUInt32  VISATimeout);

ViStatus _VI_FUNC rsrfsiggen_GetVISATimeout(ViSession instrSession,
                                            ViUInt32* VISATimeout);

ViStatus _VI_FUNC rsrfsiggen_Calibrate(ViSession instrSession,
                                       ViInt32   reserved,
                                       ViInt32   timeout,
                                       ViInt32*  result);

ViStatus _VI_FUNC rsrfsiggen_LastFactoryCalibration(ViSession instrSession,
                                                    ViInt32   bufferSize,
                                                    ViChar    calibrationDate[]);

ViStatus _VI_FUNC rsrfsiggen_SecurityVolatileMode(ViSession instrSession,
                                                  ViString  password,
                                                  ViBoolean memoryProtectionState);

ViStatus _VI_FUNC rsrfsiggen_SecurityUpdatePolicy(ViSession instrSession,
                                                  ViString  password,
                                                  ViInt32   updatePolicy);

ViStatus _VI_FUNC rsrfsiggen_SecuritySanitize(ViSession instrSession,
                                              ViString  password,
                                              ViBoolean memoryProtection);

ViStatus _VI_FUNC rsrfsiggen_ConfigureNetworkInterface(ViSession instrSession,
                                                       ViString  password,
                                                       ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_ConfigureNetworkServices(ViSession instrSession,
                                                      ViInt32   service,
                                                      ViString  password,
                                                      ViBoolean enabled);

ViStatus _VI_FUNC rsrfsiggen_DisplayLock(ViSession instrSession,
                                         ViInt32   operation,
                                         ViBoolean lockState);

ViStatus _VI_FUNC rsrfsiggen_LockUserInterface(ViSession instrSession,
                                               ViInt32   userInterface);

ViStatus _VI_FUNC rsrfsiggen_ConfigureAutoSystemErrQuery(ViSession instrSession,
                                                         ViBoolean autoSystErrQuery);

ViStatus _VI_FUNC rsrfsiggen_ConfigureMultiThreadLocking(ViSession instrSession,
                                                         ViBoolean multiThreadLocking);

ViStatus _VI_FUNC rsrfsiggen_ConfigureAttributeDataTypeMismatchReporting(
                            ViSession instrSession,
                            ViBoolean state);

ViStatus _VI_FUNC rsrfsiggen_OPCSyncWriteEnable(ViSession instrSession,
                                                ViBoolean enable);

ViStatus _VI_FUNC rsrfsiggen_OPCSyncQueryEnable(ViSession instrSession,
                                                ViBoolean enable);

ViStatus _VI_FUNC rsrfsiggen_SetOpcSyncQueryMechanism(ViSession instrSession,
                                                      ViBoolean useESB,
                                                      ViBoolean CLSBefore,
                                                      ViBoolean useMAV);

ViStatus _VI_FUNC rsrfsiggen_SetStatusRegister(ViSession instrSession,
                                               ViInt32   registerOperation,
                                               ViInt32   questionableRegister,
                                               ViInt32   enable,
                                               ViInt32   PTransition,
                                               ViInt32   NTransition);

ViStatus _VI_FUNC rsrfsiggen_GetStatusRegister(ViSession instrSession,
                                               ViInt32   registerOperation,
                                               ViInt32   questionableRegister,
                                               ViInt32   registerPart,
                                               ViInt32*  registerValue);

ViStatus _VI_FUNC rsrfsiggen_GetError(ViSession instrSession,
                                      ViStatus* code,
                                      ViInt32   bufferSize,
                                      ViChar    description[]);

ViStatus _VI_FUNC rsrfsiggen_ClearError(ViSession instrSession);

ViStatus _VI_FUNC rsrfsiggen_WriteInstrData(ViSession instrSession,
                                            ViString  writeBuffer);

ViStatus _VI_FUNC rsrfsiggen_QueryViBoolean(ViSession  instrSession,
                                            ViString   command,
                                            ViBoolean* value);

ViStatus _VI_FUNC rsrfsiggen_QueryViInt32(ViSession instrSession,
                                          ViString  command,
                                          ViInt32*  value);

ViStatus _VI_FUNC rsrfsiggen_QueryViReal64(ViSession instrSession,
                                           ViString  command,
                                           ViReal64* value);

ViStatus _VI_FUNC rsrfsiggen_QueryViString(ViSession instrSession,
                                           ViString  command,
                                           ViInt32   bufferSize,
                                           ViChar    value[]);

ViStatus _VI_FUNC rsrfsiggen_SetAttributeViInt32(ViSession instrSession,
                                                 ViString  repeatedCapabilityName,
                                                 ViAttr    attributeId,
                                                 ViInt32   attributeValue);

ViStatus _VI_FUNC rsrfsiggen_SetAttributeViInt64(ViSession instrSession,
                                                 ViString  repeatedCapabilityName,
                                                 ViAttr    attributeId,
                                                 ViInt64   attributeValue);

ViStatus _VI_FUNC rsrfsiggen_SetAttributeViReal64(ViSession instrSession,
                                                  ViString  repeatedCapabilityName,
                                                  ViAttr    attributeId,
                                                  ViReal64  attributeValue);

ViStatus _VI_FUNC rsrfsiggen_SetAttributeViString(ViSession instrSession,
                                                  ViString  repeatedCapabilityName,
                                                  ViAttr    attributeId,
                                                  ViString  attributeValue);

ViStatus _VI_FUNC rsrfsiggen_SetAttributeViBoolean(ViSession instrSession,
                                                   ViString  repeatedCapabilityName,
                                                   ViAttr    attributeId,
                                                   ViBoolean attributeValue);

ViStatus _VI_FUNC rsrfsiggen_GetAttributeViInt32(ViSession instrSession,
                                                 ViString  repeatedCapabilityName,
                                                 ViAttr    attributeId,
                                                 ViInt32*  attributeValue);

ViStatus _VI_FUNC rsrfsiggen_GetAttributeViInt64(ViSession instrSession,
                                                 ViString  repeatedCapabilityName,
                                                 ViAttr    attributeId,
                                                 ViInt64*  attributeValue);

ViStatus _VI_FUNC rsrfsiggen_GetAttributeViReal64(ViSession instrSession,
                                                  ViString  repeatedCapabilityName,
                                                  ViAttr    attributeId,
                                                  ViReal64* attributeValue);

ViStatus _VI_FUNC rsrfsiggen_GetAttributeViString(ViSession instrSession,
                                                  ViString  repeatedCapabilityName,
                                                  ViAttr    attributeId,
                                                  ViInt32   bufferSize,
                                                  ViChar    attributeValue[]);

ViStatus _VI_FUNC rsrfsiggen_GetAttributeViBoolean(ViSession  instrSession,
                                                   ViString   repeatedCapabilityName,
                                                   ViAttr     attributeId,
                                                   ViBoolean* attributeValue);

ViStatus _VI_FUNC rsrfsiggen_GetAttributeRepCapName(ViSession instrSession,
                                                    ViAttr    attributeId,
                                                    ViString  repCapNameID,
                                                    ViInt32   index,
                                                    ViInt32   arraySize,
                                                    ViChar    repCapName[]);

ViStatus _VI_FUNC rsrfsiggen_GetAttributeRepeatedCapabilityIds(
                            ViSession instrSession,
                            ViAttr    attributeId,
                            ViInt32   arraySize,
                            ViChar    repeatedCapabilityId_s[]);

ViStatus _VI_FUNC rsrfsiggen_GetAttributeRepeatedCapabilityIdNames(
                            ViSession instrSession,
                            ViAttr    attributeId,
                            ViString  repeatedCapabilityId,
                            ViInt32   bufferSize,
                            ViChar    repeatedCapabilityIdName_s[]);

ViStatus _VI_FUNC rsrfsiggen_close(ViSession instrSession);

/****************************************************************************
 *------------------------ Error And Completion Codes ----------------------*
 ****************************************************************************/

#define RSRFSIGGEN_WARN_MEASURE_UNCALIBRATED    (RS_CLASS_WARN_BASE + 0x0001L)
#define RSRFSIGGEN_WARN_OVER_RANGE              (RS_CLASS_WARN_BASE + 0x0002L)

#define RSRFSIGGEN_ERROR_INCORRECT_STATE        (RS_CLASS_ERROR_BASE + 0x0003L)
#define RSRFSIGGEN_ERROR_INCORRECT_RESPONSE     (RS_CLASS_ERROR_BASE + 0x0002L)
#define RSRFSIGGEN_ERROR_MAX_TIME_EXCEEDED      (RS_CLASS_ERROR_BASE + 0x0001L)

#define RSRFSIGGEN_WARNMSG_MEASURE_UNCALIBRATED "Uncalibrated measurement"
#define RSRFSIGGEN_WARNMSG_OVER_RANGE           "Measurement overrange"

#define RSRFSIGGEN_ERRMSG_INCORRECT_STATE     "Instrument in incorrect state"
#define RSRFSIGGEN_ERRMSG_INCORRECT_RESPONSE      "Response incorrect; report problem to R&S support!"
#define RSRFSIGGEN_ERRMSG_MAX_TIME_EXCEEDED     "Max Time Exceeded"

#define RSRFSIGGEN_ERROR_CODES_AND_MSGS \
    {RSRFSIGGEN_WARN_MEASURE_UNCALIBRATED,  RSRFSIGGEN_WARNMSG_MEASURE_UNCALIBRATED},\
    {RSRFSIGGEN_WARN_OVER_RANGE,            RSRFSIGGEN_WARNMSG_OVER_RANGE},\
    {RSRFSIGGEN_ERROR_INCORRECT_STATE ,   RSRFSIGGEN_ERRMSG_INCORRECT_STATE },\
    {RSRFSIGGEN_ERROR_INCORRECT_RESPONSE,     RSRFSIGGEN_ERRMSG_INCORRECT_RESPONSE},\
    {RSRFSIGGEN_ERROR_MAX_TIME_EXCEEDED,    RSRFSIGGEN_ERRMSG_MAX_TIME_EXCEEDED}

/****************************************************************************
 *---------------------------- End Include File ----------------------------*
 ****************************************************************************/

#if defined(__cplusplus) || defined(__cplusplus__)
}
#endif
#endif /* __RSRFSIGGEN_HEADER */
